Method: Google::Apis::BigqueryV2::JobConfigurationLoad#encoding

Defined in:
generated/google/apis/bigquery_v2/classes.rb

#encodingString

[Optional] The character encoding of the data. The supported values are UTF-8 or ISO-8859-1. The default value is UTF-8. BigQuery decodes the data after the raw, binary data has been split using the values of the quote and fieldDelimiter properties. Corresponds to the JSON property encoding

Returns:

  • (String)


1216
1217
1218
# File 'generated/google/apis/bigquery_v2/classes.rb', line 1216

def encoding
  @encoding
end