Class: Google::Apis::AnalyticsreportingV4::PivotHeaderEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/analyticsreporting_v4/classes.rb,
generated/google/apis/analyticsreporting_v4/representations.rb,
generated/google/apis/analyticsreporting_v4/representations.rb

Overview

The headers for the each of the metric column corresponding to the metrics requested in the pivots section of the response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ PivotHeaderEntry



928
929
930
# File 'generated/google/apis/analyticsreporting_v4/classes.rb', line 928

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimension_namesArray<String>

The name of the dimensions in the pivot response. Corresponds to the JSON property dimensionNames



916
917
918
# File 'generated/google/apis/analyticsreporting_v4/classes.rb', line 916

def dimension_names
  @dimension_names
end

#dimension_valuesArray<String>

The values for the dimensions in the pivot. Corresponds to the JSON property dimensionValues



921
922
923
# File 'generated/google/apis/analyticsreporting_v4/classes.rb', line 921

def dimension_values
  @dimension_values
end

#metricGoogle::Apis::AnalyticsreportingV4::MetricHeaderEntry

Header for the metrics. Corresponds to the JSON property metric



926
927
928
# File 'generated/google/apis/analyticsreporting_v4/classes.rb', line 926

def metric
  @metric
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



933
934
935
936
937
# File 'generated/google/apis/analyticsreporting_v4/classes.rb', line 933

def update!(**args)
  @dimension_names = args[:dimension_names] if args.key?(:dimension_names)
  @dimension_values = args[:dimension_values] if args.key?(:dimension_values)
  @metric = args[:metric] if args.key?(:metric)
end