Class: Google::Apis::AnalyticsreportingV4::ReportData
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticsreportingV4::ReportData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/analyticsreporting_v4/classes.rb,
generated/google/apis/analyticsreporting_v4/representations.rb,
generated/google/apis/analyticsreporting_v4/representations.rb
Overview
The data part of the report.
Instance Attribute Summary collapse
-
#data_last_refreshed ⇒ String
The last time the data in the report was refreshed.
-
#is_data_golden ⇒ Boolean
(also: #is_data_golden?)
Indicates if response to this request is golden or not.
-
#maximums ⇒ Array<Google::Apis::AnalyticsreportingV4::DateRangeValues>
Minimum and maximum values seen over all matching rows.
-
#minimums ⇒ Array<Google::Apis::AnalyticsreportingV4::DateRangeValues>
Minimum and maximum values seen over all matching rows.
-
#row_count ⇒ Fixnum
Total number of matching rows for this query.
-
#rows ⇒ Array<Google::Apis::AnalyticsreportingV4::ReportRow>
There's one ReportRow for every unique combination of dimensions.
-
#samples_read_counts ⇒ Array<String>
If the results are sampled, this returns the total number of samples read, one entry per date range.
-
#sampling_space_sizes ⇒ Array<String>
If the results are sampled, this returns the total number of samples present, one entry per date range.
-
#totals ⇒ Array<Google::Apis::AnalyticsreportingV4::DateRangeValues>
For each requested date range, for the set of all rows that match the query, every requested value format gets a total.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportData
constructor
A new instance of ReportData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ ReportData
Returns a new instance of ReportData.
693 694 695 |
# File 'generated/google/apis/analyticsreporting_v4/classes.rb', line 693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_last_refreshed ⇒ String
The last time the data in the report was refreshed. All the hits received
before this timestamp are included in the calculation of the report.
Corresponds to the JSON property dataLastRefreshed
671 672 673 |
# File 'generated/google/apis/analyticsreporting_v4/classes.rb', line 671 def data_last_refreshed @data_last_refreshed end |
#is_data_golden ⇒ Boolean Also known as: is_data_golden?
Indicates if response to this request is golden or not. Data is
golden when the exact same request will not produce any new results if
asked at a later point in time.
Corresponds to the JSON property isDataGolden
690 691 692 |
# File 'generated/google/apis/analyticsreporting_v4/classes.rb', line 690 def is_data_golden @is_data_golden end |
#maximums ⇒ Array<Google::Apis::AnalyticsreportingV4::DateRangeValues>
Minimum and maximum values seen over all matching rows. These are both
empty when hideValueRanges in the request is false, or when
rowCount is zero.
Corresponds to the JSON property maximums
643 644 645 |
# File 'generated/google/apis/analyticsreporting_v4/classes.rb', line 643 def maximums @maximums end |
#minimums ⇒ Array<Google::Apis::AnalyticsreportingV4::DateRangeValues>
Minimum and maximum values seen over all matching rows. These are both
empty when hideValueRanges in the request is false, or when
rowCount is zero.
Corresponds to the JSON property minimums
660 661 662 |
# File 'generated/google/apis/analyticsreporting_v4/classes.rb', line 660 def minimums @minimums end |
#row_count ⇒ Fixnum
Total number of matching rows for this query.
Corresponds to the JSON property rowCount
625 626 627 |
# File 'generated/google/apis/analyticsreporting_v4/classes.rb', line 625 def row_count @row_count end |
#rows ⇒ Array<Google::Apis::AnalyticsreportingV4::ReportRow>
There's one ReportRow for every unique combination of dimensions.
Corresponds to the JSON property rows
665 666 667 |
# File 'generated/google/apis/analyticsreporting_v4/classes.rb', line 665 def rows @rows end |
#samples_read_counts ⇒ Array<String>
If the results are
sampled,
this returns the total number of samples read, one entry per date range.
If the results are not sampled this field will not be defined. See
developer guide
for details.
Corresponds to the JSON property samplesReadCounts
653 654 655 |
# File 'generated/google/apis/analyticsreporting_v4/classes.rb', line 653 def samples_read_counts @samples_read_counts end |
#sampling_space_sizes ⇒ Array<String>
If the results are
sampled,
this returns the total number of
samples present, one entry per date range. If the results are not sampled
this field will not be defined. See
developer guide
for details.
Corresponds to the JSON property samplingSpaceSizes
636 637 638 |
# File 'generated/google/apis/analyticsreporting_v4/classes.rb', line 636 def sampling_space_sizes @sampling_space_sizes end |
#totals ⇒ Array<Google::Apis::AnalyticsreportingV4::DateRangeValues>
For each requested date range, for the set of all rows that match
the query, every requested value format gets a total. The total
for a value format is computed by first totaling the metrics
mentioned in the value format and then evaluating the value
format as a scalar expression. E.g., The "totals" for
3 / (ga:sessions + 2) we compute
3 / ((sum of all relevant ga:sessions) + 2).
Totals are computed before pagination.
Corresponds to the JSON property totals
683 684 685 |
# File 'generated/google/apis/analyticsreporting_v4/classes.rb', line 683 def totals @totals end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
698 699 700 701 702 703 704 705 706 707 708 |
# File 'generated/google/apis/analyticsreporting_v4/classes.rb', line 698 def update!(**args) @row_count = args[:row_count] if args.key?(:row_count) @sampling_space_sizes = args[:sampling_space_sizes] if args.key?(:sampling_space_sizes) @maximums = args[:maximums] if args.key?(:maximums) @samples_read_counts = args[:samples_read_counts] if args.key?(:samples_read_counts) @minimums = args[:minimums] if args.key?(:minimums) @rows = args[:rows] if args.key?(:rows) @data_last_refreshed = args[:data_last_refreshed] if args.key?(:data_last_refreshed) @totals = args[:totals] if args.key?(:totals) @is_data_golden = args[:is_data_golden] if args.key?(:is_data_golden) end |