Class: Google::Apis::ComputeBeta::AuditConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

Provides the configuration for non-admin_activity logging for a service. Controls exemptions and specific log sub-types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ AuditConfig

Returns a new instance of AuditConfig.



559
560
561
# File 'generated/google/apis/compute_beta/classes.rb', line 559

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audit_log_configsArray<Google::Apis::ComputeBeta::AuditLogConfig>

The configuration for each type of logging Corresponds to the JSON property auditLogConfigs



544
545
546
# File 'generated/google/apis/compute_beta/classes.rb', line 544

def audit_log_configs
  @audit_log_configs
end

#exempted_membersArray<String>

Specifies the identities that are exempted from "data access" audit logging for the service specified above. Follows the same format of Binding.members. Corresponds to the JSON property exemptedMembers

Returns:

  • (Array<String>)


550
551
552
# File 'generated/google/apis/compute_beta/classes.rb', line 550

def exempted_members
  @exempted_members
end

#serviceString

Specifies a service that will be enabled for audit logging. For example, resourcemanager, storage, compute. allServices is a special value that covers all services. Corresponds to the JSON property service

Returns:

  • (String)


557
558
559
# File 'generated/google/apis/compute_beta/classes.rb', line 557

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



564
565
566
567
568
# File 'generated/google/apis/compute_beta/classes.rb', line 564

def update!(**args)
  @audit_log_configs = args[:audit_log_configs] if args.key?(:audit_log_configs)
  @exempted_members = args[:exempted_members] if args.key?(:exempted_members)
  @service = args[:service] if args.key?(:service)
end