Class: Google::Apis::ComputeBeta::AuditLogConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::AuditLogConfig
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Provides the configuration for a sub-type of logging.
Instance Attribute Summary collapse
-
#exempted_members ⇒ Array<String>
Specifies the identities that are exempted from this type of logging Follows the same format of Binding.members.
-
#log_type ⇒ String
The log type that this config enables.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuditLogConfig
constructor
A new instance of AuditLogConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ AuditLogConfig
Returns a new instance of AuditLogConfig.
586 587 588 |
# File 'generated/google/apis/compute_beta/classes.rb', line 586 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exempted_members ⇒ Array<String>
Specifies the identities that are exempted from this type of logging Follows
the same format of Binding.members.
Corresponds to the JSON property exemptedMembers
579 580 581 |
# File 'generated/google/apis/compute_beta/classes.rb', line 579 def exempted_members @exempted_members end |
#log_type ⇒ String
The log type that this config enables.
Corresponds to the JSON property logType
584 585 586 |
# File 'generated/google/apis/compute_beta/classes.rb', line 584 def log_type @log_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
591 592 593 594 |
# File 'generated/google/apis/compute_beta/classes.rb', line 591 def update!(**args) @exempted_members = args[:exempted_members] if args.key?(:exempted_members) @log_type = args[:log_type] if args.key?(:log_type) end |