Class: Google::Apis::ComputeBeta::AutoscalingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::AutoscalingPolicy
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Cloud Autoscaler policy.
Instance Attribute Summary collapse
-
#cool_down_period_sec ⇒ Fixnum
The number of seconds that the autoscaler should wait before it starts collecting information from a new instance.
-
#cpu_utilization ⇒ Google::Apis::ComputeBeta::AutoscalingPolicyCpuUtilization
CPU utilization policy.
-
#custom_metric_utilizations ⇒ Array<Google::Apis::ComputeBeta::AutoscalingPolicyCustomMetricUtilization>
Configuration parameters of autoscaling based on a custom metric.
-
#load_balancing_utilization ⇒ Google::Apis::ComputeBeta::AutoscalingPolicyLoadBalancingUtilization
Configuration parameters of autoscaling based on load balancing.
-
#max_num_replicas ⇒ Fixnum
The maximum number of instances that the autoscaler can scale up to.
-
#min_num_replicas ⇒ Fixnum
The minimum number of replicas that the autoscaler can scale down to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalingPolicy
constructor
A new instance of AutoscalingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ AutoscalingPolicy
Returns a new instance of AutoscalingPolicy.
955 956 957 |
# File 'generated/google/apis/compute_beta/classes.rb', line 955 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cool_down_period_sec ⇒ Fixnum
The number of seconds that the autoscaler should wait before it starts
collecting information from a new instance. This prevents the autoscaler from
collecting information when the instance is initializing, during which the
collected usage would not be reliable. The default time autoscaler waits is 60
seconds.
Virtual machine initialization times might vary because of numerous factors.
We recommend that you test how long an instance may take to initialize. To do
this, create an instance and time the startup process.
Corresponds to the JSON property coolDownPeriodSec
924 925 926 |
# File 'generated/google/apis/compute_beta/classes.rb', line 924 def cool_down_period_sec @cool_down_period_sec end |
#cpu_utilization ⇒ Google::Apis::ComputeBeta::AutoscalingPolicyCpuUtilization
CPU utilization policy.
Corresponds to the JSON property cpuUtilization
929 930 931 |
# File 'generated/google/apis/compute_beta/classes.rb', line 929 def cpu_utilization @cpu_utilization end |
#custom_metric_utilizations ⇒ Array<Google::Apis::ComputeBeta::AutoscalingPolicyCustomMetricUtilization>
Configuration parameters of autoscaling based on a custom metric.
Corresponds to the JSON property customMetricUtilizations
934 935 936 |
# File 'generated/google/apis/compute_beta/classes.rb', line 934 def custom_metric_utilizations @custom_metric_utilizations end |
#load_balancing_utilization ⇒ Google::Apis::ComputeBeta::AutoscalingPolicyLoadBalancingUtilization
Configuration parameters of autoscaling based on load balancing.
Corresponds to the JSON property loadBalancingUtilization
939 940 941 |
# File 'generated/google/apis/compute_beta/classes.rb', line 939 def load_balancing_utilization @load_balancing_utilization end |
#max_num_replicas ⇒ Fixnum
The maximum number of instances that the autoscaler can scale up to. This is
required when creating or updating an autoscaler. The maximum number of
replicas should not be lower than minimal number of replicas.
Corresponds to the JSON property maxNumReplicas
946 947 948 |
# File 'generated/google/apis/compute_beta/classes.rb', line 946 def max_num_replicas @max_num_replicas end |
#min_num_replicas ⇒ Fixnum
The minimum number of replicas that the autoscaler can scale down to. This
cannot be less than 0. If not provided, autoscaler will choose a default value
depending on maximum number of instances allowed.
Corresponds to the JSON property minNumReplicas
953 954 955 |
# File 'generated/google/apis/compute_beta/classes.rb', line 953 def min_num_replicas @min_num_replicas end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
960 961 962 963 964 965 966 967 |
# File 'generated/google/apis/compute_beta/classes.rb', line 960 def update!(**args) @cool_down_period_sec = args[:cool_down_period_sec] if args.key?(:cool_down_period_sec) @cpu_utilization = args[:cpu_utilization] if args.key?(:cpu_utilization) @custom_metric_utilizations = args[:custom_metric_utilizations] if args.key?(:custom_metric_utilizations) @load_balancing_utilization = args[:load_balancing_utilization] if args.key?(:load_balancing_utilization) @max_num_replicas = args[:max_num_replicas] if args.key?(:max_num_replicas) @min_num_replicas = args[:min_num_replicas] if args.key?(:min_num_replicas) end |