Class: Google::Apis::ComputeBeta::BackendService

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

A BackendService resource. This resource defines a group of backend virtual machines and their serving capacity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ BackendService

Returns a new instance of BackendService.



1418
1419
1420
# File 'generated/google/apis/compute_beta/classes.rb', line 1418

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Lifetime of cookies in seconds if session_affinity is GENERATED_COOKIE. If set to 0, the cookie is non-persistent and lasts only until the end of the browser session (or equivalent). The maximum allowed value for TTL is one day. When the load balancing scheme is INTERNAL, this field is not used. Corresponds to the JSON property affinityCookieTtlSec

Returns:

  • (Fixnum)


1284
1285
1286
# File 'generated/google/apis/compute_beta/classes.rb', line 1284

def affinity_cookie_ttl_sec
  @affinity_cookie_ttl_sec
end

#backendsArray<Google::Apis::ComputeBeta::Backend>

The list of backends that serve this BackendService. Corresponds to the JSON property backends



1289
1290
1291
# File 'generated/google/apis/compute_beta/classes.rb', line 1289

def backends
  @backends
end

#cdn_policyGoogle::Apis::ComputeBeta::BackendServiceCdnPolicy

Message containing Cloud CDN configuration for a backend service. Corresponds to the JSON property cdnPolicy



1294
1295
1296
# File 'generated/google/apis/compute_beta/classes.rb', line 1294

def cdn_policy
  @cdn_policy
end

#connection_drainingGoogle::Apis::ComputeBeta::ConnectionDraining

Message containing connection draining configuration. Corresponds to the JSON property connectionDraining



1299
1300
1301
# File 'generated/google/apis/compute_beta/classes.rb', line 1299

def connection_draining
  @connection_draining
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


1304
1305
1306
# File 'generated/google/apis/compute_beta/classes.rb', line 1304

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


1310
1311
1312
# File 'generated/google/apis/compute_beta/classes.rb', line 1310

def description
  @description
end

#enable_cdnBoolean Also known as: enable_cdn?

If true, enable Cloud CDN for this BackendService. When the load balancing scheme is INTERNAL, this field is not used. Corresponds to the JSON property enableCDN

Returns:

  • (Boolean)


1316
1317
1318
# File 'generated/google/apis/compute_beta/classes.rb', line 1316

def enable_cdn
  @enable_cdn
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a BackendService. An up-to-date fingerprint must be provided in order to update the BackendService. Corresponds to the JSON property fingerprint

Returns:

  • (String)


1325
1326
1327
# File 'generated/google/apis/compute_beta/classes.rb', line 1325

def fingerprint
  @fingerprint
end

#health_checksArray<String>

The list of URLs to the HttpHealthCheck or HttpsHealthCheck resource for health checking this BackendService. Currently at most one health check can be specified, and a health check is required. For internal load balancing, a URL to a HealthCheck resource must be specified instead. Corresponds to the JSON property healthChecks

Returns:

  • (Array<String>)


1334
1335
1336
# File 'generated/google/apis/compute_beta/classes.rb', line 1334

def health_checks
  @health_checks
end

#iapGoogle::Apis::ComputeBeta::BackendServiceIap

Identity-Aware Proxy (Cloud Gatekeeper) Corresponds to the JSON property iap



1339
1340
1341
# File 'generated/google/apis/compute_beta/classes.rb', line 1339

def iap
  @iap
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


1345
1346
1347
# File 'generated/google/apis/compute_beta/classes.rb', line 1345

def id
  @id
end

#kindString

[Output Only] Type of resource. Always compute#backendService for backend services. Corresponds to the JSON property kind

Returns:

  • (String)


1351
1352
1353
# File 'generated/google/apis/compute_beta/classes.rb', line 1351

def kind
  @kind
end

#load_balancing_schemeString

Corresponds to the JSON property loadBalancingScheme

Returns:

  • (String)


1356
1357
1358
# File 'generated/google/apis/compute_beta/classes.rb', line 1356

def load_balancing_scheme
  @load_balancing_scheme
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


1366
1367
1368
# File 'generated/google/apis/compute_beta/classes.rb', line 1366

def name
  @name
end

#portFixnum

Deprecated in favor of portName. The TCP port to connect on the backend. The default value is 80. This cannot be used for internal load balancing. Corresponds to the JSON property port

Returns:

  • (Fixnum)


1373
1374
1375
# File 'generated/google/apis/compute_beta/classes.rb', line 1373

def port
  @port
end

#port_nameString

Name of backend port. The same name should appear in the instance groups referenced by this service. Required when the load balancing scheme is EXTERNAL. When the load balancing scheme is INTERNAL, this field is not used. Corresponds to the JSON property portName

Returns:

  • (String)


1381
1382
1383
# File 'generated/google/apis/compute_beta/classes.rb', line 1381

def port_name
  @port_name
end

#protocolString

The protocol this BackendService uses to communicate with backends. Possible values are HTTP, HTTPS, HTTP2, TCP and SSL. The default is HTTP. For internal load balancing, the possible values are TCP and UDP, and the default is TCP. Corresponds to the JSON property protocol

Returns:

  • (String)


1389
1390
1391
# File 'generated/google/apis/compute_beta/classes.rb', line 1389

def protocol
  @protocol
end

#regionString

[Output Only] URL of the region where the regional backend service resides. This field is not applicable to global backend services. Corresponds to the JSON property region

Returns:

  • (String)


1395
1396
1397
# File 'generated/google/apis/compute_beta/classes.rb', line 1395

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


1400
1401
1402
# File 'generated/google/apis/compute_beta/classes.rb', line 1400

def self_link
  @self_link
end

#session_affinityString

Type of session affinity to use. The default is NONE. When the load balancing scheme is EXTERNAL, can be NONE, CLIENT_IP, or GENERATED_COOKIE. When the load balancing scheme is INTERNAL, can be NONE, CLIENT_IP, CLIENT_IP_PROTO, or CLIENT_IP_PORT_PROTO. When the protocol is UDP, this field is not used. Corresponds to the JSON property sessionAffinity

Returns:

  • (String)


1410
1411
1412
# File 'generated/google/apis/compute_beta/classes.rb', line 1410

def session_affinity
  @session_affinity
end

#timeout_secFixnum

How many seconds to wait for the backend before considering it a failed request. Default is 30 seconds. Corresponds to the JSON property timeoutSec

Returns:

  • (Fixnum)


1416
1417
1418
# File 'generated/google/apis/compute_beta/classes.rb', line 1416

def timeout_sec
  @timeout_sec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
# File 'generated/google/apis/compute_beta/classes.rb', line 1423

def update!(**args)
  @affinity_cookie_ttl_sec = args[:affinity_cookie_ttl_sec] if args.key?(:affinity_cookie_ttl_sec)
  @backends = args[:backends] if args.key?(:backends)
  @cdn_policy = args[:cdn_policy] if args.key?(:cdn_policy)
  @connection_draining = args[:connection_draining] if args.key?(:connection_draining)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @enable_cdn = args[:enable_cdn] if args.key?(:enable_cdn)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @health_checks = args[:health_checks] if args.key?(:health_checks)
  @iap = args[:iap] if args.key?(:iap)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme)
  @name = args[:name] if args.key?(:name)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @protocol = args[:protocol] if args.key?(:protocol)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @session_affinity = args[:session_affinity] if args.key?(:session_affinity)
  @timeout_sec = args[:timeout_sec] if args.key?(:timeout_sec)
end