Class: Google::Apis::ComputeBeta::Disk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

A Disk resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ Disk

Returns a new instance of Disk.



2200
2201
2202
# File 'generated/google/apis/compute_beta/classes.rb', line 2200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


2029
2030
2031
# File 'generated/google/apis/compute_beta/classes.rb', line 2029

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


2035
2036
2037
# File 'generated/google/apis/compute_beta/classes.rb', line 2035

def description
  @description
end

#disk_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

Represents a customer-supplied encryption key Corresponds to the JSON property diskEncryptionKey



2040
2041
2042
# File 'generated/google/apis/compute_beta/classes.rb', line 2040

def disk_encryption_key
  @disk_encryption_key
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


2046
2047
2048
# File 'generated/google/apis/compute_beta/classes.rb', line 2046

def id
  @id
end

#kindString

[Output Only] Type of the resource. Always compute#disk for disks. Corresponds to the JSON property kind

Returns:

  • (String)


2051
2052
2053
# File 'generated/google/apis/compute_beta/classes.rb', line 2051

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this disk, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make a get() request to retrieve a disk. Corresponds to the JSON property labelFingerprint

Returns:

  • (String)


2061
2062
2063
# File 'generated/google/apis/compute_beta/classes.rb', line 2061

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this disk. These can be later modified by the setLabels method. Each label key/value pair must comply with RFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2068
2069
2070
# File 'generated/google/apis/compute_beta/classes.rb', line 2068

def labels
  @labels
end

#last_attach_timestampString

[Output Only] Last attach timestamp in RFC3339 text format. Corresponds to the JSON property lastAttachTimestamp

Returns:

  • (String)


2073
2074
2075
# File 'generated/google/apis/compute_beta/classes.rb', line 2073

def last_attach_timestamp
  @last_attach_timestamp
end

#last_detach_timestampString

[Output Only] Last detach timestamp in RFC3339 text format. Corresponds to the JSON property lastDetachTimestamp

Returns:

  • (String)


2078
2079
2080
# File 'generated/google/apis/compute_beta/classes.rb', line 2078

def last_detach_timestamp
  @last_detach_timestamp
end

#licensesArray<String>

Any applicable publicly visible licenses. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


2083
2084
2085
# File 'generated/google/apis/compute_beta/classes.rb', line 2083

def licenses
  @licenses
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


2093
2094
2095
# File 'generated/google/apis/compute_beta/classes.rb', line 2093

def name
  @name
end

#optionsString

Internal use only. Corresponds to the JSON property options

Returns:

  • (String)


2098
2099
2100
# File 'generated/google/apis/compute_beta/classes.rb', line 2098

def options
  @options
end

[Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2103
2104
2105
# File 'generated/google/apis/compute_beta/classes.rb', line 2103

def self_link
  @self_link
end

#size_gbString

Size of the persistent disk, specified in GB. You can specify this field when creating a persistent disk using the sourceImage or sourceSnapshot parameter, or specify it alone to create an empty persistent disk. If you specify this field along with sourceImage or sourceSnapshot, the value of sizeGb must not be less than the size of the sourceImage or the size of the snapshot. Corresponds to the JSON property sizeGb

Returns:

  • (String)


2113
2114
2115
# File 'generated/google/apis/compute_beta/classes.rb', line 2113

def size_gb
  @size_gb
end

#source_imageString

The source image used to create this disk. If the source image is deleted, this field will not be set. To create a disk with one of the public operating system images, specify the image by its family name. For example, specify family/debian-8 to use the latest Debian 8 image: projects/debian-cloud/global/images/family/debian-8 Alternatively, use a specific version of a public operating system image: projects/debian-cloud/global/images/debian-8-jessie-vYYYYMMDD To create a disk with a private image that you created, specify the image name in the following format: global/images/my-private-image You can also specify a private image by its image family, which returns the latest version of the image in that family. Replace the image name with family/ family-name: global/images/family/my-private-family Corresponds to the JSON property sourceImage

Returns:

  • (String)


2132
2133
2134
# File 'generated/google/apis/compute_beta/classes.rb', line 2132

def source_image
  @source_image
end

#source_image_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

Represents a customer-supplied encryption key Corresponds to the JSON property sourceImageEncryptionKey



2137
2138
2139
# File 'generated/google/apis/compute_beta/classes.rb', line 2137

def source_image_encryption_key
  @source_image_encryption_key
end

#source_image_idString

[Output Only] The ID value of the image used to create this disk. This value identifies the exact image that was used to create this persistent disk. For example, if you created the persistent disk from an image that was later deleted and recreated under the same name, the source image ID would identify the exact version of the image that was used. Corresponds to the JSON property sourceImageId

Returns:

  • (String)


2146
2147
2148
# File 'generated/google/apis/compute_beta/classes.rb', line 2146

def source_image_id
  @source_image_id
end

#source_snapshotString

The source snapshot used to create this disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


2157
2158
2159
# File 'generated/google/apis/compute_beta/classes.rb', line 2157

def source_snapshot
  @source_snapshot
end

#source_snapshot_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

Represents a customer-supplied encryption key Corresponds to the JSON property sourceSnapshotEncryptionKey



2162
2163
2164
# File 'generated/google/apis/compute_beta/classes.rb', line 2162

def source_snapshot_encryption_key
  @source_snapshot_encryption_key
end

#source_snapshot_idString

[Output Only] The unique ID of the snapshot used to create this disk. This value identifies the exact snapshot that was used to create this persistent disk. For example, if you created the persistent disk from a snapshot that was later deleted and recreated under the same name, the source snapshot ID would identify the exact version of the snapshot that was used. Corresponds to the JSON property sourceSnapshotId

Returns:

  • (String)


2171
2172
2173
# File 'generated/google/apis/compute_beta/classes.rb', line 2171

def source_snapshot_id
  @source_snapshot_id
end

#statusString

[Output Only] The status of disk creation. Corresponds to the JSON property status

Returns:

  • (String)


2176
2177
2178
# File 'generated/google/apis/compute_beta/classes.rb', line 2176

def status
  @status
end

#storage_typeString

[Deprecated] Storage type of the persistent disk. Corresponds to the JSON property storageType

Returns:

  • (String)


2181
2182
2183
# File 'generated/google/apis/compute_beta/classes.rb', line 2181

def storage_type
  @storage_type
end

#typeString

URL of the disk type resource describing which disk type to use to create the disk. Provide this when creating the disk. Corresponds to the JSON property type

Returns:

  • (String)


2187
2188
2189
# File 'generated/google/apis/compute_beta/classes.rb', line 2187

def type
  @type
end

#usersArray<String>

[Output Only] Links to the users of the disk (attached instances) in form: project/zones/zone/instances/instance Corresponds to the JSON property users

Returns:

  • (Array<String>)


2193
2194
2195
# File 'generated/google/apis/compute_beta/classes.rb', line 2193

def users
  @users
end

#zoneString

[Output Only] URL of the zone where the disk resides. Corresponds to the JSON property zone

Returns:

  • (String)


2198
2199
2200
# File 'generated/google/apis/compute_beta/classes.rb', line 2198

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
2229
2230
2231
# File 'generated/google/apis/compute_beta/classes.rb', line 2205

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @last_attach_timestamp = args[:last_attach_timestamp] if args.key?(:last_attach_timestamp)
  @last_detach_timestamp = args[:last_detach_timestamp] if args.key?(:last_detach_timestamp)
  @licenses = args[:licenses] if args.key?(:licenses)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @self_link = args[:self_link] if args.key?(:self_link)
  @size_gb = args[:size_gb] if args.key?(:size_gb)
  @source_image = args[:source_image] if args.key?(:source_image)
  @source_image_encryption_key = args[:source_image_encryption_key] if args.key?(:source_image_encryption_key)
  @source_image_id = args[:source_image_id] if args.key?(:source_image_id)
  @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot)
  @source_snapshot_encryption_key = args[:source_snapshot_encryption_key] if args.key?(:source_snapshot_encryption_key)
  @source_snapshot_id = args[:source_snapshot_id] if args.key?(:source_snapshot_id)
  @status = args[:status] if args.key?(:status)
  @storage_type = args[:storage_type] if args.key?(:storage_type)
  @type = args[:type] if args.key?(:type)
  @users = args[:users] if args.key?(:users)
  @zone = args[:zone] if args.key?(:zone)
end