Class: Google::Apis::ComputeBeta::DiskAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ DiskAggregatedList

Returns a new instance of DiskAggregatedList.



2269
2270
2271
# File 'generated/google/apis/compute_beta/classes.rb', line 2269

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


2242
2243
2244
# File 'generated/google/apis/compute_beta/classes.rb', line 2242

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::DisksScopedList>

[Output Only] A map of scoped disk lists. Corresponds to the JSON property items



2247
2248
2249
# File 'generated/google/apis/compute_beta/classes.rb', line 2247

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#diskAggregatedList for aggregated lists of persistent disks. Corresponds to the JSON property kind

Returns:

  • (String)


2253
2254
2255
# File 'generated/google/apis/compute_beta/classes.rb', line 2253

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2262
2263
2264
# File 'generated/google/apis/compute_beta/classes.rb', line 2262

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2267
2268
2269
# File 'generated/google/apis/compute_beta/classes.rb', line 2267

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2274
2275
2276
2277
2278
2279
2280
# File 'generated/google/apis/compute_beta/classes.rb', line 2274

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end