Class: Google::Apis::ComputeBeta::DiskList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

A list of Disk resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ DiskList

Returns a new instance of DiskList.



2317
2318
2319
# File 'generated/google/apis/compute_beta/classes.rb', line 2317

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


2291
2292
2293
# File 'generated/google/apis/compute_beta/classes.rb', line 2291

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Disk>

[Output Only] A list of persistent disks. Corresponds to the JSON property items



2296
2297
2298
# File 'generated/google/apis/compute_beta/classes.rb', line 2296

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#diskList for lists of disks. Corresponds to the JSON property kind

Returns:

  • (String)


2301
2302
2303
# File 'generated/google/apis/compute_beta/classes.rb', line 2301

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2310
2311
2312
# File 'generated/google/apis/compute_beta/classes.rb', line 2310

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2315
2316
2317
# File 'generated/google/apis/compute_beta/classes.rb', line 2315

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2322
2323
2324
2325
2326
2327
2328
# File 'generated/google/apis/compute_beta/classes.rb', line 2322

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end