Class: Google::Apis::ComputeBeta::DiskTypeAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ DiskTypeAggregatedList

Returns a new instance of DiskTypeAggregatedList.



2473
2474
2475
# File 'generated/google/apis/compute_beta/classes.rb', line 2473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


2447
2448
2449
# File 'generated/google/apis/compute_beta/classes.rb', line 2447

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::DiskTypesScopedList>

[Output Only] A map of scoped disk type lists. Corresponds to the JSON property items



2452
2453
2454
# File 'generated/google/apis/compute_beta/classes.rb', line 2452

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#diskTypeAggregatedList. Corresponds to the JSON property kind

Returns:

  • (String)


2457
2458
2459
# File 'generated/google/apis/compute_beta/classes.rb', line 2457

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2466
2467
2468
# File 'generated/google/apis/compute_beta/classes.rb', line 2466

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2471
2472
2473
# File 'generated/google/apis/compute_beta/classes.rb', line 2471

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2478
2479
2480
2481
2482
2483
2484
# File 'generated/google/apis/compute_beta/classes.rb', line 2478

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end