Class: Google::Apis::ComputeBeta::DiskTypeList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

Contains a list of disk types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ DiskTypeList

Returns a new instance of DiskTypeList.



2521
2522
2523
# File 'generated/google/apis/compute_beta/classes.rb', line 2521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


2495
2496
2497
# File 'generated/google/apis/compute_beta/classes.rb', line 2495

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::DiskType>

[Output Only] A list of Disk Type resources. Corresponds to the JSON property items



2500
2501
2502
# File 'generated/google/apis/compute_beta/classes.rb', line 2500

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#diskTypeList for disk types. Corresponds to the JSON property kind

Returns:

  • (String)


2505
2506
2507
# File 'generated/google/apis/compute_beta/classes.rb', line 2505

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2514
2515
2516
# File 'generated/google/apis/compute_beta/classes.rb', line 2514

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2519
2520
2521
# File 'generated/google/apis/compute_beta/classes.rb', line 2519

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2526
2527
2528
2529
2530
2531
2532
# File 'generated/google/apis/compute_beta/classes.rb', line 2526

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end