Class: Google::Apis::ComputeBeta::HostRule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HostRule
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
UrlMaps A host-matching rule for a URL. If matched, will use the named PathMatcher to select the BackendService.
Instance Attribute Summary collapse
-
#description ⇒ String
An optional description of this resource.
-
#hosts ⇒ Array<String>
The list of host patterns to match.
-
#path_matcher ⇒ String
The name of the PathMatcher to use to match the path portion of the URL if the hostRule matches the URL's host portion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HostRule
constructor
A new instance of HostRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ HostRule
Returns a new instance of HostRule.
3681 3682 3683 |
# File 'generated/google/apis/compute_beta/classes.rb', line 3681 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
3666 3667 3668 |
# File 'generated/google/apis/compute_beta/classes.rb', line 3666 def description @description end |
#hosts ⇒ Array<String>
The list of host patterns to match. They must be valid hostnames, except *
will match any string of ([a-z0-9-.]*). In that case, * must be the first
character and must be followed in the pattern by either - or ..
Corresponds to the JSON property hosts
3673 3674 3675 |
# File 'generated/google/apis/compute_beta/classes.rb', line 3673 def hosts @hosts end |
#path_matcher ⇒ String
The name of the PathMatcher to use to match the path portion of the URL if the
hostRule matches the URL's host portion.
Corresponds to the JSON property pathMatcher
3679 3680 3681 |
# File 'generated/google/apis/compute_beta/classes.rb', line 3679 def path_matcher @path_matcher end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3686 3687 3688 3689 3690 |
# File 'generated/google/apis/compute_beta/classes.rb', line 3686 def update!(**args) @description = args[:description] if args.key?(:description) @hosts = args[:hosts] if args.key?(:hosts) @path_matcher = args[:path_matcher] if args.key?(:path_matcher) end |