Class: Google::Apis::ComputeBeta::HttpsHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

An HttpsHealthCheck resource. This resource defines a template for how individual instances should be checked for health, via HTTPS.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ HttpsHealthCheck



3410
3411
3412
# File 'generated/google/apis/compute_beta/classes.rb', line 3410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_interval_secFixnum

How often (in seconds) to send a health check. The default value is 5 seconds. Corresponds to the JSON property checkIntervalSec



3854
3855
3856
# File 'generated/google/apis/compute_beta/classes.rb', line 3854

def check_interval_sec
  @check_interval_sec
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp



3859
3860
3861
# File 'generated/google/apis/compute_beta/classes.rb', line 3859

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description



3865
3866
3867
# File 'generated/google/apis/compute_beta/classes.rb', line 3865

def description
  @description
end

#healthy_thresholdFixnum

A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2. Corresponds to the JSON property healthyThreshold



3871
3872
3873
# File 'generated/google/apis/compute_beta/classes.rb', line 3871

def healthy_threshold
  @healthy_threshold
end

#hostString

The value of the host header in the HTTPS health check request. If left empty ( default value), the public IP on behalf of which this health check is performed will be used. Corresponds to the JSON property host



3386
3387
3388
# File 'generated/google/apis/compute_beta/classes.rb', line 3386

def host
  @host
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id



3884
3885
3886
# File 'generated/google/apis/compute_beta/classes.rb', line 3884

def id
  @id
end

#kindString

Type of the resource. Corresponds to the JSON property kind



3889
3890
3891
# File 'generated/google/apis/compute_beta/classes.rb', line 3889

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name



3899
3900
3901
# File 'generated/google/apis/compute_beta/classes.rb', line 3899

def name
  @name
end

#portFixnum

The TCP port number for the HTTPS health check request. The default value is 443. Corresponds to the JSON property port



3391
3392
3393
# File 'generated/google/apis/compute_beta/classes.rb', line 3391

def port
  @port
end

#port_nameString

Port name as defined in InstanceGroup#NamedPort#name. If both port and port_name are defined, port takes precedence. Corresponds to the JSON property portName



3397
3398
3399
# File 'generated/google/apis/compute_beta/classes.rb', line 3397

def port_name
  @port_name
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader



3403
3404
3405
# File 'generated/google/apis/compute_beta/classes.rb', line 3403

def proxy_header
  @proxy_header
end

#request_pathString

The request path of the HTTPS health check request. The default value is "/". Corresponds to the JSON property requestPath



3408
3409
3410
# File 'generated/google/apis/compute_beta/classes.rb', line 3408

def request_path
  @request_path
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink



3915
3916
3917
# File 'generated/google/apis/compute_beta/classes.rb', line 3915

def self_link
  @self_link
end

#timeout_secFixnum

How long (in seconds) to wait before claiming failure. The default value is 5 seconds. It is invalid for timeoutSec to have a greater value than checkIntervalSec. Corresponds to the JSON property timeoutSec



3922
3923
3924
# File 'generated/google/apis/compute_beta/classes.rb', line 3922

def timeout_sec
  @timeout_sec
end

#unhealthy_thresholdFixnum

A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2. Corresponds to the JSON property unhealthyThreshold



3928
3929
3930
# File 'generated/google/apis/compute_beta/classes.rb', line 3928

def unhealthy_threshold
  @unhealthy_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3415
3416
3417
3418
3419
3420
3421
# File 'generated/google/apis/compute_beta/classes.rb', line 3415

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @request_path = args[:request_path] if args.key?(:request_path)
end