Class: Google::Apis::ComputeBeta::Image::RawDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

The parameters of the raw disk image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ RawDisk

Returns a new instance of RawDisk.



4197
4198
4199
# File 'generated/google/apis/compute_beta/classes.rb', line 4197

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_typeString

The format used to encode and transmit the block device, which should be TAR. This is just a container and transmission format and not a runtime format. Provided by the client when the disk image is created. Corresponds to the JSON property containerType

Returns:

  • (String)


4183
4184
4185
# File 'generated/google/apis/compute_beta/classes.rb', line 4183

def container_type
  @container_type
end

#sha1_checksumString

An optional SHA1 checksum of the disk image before unpackaging; provided by the client when the disk image is created. Corresponds to the JSON property sha1Checksum

Returns:

  • (String)


4189
4190
4191
# File 'generated/google/apis/compute_beta/classes.rb', line 4189

def sha1_checksum
  @sha1_checksum
end

#sourceString

The full Google Cloud Storage URL where the disk image is stored. You must provide either this property or the sourceDisk property but not both. Corresponds to the JSON property source

Returns:

  • (String)


4195
4196
4197
# File 'generated/google/apis/compute_beta/classes.rb', line 4195

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4202
4203
4204
4205
4206
# File 'generated/google/apis/compute_beta/classes.rb', line 4202

def update!(**args)
  @container_type = args[:container_type] if args.key?(:container_type)
  @sha1_checksum = args[:sha1_checksum] if args.key?(:sha1_checksum)
  @source = args[:source] if args.key?(:source)
end