Class: Google::Apis::ComputeBeta::ImageList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ImageList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Contains a list of images.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Image>
[Output Only] A list of Image resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageList
constructor
A new instance of ImageList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ ImageList
Returns a new instance of ImageList.
4244 4245 4246 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4244 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
4218 4219 4220 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4218 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Image>
[Output Only] A list of Image resources.
Corresponds to the JSON property items
4223 4224 4225 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4223 def items @items end |
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
4228 4229 4230 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4228 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
4237 4238 4239 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4237 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
4242 4243 4244 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4242 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4249 4250 4251 4252 4253 4254 4255 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4249 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |