Class: Google::Apis::ComputeBeta::Instance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

An Instance resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



4399
4400
4401
# File 'generated/google/apis/compute_beta/classes.rb', line 4399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_ip_forwardBoolean Also known as: can_ip_forward?

Allows this instance to send and receive packets with non-matching destination or source IPs. This is required if you plan to use this instance to forward routes. For more information, see Enabling IP Forwarding. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


4267
4268
4269
# File 'generated/google/apis/compute_beta/classes.rb', line 4267

def can_ip_forward
  @can_ip_forward
end

#cpu_platformString

[Output Only] The CPU platform used by this instance. Corresponds to the JSON property cpuPlatform

Returns:

  • (String)


4273
4274
4275
# File 'generated/google/apis/compute_beta/classes.rb', line 4273

def cpu_platform
  @cpu_platform
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


4278
4279
4280
# File 'generated/google/apis/compute_beta/classes.rb', line 4278

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


4284
4285
4286
# File 'generated/google/apis/compute_beta/classes.rb', line 4284

def description
  @description
end

#disksArray<Google::Apis::ComputeBeta::AttachedDisk>

Array of disks associated with this instance. Persistent disks must be created before you can assign them. Corresponds to the JSON property disks



4290
4291
4292
# File 'generated/google/apis/compute_beta/classes.rb', line 4290

def disks
  @disks
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


4296
4297
4298
# File 'generated/google/apis/compute_beta/classes.rb', line 4296

def id
  @id
end

#kindString

[Output Only] Type of the resource. Always compute#instance for instances. Corresponds to the JSON property kind

Returns:

  • (String)


4301
4302
4303
# File 'generated/google/apis/compute_beta/classes.rb', line 4301

def kind
  @kind
end

#label_fingerprintString

A fingerprint for this request, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata. To see the latest fingerprint, make get() request to the instance. Corresponds to the JSON property labelFingerprint

Returns:

  • (String)


4311
4312
4313
# File 'generated/google/apis/compute_beta/classes.rb', line 4311

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this instance. These can be later modified by the setLabels method. Each label key/value pair must comply with RFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4318
4319
4320
# File 'generated/google/apis/compute_beta/classes.rb', line 4318

def labels
  @labels
end

#machine_typeString

Full or partial URL of the machine type resource to use for this instance, in the format: zones/zone/machineTypes/machine-type. This is provided by the client when the instance is created. For example, the following is a valid partial url to a predefined machine type: zones/us-central1-f/machineTypes/n1-standard-1 To create a custom machine type, provide a URL to a machine type in the following format, where CPUS is 1 or an even number up to 32 (2, 4, 6, ... 24, etc), and MEMORY is the total memory for this instance. Memory must be a multiple of 256 MB and must be supplied in MB (e.g. 5 GB of memory is 5120 MB): zones/zone/machineTypes/custom-CPUS-MEMORY For example: zones/us-central1-f/machineTypes/custom-4-5120 For a full list of restrictions, read the Specifications for custom machine types. Corresponds to the JSON property machineType

Returns:

  • (String)


4335
4336
4337
# File 'generated/google/apis/compute_beta/classes.rb', line 4335

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeBeta::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



4340
4341
4342
# File 'generated/google/apis/compute_beta/classes.rb', line 4340

def 
  
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


4350
4351
4352
# File 'generated/google/apis/compute_beta/classes.rb', line 4350

def name
  @name
end

#network_interfacesArray<Google::Apis::ComputeBeta::NetworkInterface>

An array of configurations for this interface. This specifies how this interface is configured to interact with other network services, such as connecting to the internet. Only one interface is supported per instance. Corresponds to the JSON property networkInterfaces



4357
4358
4359
# File 'generated/google/apis/compute_beta/classes.rb', line 4357

def network_interfaces
  @network_interfaces
end

#schedulingGoogle::Apis::ComputeBeta::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



4362
4363
4364
# File 'generated/google/apis/compute_beta/classes.rb', line 4362

def scheduling
  @scheduling
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


4367
4368
4369
# File 'generated/google/apis/compute_beta/classes.rb', line 4367

def self_link
  @self_link
end

#service_accountsArray<Google::Apis::ComputeBeta::ServiceAccount>

A list of service accounts, with their specified scopes, authorized for this instance. Service accounts generate access tokens that can be accessed through the metadata server and used to authenticate applications on the instance. See Service Accounts for more information. Corresponds to the JSON property serviceAccounts



4375
4376
4377
# File 'generated/google/apis/compute_beta/classes.rb', line 4375

def service_accounts
  @service_accounts
end

#statusString

[Output Only] The status of the instance. One of the following values: PROVISIONING, STAGING, RUNNING, STOPPING, SUSPENDING, SUSPENDED, and TERMINATED. Corresponds to the JSON property status

Returns:

  • (String)


4382
4383
4384
# File 'generated/google/apis/compute_beta/classes.rb', line 4382

def status
  @status
end

#status_messageString

[Output Only] An optional, human-readable explanation of the status. Corresponds to the JSON property statusMessage

Returns:

  • (String)


4387
4388
4389
# File 'generated/google/apis/compute_beta/classes.rb', line 4387

def status_message
  @status_message
end

#tagsGoogle::Apis::ComputeBeta::Tags

A set of instance tags. Corresponds to the JSON property tags



4392
4393
4394
# File 'generated/google/apis/compute_beta/classes.rb', line 4392

def tags
  @tags
end

#zoneString

[Output Only] URL of the zone where the instance resides. Corresponds to the JSON property zone

Returns:

  • (String)


4397
4398
4399
# File 'generated/google/apis/compute_beta/classes.rb', line 4397

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
4415
4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
# File 'generated/google/apis/compute_beta/classes.rb', line 4404

def update!(**args)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
   = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @self_link = args[:self_link] if args.key?(:self_link)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @tags = args[:tags] if args.key?(:tags)
  @zone = args[:zone] if args.key?(:zone)
end