Class: Google::Apis::ComputeBeta::InstanceGroupManager

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

An Instance Group Manager resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ InstanceGroupManager

Returns a new instance of InstanceGroupManager.



4803
4804
4805
# File 'generated/google/apis/compute_beta/classes.rb', line 4803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_healing_policiesArray<Google::Apis::ComputeBeta::InstanceGroupManagerAutoHealingPolicy>

The autohealing policy for this managed instance group. You can specify only one value. Corresponds to the JSON property autoHealingPolicies



4687
4688
4689
# File 'generated/google/apis/compute_beta/classes.rb', line 4687

def auto_healing_policies
  @auto_healing_policies
end

#base_instance_nameString

The base instance name to use for instances in this group. The value must be 1- 58 characters long. Instances are named by appending a hyphen and a random four-character string to the base instance name. The base instance name must comply with RFC1035. Corresponds to the JSON property baseInstanceName

Returns:

  • (String)


4695
4696
4697
# File 'generated/google/apis/compute_beta/classes.rb', line 4695

def base_instance_name
  @base_instance_name
end

#creation_timestampString

[Output Only] The creation timestamp for this managed instance group in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


4701
4702
4703
# File 'generated/google/apis/compute_beta/classes.rb', line 4701

def creation_timestamp
  @creation_timestamp
end

#current_actionsGoogle::Apis::ComputeBeta::InstanceGroupManagerActionsSummary

[Output Only] The list of instance actions and the number of instances in this managed instance group that are scheduled for each of those actions. Corresponds to the JSON property currentActions



4707
4708
4709
# File 'generated/google/apis/compute_beta/classes.rb', line 4707

def current_actions
  @current_actions
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


4713
4714
4715
# File 'generated/google/apis/compute_beta/classes.rb', line 4713

def description
  @description
end

#failover_actionString

The action to perform in case of zone failure. Only one value is supported, NO_FAILOVER. The default is NO_FAILOVER. Corresponds to the JSON property failoverAction

Returns:

  • (String)


4719
4720
4721
# File 'generated/google/apis/compute_beta/classes.rb', line 4719

def failover_action
  @failover_action
end

#fingerprintString

[Output Only] The fingerprint of the resource data. You can use this optional field for optimistic locking when you update the resource. Corresponds to the JSON property fingerprint

Returns:

  • (String)


4725
4726
4727
# File 'generated/google/apis/compute_beta/classes.rb', line 4725

def fingerprint
  @fingerprint
end

#idString

[Output Only] A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (String)


4731
4732
4733
# File 'generated/google/apis/compute_beta/classes.rb', line 4731

def id
  @id
end

#instance_groupString

[Output Only] The URL of the Instance Group resource. Corresponds to the JSON property instanceGroup

Returns:

  • (String)


4736
4737
4738
# File 'generated/google/apis/compute_beta/classes.rb', line 4736

def instance_group
  @instance_group
end

#instance_templateString

The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


4743
4744
4745
# File 'generated/google/apis/compute_beta/classes.rb', line 4743

def instance_template
  @instance_template
end

#kindString

[Output Only] The resource type, which is always compute#instanceGroupManager for managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


4749
4750
4751
# File 'generated/google/apis/compute_beta/classes.rb', line 4749

def kind
  @kind
end

#nameString

The name of the managed instance group. The name must be 1-63 characters long, and comply with RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


4755
4756
4757
# File 'generated/google/apis/compute_beta/classes.rb', line 4755

def name
  @name
end

#named_portsArray<Google::Apis::ComputeBeta::NamedPort>

Named ports configured for the Instance Groups complementary to this Instance Group Manager. Corresponds to the JSON property namedPorts



4761
4762
4763
# File 'generated/google/apis/compute_beta/classes.rb', line 4761

def named_ports
  @named_ports
end

#regionString

[Output Only] The URL of the region where the managed instance group resides ( for regional resources). Corresponds to the JSON property region

Returns:

  • (String)


4767
4768
4769
# File 'generated/google/apis/compute_beta/classes.rb', line 4767

def region
  @region
end

[Output Only] The URL for this managed instance group. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


4773
4774
4775
# File 'generated/google/apis/compute_beta/classes.rb', line 4773

def self_link
  @self_link
end

#service_accountString

Service account will be used as credentials for all operations performed by managed instance group on instances. The service accounts needs all permissions required to create and delete instances. When not specified, the service account projectNumber@cloudservices.gserviceaccount.com will be used. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


4781
4782
4783
# File 'generated/google/apis/compute_beta/classes.rb', line 4781

def 
  @service_account
end

#target_poolsArray<String>

The URLs for all TargetPool resources to which instances in the instanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group. Corresponds to the JSON property targetPools

Returns:

  • (Array<String>)


4788
4789
4790
# File 'generated/google/apis/compute_beta/classes.rb', line 4788

def target_pools
  @target_pools
end

#target_sizeFixnum

The target number of running instances for this managed instance group. Deleting or abandoning instances reduces this number. Resizing the group changes this number. Corresponds to the JSON property targetSize

Returns:

  • (Fixnum)


4795
4796
4797
# File 'generated/google/apis/compute_beta/classes.rb', line 4795

def target_size
  @target_size
end

#zoneString

[Output Only] The URL of the zone where the managed instance group is located ( for zonal resources). Corresponds to the JSON property zone

Returns:

  • (String)


4801
4802
4803
# File 'generated/google/apis/compute_beta/classes.rb', line 4801

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4808
4809
4810
4811
4812
4813
4814
4815
4816
4817
4818
4819
4820
4821
4822
4823
4824
4825
4826
4827
4828
# File 'generated/google/apis/compute_beta/classes.rb', line 4808

def update!(**args)
  @auto_healing_policies = args[:auto_healing_policies] if args.key?(:auto_healing_policies)
  @base_instance_name = args[:base_instance_name] if args.key?(:base_instance_name)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @current_actions = args[:current_actions] if args.key?(:current_actions)
  @description = args[:description] if args.key?(:description)
  @failover_action = args[:failover_action] if args.key?(:failover_action)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @instance_group = args[:instance_group] if args.key?(:instance_group)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @named_ports = args[:named_ports] if args.key?(:named_ports)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @service_account = args[:service_account] if args.key?(:service_account)
  @target_pools = args[:target_pools] if args.key?(:target_pools)
  @target_size = args[:target_size] if args.key?(:target_size)
  @zone = args[:zone] if args.key?(:zone)
end