Class: Google::Apis::ComputeBeta::InstanceGroupManagerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerAggregatedList

Returns a new instance of InstanceGroupManagerAggregatedList.



4946
4947
4948
# File 'generated/google/apis/compute_beta/classes.rb', line 4946

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] A unique identifier for this aggregated list of managed instance groups. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (String)


4918
4919
4920
# File 'generated/google/apis/compute_beta/classes.rb', line 4918

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::InstanceGroupManagersScopedList>

[Output Only] A map of filtered managed instance group lists. Corresponds to the JSON property items



4923
4924
4925
# File 'generated/google/apis/compute_beta/classes.rb', line 4923

def items
  @items
end

#kindString

[Output Only] The resource type, which is always compute# instanceGroupManagerAggregatedList for an aggregated list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


4930
4931
4932
# File 'generated/google/apis/compute_beta/classes.rb', line 4930

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4939
4940
4941
# File 'generated/google/apis/compute_beta/classes.rb', line 4939

def next_page_token
  @next_page_token
end

[Output Only] The URL for this resource type. The server generates this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


4944
4945
4946
# File 'generated/google/apis/compute_beta/classes.rb', line 4944

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4951
4952
4953
4954
4955
4956
4957
# File 'generated/google/apis/compute_beta/classes.rb', line 4951

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end