Class: Google::Apis::ComputeBeta::InstanceGroupsListInstances

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ InstanceGroupsListInstances

Returns a new instance of InstanceGroupsListInstances.



5380
5381
5382
# File 'generated/google/apis/compute_beta/classes.rb', line 5380

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] A unique identifier for this list of instances in the specified instance group. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (String)


5350
5351
5352
# File 'generated/google/apis/compute_beta/classes.rb', line 5350

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceWithNamedPorts>

[Output Only] A list of instances and any named ports that are assigned to those instances. Corresponds to the JSON property items



5356
5357
5358
# File 'generated/google/apis/compute_beta/classes.rb', line 5356

def items
  @items
end

#kindString

[Output Only] The resource type, which is always compute# instanceGroupsListInstances for the list of instances in the specified instance group. Corresponds to the JSON property kind

Returns:

  • (String)


5363
5364
5365
# File 'generated/google/apis/compute_beta/classes.rb', line 5363

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5372
5373
5374
# File 'generated/google/apis/compute_beta/classes.rb', line 5372

def next_page_token
  @next_page_token
end

[Output Only] The URL for this list of instances in the specified instance groups. The server generates this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


5378
5379
5380
# File 'generated/google/apis/compute_beta/classes.rb', line 5378

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5385
5386
5387
5388
5389
5390
5391
# File 'generated/google/apis/compute_beta/classes.rb', line 5385

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end