Class: Google::Apis::ComputeBeta::InstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Contains a list of instances.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Instance>
[Output Only] A list of instances.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceList
constructor
A new instance of InstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InstanceList
Returns a new instance of InstanceList.
5590 5591 5592 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5590 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
5563 5564 5565 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5563 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Instance>
[Output Only] A list of instances.
Corresponds to the JSON property items
5568 5569 5570 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5568 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#instanceList for lists of
Instance resources.
Corresponds to the JSON property kind
5574 5575 5576 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5574 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
5583 5584 5585 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5583 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
5588 5589 5590 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5588 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5595 5596 5597 5598 5599 5600 5601 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5595 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |