Class: Google::Apis::ComputeBeta::InstanceProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ InstanceProperties

Returns a new instance of InstanceProperties.



5703
5704
5705
# File 'generated/google/apis/compute_beta/classes.rb', line 5703

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_ip_forwardBoolean Also known as: can_ip_forward?

Enables instances created based on this template to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set to false. See the Enable IP forwarding for instances documentation for more information. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


5650
5651
5652
# File 'generated/google/apis/compute_beta/classes.rb', line 5650

def can_ip_forward
  @can_ip_forward
end

#descriptionString

An optional text description for the instances that are created from this instance template. Corresponds to the JSON property description

Returns:

  • (String)


5657
5658
5659
# File 'generated/google/apis/compute_beta/classes.rb', line 5657

def description
  @description
end

#disksArray<Google::Apis::ComputeBeta::AttachedDisk>

An array of disks that are associated with the instances that are created from this template. Corresponds to the JSON property disks



5663
5664
5665
# File 'generated/google/apis/compute_beta/classes.rb', line 5663

def disks
  @disks
end

#labelsHash<String,String>

Labels to apply to instances that are created from this template. Each label key/value pair must comply with RFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5669
5670
5671
# File 'generated/google/apis/compute_beta/classes.rb', line 5669

def labels
  @labels
end

#machine_typeString

The machine type to use for instances that are created from this template. Corresponds to the JSON property machineType

Returns:

  • (String)


5674
5675
5676
# File 'generated/google/apis/compute_beta/classes.rb', line 5674

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeBeta::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



5679
5680
5681
# File 'generated/google/apis/compute_beta/classes.rb', line 5679

def 
  @metadata
end

#network_interfacesArray<Google::Apis::ComputeBeta::NetworkInterface>

An array of network access configurations for this interface. Corresponds to the JSON property networkInterfaces



5684
5685
5686
# File 'generated/google/apis/compute_beta/classes.rb', line 5684

def network_interfaces
  @network_interfaces
end

#schedulingGoogle::Apis::ComputeBeta::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



5689
5690
5691
# File 'generated/google/apis/compute_beta/classes.rb', line 5689

def scheduling
  @scheduling
end

#service_accountsArray<Google::Apis::ComputeBeta::ServiceAccount>

A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from this template. Use metadata queries to obtain the access tokens for these instances. Corresponds to the JSON property serviceAccounts



5696
5697
5698
# File 'generated/google/apis/compute_beta/classes.rb', line 5696

def service_accounts
  @service_accounts
end

#tagsGoogle::Apis::ComputeBeta::Tags

A set of instance tags. Corresponds to the JSON property tags



5701
5702
5703
# File 'generated/google/apis/compute_beta/classes.rb', line 5701

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5708
5709
5710
5711
5712
5713
5714
5715
5716
5717
5718
5719
# File 'generated/google/apis/compute_beta/classes.rb', line 5708

def update!(**args)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @labels = args[:labels] if args.key?(:labels)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @tags = args[:tags] if args.key?(:tags)
end