Class: Google::Apis::ComputeBeta::MachineTypeList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

Contains a list of machine types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ MachineTypeList

Returns a new instance of MachineTypeList.



6346
6347
6348
# File 'generated/google/apis/compute_beta/classes.rb', line 6346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


6319
6320
6321
# File 'generated/google/apis/compute_beta/classes.rb', line 6319

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::MachineType>

[Output Only] A list of Machine Type resources. Corresponds to the JSON property items



6324
6325
6326
# File 'generated/google/apis/compute_beta/classes.rb', line 6324

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#machineTypeList for lists of machine types. Corresponds to the JSON property kind

Returns:

  • (String)


6330
6331
6332
# File 'generated/google/apis/compute_beta/classes.rb', line 6330

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6339
6340
6341
# File 'generated/google/apis/compute_beta/classes.rb', line 6339

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


6344
6345
6346
# File 'generated/google/apis/compute_beta/classes.rb', line 6344

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6351
6352
6353
6354
6355
6356
6357
# File 'generated/google/apis/compute_beta/classes.rb', line 6351

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end