Class: Google::Apis::ComputeBeta::ManagedInstance
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ManagedInstance
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#current_action ⇒ String
[Output Only] The current action that the managed instance group has scheduled for the instance.
-
#id ⇒ String
[Output only] The unique identifier for this resource.
-
#instance ⇒ String
[Output Only] The URL of the instance.
-
#instance_status ⇒ String
[Output Only] The status of the instance.
-
#last_attempt ⇒ Google::Apis::ComputeBeta::ManagedInstanceLastAttempt
[Output Only] Information about the last attempt to create or delete the instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstance
constructor
A new instance of ManagedInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ ManagedInstance
Returns a new instance of ManagedInstance.
6501 6502 6503 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6501 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_action ⇒ String
[Output Only] The current action that the managed instance group has scheduled for the instance. Possible values:
- NONE The instance is running, and the managed instance group does not have any scheduled actions for this instance.
- CREATING The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.
- CREATING_WITHOUT_RETRIES The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group's targetSize value is decreased instead.
- RECREATING The managed instance group is recreating this instance.
- DELETING The managed instance group is permanently deleting this instance.
- ABANDONING The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.
- RESTARTING The managed instance group is restarting the instance.
- REFRESHING The managed instance group is applying configuration changes to
the instance without stopping it. For example, the group can update the target
pool list for an instance without stopping that instance.
Corresponds to the JSON property
currentAction
6475 6476 6477 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6475 def current_action @current_action end |
#id ⇒ String
[Output only] The unique identifier for this resource. This field is empty
when instance does not exist.
Corresponds to the JSON property id
6481 6482 6483 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6481 def id @id end |
#instance ⇒ String
[Output Only] The URL of the instance. The URL can exist even if the instance
has not yet been created.
Corresponds to the JSON property instance
6487 6488 6489 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6487 def instance @instance end |
#instance_status ⇒ String
[Output Only] The status of the instance. This field is empty when the
instance does not exist.
Corresponds to the JSON property instanceStatus
6493 6494 6495 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6493 def instance_status @instance_status end |
#last_attempt ⇒ Google::Apis::ComputeBeta::ManagedInstanceLastAttempt
[Output Only] Information about the last attempt to create or delete the
instance.
Corresponds to the JSON property lastAttempt
6499 6500 6501 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6499 def last_attempt @last_attempt end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6506 6507 6508 6509 6510 6511 6512 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6506 def update!(**args) @current_action = args[:current_action] if args.key?(:current_action) @id = args[:id] if args.key?(:id) @instance = args[:instance] if args.key?(:instance) @instance_status = args[:instance_status] if args.key?(:instance_status) @last_attempt = args[:last_attempt] if args.key?(:last_attempt) end |