Class: Google::Apis::ComputeBeta::Metadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

A metadata key/value entry.

Defined Under Namespace

Classes: Item

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ Metadata

Returns a new instance of Metadata.



6611
6612
6613
# File 'generated/google/apis/compute_beta/classes.rb', line 6611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fingerprintString

Specifies a fingerprint for this request, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata. Corresponds to the JSON property fingerprint

Returns:

  • (String)


6598
6599
6600
# File 'generated/google/apis/compute_beta/classes.rb', line 6598

def fingerprint
  @fingerprint
end

#itemsArray<Google::Apis::ComputeBeta::Metadata::Item>

Array of key/value pairs. The total size of all keys and values must be less than 512 KB. Corresponds to the JSON property items



6604
6605
6606
# File 'generated/google/apis/compute_beta/classes.rb', line 6604

def items
  @items
end

#kindString

[Output Only] Type of the resource. Always compute#metadata for metadata. Corresponds to the JSON property kind

Returns:

  • (String)


6609
6610
6611
# File 'generated/google/apis/compute_beta/classes.rb', line 6609

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6616
6617
6618
6619
6620
# File 'generated/google/apis/compute_beta/classes.rb', line 6616

def update!(**args)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
end