Class: Google::Apis::ComputeBeta::Metadata::Item
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Metadata::Item
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#key ⇒ String
Key for the metadata entry.
-
#value ⇒ String
Value for the metadata entry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Item
constructor
A new instance of Item.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ Item
Returns a new instance of Item.
6642 6643 6644 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6642 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
Key for the metadata entry. Keys must conform to the following regexp: [a-zA-
Z0-9-_]+, and be less than 128 bytes in length. This is reflected as part of a
URL in the metadata server. Additionally, to avoid ambiguity, keys must not
conflict with any other metadata keys for the project.
Corresponds to the JSON property key
6632 6633 6634 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6632 def key @key end |
#value ⇒ String
Value for the metadata entry. These are free-form strings, and only have
meaning as interpreted by the image running in the instance. The only
restriction placed on values is that their size must be less than or equal to
32768 bytes.
Corresponds to the JSON property value
6640 6641 6642 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6640 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6647 6648 6649 6650 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6647 def update!(**args) @key = args[:key] if args.key?(:key) @value = args[:value] if args.key?(:value) end |