Class: Google::Apis::ComputeBeta::NetworkInterface

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

A network interface resource attached to an instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ NetworkInterface

Returns a new instance of NetworkInterface.



6827
6828
6829
# File 'generated/google/apis/compute_beta/classes.rb', line 6827

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_configsArray<Google::Apis::ComputeBeta::AccessConfig>

An array of configurations for this interface. Currently, only one access config, ONE_TO_ONE_NAT, is supported. If there are no accessConfigs specified, then this instance will have no external internet access. Corresponds to the JSON property accessConfigs



6779
6780
6781
# File 'generated/google/apis/compute_beta/classes.rb', line 6779

def access_configs
  @access_configs
end

#kindString

[Output Only] Type of the resource. Always compute#networkInterface for network interfaces. Corresponds to the JSON property kind

Returns:

  • (String)


6785
6786
6787
# File 'generated/google/apis/compute_beta/classes.rb', line 6785

def kind
  @kind
end

#nameString

[Output Only] The name of the network interface, generated by the server. For network devices, these are eth0, eth1, etc. Corresponds to the JSON property name

Returns:

  • (String)


6791
6792
6793
# File 'generated/google/apis/compute_beta/classes.rb', line 6791

def name
  @name
end

#networkString

URL of the network resource for this instance. This is required for creating an instance but optional when creating a firewall rule. If not specified when creating a firewall rule, the default network is used: global/networks/default If you specify this property, you can specify the network as a full or partial URL. For example, the following are all valid URLs:

Returns:

  • (String)


6805
6806
6807
# File 'generated/google/apis/compute_beta/classes.rb', line 6805

def network
  @network
end

#network_ipString

An IPv4 internal network address to assign to the instance for this network interface. If not specified by the user, an unused internal IP is assigned by the system. Corresponds to the JSON property networkIP

Returns:

  • (String)


6812
6813
6814
# File 'generated/google/apis/compute_beta/classes.rb', line 6812

def network_ip
  @network_ip
end

#subnetworkString

The URL of the Subnetwork resource for this instance. If the network resource is in legacy mode, do not provide this property. If the network is in auto subnet mode, providing the subnetwork is optional. If the network is in custom subnet mode, then this field should be specified. If you specify this property, you can specify the subnetwork as a full or partial URL. For example, the following are all valid URLs:

Returns:

  • (String)


6825
6826
6827
# File 'generated/google/apis/compute_beta/classes.rb', line 6825

def subnetwork
  @subnetwork
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6832
6833
6834
6835
6836
6837
6838
6839
# File 'generated/google/apis/compute_beta/classes.rb', line 6832

def update!(**args)
  @access_configs = args[:access_configs] if args.key?(:access_configs)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @network_ip = args[:network_ip] if args.key?(:network_ip)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
end