Class: Google::Apis::ComputeBeta::Operation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

An Operation resource, used to manage asynchronous API requests.

Defined Under Namespace

Classes: Error, Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



7032
7033
7034
# File 'generated/google/apis/compute_beta/classes.rb', line 7032

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_operation_idString

[Output Only] Reserved for future use. Corresponds to the JSON property clientOperationId

Returns:

  • (String)


6898
6899
6900
# File 'generated/google/apis/compute_beta/classes.rb', line 6898

def client_operation_id
  @client_operation_id
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


6903
6904
6905
# File 'generated/google/apis/compute_beta/classes.rb', line 6903

def creation_timestamp
  @creation_timestamp
end

#descriptionString

[Output Only] A textual description of the operation, which is set when the operation is created. Corresponds to the JSON property description

Returns:

  • (String)


6909
6910
6911
# File 'generated/google/apis/compute_beta/classes.rb', line 6909

def description
  @description
end

#end_timeString

[Output Only] The time that this operation was completed. This value is in RFC3339 text format. Corresponds to the JSON property endTime

Returns:

  • (String)


6915
6916
6917
# File 'generated/google/apis/compute_beta/classes.rb', line 6915

def end_time
  @end_time
end

#errorGoogle::Apis::ComputeBeta::Operation::Error

[Output Only] If errors are generated during processing of the operation, this field will be populated. Corresponds to the JSON property error



6921
6922
6923
# File 'generated/google/apis/compute_beta/classes.rb', line 6921

def error
  @error
end

#http_error_messageString

[Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as NOT FOUND. Corresponds to the JSON property httpErrorMessage

Returns:

  • (String)


6927
6928
6929
# File 'generated/google/apis/compute_beta/classes.rb', line 6927

def http_error_message
  @http_error_message
end

#http_error_status_codeFixnum

[Output Only] If the operation fails, this field contains the HTTP error status code that was returned. For example, a 404 means the resource was not found. Corresponds to the JSON property httpErrorStatusCode

Returns:

  • (Fixnum)


6934
6935
6936
# File 'generated/google/apis/compute_beta/classes.rb', line 6934

def http_error_status_code
  @http_error_status_code
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


6940
6941
6942
# File 'generated/google/apis/compute_beta/classes.rb', line 6940

def id
  @id
end

#insert_timeString

[Output Only] The time that this operation was requested. This value is in RFC3339 text format. Corresponds to the JSON property insertTime

Returns:

  • (String)


6946
6947
6948
# File 'generated/google/apis/compute_beta/classes.rb', line 6946

def insert_time
  @insert_time
end

#kindString

[Output Only] Type of the resource. Always compute#operation for Operation resources. Corresponds to the JSON property kind

Returns:

  • (String)


6952
6953
6954
# File 'generated/google/apis/compute_beta/classes.rb', line 6952

def kind
  @kind
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


6957
6958
6959
# File 'generated/google/apis/compute_beta/classes.rb', line 6957

def name
  @name
end

#operation_typeString

[Output Only] The type of operation, such as insert, update, or delete, and so on. Corresponds to the JSON property operationType

Returns:

  • (String)


6963
6964
6965
# File 'generated/google/apis/compute_beta/classes.rb', line 6963

def operation_type
  @operation_type
end

#progressFixnum

[Output Only] An optional progress indicator that ranges from 0 to 100. There is no requirement that this be linear or support any granularity of operations. This should not be used to guess when the operation will be complete. This number should monotonically increase as the operation progresses. Corresponds to the JSON property progress

Returns:

  • (Fixnum)


6971
6972
6973
# File 'generated/google/apis/compute_beta/classes.rb', line 6971

def progress
  @progress
end

#regionString

[Output Only] The URL of the region where the operation resides. Only available when performing regional operations. Corresponds to the JSON property region

Returns:

  • (String)


6977
6978
6979
# File 'generated/google/apis/compute_beta/classes.rb', line 6977

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


6982
6983
6984
# File 'generated/google/apis/compute_beta/classes.rb', line 6982

def self_link
  @self_link
end

#start_timeString

[Output Only] The time that this operation was started by the server. This value is in RFC3339 text format. Corresponds to the JSON property startTime

Returns:

  • (String)


6988
6989
6990
# File 'generated/google/apis/compute_beta/classes.rb', line 6988

def start_time
  @start_time
end

#statusString

[Output Only] The status of the operation, which can be one of the following: PENDING, RUNNING, or DONE. Corresponds to the JSON property status

Returns:

  • (String)


6994
6995
6996
# File 'generated/google/apis/compute_beta/classes.rb', line 6994

def status
  @status
end

#status_messageString

[Output Only] An optional textual description of the current status of the operation. Corresponds to the JSON property statusMessage

Returns:

  • (String)


7000
7001
7002
# File 'generated/google/apis/compute_beta/classes.rb', line 7000

def status_message
  @status_message
end

#target_idString

[Output Only] The unique target ID, which identifies a specific incarnation of the target resource. Corresponds to the JSON property targetId

Returns:

  • (String)


7006
7007
7008
# File 'generated/google/apis/compute_beta/classes.rb', line 7006

def target_id
  @target_id
end

[Output Only] The URL of the resource that the operation modifies. For operations related to creating a snapshot, this points to the persistent disk that the snapshot was created from. Corresponds to the JSON property targetLink

Returns:

  • (String)


7013
7014
7015
# File 'generated/google/apis/compute_beta/classes.rb', line 7013

def target_link
  @target_link
end

#userString

[Output Only] User who requested the operation, for example: [email protected]. Corresponds to the JSON property user

Returns:

  • (String)


7018
7019
7020
# File 'generated/google/apis/compute_beta/classes.rb', line 7018

def user
  @user
end

#warningsArray<Google::Apis::ComputeBeta::Operation::Warning>

[Output Only] If warning messages are generated during processing of the operation, this field will be populated. Corresponds to the JSON property warnings



7024
7025
7026
# File 'generated/google/apis/compute_beta/classes.rb', line 7024

def warnings
  @warnings
end

#zoneString

[Output Only] The URL of the zone where the operation resides. Only available when performing per-zone operations. Corresponds to the JSON property zone

Returns:

  • (String)


7030
7031
7032
# File 'generated/google/apis/compute_beta/classes.rb', line 7030

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7037
7038
7039
7040
7041
7042
7043
7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
7061
# File 'generated/google/apis/compute_beta/classes.rb', line 7037

def update!(**args)
  @client_operation_id = args[:client_operation_id] if args.key?(:client_operation_id)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @http_error_message = args[:http_error_message] if args.key?(:http_error_message)
  @http_error_status_code = args[:http_error_status_code] if args.key?(:http_error_status_code)
  @id = args[:id] if args.key?(:id)
  @insert_time = args[:insert_time] if args.key?(:insert_time)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @operation_type = args[:operation_type] if args.key?(:operation_type)
  @progress = args[:progress] if args.key?(:progress)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @start_time = args[:start_time] if args.key?(:start_time)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target_id = args[:target_id] if args.key?(:target_id)
  @target_link = args[:target_link] if args.key?(:target_link)
  @user = args[:user] if args.key?(:user)
  @warnings = args[:warnings] if args.key?(:warnings)
  @zone = args[:zone] if args.key?(:zone)
end