Class: Google::Apis::ComputeBeta::OperationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ OperationAggregatedList

Returns a new instance of OperationAggregatedList.



7215
7216
7217
# File 'generated/google/apis/compute_beta/classes.rb', line 7215

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:



7188
7189
7190
# File 'generated/google/apis/compute_beta/classes.rb', line 7188

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::OperationsScopedList>

[Output Only] A map of scoped operation lists. Corresponds to the JSON property items

Returns:



7193
7194
7195
# File 'generated/google/apis/compute_beta/classes.rb', line 7193

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#operationAggregatedList for aggregated lists of operations. Corresponds to the JSON property kind

Returns:



7199
7200
7201
# File 'generated/google/apis/compute_beta/classes.rb', line 7199

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:



7208
7209
7210
# File 'generated/google/apis/compute_beta/classes.rb', line 7208

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:



7213
7214
7215
# File 'generated/google/apis/compute_beta/classes.rb', line 7213

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7220
7221
7222
7223
7224
7225
7226
# File 'generated/google/apis/compute_beta/classes.rb', line 7220

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end