Class: Google::Apis::ComputeBeta::Project

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

A Project resource. Projects can only be created in the Google Cloud Platform Console. Unless marked otherwise, values can only be modified in the console.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ Project

Returns a new instance of Project.



7597
7598
7599
# File 'generated/google/apis/compute_beta/classes.rb', line 7597

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#common_instance_metadataGoogle::Apis::ComputeBeta::Metadata

A metadata key/value entry. Corresponds to the JSON property commonInstanceMetadata



7535
7536
7537
# File 'generated/google/apis/compute_beta/classes.rb', line 7535

def 
  @common_instance_metadata
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


7540
7541
7542
# File 'generated/google/apis/compute_beta/classes.rb', line 7540

def creation_timestamp
  @creation_timestamp
end

#default_service_accountString

[Output Only] Default service account used by VMs running in this project. Corresponds to the JSON property defaultServiceAccount

Returns:

  • (String)


7545
7546
7547
# File 'generated/google/apis/compute_beta/classes.rb', line 7545

def 
  @default_service_account
end

#descriptionString

An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


7550
7551
7552
# File 'generated/google/apis/compute_beta/classes.rb', line 7550

def description
  @description
end

#enabled_featuresArray<String>

Restricted features enabled for use on this project. Corresponds to the JSON property enabledFeatures

Returns:

  • (Array<String>)


7555
7556
7557
# File 'generated/google/apis/compute_beta/classes.rb', line 7555

def enabled_features
  @enabled_features
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. This is not the project ID, and is just a unique ID used by Compute Engine to identify resources. Corresponds to the JSON property id

Returns:

  • (String)


7562
7563
7564
# File 'generated/google/apis/compute_beta/classes.rb', line 7562

def id
  @id
end

#kindString

[Output Only] Type of the resource. Always compute#project for projects. Corresponds to the JSON property kind

Returns:

  • (String)


7567
7568
7569
# File 'generated/google/apis/compute_beta/classes.rb', line 7567

def kind
  @kind
end

#nameString

The project ID. For example: my-example-project. Use the project ID to make requests to Compute Engine. Corresponds to the JSON property name

Returns:

  • (String)


7573
7574
7575
# File 'generated/google/apis/compute_beta/classes.rb', line 7573

def name
  @name
end

#quotasArray<Google::Apis::ComputeBeta::Quota>

[Output Only] Quotas assigned to this project. Corresponds to the JSON property quotas



7578
7579
7580
# File 'generated/google/apis/compute_beta/classes.rb', line 7578

def quotas
  @quotas
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


7583
7584
7585
# File 'generated/google/apis/compute_beta/classes.rb', line 7583

def self_link
  @self_link
end

#usage_export_locationGoogle::Apis::ComputeBeta::UsageExportLocation

The location in Cloud Storage and naming method of the daily usage report. Contains bucket_name and report_name prefix. Corresponds to the JSON property usageExportLocation



7589
7590
7591
# File 'generated/google/apis/compute_beta/classes.rb', line 7589

def usage_export_location
  @usage_export_location
end

#xpn_project_statusString

[Output Only] The role this project has in a Cross Project Network (XPN) configuration. Currently only HOST projects are differentiated. Corresponds to the JSON property xpnProjectStatus

Returns:

  • (String)


7595
7596
7597
# File 'generated/google/apis/compute_beta/classes.rb', line 7595

def xpn_project_status
  @xpn_project_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
# File 'generated/google/apis/compute_beta/classes.rb', line 7602

def update!(**args)
  @common_instance_metadata = args[:common_instance_metadata] if args.key?(:common_instance_metadata)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_service_account = args[:default_service_account] if args.key?(:default_service_account)
  @description = args[:description] if args.key?(:description)
  @enabled_features = args[:enabled_features] if args.key?(:enabled_features)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @quotas = args[:quotas] if args.key?(:quotas)
  @self_link = args[:self_link] if args.key?(:self_link)
  @usage_export_location = args[:usage_export_location] if args.key?(:usage_export_location)
  @xpn_project_status = args[:xpn_project_status] if args.key?(:xpn_project_status)
end