Class: Google::Apis::ComputeBeta::ProjectsListXpnHostsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ ProjectsListXpnHostsRequest

Returns a new instance of ProjectsListXpnHostsRequest.



7629
7630
7631
# File 'generated/google/apis/compute_beta/classes.rb', line 7629

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#organizationString

Optional organization ID managed by Cloud Resource Manager, for which to list XPN host projects. If not specified, the organization will be inferred from the project. Corresponds to the JSON property organization

Returns:

  • (String)


7627
7628
7629
# File 'generated/google/apis/compute_beta/classes.rb', line 7627

def organization
  @organization
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7634
7635
7636
# File 'generated/google/apis/compute_beta/classes.rb', line 7634

def update!(**args)
  @organization = args[:organization] if args.key?(:organization)
end