Class: Google::Apis::ComputeBeta::Region
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Region
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Region resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] Textual description of the resource.
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#quotas ⇒ Array<Google::Apis::ComputeBeta::Quota>
[Output Only] Quotas assigned to this region.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ String
[Output Only] Status of the region, either UP or DOWN.
-
#zones ⇒ Array<String>
[Output Only] A list of zones available in this region, in the form of resource URLs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Region
constructor
A new instance of Region.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ Region
Returns a new instance of Region.
7726 7727 7728 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7726 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
7677 7678 7679 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7677 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
7682 7683 7684 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7682 def deprecated @deprecated end |
#description ⇒ String
[Output Only] Textual description of the resource.
Corresponds to the JSON property description
7687 7688 7689 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7687 def description @description end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
7693 7694 7695 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7693 def id @id end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#region for regions.
Corresponds to the JSON property kind
7698 7699 7700 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7698 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
7703 7704 7705 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7703 def name @name end |
#quotas ⇒ Array<Google::Apis::ComputeBeta::Quota>
[Output Only] Quotas assigned to this region.
Corresponds to the JSON property quotas
7708 7709 7710 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7708 def quotas @quotas end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
7713 7714 7715 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7713 def self_link @self_link end |
#status ⇒ String
[Output Only] Status of the region, either UP or DOWN.
Corresponds to the JSON property status
7718 7719 7720 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7718 def status @status end |
#zones ⇒ Array<String>
[Output Only] A list of zones available in this region, in the form of
resource URLs.
Corresponds to the JSON property zones
7724 7725 7726 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7724 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7731 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @quotas = args[:quotas] if args.key?(:quotas) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) @zones = args[:zones] if args.key?(:zones) end |