Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

Contains a list of managed instance groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerList



7869
7870
7871
# File 'generated/google/apis/compute_beta/classes.rb', line 7869

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id



7845
7846
7847
# File 'generated/google/apis/compute_beta/classes.rb', line 7845

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManager>

A list of managed instance groups. Corresponds to the JSON property items



7850
7851
7852
# File 'generated/google/apis/compute_beta/classes.rb', line 7850

def items
  @items
end

#kindString

[Output Only] The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups that exist in th regional scope. Corresponds to the JSON property kind



7857
7858
7859
# File 'generated/google/apis/compute_beta/classes.rb', line 7857

def kind
  @kind
end

#next_page_tokenString

[Output only] A token used to continue a truncated list request. Corresponds to the JSON property nextPageToken



7862
7863
7864
# File 'generated/google/apis/compute_beta/classes.rb', line 7862

def next_page_token
  @next_page_token
end

[Output only] The URL for this resource type. The server generates this URL. Corresponds to the JSON property selfLink



7867
7868
7869
# File 'generated/google/apis/compute_beta/classes.rb', line 7867

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7874
7875
7876
7877
7878
7879
7880
# File 'generated/google/apis/compute_beta/classes.rb', line 7874

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end