Class: Google::Apis::ComputeBeta::RegionInstanceGroupsListInstances
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RegionInstanceGroupsListInstances
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceWithNamedPorts>
A list of instances and any named ports that are assigned to those instances.
-
#kind ⇒ String
The resource type.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupsListInstances
constructor
A new instance of RegionInstanceGroupsListInstances.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupsListInstances
Returns a new instance of RegionInstanceGroupsListInstances.
8060 8061 8062 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8060 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource. Defined by the server.
Corresponds to the JSON property id
8034 8035 8036 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8034 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceWithNamedPorts>
A list of instances and any named ports that are assigned to those instances.
Corresponds to the JSON property items
8039 8040 8041 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8039 def items @items end |
#kind ⇒ String
The resource type.
Corresponds to the JSON property kind
8044 8045 8046 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8044 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
8053 8054 8055 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8053 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
8058 8059 8060 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8058 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8065 8066 8067 8068 8069 8070 8071 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8065 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |