Class: Google::Apis::ComputeBeta::Route

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

Represents a Route resource. A route specifies how certain packets should be handled by the network. Routes are associated with instances by tags and the set of routes for a particular instance is called its routing table. For each packet leaving a instance, the system searches that instance's routing table for a single best matching route. Routes match packets by destination IP address, preferring smaller or more specific ranges over larger ones. If there is a tie, the system selects the route with the smallest priority value. If there is still a tie, it uses the layer three and four packet headers to select just one of the remaining matching routes. The packet is then forwarded as specified by the nextHop field of the winning route - either to another instance destination, a instance gateway or a Google Compute Engine-operated gateway. Packets that do not match any route in the sending instance's routing table are dropped.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ Route

Returns a new instance of Route.



8313
8314
8315
# File 'generated/google/apis/compute_beta/classes.rb', line 8313

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


8219
8220
8221
# File 'generated/google/apis/compute_beta/classes.rb', line 8219

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


8225
8226
8227
# File 'generated/google/apis/compute_beta/classes.rb', line 8225

def description
  @description
end

#dest_rangeString

The destination range of outgoing packets that this route applies to. Only IPv4 is supported. Corresponds to the JSON property destRange

Returns:

  • (String)


8231
8232
8233
# File 'generated/google/apis/compute_beta/classes.rb', line 8231

def dest_range
  @dest_range
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


8237
8238
8239
# File 'generated/google/apis/compute_beta/classes.rb', line 8237

def id
  @id
end

#kindString

[Output Only] Type of this resource. Always compute#routes for Route resources. Corresponds to the JSON property kind

Returns:

  • (String)


8242
8243
8244
# File 'generated/google/apis/compute_beta/classes.rb', line 8242

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


8252
8253
8254
# File 'generated/google/apis/compute_beta/classes.rb', line 8252

def name
  @name
end

#networkString

Fully-qualified URL of the network that this route applies to. Corresponds to the JSON property network

Returns:

  • (String)


8257
8258
8259
# File 'generated/google/apis/compute_beta/classes.rb', line 8257

def network
  @network
end

#next_hop_gatewayString

The URL to a gateway that should handle matching packets. You can only specify the internet gateway using a full or partial valid URL: projects// global/gateways/default-internet-gateway Corresponds to the JSON property nextHopGateway

Returns:

  • (String)


8264
8265
8266
# File 'generated/google/apis/compute_beta/classes.rb', line 8264

def next_hop_gateway
  @next_hop_gateway
end

#next_hop_instanceString

The URL to an instance that should handle matching packets. You can specify this as a full or partial URL. For example: https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/ Corresponds to the JSON property nextHopInstance

Returns:

  • (String)


8271
8272
8273
# File 'generated/google/apis/compute_beta/classes.rb', line 8271

def next_hop_instance
  @next_hop_instance
end

#next_hop_ipString

The network IP address of an instance that should handle matching packets. Only IPv4 is supported. Corresponds to the JSON property nextHopIp

Returns:

  • (String)


8277
8278
8279
# File 'generated/google/apis/compute_beta/classes.rb', line 8277

def next_hop_ip
  @next_hop_ip
end

#next_hop_networkString

The URL of the local network if it should handle matching packets. Corresponds to the JSON property nextHopNetwork

Returns:

  • (String)


8282
8283
8284
# File 'generated/google/apis/compute_beta/classes.rb', line 8282

def next_hop_network
  @next_hop_network
end

#next_hop_vpn_tunnelString

The URL to a VpnTunnel that should handle matching packets. Corresponds to the JSON property nextHopVpnTunnel

Returns:

  • (String)


8287
8288
8289
# File 'generated/google/apis/compute_beta/classes.rb', line 8287

def next_hop_vpn_tunnel
  @next_hop_vpn_tunnel
end

#priorityFixnum

The priority of this route. Priority is used to break ties in cases where there is more than one matching route of equal prefix length. In the case of two routes with equal prefix length, the one with the lowest-numbered priority value wins. Default value is 1000. Valid range is 0 through 65535. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


8295
8296
8297
# File 'generated/google/apis/compute_beta/classes.rb', line 8295

def priority
  @priority
end

[Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8300
8301
8302
# File 'generated/google/apis/compute_beta/classes.rb', line 8300

def self_link
  @self_link
end

#tagsArray<String>

A list of instance tags to which this route applies. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


8305
8306
8307
# File 'generated/google/apis/compute_beta/classes.rb', line 8305

def tags
  @tags
end

#warningsArray<Google::Apis::ComputeBeta::Route::Warning>

[Output Only] If potential misconfigurations are detected for this route, this field will be populated with warning messages. Corresponds to the JSON property warnings



8311
8312
8313
# File 'generated/google/apis/compute_beta/classes.rb', line 8311

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8318
8319
8320
8321
8322
8323
8324
8325
8326
8327
8328
8329
8330
8331
8332
8333
8334
8335
# File 'generated/google/apis/compute_beta/classes.rb', line 8318

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @dest_range = args[:dest_range] if args.key?(:dest_range)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @next_hop_gateway = args[:next_hop_gateway] if args.key?(:next_hop_gateway)
  @next_hop_instance = args[:next_hop_instance] if args.key?(:next_hop_instance)
  @next_hop_ip = args[:next_hop_ip] if args.key?(:next_hop_ip)
  @next_hop_network = args[:next_hop_network] if args.key?(:next_hop_network)
  @next_hop_vpn_tunnel = args[:next_hop_vpn_tunnel] if args.key?(:next_hop_vpn_tunnel)
  @priority = args[:priority] if args.key?(:priority)
  @self_link = args[:self_link] if args.key?(:self_link)
  @tags = args[:tags] if args.key?(:tags)
  @warnings = args[:warnings] if args.key?(:warnings)
end