Class: Google::Apis::ComputeBeta::RouteList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouteList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Contains a list of Route resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Route>
[Output Only] A list of Route resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouteList
constructor
A new instance of RouteList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ RouteList
Returns a new instance of RouteList.
8435 8436 8437 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8435 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource. Defined by the server.
Corresponds to the JSON property id
8409 8410 8411 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8409 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Route>
[Output Only] A list of Route resources.
Corresponds to the JSON property items
8414 8415 8416 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8414 def items @items end |
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
8419 8420 8421 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8419 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
8428 8429 8430 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8428 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
8433 8434 8435 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8433 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8440 8441 8442 8443 8444 8445 8446 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8440 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |