Class: Google::Apis::ComputeBeta::RouterBgpPeer

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ RouterBgpPeer

Returns a new instance of RouterBgpPeer.



8646
8647
8648
# File 'generated/google/apis/compute_beta/classes.rb', line 8646

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertised_route_priorityFixnum

The priority of routes advertised to this BGP peer. In the case where there is more than one matching route of maximum length, the routes with lowest priority value win. Corresponds to the JSON property advertisedRoutePriority

Returns:

  • (Fixnum)


8616
8617
8618
# File 'generated/google/apis/compute_beta/classes.rb', line 8616

def advertised_route_priority
  @advertised_route_priority
end

#interface_nameString

Name of the interface the BGP peer is associated with. Corresponds to the JSON property interfaceName

Returns:

  • (String)


8621
8622
8623
# File 'generated/google/apis/compute_beta/classes.rb', line 8621

def interface_name
  @interface_name
end

#ip_addressString

IP address of the interface inside Google Cloud Platform. Only IPv4 is supported. Corresponds to the JSON property ipAddress

Returns:

  • (String)


8627
8628
8629
# File 'generated/google/apis/compute_beta/classes.rb', line 8627

def ip_address
  @ip_address
end

#nameString

Name of this BGP peer. The name must be 1-63 characters long and comply with RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


8633
8634
8635
# File 'generated/google/apis/compute_beta/classes.rb', line 8633

def name
  @name
end

#peer_asnFixnum

Peer BGP Autonomous System Number (ASN). For VPN use case, this value can be different for every tunnel. Corresponds to the JSON property peerAsn

Returns:

  • (Fixnum)


8639
8640
8641
# File 'generated/google/apis/compute_beta/classes.rb', line 8639

def peer_asn
  @peer_asn
end

#peer_ip_addressString

IP address of the BGP interface outside Google cloud. Only IPv4 is supported. Corresponds to the JSON property peerIpAddress

Returns:

  • (String)


8644
8645
8646
# File 'generated/google/apis/compute_beta/classes.rb', line 8644

def peer_ip_address
  @peer_ip_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8651
8652
8653
8654
8655
8656
8657
8658
# File 'generated/google/apis/compute_beta/classes.rb', line 8651

def update!(**args)
  @advertised_route_priority = args[:advertised_route_priority] if args.key?(:advertised_route_priority)
  @interface_name = args[:interface_name] if args.key?(:interface_name)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @name = args[:name] if args.key?(:name)
  @peer_asn = args[:peer_asn] if args.key?(:peer_asn)
  @peer_ip_address = args[:peer_ip_address] if args.key?(:peer_ip_address)
end