Class: Google::Apis::ComputeBeta::RouterInterface

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ RouterInterface

Returns a new instance of RouterInterface.



8685
8686
8687
# File 'generated/google/apis/compute_beta/classes.rb', line 8685

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_rangeString

IP address and range of the interface. The IP range must be in the RFC3927 link-local IP space. The value must be a CIDR-formatted string, for example: 169.254.0.1/30. NOTE: Do not truncate the address as it represents the IP address of the interface. Corresponds to the JSON property ipRange

Returns:

  • (String)


8671
8672
8673
# File 'generated/google/apis/compute_beta/classes.rb', line 8671

def ip_range
  @ip_range
end

#linked_vpn_tunnelString

URI of linked VPN tunnel. It must be in the same region as the router. Each interface can have at most one linked resource. Corresponds to the JSON property linkedVpnTunnel

Returns:

  • (String)


8677
8678
8679
# File 'generated/google/apis/compute_beta/classes.rb', line 8677

def linked_vpn_tunnel
  @linked_vpn_tunnel
end

#nameString

Name of this interface entry. The name must be 1-63 characters long and comply with RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


8683
8684
8685
# File 'generated/google/apis/compute_beta/classes.rb', line 8683

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8690
8691
8692
8693
8694
# File 'generated/google/apis/compute_beta/classes.rb', line 8690

def update!(**args)
  @ip_range = args[:ip_range] if args.key?(:ip_range)
  @linked_vpn_tunnel = args[:linked_vpn_tunnel] if args.key?(:linked_vpn_tunnel)
  @name = args[:name] if args.key?(:name)
end