Class: Google::Apis::ComputeBeta::RouterList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Contains a list of Router resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Router>
A list of Router resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterList
constructor
A new instance of RouterList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ RouterList
Returns a new instance of RouterList.
8731 8732 8733 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8731 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
8705 8706 8707 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8705 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Router>
A list of Router resources.
Corresponds to the JSON property items
8710 8711 8712 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8710 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#router for routers.
Corresponds to the JSON property kind
8715 8716 8717 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8715 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
8724 8725 8726 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8724 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
8729 8730 8731 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8729 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8736 8737 8738 8739 8740 8741 8742 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8736 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |