Class: Google::Apis::ComputeBeta::Scheduling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

Sets the scheduling options for an Instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ Scheduling

Returns a new instance of Scheduling.



9122
9123
9124
# File 'generated/google/apis/compute_beta/classes.rb', line 9122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automatic_restartBoolean Also known as: automatic_restart?

Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user). You can only set the automatic restart option for standard instances. Preemptible instances cannot be automatically restarted. Corresponds to the JSON property automaticRestart

Returns:

  • (Boolean)


9105
9106
9107
# File 'generated/google/apis/compute_beta/classes.rb', line 9105

def automatic_restart
  @automatic_restart
end

#on_host_maintenanceString

Defines the maintenance behavior for this instance. For standard instances, the default behavior is MIGRATE. For preemptible instances, the default and only possible behavior is TERMINATE. For more information, see Setting Instance Scheduling Options. Corresponds to the JSON property onHostMaintenance

Returns:

  • (String)


9114
9115
9116
# File 'generated/google/apis/compute_beta/classes.rb', line 9114

def on_host_maintenance
  @on_host_maintenance
end

#preemptibleBoolean Also known as: preemptible?

Whether the instance is preemptible. Corresponds to the JSON property preemptible

Returns:

  • (Boolean)


9119
9120
9121
# File 'generated/google/apis/compute_beta/classes.rb', line 9119

def preemptible
  @preemptible
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9127
9128
9129
9130
9131
# File 'generated/google/apis/compute_beta/classes.rb', line 9127

def update!(**args)
  @automatic_restart = args[:automatic_restart] if args.key?(:automatic_restart)
  @on_host_maintenance = args[:on_host_maintenance] if args.key?(:on_host_maintenance)
  @preemptible = args[:preemptible] if args.key?(:preemptible)
end