Class: Google::Apis::ComputeBeta::SerialPortOutput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

An instance's serial console output.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ SerialPortOutput

Returns a new instance of SerialPortOutput.



9168
9169
9170
# File 'generated/google/apis/compute_beta/classes.rb', line 9168

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsString

[Output Only] The contents of the console output. Corresponds to the JSON property contents

Returns:

  • (String)


9141
9142
9143
# File 'generated/google/apis/compute_beta/classes.rb', line 9141

def contents
  @contents
end

#kindString

[Output Only] Type of the resource. Always compute#serialPortOutput for serial port output. Corresponds to the JSON property kind

Returns:

  • (String)


9147
9148
9149
# File 'generated/google/apis/compute_beta/classes.rb', line 9147

def kind
  @kind
end

#nextString

[Output Only] The position of the next byte of content from the serial console output. Use this value in the next request as the start parameter. Corresponds to the JSON property next

Returns:

  • (String)


9153
9154
9155
# File 'generated/google/apis/compute_beta/classes.rb', line 9153

def next
  @next
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9158
9159
9160
# File 'generated/google/apis/compute_beta/classes.rb', line 9158

def self_link
  @self_link
end

#startString

[Output Only] The starting byte position of the output that was returned. This should match the start parameter sent with the request. If the serial console output exceeds the size of the buffer, older output will be overwritten by newer content and the start values will be mismatched. Corresponds to the JSON property start

Returns:

  • (String)


9166
9167
9168
# File 'generated/google/apis/compute_beta/classes.rb', line 9166

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9173
9174
9175
9176
9177
9178
9179
# File 'generated/google/apis/compute_beta/classes.rb', line 9173

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @kind = args[:kind] if args.key?(:kind)
  @next = args[:next] if args.key?(:next)
  @self_link = args[:self_link] if args.key?(:self_link)
  @start = args[:start] if args.key?(:start)
end