Class: Google::Apis::ComputeBeta::SnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

Contains a list of Snapshot resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ SnapshotList

Returns a new instance of SnapshotList.



9381
9382
9383
# File 'generated/google/apis/compute_beta/classes.rb', line 9381

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9355
9356
9357
# File 'generated/google/apis/compute_beta/classes.rb', line 9355

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Snapshot>

[Output Only] A list of Snapshot resources. Corresponds to the JSON property items



9360
9361
9362
# File 'generated/google/apis/compute_beta/classes.rb', line 9360

def items
  @items
end

#kindString

Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


9365
9366
9367
# File 'generated/google/apis/compute_beta/classes.rb', line 9365

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9374
9375
9376
# File 'generated/google/apis/compute_beta/classes.rb', line 9374

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9379
9380
9381
# File 'generated/google/apis/compute_beta/classes.rb', line 9379

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9386
9387
9388
9389
9390
9391
9392
# File 'generated/google/apis/compute_beta/classes.rb', line 9386

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end