Class: Google::Apis::ComputeBeta::SslHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ SslHealthCheck



9081
9082
9083
# File 'generated/google/apis/compute_beta/classes.rb', line 9081

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#portFixnum

The TCP port number for the health check request. The default value is 443. Corresponds to the JSON property port



9052
9053
9054
# File 'generated/google/apis/compute_beta/classes.rb', line 9052

def port
  @port
end

#port_nameString

Port name as defined in InstanceGroup#NamedPort#name. If both port and port_name are defined, port takes precedence. Corresponds to the JSON property portName



9058
9059
9060
# File 'generated/google/apis/compute_beta/classes.rb', line 9058

def port_name
  @port_name
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader



9064
9065
9066
# File 'generated/google/apis/compute_beta/classes.rb', line 9064

def proxy_header
  @proxy_header
end

#requestString

The application data to send once the SSL connection has been established ( default value is empty). If both request and response are empty, the connection establishment alone will indicate health. The request data can only be ASCII. Corresponds to the JSON property request



9072
9073
9074
# File 'generated/google/apis/compute_beta/classes.rb', line 9072

def request
  @request
end

#responseString

The bytes to match against the beginning of the response data. If left empty ( the default value), any response will indicate health. The response data can only be ASCII. Corresponds to the JSON property response



9079
9080
9081
# File 'generated/google/apis/compute_beta/classes.rb', line 9079

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9086
9087
9088
9089
9090
9091
9092
# File 'generated/google/apis/compute_beta/classes.rb', line 9086

def update!(**args)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @request = args[:request] if args.key?(:request)
  @response = args[:response] if args.key?(:response)
end