Class: Google::Apis::ComputeBeta::Subnetwork

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

A Subnetwork resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ Subnetwork

Returns a new instance of Subnetwork.



9584
9585
9586
# File 'generated/google/apis/compute_beta/classes.rb', line 9584

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


9523
9524
9525
# File 'generated/google/apis/compute_beta/classes.rb', line 9523

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


9529
9530
9531
# File 'generated/google/apis/compute_beta/classes.rb', line 9529

def description
  @description
end

#gateway_addressString

[Output Only] The gateway address for default routes to reach destination addresses outside this subnetwork. Corresponds to the JSON property gatewayAddress

Returns:

  • (String)


9535
9536
9537
# File 'generated/google/apis/compute_beta/classes.rb', line 9535

def gateway_address
  @gateway_address
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9541
9542
9543
# File 'generated/google/apis/compute_beta/classes.rb', line 9541

def id
  @id
end

#ip_cidr_rangeString

The range of internal addresses that are owned by this subnetwork. Provide this property when you create the subnetwork. For example, 10.0.0.0/8 or 192. 168.0.0/16. Ranges must be unique and non-overlapping within a network. Only IPv4 is supported. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


9549
9550
9551
# File 'generated/google/apis/compute_beta/classes.rb', line 9549

def ip_cidr_range
  @ip_cidr_range
end

#kindString

[Output Only] Type of the resource. Always compute#subnetwork for Subnetwork resources. Corresponds to the JSON property kind

Returns:

  • (String)


9555
9556
9557
# File 'generated/google/apis/compute_beta/classes.rb', line 9555

def kind
  @kind
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


9565
9566
9567
# File 'generated/google/apis/compute_beta/classes.rb', line 9565

def name
  @name
end

#networkString

The URL of the network to which this subnetwork belongs, provided by the client when initially creating the subnetwork. Only networks that are in the distributed mode can have subnetworks. Corresponds to the JSON property network

Returns:

  • (String)


9572
9573
9574
# File 'generated/google/apis/compute_beta/classes.rb', line 9572

def network
  @network
end

#regionString

URL of the region where the Subnetwork resides. Corresponds to the JSON property region

Returns:

  • (String)


9577
9578
9579
# File 'generated/google/apis/compute_beta/classes.rb', line 9577

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9582
9583
9584
# File 'generated/google/apis/compute_beta/classes.rb', line 9582

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9589
9590
9591
9592
9593
9594
9595
9596
9597
9598
9599
9600
# File 'generated/google/apis/compute_beta/classes.rb', line 9589

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @gateway_address = args[:gateway_address] if args.key?(:gateway_address)
  @id = args[:id] if args.key?(:id)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
end