Class: Google::Apis::ComputeBeta::SubnetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

Contains a list of Subnetwork resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ SubnetworkList

Returns a new instance of SubnetworkList.



9687
9688
9689
# File 'generated/google/apis/compute_beta/classes.rb', line 9687

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9660
9661
9662
# File 'generated/google/apis/compute_beta/classes.rb', line 9660

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Subnetwork>

The Subnetwork resources. Corresponds to the JSON property items



9665
9666
9667
# File 'generated/google/apis/compute_beta/classes.rb', line 9665

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#subnetworkList for lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


9671
9672
9673
# File 'generated/google/apis/compute_beta/classes.rb', line 9671

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9680
9681
9682
# File 'generated/google/apis/compute_beta/classes.rb', line 9680

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9685
9686
9687
# File 'generated/google/apis/compute_beta/classes.rb', line 9685

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9692
9693
9694
9695
9696
9697
9698
# File 'generated/google/apis/compute_beta/classes.rb', line 9692

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end