Class: Google::Apis::ComputeBeta::TargetHttpProxy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetHttpProxy
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
A TargetHttpProxy resource. This resource defines an HTTP proxy.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#name ⇒ String
Name of the resource.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#url_map ⇒ String
URL to the UrlMap resource that defines the mapping from URL to the BackendService.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpProxy
constructor
A new instance of TargetHttpProxy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ TargetHttpProxy
Returns a new instance of TargetHttpProxy.
9941 9942 9943 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9941 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
9900 9901 9902 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9900 def end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
9906 9907 9908 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9906 def description @description end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
9912 9913 9914 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9912 def id @id end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#targetHttpProxy for target HTTP
proxies.
Corresponds to the JSON property kind
9918 9919 9920 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9918 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
9928 9929 9930 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9928 def name @name end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
9933 9934 9935 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9933 def self_link @self_link end |
#url_map ⇒ String
URL to the UrlMap resource that defines the mapping from URL to the
BackendService.
Corresponds to the JSON property urlMap
9939 9940 9941 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9939 def url_map @url_map end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9946 9947 9948 9949 9950 9951 9952 9953 9954 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9946 def update!(**args) = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @url_map = args[:url_map] if args.key?(:url_map) end |