Class: Google::Apis::ComputeBeta::TargetHttpsProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetHttpsProxyList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Contains a list of TargetHttpsProxy resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetHttpsProxy>
A list of TargetHttpsProxy resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpsProxyList
constructor
A new instance of TargetHttpsProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ TargetHttpsProxyList
Returns a new instance of TargetHttpsProxyList.
10137 10138 10139 |
# File 'generated/google/apis/compute_beta/classes.rb', line 10137 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
10110 10111 10112 |
# File 'generated/google/apis/compute_beta/classes.rb', line 10110 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetHttpsProxy>
A list of TargetHttpsProxy resources.
Corresponds to the JSON property items
10115 10116 10117 |
# File 'generated/google/apis/compute_beta/classes.rb', line 10115 def items @items end |
#kind ⇒ String
Type of resource. Always compute#targetHttpsProxyList for lists of target
HTTPS proxies.
Corresponds to the JSON property kind
10121 10122 10123 |
# File 'generated/google/apis/compute_beta/classes.rb', line 10121 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
10130 10131 10132 |
# File 'generated/google/apis/compute_beta/classes.rb', line 10130 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
10135 10136 10137 |
# File 'generated/google/apis/compute_beta/classes.rb', line 10135 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10142 10143 10144 10145 10146 10147 10148 |
# File 'generated/google/apis/compute_beta/classes.rb', line 10142 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |