Class: Google::Apis::ComputeBeta::TargetPoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ TargetPoolAggregatedList

Returns a new instance of TargetPoolAggregatedList.



10577
10578
10579
# File 'generated/google/apis/compute_beta/classes.rb', line 10577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource. Defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


10550
10551
10552
# File 'generated/google/apis/compute_beta/classes.rb', line 10550

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetPoolsScopedList>

[Output Only] A map of scoped target pool lists. Corresponds to the JSON property items



10555
10556
10557
# File 'generated/google/apis/compute_beta/classes.rb', line 10555

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#targetPoolAggregatedList for aggregated lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


10561
10562
10563
# File 'generated/google/apis/compute_beta/classes.rb', line 10561

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10570
10571
10572
# File 'generated/google/apis/compute_beta/classes.rb', line 10570

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10575
10576
10577
# File 'generated/google/apis/compute_beta/classes.rb', line 10575

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10582
10583
10584
10585
10586
10587
10588
# File 'generated/google/apis/compute_beta/classes.rb', line 10582

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end