Class: Google::Apis::ComputeBeta::TargetPoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetPoolList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Contains a list of TargetPool resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetPool>
A list of TargetPool resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPoolList
constructor
A new instance of TargetPoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ TargetPoolList
Returns a new instance of TargetPoolList.
10651 10652 10653 |
# File 'generated/google/apis/compute_beta/classes.rb', line 10651 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource. Defined by the server.
Corresponds to the JSON property id
10624 10625 10626 |
# File 'generated/google/apis/compute_beta/classes.rb', line 10624 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetPool>
A list of TargetPool resources.
Corresponds to the JSON property items
10629 10630 10631 |
# File 'generated/google/apis/compute_beta/classes.rb', line 10629 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#targetPoolList for lists of
target pools.
Corresponds to the JSON property kind
10635 10636 10637 |
# File 'generated/google/apis/compute_beta/classes.rb', line 10635 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
10644 10645 10646 |
# File 'generated/google/apis/compute_beta/classes.rb', line 10644 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
10649 10650 10651 |
# File 'generated/google/apis/compute_beta/classes.rb', line 10649 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10656 10657 10658 10659 10660 10661 10662 |
# File 'generated/google/apis/compute_beta/classes.rb', line 10656 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |