Class: Google::Apis::ComputeBeta::TargetVpnGateway

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb

Overview

Represents a Target VPN gateway resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ TargetVpnGateway



11116
11117
11118
# File 'generated/google/apis/compute_beta/classes.rb', line 11116

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp



11052
11053
11054
# File 'generated/google/apis/compute_beta/classes.rb', line 11052

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description



11058
11059
11060
# File 'generated/google/apis/compute_beta/classes.rb', line 11058

def description
  @description
end

#forwarding_rulesArray<String>

[Output Only] A list of URLs to the ForwardingRule resources. ForwardingRules are created using compute.forwardingRules.insert and associated to a VPN gateway. Corresponds to the JSON property forwardingRules



11065
11066
11067
# File 'generated/google/apis/compute_beta/classes.rb', line 11065

def forwarding_rules
  @forwarding_rules
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id



11071
11072
11073
# File 'generated/google/apis/compute_beta/classes.rb', line 11071

def id
  @id
end

#kindString

[Output Only] Type of resource. Always compute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind



11077
11078
11079
# File 'generated/google/apis/compute_beta/classes.rb', line 11077

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name



11087
11088
11089
# File 'generated/google/apis/compute_beta/classes.rb', line 11087

def name
  @name
end

#networkString

URL of the network to which this VPN gateway is attached. Provided by the client when the VPN gateway is created. Corresponds to the JSON property network



11093
11094
11095
# File 'generated/google/apis/compute_beta/classes.rb', line 11093

def network
  @network
end

#regionString

[Output Only] URL of the region where the target VPN gateway resides. Corresponds to the JSON property region



11098
11099
11100
# File 'generated/google/apis/compute_beta/classes.rb', line 11098

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink



11103
11104
11105
# File 'generated/google/apis/compute_beta/classes.rb', line 11103

def self_link
  @self_link
end

#statusString

[Output Only] The status of the VPN gateway. Corresponds to the JSON property status



11108
11109
11110
# File 'generated/google/apis/compute_beta/classes.rb', line 11108

def status
  @status
end

#tunnelsArray<String>

[Output Only] A list of URLs to VpnTunnel resources. VpnTunnels are created using compute.vpntunnels.insert method and associated to a VPN gateway. Corresponds to the JSON property tunnels



11114
11115
11116
# File 'generated/google/apis/compute_beta/classes.rb', line 11114

def tunnels
  @tunnels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11121
11122
11123
11124
11125
11126
11127
11128
11129
11130
11131
11132
11133
# File 'generated/google/apis/compute_beta/classes.rb', line 11121

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @status = args[:status] if args.key?(:status)
  @tunnels = args[:tunnels] if args.key?(:tunnels)
end