Class: Google::Apis::ComputeBeta::TargetVpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetVpnGatewayList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Contains a list of TargetVpnGateway resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetVpnGateway>
[Output Only] A list of TargetVpnGateway resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetVpnGatewayList
constructor
A new instance of TargetVpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ TargetVpnGatewayList
Returns a new instance of TargetVpnGatewayList.
11220 11221 11222 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11220 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
11193 11194 11195 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11193 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetVpnGateway>
[Output Only] A list of TargetVpnGateway resources.
Corresponds to the JSON property items
11198 11199 11200 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11198 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#targetVpnGateway for target VPN
gateways.
Corresponds to the JSON property kind
11204 11205 11206 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11204 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
11213 11214 11215 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11213 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
11218 11219 11220 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11218 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11225 11226 11227 11228 11229 11230 11231 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11225 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |