Class: Google::Apis::ComputeBeta::TcpHealthCheck
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TcpHealthCheck
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#port ⇒ Fixnum
The TCP port number for the health check request.
-
#port_name ⇒ String
Port name as defined in InstanceGroup#NamedPort#name.
-
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1.
-
#request ⇒ String
The application data to send once the TCP connection has been established ( default value is empty).
-
#response ⇒ String
The bytes to match against the beginning of the response data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TcpHealthCheck
constructor
A new instance of TcpHealthCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ TcpHealthCheck
Returns a new instance of TcpHealthCheck.
9848 9849 9850 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9848 def initialize(**args) update!(**args) end |
Instance Attribute Details
#port ⇒ Fixnum
The TCP port number for the health check request. The default value is 80.
Corresponds to the JSON property port
9819 9820 9821 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9819 def port @port end |
#port_name ⇒ String
Port name as defined in InstanceGroup#NamedPort#name. If both port and
port_name are defined, port takes precedence.
Corresponds to the JSON property portName
9825 9826 9827 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9825 def port_name @port_name end |
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the
backend, either NONE or PROXY_V1. The default is NONE.
Corresponds to the JSON property proxyHeader
9831 9832 9833 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9831 def proxy_header @proxy_header end |
#request ⇒ String
The application data to send once the TCP connection has been established (
default value is empty). If both request and response are empty, the
connection establishment alone will indicate health. The request data can only
be ASCII.
Corresponds to the JSON property request
9839 9840 9841 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9839 def request @request end |
#response ⇒ String
The bytes to match against the beginning of the response data. If left empty (
the default value), any response will indicate health. The response data can
only be ASCII.
Corresponds to the JSON property response
9846 9847 9848 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9846 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9853 9854 9855 9856 9857 9858 9859 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9853 def update!(**args) @port = args[:port] if args.key?(:port) @port_name = args[:port_name] if args.key?(:port_name) @proxy_header = args[:proxy_header] if args.key?(:proxy_header) @request = args[:request] if args.key?(:request) @response = args[:response] if args.key?(:response) end |