Class: Google::Apis::ComputeBeta::UdpHealthCheck
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UdpHealthCheck
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#port ⇒ Fixnum
The UDP port number for the health check request.
-
#port_name ⇒ String
Port name as defined in InstanceGroup#NamedPort#name.
-
#request ⇒ String
Raw data of request to send in payload of UDP packet.
-
#response ⇒ String
The bytes to match against the beginning of the response data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UdpHealthCheck
constructor
A new instance of UdpHealthCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ UdpHealthCheck
Returns a new instance of UdpHealthCheck.
11428 11429 11430 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11428 def initialize(**args) update!(**args) end |
Instance Attribute Details
#port ⇒ Fixnum
The UDP port number for the health check request.
Corresponds to the JSON property port
11408 11409 11410 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11408 def port @port end |
#port_name ⇒ String
Port name as defined in InstanceGroup#NamedPort#name. If both port and
port_name are defined, port takes precedence.
Corresponds to the JSON property portName
11414 11415 11416 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11414 def port_name @port_name end |
#request ⇒ String
Raw data of request to send in payload of UDP packet. It is an error if this
is empty. The request data can only be ASCII.
Corresponds to the JSON property request
11420 11421 11422 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11420 def request @request end |
#response ⇒ String
The bytes to match against the beginning of the response data. It is an error
if this is empty. The response data can only be ASCII.
Corresponds to the JSON property response
11426 11427 11428 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11426 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11433 11434 11435 11436 11437 11438 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11433 def update!(**args) @port = args[:port] if args.key?(:port) @port_name = args[:port_name] if args.key?(:port_name) @request = args[:request] if args.key?(:request) @response = args[:response] if args.key?(:response) end |