Class: Google::Apis::ComputeBeta::UrlMapList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UrlMapList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Contains a list of UrlMap resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::UrlMap>
A list of UrlMap resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapList
constructor
A new instance of UrlMapList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ UrlMapList
11566 11567 11568 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11566 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource. Set by the server.
Corresponds to the JSON property id
11540 11541 11542 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11540 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::UrlMap>
A list of UrlMap resources.
Corresponds to the JSON property items
11545 11546 11547 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11545 def items @items end |
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
11550 11551 11552 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11550 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
11559 11560 11561 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11559 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
11564 11565 11566 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11564 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11571 11572 11573 11574 11575 11576 11577 |
# File 'generated/google/apis/compute_beta/classes.rb', line 11571 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |