Class: Google::Apis::ComputeBeta::Zone
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Zone
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
A Zone resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] Textual description of the resource.
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#region ⇒ String
[Output Only] Full URL reference to the region which hosts the zone.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ String
[Output Only] Status of the zone, either UP or DOWN.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Zone
constructor
A new instance of Zone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ Zone
12166 12167 12168 |
# File 'generated/google/apis/compute_beta/classes.rb', line 12166 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
12123 12124 12125 |
# File 'generated/google/apis/compute_beta/classes.rb', line 12123 def end |
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
12128 12129 12130 |
# File 'generated/google/apis/compute_beta/classes.rb', line 12128 def deprecated @deprecated end |
#description ⇒ String
[Output Only] Textual description of the resource.
Corresponds to the JSON property description
12133 12134 12135 |
# File 'generated/google/apis/compute_beta/classes.rb', line 12133 def description @description end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
12139 12140 12141 |
# File 'generated/google/apis/compute_beta/classes.rb', line 12139 def id @id end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#zone for zones.
Corresponds to the JSON property kind
12144 12145 12146 |
# File 'generated/google/apis/compute_beta/classes.rb', line 12144 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
12149 12150 12151 |
# File 'generated/google/apis/compute_beta/classes.rb', line 12149 def name @name end |
#region ⇒ String
[Output Only] Full URL reference to the region which hosts the zone.
Corresponds to the JSON property region
12154 12155 12156 |
# File 'generated/google/apis/compute_beta/classes.rb', line 12154 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
12159 12160 12161 |
# File 'generated/google/apis/compute_beta/classes.rb', line 12159 def self_link @self_link end |
#status ⇒ String
[Output Only] Status of the zone, either UP or DOWN.
Corresponds to the JSON property status
12164 12165 12166 |
# File 'generated/google/apis/compute_beta/classes.rb', line 12164 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12171 12172 12173 12174 12175 12176 12177 12178 12179 12180 12181 |
# File 'generated/google/apis/compute_beta/classes.rb', line 12171 def update!(**args) = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) end |