Class: Google::Apis::ComputeBeta::ZoneSetLabelsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ZoneSetLabelsRequest
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#label_fingerprint ⇒ String
The fingerprint of the previous set of labels for this resource, used to detect conflicts.
-
#labels ⇒ Hash<String,String>
The labels to set for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ZoneSetLabelsRequest
constructor
A new instance of ZoneSetLabelsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ ZoneSetLabelsRequest
Returns a new instance of ZoneSetLabelsRequest.
12249 12250 12251 |
# File 'generated/google/apis/compute_beta/classes.rb', line 12249 def initialize(**args) update!(**args) end |
Instance Attribute Details
#label_fingerprint ⇒ String
The fingerprint of the previous set of labels for this resource, used to
detect conflicts. The fingerprint is initially generated by Compute Engine and
changes after every request to modify or update labels. You must always
provide an up-to-date fingerprint hash in order to update or change labels.
Make a get() request to the resource to get the latest fingerprint.
Corresponds to the JSON property labelFingerprint
12242 12243 12244 |
# File 'generated/google/apis/compute_beta/classes.rb', line 12242 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
The labels to set for this resource.
Corresponds to the JSON property labels
12247 12248 12249 |
# File 'generated/google/apis/compute_beta/classes.rb', line 12247 def labels @labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12254 12255 12256 12257 |
# File 'generated/google/apis/compute_beta/classes.rb', line 12254 def update!(**args) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) end |