Class: Google::Apis::ComputeV1::DiskTypeList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

Contains a list of disk types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ DiskTypeList

Returns a new instance of DiskTypeList.



2051
2052
2053
# File 'generated/google/apis/compute_v1/classes.rb', line 2051

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


2025
2026
2027
# File 'generated/google/apis/compute_v1/classes.rb', line 2025

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::DiskType>

[Output Only] A list of Disk Type resources. Corresponds to the JSON property items



2030
2031
2032
# File 'generated/google/apis/compute_v1/classes.rb', line 2030

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#diskTypeList for disk types. Corresponds to the JSON property kind

Returns:

  • (String)


2035
2036
2037
# File 'generated/google/apis/compute_v1/classes.rb', line 2035

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2044
2045
2046
# File 'generated/google/apis/compute_v1/classes.rb', line 2044

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2049
2050
2051
# File 'generated/google/apis/compute_v1/classes.rb', line 2049

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2056
2057
2058
2059
2060
2061
2062
# File 'generated/google/apis/compute_v1/classes.rb', line 2056

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end