Class: Google::Apis::ComputeV1::ForwardingRuleList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ForwardingRuleList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
Contains a list of ForwardingRule resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::ForwardingRule>
A list of ForwardingRule resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleList
constructor
A new instance of ForwardingRuleList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ ForwardingRuleList
Returns a new instance of ForwardingRuleList.
2698 2699 2700 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2698 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource. Set by the server.
Corresponds to the JSON property id
2672 2673 2674 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2672 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::ForwardingRule>
A list of ForwardingRule resources.
Corresponds to the JSON property items
2677 2678 2679 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2677 def items @items end |
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
2682 2683 2684 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2682 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
2691 2692 2693 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2691 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
2696 2697 2698 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2696 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2703 2704 2705 2706 2707 2708 2709 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2703 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |