Class: Google::Apis::ComputeV1::HostRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

UrlMaps A host-matching rule for a URL. If matched, will use the named PathMatcher to select the BackendService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ HostRule

Returns a new instance of HostRule.



3170
3171
3172
# File 'generated/google/apis/compute_v1/classes.rb', line 3170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


3155
3156
3157
# File 'generated/google/apis/compute_v1/classes.rb', line 3155

def description
  @description
end

#hostsArray<String>

The list of host patterns to match. They must be valid hostnames, except * will match any string of ([a-z0-9-.]*). In that case, * must be the first character and must be followed in the pattern by either - or .. Corresponds to the JSON property hosts

Returns:

  • (Array<String>)


3162
3163
3164
# File 'generated/google/apis/compute_v1/classes.rb', line 3162

def hosts
  @hosts
end

#path_matcherString

The name of the PathMatcher to use to match the path portion of the URL if the hostRule matches the URL's host portion. Corresponds to the JSON property pathMatcher

Returns:

  • (String)


3168
3169
3170
# File 'generated/google/apis/compute_v1/classes.rb', line 3168

def path_matcher
  @path_matcher
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3175
3176
3177
3178
3179
# File 'generated/google/apis/compute_v1/classes.rb', line 3175

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @hosts = args[:hosts] if args.key?(:hosts)
  @path_matcher = args[:path_matcher] if args.key?(:path_matcher)
end