Class: Google::Apis::ComputeV1::HttpHealthCheck
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::HttpHealthCheck
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
An HttpHealthCheck resource. This resource defines a template for how individual instances should be checked for health, via HTTP.
Instance Attribute Summary collapse
-
#check_interval_sec ⇒ Fixnum
How often (in seconds) to send a health check.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#healthy_threshold ⇒ Fixnum
A so-far unhealthy instance will be marked healthy after this many consecutive successes.
-
#host ⇒ String
The value of the host header in the HTTP health check request.
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#name ⇒ String
Name of the resource.
-
#port ⇒ Fixnum
The TCP port number for the HTTP health check request.
-
#port_name ⇒ String
Port name as defined in InstanceGroup#NamedPort#name.
-
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1.
-
#request_path ⇒ String
The request path of the HTTP health check request.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#timeout_sec ⇒ Fixnum
How long (in seconds) to wait before claiming failure.
-
#unhealthy_threshold ⇒ Fixnum
A so-far healthy instance will be marked unhealthy after this many consecutive failures.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHealthCheck
constructor
A new instance of HttpHealthCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ HttpHealthCheck
Returns a new instance of HttpHealthCheck.
2858 2859 2860 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2858 def initialize(**args) update!(**args) end |
Instance Attribute Details
#check_interval_sec ⇒ Fixnum
How often (in seconds) to send a health check. The default value is 5 seconds.
Corresponds to the JSON property checkIntervalSec
3190 3191 3192 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3190 def check_interval_sec @check_interval_sec end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
3195 3196 3197 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3195 def end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
3201 3202 3203 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3201 def description @description end |
#healthy_threshold ⇒ Fixnum
A so-far unhealthy instance will be marked healthy after this many consecutive
successes. The default value is 2.
Corresponds to the JSON property healthyThreshold
3207 3208 3209 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3207 def healthy_threshold @healthy_threshold end |
#host ⇒ String
The value of the host header in the HTTP health check request. If left empty (
default value), the public IP on behalf of which this health check is
performed will be used.
Corresponds to the JSON property host
2834 2835 2836 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2834 def host @host end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
3220 3221 3222 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3220 def id @id end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#httpHealthCheck for HTTP
health checks.
Corresponds to the JSON property kind
3226 3227 3228 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3226 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
3236 3237 3238 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3236 def name @name end |
#port ⇒ Fixnum
The TCP port number for the HTTP health check request. The default value is 80.
Corresponds to the JSON property port
2839 2840 2841 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2839 def port @port end |
#port_name ⇒ String
Port name as defined in InstanceGroup#NamedPort#name. If both port and
port_name are defined, port takes precedence.
Corresponds to the JSON property portName
2845 2846 2847 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2845 def port_name @port_name end |
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the
backend, either NONE or PROXY_V1. The default is NONE.
Corresponds to the JSON property proxyHeader
2851 2852 2853 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2851 def proxy_header @proxy_header end |
#request_path ⇒ String
The request path of the HTTP health check request. The default value is /.
Corresponds to the JSON property requestPath
2856 2857 2858 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2856 def request_path @request_path end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
3251 3252 3253 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3251 def self_link @self_link end |
#timeout_sec ⇒ Fixnum
How long (in seconds) to wait before claiming failure. The default value is 5
seconds. It is invalid for timeoutSec to have greater value than
checkIntervalSec.
Corresponds to the JSON property timeoutSec
3258 3259 3260 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3258 def timeout_sec @timeout_sec end |
#unhealthy_threshold ⇒ Fixnum
A so-far healthy instance will be marked unhealthy after this many consecutive
failures. The default value is 2.
Corresponds to the JSON property unhealthyThreshold
3264 3265 3266 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3264 def unhealthy_threshold @unhealthy_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2863 2864 2865 2866 2867 2868 2869 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2863 def update!(**args) @host = args[:host] if args.key?(:host) @port = args[:port] if args.key?(:port) @port_name = args[:port_name] if args.key?(:port_name) @proxy_header = args[:proxy_header] if args.key?(:proxy_header) @request_path = args[:request_path] if args.key?(:request_path) end |