Class: Google::Apis::ComputeV1::Image
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Image
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
An Image resource.
Defined Under Namespace
Classes: RawDisk
Instance Attribute Summary collapse
-
#archive_size_bytes ⇒ String
Size of the image tar.gz archive stored in Google Cloud Storage (in bytes).
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
An optional description of this resource.
-
#disk_size_gb ⇒ String
Size of the image when restored onto a persistent disk (in GB).
-
#family ⇒ String
The name of the image family to which this image belongs.
-
#guest_os_features ⇒ Array<Google::Apis::ComputeV1::GuestOsFeature>
A list of features to enable on the guest OS.
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#image_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Represents a customer-supplied encryption key Corresponds to the JSON property
imageEncryptionKey. -
#kind ⇒ String
[Output Only] Type of the resource.
-
#licenses ⇒ Array<String>
Any applicable license URI.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#raw_disk ⇒ Google::Apis::ComputeV1::Image::RawDisk
The parameters of the raw disk image.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#source_disk ⇒ String
URL of the source disk used to create this image.
-
#source_disk_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Represents a customer-supplied encryption key Corresponds to the JSON property
sourceDiskEncryptionKey. -
#source_disk_id ⇒ String
The ID value of the disk used to create this image.
-
#source_type ⇒ String
The type of the image used to create this disk.
-
#status ⇒ String
[Output Only] The status of the image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Image
constructor
A new instance of Image.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ Image
Returns a new instance of Image.
3617 3618 3619 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3617 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive_size_bytes ⇒ String
Size of the image tar.gz archive stored in Google Cloud Storage (in bytes).
Corresponds to the JSON property archiveSizeBytes
3495 3496 3497 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3495 def archive_size_bytes @archive_size_bytes end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
3500 3501 3502 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3500 def end |
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
3505 3506 3507 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3505 def deprecated @deprecated end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
3511 3512 3513 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3511 def description @description end |
#disk_size_gb ⇒ String
Size of the image when restored onto a persistent disk (in GB).
Corresponds to the JSON property diskSizeGb
3516 3517 3518 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3516 def disk_size_gb @disk_size_gb end |
#family ⇒ String
The name of the image family to which this image belongs. You can create disks
by specifying an image family instead of a specific image name. The image
family always returns its latest image that is not deprecated. The name of the
image family must comply with RFC1035.
Corresponds to the JSON property family
3524 3525 3526 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3524 def family @family end |
#guest_os_features ⇒ Array<Google::Apis::ComputeV1::GuestOsFeature>
A list of features to enable on the guest OS. Applicable for bootable images
only. Currently, only one feature can be enabled, VIRTIO_SCSCI_MULTIQUEUE,
which allows each virtual CPU to have its own queue. For Windows images, you
can only enable VIRTIO_SCSCI_MULTIQUEUE on images with driver version 1.2.0.
1621 or higher. Linux images with kernel versions 3.17 and higher will support
VIRTIO_SCSCI_MULTIQUEUE.
For new Windows images, the server might also populate this field with the
value WINDOWS, to indicate that this is a Windows image. This value is purely
informational and does not enable or disable any features.
Corresponds to the JSON property guestOsFeatures
3537 3538 3539 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3537 def guest_os_features @guest_os_features end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
3543 3544 3545 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3543 def id @id end |
#image_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Represents a customer-supplied encryption key
Corresponds to the JSON property imageEncryptionKey
3548 3549 3550 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3548 def image_encryption_key @image_encryption_key end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#image for images.
Corresponds to the JSON property kind
3553 3554 3555 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3553 def kind @kind end |
#licenses ⇒ Array<String>
Any applicable license URI.
Corresponds to the JSON property licenses
3558 3559 3560 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3558 def licenses @licenses end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
3568 3569 3570 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3568 def name @name end |
#raw_disk ⇒ Google::Apis::ComputeV1::Image::RawDisk
The parameters of the raw disk image.
Corresponds to the JSON property rawDisk
3573 3574 3575 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3573 def raw_disk @raw_disk end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
3578 3579 3580 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3578 def self_link @self_link end |
#source_disk ⇒ String
URL of the source disk used to create this image. This can be a full or valid partial URL. You must provide either this property or the rawDisk.source property but not both to create an image. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/disk
- projects/project/zones/zone/disks/disk
- zones/zone/disks/disk
Corresponds to the JSON property
sourceDisk
3589 3590 3591 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3589 def source_disk @source_disk end |
#source_disk_encryption_key ⇒ Google::Apis::ComputeV1::CustomerEncryptionKey
Represents a customer-supplied encryption key
Corresponds to the JSON property sourceDiskEncryptionKey
3594 3595 3596 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3594 def source_disk_encryption_key @source_disk_encryption_key end |
#source_disk_id ⇒ String
The ID value of the disk used to create this image. This value may be used to
determine whether the image was taken from the current or a previous instance
of a given disk name.
Corresponds to the JSON property sourceDiskId
3601 3602 3603 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3601 def source_disk_id @source_disk_id end |
#source_type ⇒ String
The type of the image used to create this disk. The default and only value is
RAW
Corresponds to the JSON property sourceType
3607 3608 3609 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3607 def source_type @source_type end |
#status ⇒ String
[Output Only] The status of the image. An image can be used to create other
resources, such as instances, only after the image has been successfully
created and the status is set to READY. Possible values are FAILED, PENDING,
or READY.
Corresponds to the JSON property status
3615 3616 3617 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3615 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 3639 3640 3641 3642 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3622 def update!(**args) @archive_size_bytes = args[:archive_size_bytes] if args.key?(:archive_size_bytes) = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @family = args[:family] if args.key?(:family) @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features) @id = args[:id] if args.key?(:id) @image_encryption_key = args[:image_encryption_key] if args.key?(:image_encryption_key) @kind = args[:kind] if args.key?(:kind) @licenses = args[:licenses] if args.key?(:licenses) @name = args[:name] if args.key?(:name) @raw_disk = args[:raw_disk] if args.key?(:raw_disk) @self_link = args[:self_link] if args.key?(:self_link) @source_disk = args[:source_disk] if args.key?(:source_disk) @source_disk_encryption_key = args[:source_disk_encryption_key] if args.key?(:source_disk_encryption_key) @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id) @source_type = args[:source_type] if args.key?(:source_type) @status = args[:status] if args.key?(:status) end |