Class: Google::Apis::ComputeV1::Instance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

An Instance resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



3852
3853
3854
# File 'generated/google/apis/compute_v1/classes.rb', line 3852

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_ip_forwardBoolean Also known as: can_ip_forward?

Allows this instance to send and receive packets with non-matching destination or source IPs. This is required if you plan to use this instance to forward routes. For more information, see Enabling IP Forwarding. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


3737
3738
3739
# File 'generated/google/apis/compute_v1/classes.rb', line 3737

def can_ip_forward
  @can_ip_forward
end

#cpu_platformString

[Output Only] The CPU platform used by this instance. Corresponds to the JSON property cpuPlatform

Returns:

  • (String)


3743
3744
3745
# File 'generated/google/apis/compute_v1/classes.rb', line 3743

def cpu_platform
  @cpu_platform
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


3748
3749
3750
# File 'generated/google/apis/compute_v1/classes.rb', line 3748

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


3754
3755
3756
# File 'generated/google/apis/compute_v1/classes.rb', line 3754

def description
  @description
end

#disksArray<Google::Apis::ComputeV1::AttachedDisk>

Array of disks associated with this instance. Persistent disks must be created before you can assign them. Corresponds to the JSON property disks



3760
3761
3762
# File 'generated/google/apis/compute_v1/classes.rb', line 3760

def disks
  @disks
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


3766
3767
3768
# File 'generated/google/apis/compute_v1/classes.rb', line 3766

def id
  @id
end

#kindString

[Output Only] Type of the resource. Always compute#instance for instances. Corresponds to the JSON property kind

Returns:

  • (String)


3771
3772
3773
# File 'generated/google/apis/compute_v1/classes.rb', line 3771

def kind
  @kind
end

#machine_typeString

Full or partial URL of the machine type resource to use for this instance, in the format: zones/zone/machineTypes/machine-type. This is provided by the client when the instance is created. For example, the following is a valid partial url to a predefined machine type: zones/us-central1-f/machineTypes/n1-standard-1 To create a custom machine type, provide a URL to a machine type in the following format, where CPUS is 1 or an even number up to 32 (2, 4, 6, ... 24, etc), and MEMORY is the total memory for this instance. Memory must be a multiple of 256 MB and must be supplied in MB (e.g. 5 GB of memory is 5120 MB): zones/zone/machineTypes/custom-CPUS-MEMORY For example: zones/us-central1-f/machineTypes/custom-4-5120 For a full list of restrictions, read the Specifications for custom machine types. Corresponds to the JSON property machineType

Returns:

  • (String)


3788
3789
3790
# File 'generated/google/apis/compute_v1/classes.rb', line 3788

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeV1::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



3793
3794
3795
# File 'generated/google/apis/compute_v1/classes.rb', line 3793

def 
  
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


3803
3804
3805
# File 'generated/google/apis/compute_v1/classes.rb', line 3803

def name
  @name
end

#network_interfacesArray<Google::Apis::ComputeV1::NetworkInterface>

An array of configurations for this interface. This specifies how this interface is configured to interact with other network services, such as connecting to the internet. Only one interface is supported per instance. Corresponds to the JSON property networkInterfaces



3810
3811
3812
# File 'generated/google/apis/compute_v1/classes.rb', line 3810

def network_interfaces
  @network_interfaces
end

#schedulingGoogle::Apis::ComputeV1::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



3815
3816
3817
# File 'generated/google/apis/compute_v1/classes.rb', line 3815

def scheduling
  @scheduling
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


3820
3821
3822
# File 'generated/google/apis/compute_v1/classes.rb', line 3820

def self_link
  @self_link
end

#service_accountsArray<Google::Apis::ComputeV1::ServiceAccount>

A list of service accounts, with their specified scopes, authorized for this instance. Service accounts generate access tokens that can be accessed through the metadata server and used to authenticate applications on the instance. See Service Accounts for more information. Corresponds to the JSON property serviceAccounts



3828
3829
3830
# File 'generated/google/apis/compute_v1/classes.rb', line 3828

def service_accounts
  @service_accounts
end

#statusString

[Output Only] The status of the instance. One of the following values: PROVISIONING, STAGING, RUNNING, STOPPING, SUSPENDING, SUSPENDED, and TERMINATED. Corresponds to the JSON property status

Returns:

  • (String)


3835
3836
3837
# File 'generated/google/apis/compute_v1/classes.rb', line 3835

def status
  @status
end

#status_messageString

[Output Only] An optional, human-readable explanation of the status. Corresponds to the JSON property statusMessage

Returns:

  • (String)


3840
3841
3842
# File 'generated/google/apis/compute_v1/classes.rb', line 3840

def status_message
  @status_message
end

#tagsGoogle::Apis::ComputeV1::Tags

A set of instance tags. Corresponds to the JSON property tags



3845
3846
3847
# File 'generated/google/apis/compute_v1/classes.rb', line 3845

def tags
  @tags
end

#zoneString

[Output Only] URL of the zone where the instance resides. Corresponds to the JSON property zone

Returns:

  • (String)


3850
3851
3852
# File 'generated/google/apis/compute_v1/classes.rb', line 3850

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
3873
3874
3875
3876
# File 'generated/google/apis/compute_v1/classes.rb', line 3857

def update!(**args)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
   = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @self_link = args[:self_link] if args.key?(:self_link)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @tags = args[:tags] if args.key?(:tags)
  @zone = args[:zone] if args.key?(:zone)
end