Class: Google::Apis::ComputeV1::InstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceAggregatedList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::InstancesScopedList>
[Output Only] A map of scoped instance lists.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceAggregatedList
constructor
A new instance of InstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InstanceAggregatedList
Returns a new instance of InstanceAggregatedList.
3914 3915 3916 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3914 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
3887 3888 3889 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3887 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::InstancesScopedList>
[Output Only] A map of scoped instance lists.
Corresponds to the JSON property items
3892 3893 3894 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3892 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#instanceAggregatedList for
aggregated lists of Instance resources.
Corresponds to the JSON property kind
3898 3899 3900 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3898 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
3907 3908 3909 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3907 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
3912 3913 3914 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3912 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3919 3920 3921 3922 3923 3924 3925 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3919 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |