Class: Google::Apis::ComputeV1::InstanceGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroup
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] The creation timestamp for this instance group in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
[Output Only] The fingerprint of the named ports.
-
#id ⇒ String
[Output Only] A unique identifier for this instance group, generated by the server.
-
#kind ⇒ String
[Output Only] The resource type, which is always compute#instanceGroup for instance groups.
-
#name ⇒ String
The name of the instance group.
-
#named_ports ⇒ Array<Google::Apis::ComputeV1::NamedPort>
Assigns a name to a port number.
-
#network ⇒ String
The URL of the network to which all instances in the instance group belong.
-
#region ⇒ String
The URL of the region where the instance group is located (for regional resources).
-
#self_link ⇒ String
[Output Only] The URL for this instance group.
-
#size ⇒ Fixnum
[Output Only] The total number of instances in the instance group.
-
#subnetwork ⇒ String
The URL of the subnetwork to which all instances in the instance group belong.
-
#zone ⇒ String
[Output Only] The URL of the zone where the instance group is located (for zonal resources).
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroup
constructor
A new instance of InstanceGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InstanceGroup
Returns a new instance of InstanceGroup.
4010 4011 4012 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4010 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] The creation timestamp for this instance group in RFC3339 text
format.
Corresponds to the JSON property creationTimestamp
3936 3937 3938 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3936 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
3942 3943 3944 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3942 def description @description end |
#fingerprint ⇒ String
[Output Only] The fingerprint of the named ports. The system uses this
fingerprint to detect conflicts when multiple users change the named ports
concurrently.
Corresponds to the JSON property fingerprint
3949 3950 3951 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3949 def fingerprint @fingerprint end |
#id ⇒ String
[Output Only] A unique identifier for this instance group, generated by the
server.
Corresponds to the JSON property id
3955 3956 3957 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3955 def id @id end |
#kind ⇒ String
[Output Only] The resource type, which is always compute#instanceGroup for
instance groups.
Corresponds to the JSON property kind
3961 3962 3963 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3961 def kind @kind end |
#name ⇒ String
The name of the instance group. The name must be 1-63 characters long, and
comply with RFC1035.
Corresponds to the JSON property name
3967 3968 3969 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3967 def name @name end |
#named_ports ⇒ Array<Google::Apis::ComputeV1::NamedPort>
Assigns a name to a port number. For example: name: "http", port: 80
This allows the system to reference ports by the assigned name instead of a
port number. Named ports can also contain multiple ports. For example: [name:
"http", port: 80,name: "http", port: 8080]
Named ports apply to all instances in this instance group.
Corresponds to the JSON property namedPorts
3976 3977 3978 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3976 def named_ports @named_ports end |
#network ⇒ String
The URL of the network to which all instances in the instance group belong.
Corresponds to the JSON property network
3981 3982 3983 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3981 def network @network end |
#region ⇒ String
The URL of the region where the instance group is located (for regional
resources).
Corresponds to the JSON property region
3987 3988 3989 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3987 def region @region end |
#self_link ⇒ String
[Output Only] The URL for this instance group. The server generates this URL.
Corresponds to the JSON property selfLink
3992 3993 3994 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3992 def self_link @self_link end |
#size ⇒ Fixnum
[Output Only] The total number of instances in the instance group.
Corresponds to the JSON property size
3997 3998 3999 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3997 def size @size end |
#subnetwork ⇒ String
The URL of the subnetwork to which all instances in the instance group belong.
Corresponds to the JSON property subnetwork
4002 4003 4004 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4002 def subnetwork @subnetwork end |
#zone ⇒ String
[Output Only] The URL of the zone where the instance group is located (for
zonal resources).
Corresponds to the JSON property zone
4008 4009 4010 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4008 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 4029 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4015 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @named_ports = args[:named_ports] if args.key?(:named_ports) @network = args[:network] if args.key?(:network) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @size = args[:size] if args.key?(:size) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @zone = args[:zone] if args.key?(:zone) end |