Class: Google::Apis::ComputeV1::InstanceGroupAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupAggregatedList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] A unique identifier for this aggregated list of instance groups.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::InstanceGroupsScopedList>
A map of scoped instance group lists.
-
#kind ⇒ String
[Output Only] The resource type, which is always compute# instanceGroupAggregatedList for aggregated lists of instance groups.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] The URL for this resource type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupAggregatedList
constructor
A new instance of InstanceGroupAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InstanceGroupAggregatedList
Returns a new instance of InstanceGroupAggregatedList.
4067 4068 4069 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4067 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] A unique identifier for this aggregated list of instance groups.
The server generates this identifier.
Corresponds to the JSON property id
4040 4041 4042 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4040 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::InstanceGroupsScopedList>
A map of scoped instance group lists.
Corresponds to the JSON property items
4045 4046 4047 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4045 def items @items end |
#kind ⇒ String
[Output Only] The resource type, which is always compute#
instanceGroupAggregatedList for aggregated lists of instance groups.
Corresponds to the JSON property kind
4051 4052 4053 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4051 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
4060 4061 4062 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4060 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] The URL for this resource type. The server generates this URL.
Corresponds to the JSON property selfLink
4065 4066 4067 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4065 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4072 4073 4074 4075 4076 4077 4078 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4072 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |