Class: Google::Apis::ComputeV1::InstanceGroupManager

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

An Instance Group Manager resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ InstanceGroupManager

Returns a new instance of InstanceGroupManager.



4234
4235
4236
# File 'generated/google/apis/compute_v1/classes.rb', line 4234

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_instance_nameString

The base instance name to use for instances in this group. The value must be 1- 58 characters long. Instances are named by appending a hyphen and a random four-character string to the base instance name. The base instance name must comply with RFC1035. Corresponds to the JSON property baseInstanceName

Returns:

  • (String)


4140
4141
4142
# File 'generated/google/apis/compute_v1/classes.rb', line 4140

def base_instance_name
  @base_instance_name
end

#creation_timestampString

[Output Only] The creation timestamp for this managed instance group in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


4146
4147
4148
# File 'generated/google/apis/compute_v1/classes.rb', line 4146

def creation_timestamp
  @creation_timestamp
end

#current_actionsGoogle::Apis::ComputeV1::InstanceGroupManagerActionsSummary

[Output Only] The list of instance actions and the number of instances in this managed instance group that are scheduled for each of those actions. Corresponds to the JSON property currentActions



4152
4153
4154
# File 'generated/google/apis/compute_v1/classes.rb', line 4152

def current_actions
  @current_actions
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


4158
4159
4160
# File 'generated/google/apis/compute_v1/classes.rb', line 4158

def description
  @description
end

#fingerprintString

[Output Only] The fingerprint of the resource data. You can use this optional field for optimistic locking when you update the resource. Corresponds to the JSON property fingerprint

Returns:

  • (String)


4164
4165
4166
# File 'generated/google/apis/compute_v1/classes.rb', line 4164

def fingerprint
  @fingerprint
end

#idString

[Output Only] A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (String)


4170
4171
4172
# File 'generated/google/apis/compute_v1/classes.rb', line 4170

def id
  @id
end

#instance_groupString

[Output Only] The URL of the Instance Group resource. Corresponds to the JSON property instanceGroup

Returns:

  • (String)


4175
4176
4177
# File 'generated/google/apis/compute_v1/classes.rb', line 4175

def instance_group
  @instance_group
end

#instance_templateString

The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


4182
4183
4184
# File 'generated/google/apis/compute_v1/classes.rb', line 4182

def instance_template
  @instance_template
end

#kindString

[Output Only] The resource type, which is always compute#instanceGroupManager for managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


4188
4189
4190
# File 'generated/google/apis/compute_v1/classes.rb', line 4188

def kind
  @kind
end

#nameString

The name of the managed instance group. The name must be 1-63 characters long, and comply with RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


4194
4195
4196
# File 'generated/google/apis/compute_v1/classes.rb', line 4194

def name
  @name
end

#named_portsArray<Google::Apis::ComputeV1::NamedPort>

Named ports configured for the Instance Groups complementary to this Instance Group Manager. Corresponds to the JSON property namedPorts



4200
4201
4202
# File 'generated/google/apis/compute_v1/classes.rb', line 4200

def named_ports
  @named_ports
end

#regionString

[Output Only] The URL of the region where the managed instance group resides ( for regional resources). Corresponds to the JSON property region

Returns:

  • (String)


4206
4207
4208
# File 'generated/google/apis/compute_v1/classes.rb', line 4206

def region
  @region
end

[Output Only] The URL for this managed instance group. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


4212
4213
4214
# File 'generated/google/apis/compute_v1/classes.rb', line 4212

def self_link
  @self_link
end

#target_poolsArray<String>

The URLs for all TargetPool resources to which instances in the instanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group. Corresponds to the JSON property targetPools

Returns:

  • (Array<String>)


4219
4220
4221
# File 'generated/google/apis/compute_v1/classes.rb', line 4219

def target_pools
  @target_pools
end

#target_sizeFixnum

The target number of running instances for this managed instance group. Deleting or abandoning instances reduces this number. Resizing the group changes this number. Corresponds to the JSON property targetSize

Returns:

  • (Fixnum)


4226
4227
4228
# File 'generated/google/apis/compute_v1/classes.rb', line 4226

def target_size
  @target_size
end

#zoneString

[Output Only] The URL of the zone where the managed instance group is located ( for zonal resources). Corresponds to the JSON property zone

Returns:

  • (String)


4232
4233
4234
# File 'generated/google/apis/compute_v1/classes.rb', line 4232

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
# File 'generated/google/apis/compute_v1/classes.rb', line 4239

def update!(**args)
  @base_instance_name = args[:base_instance_name] if args.key?(:base_instance_name)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @current_actions = args[:current_actions] if args.key?(:current_actions)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @instance_group = args[:instance_group] if args.key?(:instance_group)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @named_ports = args[:named_ports] if args.key?(:named_ports)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @target_pools = args[:target_pools] if args.key?(:target_pools)
  @target_size = args[:target_size] if args.key?(:target_size)
  @zone = args[:zone] if args.key?(:zone)
end