Class: Google::Apis::ComputeV1::InstanceGroupManagerActionsSummary
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupManagerActionsSummary
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#abandoning ⇒ Fixnum
[Output Only] The total number of instances in the managed instance group that are scheduled to be abandoned.
-
#creating ⇒ Fixnum
[Output Only] The number of instances in the managed instance group that are scheduled to be created or are currently being created.
-
#creating_without_retries ⇒ Fixnum
[Output Only] The number of instances that the managed instance group will attempt to create.
-
#deleting ⇒ Fixnum
[Output Only] The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted.
-
#none ⇒ Fixnum
[Output Only] The number of instances in the managed instance group that are running and have no scheduled actions.
-
#recreating ⇒ Fixnum
[Output Only] The number of instances in the managed instance group that are scheduled to be recreated or are currently being being recreated.
-
#refreshing ⇒ Fixnum
[Output Only] The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action.
-
#restarting ⇒ Fixnum
[Output Only] The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
constructor
A new instance of InstanceGroupManagerActionsSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
Returns a new instance of InstanceGroupManagerActionsSummary.
4321 4322 4323 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4321 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abandoning ⇒ Fixnum
[Output Only] The total number of instances in the managed instance group that
are scheduled to be abandoned. Abandoning an instance removes it from the
managed instance group without deleting it.
Corresponds to the JSON property abandoning
4268 4269 4270 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4268 def abandoning @abandoning end |
#creating ⇒ Fixnum
[Output Only] The number of instances in the managed instance group that are
scheduled to be created or are currently being created. If the group fails to
create any of these instances, it tries again until it creates the instance
successfully.
If you have disabled creation retries, this field will not be populated;
instead, the creatingWithoutRetries field will be populated.
Corresponds to the JSON property creating
4278 4279 4280 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4278 def creating @creating end |
#creating_without_retries ⇒ Fixnum
[Output Only] The number of instances that the managed instance group will
attempt to create. The group attempts to create each instance only once. If
the group fails to create any of these instances, it decreases the group's
targetSize value accordingly.
Corresponds to the JSON property creatingWithoutRetries
4286 4287 4288 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4286 def creating_without_retries @creating_without_retries end |
#deleting ⇒ Fixnum
[Output Only] The number of instances in the managed instance group that are
scheduled to be deleted or are currently being deleted.
Corresponds to the JSON property deleting
4292 4293 4294 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4292 def deleting @deleting end |
#none ⇒ Fixnum
[Output Only] The number of instances in the managed instance group that are
running and have no scheduled actions.
Corresponds to the JSON property none
4298 4299 4300 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4298 def none @none end |
#recreating ⇒ Fixnum
[Output Only] The number of instances in the managed instance group that are
scheduled to be recreated or are currently being being recreated. Recreating
an instance deletes the existing root persistent disk and creates a new disk
from the image that is defined in the instance template.
Corresponds to the JSON property recreating
4306 4307 4308 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4306 def recreating @recreating end |
#refreshing ⇒ Fixnum
[Output Only] The number of instances in the managed instance group that are
being reconfigured with properties that do not require a restart or a recreate
action. For example, setting or removing target pools for the instance.
Corresponds to the JSON property refreshing
4313 4314 4315 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4313 def refreshing @refreshing end |
#restarting ⇒ Fixnum
[Output Only] The number of instances in the managed instance group that are
scheduled to be restarted or are currently being restarted.
Corresponds to the JSON property restarting
4319 4320 4321 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4319 def restarting @restarting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4326 def update!(**args) @abandoning = args[:abandoning] if args.key?(:abandoning) @creating = args[:creating] if args.key?(:creating) @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries) @deleting = args[:deleting] if args.key?(:deleting) @none = args[:none] if args.key?(:none) @recreating = args[:recreating] if args.key?(:recreating) @refreshing = args[:refreshing] if args.key?(:refreshing) @restarting = args[:restarting] if args.key?(:restarting) end |