Class: Google::Apis::ComputeV1::InstanceGroupManagerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerAggregatedList

Returns a new instance of InstanceGroupManagerAggregatedList.



4374
4375
4376
# File 'generated/google/apis/compute_v1/classes.rb', line 4374

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] A unique identifier for this aggregated list of managed instance groups. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (String)


4346
4347
4348
# File 'generated/google/apis/compute_v1/classes.rb', line 4346

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::InstanceGroupManagersScopedList>

[Output Only] A map of filtered managed instance group lists. Corresponds to the JSON property items



4351
4352
4353
# File 'generated/google/apis/compute_v1/classes.rb', line 4351

def items
  @items
end

#kindString

[Output Only] The resource type, which is always compute# instanceGroupManagerAggregatedList for an aggregated list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


4358
4359
4360
# File 'generated/google/apis/compute_v1/classes.rb', line 4358

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4367
4368
4369
# File 'generated/google/apis/compute_v1/classes.rb', line 4367

def next_page_token
  @next_page_token
end

[Output Only] The URL for this resource type. The server generates this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


4372
4373
4374
# File 'generated/google/apis/compute_v1/classes.rb', line 4372

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4379
4380
4381
4382
4383
4384
4385
# File 'generated/google/apis/compute_v1/classes.rb', line 4379

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end