Class: Google::Apis::ComputeV1::InstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

[Output Only] A list of managed instance groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerList

Returns a new instance of InstanceGroupManagerList.



4423
4424
4425
# File 'generated/google/apis/compute_v1/classes.rb', line 4423

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (String)


4396
4397
4398
# File 'generated/google/apis/compute_v1/classes.rb', line 4396

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::InstanceGroupManager>

[Output Only] A list of managed instance groups. Corresponds to the JSON property items



4401
4402
4403
# File 'generated/google/apis/compute_v1/classes.rb', line 4401

def items
  @items
end

#kindString

[Output Only] The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


4407
4408
4409
# File 'generated/google/apis/compute_v1/classes.rb', line 4407

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4416
4417
4418
# File 'generated/google/apis/compute_v1/classes.rb', line 4416

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


4421
4422
4423
# File 'generated/google/apis/compute_v1/classes.rb', line 4421

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4428
4429
4430
4431
4432
4433
4434
# File 'generated/google/apis/compute_v1/classes.rb', line 4428

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end