Class: Google::Apis::ComputeV1::InstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
Contains a list of instances.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::Instance>
[Output Only] A list of instances.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceList
constructor
A new instance of InstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InstanceList
Returns a new instance of InstanceList.
4926 4927 4928 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4926 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
4899 4900 4901 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4899 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Instance>
[Output Only] A list of instances.
Corresponds to the JSON property items
4904 4905 4906 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4904 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#instanceList for lists of
Instance resources.
Corresponds to the JSON property kind
4910 4911 4912 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4910 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
4919 4920 4921 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4919 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
4924 4925 4926 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4924 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4931 4932 4933 4934 4935 4936 4937 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4931 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |