Class: Google::Apis::ComputeV1::MachineTypeAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ MachineTypeAggregatedList

Returns a new instance of MachineTypeAggregatedList.



5580
5581
5582
# File 'generated/google/apis/compute_v1/classes.rb', line 5580

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


5553
5554
5555
# File 'generated/google/apis/compute_v1/classes.rb', line 5553

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::MachineTypesScopedList>

[Output Only] A map of scoped machine type lists. Corresponds to the JSON property items



5558
5559
5560
# File 'generated/google/apis/compute_v1/classes.rb', line 5558

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#machineTypeAggregatedList for aggregated lists of machine types. Corresponds to the JSON property kind

Returns:

  • (String)


5564
5565
5566
# File 'generated/google/apis/compute_v1/classes.rb', line 5564

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5573
5574
5575
# File 'generated/google/apis/compute_v1/classes.rb', line 5573

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


5578
5579
5580
# File 'generated/google/apis/compute_v1/classes.rb', line 5578

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5585
5586
5587
5588
5589
5590
5591
# File 'generated/google/apis/compute_v1/classes.rb', line 5585

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end