Class: Google::Apis::ComputeV1::MachineTypeList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

Contains a list of machine types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ MachineTypeList



5629
5630
5631
# File 'generated/google/apis/compute_v1/classes.rb', line 5629

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id



5602
5603
5604
# File 'generated/google/apis/compute_v1/classes.rb', line 5602

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::MachineType>

[Output Only] A list of Machine Type resources. Corresponds to the JSON property items



5607
5608
5609
# File 'generated/google/apis/compute_v1/classes.rb', line 5607

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#machineTypeList for lists of machine types. Corresponds to the JSON property kind



5613
5614
5615
# File 'generated/google/apis/compute_v1/classes.rb', line 5613

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken



5622
5623
5624
# File 'generated/google/apis/compute_v1/classes.rb', line 5622

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink



5627
5628
5629
# File 'generated/google/apis/compute_v1/classes.rb', line 5627

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5634
5635
5636
5637
5638
5639
5640
# File 'generated/google/apis/compute_v1/classes.rb', line 5634

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end