Class: Google::Apis::ComputeV1::Metadata
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Metadata
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
A metadata key/value entry.
Defined Under Namespace
Classes: Item
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
Specifies a fingerprint for this request, which is essentially a hash of the metadata's contents and used for optimistic locking.
-
#items ⇒ Array<Google::Apis::ComputeV1::Metadata::Item>
Array of key/value pairs.
-
#kind ⇒ String
[Output Only] Type of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Metadata
constructor
A new instance of Metadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ Metadata
Returns a new instance of Metadata.
5894 5895 5896 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5894 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
Specifies a fingerprint for this request, which is essentially a hash of the
metadata's contents and used for optimistic locking. The fingerprint is
initially generated by Compute Engine and changes after every request to
modify or update metadata. You must always provide an up-to-date fingerprint
hash in order to update or change metadata.
Corresponds to the JSON property fingerprint
5881 5882 5883 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5881 def fingerprint @fingerprint end |
#items ⇒ Array<Google::Apis::ComputeV1::Metadata::Item>
Array of key/value pairs. The total size of all keys and values must be less
than 512 KB.
Corresponds to the JSON property items
5887 5888 5889 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5887 def items @items end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#metadata for metadata.
Corresponds to the JSON property kind
5892 5893 5894 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5892 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5899 5900 5901 5902 5903 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5899 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) end |