Class: Google::Apis::ComputeV1::Metadata::Item

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ Item

Returns a new instance of Item.



5925
5926
5927
# File 'generated/google/apis/compute_v1/classes.rb', line 5925

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Key for the metadata entry. Keys must conform to the following regexp: [a-zA- Z0-9-_]+, and be less than 128 bytes in length. This is reflected as part of a URL in the metadata server. Additionally, to avoid ambiguity, keys must not conflict with any other metadata keys for the project. Corresponds to the JSON property key

Returns:

  • (String)


5915
5916
5917
# File 'generated/google/apis/compute_v1/classes.rb', line 5915

def key
  @key
end

#valueString

Value for the metadata entry. These are free-form strings, and only have meaning as interpreted by the image running in the instance. The only restriction placed on values is that their size must be less than or equal to 32768 bytes. Corresponds to the JSON property value

Returns:

  • (String)


5923
5924
5925
# File 'generated/google/apis/compute_v1/classes.rb', line 5923

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5930
5931
5932
5933
# File 'generated/google/apis/compute_v1/classes.rb', line 5930

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @value = args[:value] if args.key?(:value)
end