Class: Google::Apis::ComputeV1::NetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

Contains a list of networks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ NetworkList

Returns a new instance of NetworkList.



6160
6161
6162
# File 'generated/google/apis/compute_v1/classes.rb', line 6160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


6133
6134
6135
# File 'generated/google/apis/compute_v1/classes.rb', line 6133

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Network>

[Output Only] A list of Network resources. Corresponds to the JSON property items



6138
6139
6140
# File 'generated/google/apis/compute_v1/classes.rb', line 6138

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#networkList for lists of networks. Corresponds to the JSON property kind

Returns:

  • (String)


6144
6145
6146
# File 'generated/google/apis/compute_v1/classes.rb', line 6144

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6153
6154
6155
# File 'generated/google/apis/compute_v1/classes.rb', line 6153

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


6158
6159
6160
# File 'generated/google/apis/compute_v1/classes.rb', line 6158

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6165
6166
6167
6168
6169
6170
6171
# File 'generated/google/apis/compute_v1/classes.rb', line 6165

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end