Class: Google::Apis::ComputeV1::Operation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

An Operation resource, used to manage asynchronous API requests.

Defined Under Namespace

Classes: Error, Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



6315
6316
6317
# File 'generated/google/apis/compute_v1/classes.rb', line 6315

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_operation_idString

[Output Only] Reserved for future use. Corresponds to the JSON property clientOperationId

Returns:

  • (String)


6181
6182
6183
# File 'generated/google/apis/compute_v1/classes.rb', line 6181

def client_operation_id
  @client_operation_id
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


6186
6187
6188
# File 'generated/google/apis/compute_v1/classes.rb', line 6186

def creation_timestamp
  @creation_timestamp
end

#descriptionString

[Output Only] A textual description of the operation, which is set when the operation is created. Corresponds to the JSON property description

Returns:

  • (String)


6192
6193
6194
# File 'generated/google/apis/compute_v1/classes.rb', line 6192

def description
  @description
end

#end_timeString

[Output Only] The time that this operation was completed. This value is in RFC3339 text format. Corresponds to the JSON property endTime

Returns:

  • (String)


6198
6199
6200
# File 'generated/google/apis/compute_v1/classes.rb', line 6198

def end_time
  @end_time
end

#errorGoogle::Apis::ComputeV1::Operation::Error

[Output Only] If errors are generated during processing of the operation, this field will be populated. Corresponds to the JSON property error



6204
6205
6206
# File 'generated/google/apis/compute_v1/classes.rb', line 6204

def error
  @error
end

#http_error_messageString

[Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as NOT FOUND. Corresponds to the JSON property httpErrorMessage

Returns:

  • (String)


6210
6211
6212
# File 'generated/google/apis/compute_v1/classes.rb', line 6210

def http_error_message
  @http_error_message
end

#http_error_status_codeFixnum

[Output Only] If the operation fails, this field contains the HTTP error status code that was returned. For example, a 404 means the resource was not found. Corresponds to the JSON property httpErrorStatusCode

Returns:

  • (Fixnum)


6217
6218
6219
# File 'generated/google/apis/compute_v1/classes.rb', line 6217

def http_error_status_code
  @http_error_status_code
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


6223
6224
6225
# File 'generated/google/apis/compute_v1/classes.rb', line 6223

def id
  @id
end

#insert_timeString

[Output Only] The time that this operation was requested. This value is in RFC3339 text format. Corresponds to the JSON property insertTime

Returns:

  • (String)


6229
6230
6231
# File 'generated/google/apis/compute_v1/classes.rb', line 6229

def insert_time
  @insert_time
end

#kindString

[Output Only] Type of the resource. Always compute#operation for Operation resources. Corresponds to the JSON property kind

Returns:

  • (String)


6235
6236
6237
# File 'generated/google/apis/compute_v1/classes.rb', line 6235

def kind
  @kind
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


6240
6241
6242
# File 'generated/google/apis/compute_v1/classes.rb', line 6240

def name
  @name
end

#operation_typeString

[Output Only] The type of operation, such as insert, update, or delete, and so on. Corresponds to the JSON property operationType

Returns:

  • (String)


6246
6247
6248
# File 'generated/google/apis/compute_v1/classes.rb', line 6246

def operation_type
  @operation_type
end

#progressFixnum

[Output Only] An optional progress indicator that ranges from 0 to 100. There is no requirement that this be linear or support any granularity of operations. This should not be used to guess when the operation will be complete. This number should monotonically increase as the operation progresses. Corresponds to the JSON property progress

Returns:

  • (Fixnum)


6254
6255
6256
# File 'generated/google/apis/compute_v1/classes.rb', line 6254

def progress
  @progress
end

#regionString

[Output Only] The URL of the region where the operation resides. Only available when performing regional operations. Corresponds to the JSON property region

Returns:

  • (String)


6260
6261
6262
# File 'generated/google/apis/compute_v1/classes.rb', line 6260

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


6265
6266
6267
# File 'generated/google/apis/compute_v1/classes.rb', line 6265

def self_link
  @self_link
end

#start_timeString

[Output Only] The time that this operation was started by the server. This value is in RFC3339 text format. Corresponds to the JSON property startTime

Returns:

  • (String)


6271
6272
6273
# File 'generated/google/apis/compute_v1/classes.rb', line 6271

def start_time
  @start_time
end

#statusString

[Output Only] The status of the operation, which can be one of the following: PENDING, RUNNING, or DONE. Corresponds to the JSON property status

Returns:

  • (String)


6277
6278
6279
# File 'generated/google/apis/compute_v1/classes.rb', line 6277

def status
  @status
end

#status_messageString

[Output Only] An optional textual description of the current status of the operation. Corresponds to the JSON property statusMessage

Returns:

  • (String)


6283
6284
6285
# File 'generated/google/apis/compute_v1/classes.rb', line 6283

def status_message
  @status_message
end

#target_idString

[Output Only] The unique target ID, which identifies a specific incarnation of the target resource. Corresponds to the JSON property targetId

Returns:

  • (String)


6289
6290
6291
# File 'generated/google/apis/compute_v1/classes.rb', line 6289

def target_id
  @target_id
end

[Output Only] The URL of the resource that the operation modifies. For operations related to creating a snapshot, this points to the persistent disk that the snapshot was created from. Corresponds to the JSON property targetLink

Returns:

  • (String)


6296
6297
6298
# File 'generated/google/apis/compute_v1/classes.rb', line 6296

def target_link
  @target_link
end

#userString

[Output Only] User who requested the operation, for example: [email protected]. Corresponds to the JSON property user

Returns:

  • (String)


6301
6302
6303
# File 'generated/google/apis/compute_v1/classes.rb', line 6301

def user
  @user
end

#warningsArray<Google::Apis::ComputeV1::Operation::Warning>

[Output Only] If warning messages are generated during processing of the operation, this field will be populated. Corresponds to the JSON property warnings



6307
6308
6309
# File 'generated/google/apis/compute_v1/classes.rb', line 6307

def warnings
  @warnings
end

#zoneString

[Output Only] The URL of the zone where the operation resides. Only available when performing per-zone operations. Corresponds to the JSON property zone

Returns:

  • (String)


6313
6314
6315
# File 'generated/google/apis/compute_v1/classes.rb', line 6313

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6320
6321
6322
6323
6324
6325
6326
6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
# File 'generated/google/apis/compute_v1/classes.rb', line 6320

def update!(**args)
  @client_operation_id = args[:client_operation_id] if args.key?(:client_operation_id)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @http_error_message = args[:http_error_message] if args.key?(:http_error_message)
  @http_error_status_code = args[:http_error_status_code] if args.key?(:http_error_status_code)
  @id = args[:id] if args.key?(:id)
  @insert_time = args[:insert_time] if args.key?(:insert_time)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @operation_type = args[:operation_type] if args.key?(:operation_type)
  @progress = args[:progress] if args.key?(:progress)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @start_time = args[:start_time] if args.key?(:start_time)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target_id = args[:target_id] if args.key?(:target_id)
  @target_link = args[:target_link] if args.key?(:target_link)
  @user = args[:user] if args.key?(:user)
  @warnings = args[:warnings] if args.key?(:warnings)
  @zone = args[:zone] if args.key?(:zone)
end