Class: Google::Apis::ComputeV1::PathMatcher

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

A matcher for the path portion of the URL. The BackendService from the longest- matched rule will serve the URL. If no rule was matched, the default service will be used.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ PathMatcher

Returns a new instance of PathMatcher.



6686
6687
6688
# File 'generated/google/apis/compute_v1/classes.rb', line 6686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_serviceString

The full or partial URL to the BackendService resource. This will be used if none of the pathRules defined by this PathMatcher is matched by the URL's path portion. For example, the following are all valid URLs to a BackendService resource:

Returns:

  • (String)


6668
6669
6670
# File 'generated/google/apis/compute_v1/classes.rb', line 6668

def default_service
  @default_service
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


6674
6675
6676
# File 'generated/google/apis/compute_v1/classes.rb', line 6674

def description
  @description
end

#nameString

The name to which this PathMatcher is referred by the HostRule. Corresponds to the JSON property name

Returns:

  • (String)


6679
6680
6681
# File 'generated/google/apis/compute_v1/classes.rb', line 6679

def name
  @name
end

#path_rulesArray<Google::Apis::ComputeV1::PathRule>

The list of path rules. Corresponds to the JSON property pathRules



6684
6685
6686
# File 'generated/google/apis/compute_v1/classes.rb', line 6684

def path_rules
  @path_rules
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6691
6692
6693
6694
6695
6696
# File 'generated/google/apis/compute_v1/classes.rb', line 6691

def update!(**args)
  @default_service = args[:default_service] if args.key?(:default_service)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @path_rules = args[:path_rules] if args.key?(:path_rules)
end