Class: Google::Apis::ComputeV1::Project

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

A Project resource. Projects can only be created in the Google Cloud Platform Console. Unless marked otherwise, values can only be modified in the console.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ Project

Returns a new instance of Project.



6792
6793
6794
# File 'generated/google/apis/compute_v1/classes.rb', line 6792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#common_instance_metadataGoogle::Apis::ComputeV1::Metadata

A metadata key/value entry. Corresponds to the JSON property commonInstanceMetadata



6736
6737
6738
# File 'generated/google/apis/compute_v1/classes.rb', line 6736

def 
  
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


6741
6742
6743
# File 'generated/google/apis/compute_v1/classes.rb', line 6741

def creation_timestamp
  @creation_timestamp
end

#default_service_accountString

[Output Only] Default service account used by VMs running in this project. Corresponds to the JSON property defaultServiceAccount

Returns:

  • (String)


6746
6747
6748
# File 'generated/google/apis/compute_v1/classes.rb', line 6746

def 
  
end

#descriptionString

An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


6751
6752
6753
# File 'generated/google/apis/compute_v1/classes.rb', line 6751

def description
  @description
end

#enabled_featuresArray<String>

Restricted features enabled for use on this project. Corresponds to the JSON property enabledFeatures

Returns:

  • (Array<String>)


6756
6757
6758
# File 'generated/google/apis/compute_v1/classes.rb', line 6756

def enabled_features
  @enabled_features
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. This is not the project ID, and is just a unique ID used by Compute Engine to identify resources. Corresponds to the JSON property id

Returns:

  • (String)


6763
6764
6765
# File 'generated/google/apis/compute_v1/classes.rb', line 6763

def id
  @id
end

#kindString

[Output Only] Type of the resource. Always compute#project for projects. Corresponds to the JSON property kind

Returns:

  • (String)


6768
6769
6770
# File 'generated/google/apis/compute_v1/classes.rb', line 6768

def kind
  @kind
end

#nameString

The project ID. For example: my-example-project. Use the project ID to make requests to Compute Engine. Corresponds to the JSON property name

Returns:

  • (String)


6774
6775
6776
# File 'generated/google/apis/compute_v1/classes.rb', line 6774

def name
  @name
end

#quotasArray<Google::Apis::ComputeV1::Quota>

[Output Only] Quotas assigned to this project. Corresponds to the JSON property quotas

Returns:



6779
6780
6781
# File 'generated/google/apis/compute_v1/classes.rb', line 6779

def quotas
  @quotas
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


6784
6785
6786
# File 'generated/google/apis/compute_v1/classes.rb', line 6784

def self_link
  @self_link
end

#usage_export_locationGoogle::Apis::ComputeV1::UsageExportLocation

The location in Cloud Storage and naming method of the daily usage report. Contains bucket_name and report_name prefix. Corresponds to the JSON property usageExportLocation



6790
6791
6792
# File 'generated/google/apis/compute_v1/classes.rb', line 6790

def usage_export_location
  @usage_export_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6797
6798
6799
6800
6801
6802
6803
6804
6805
6806
6807
6808
6809
# File 'generated/google/apis/compute_v1/classes.rb', line 6797

def update!(**args)
   = args[:common_instance_metadata] if args.key?(:common_instance_metadata)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
   = args[:default_service_account] if args.key?(:default_service_account)
  @description = args[:description] if args.key?(:description)
  @enabled_features = args[:enabled_features] if args.key?(:enabled_features)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @quotas = args[:quotas] if args.key?(:quotas)
  @self_link = args[:self_link] if args.key?(:self_link)
  @usage_export_location = args[:usage_export_location] if args.key?(:usage_export_location)
end