Class: Google::Apis::ComputeV1::Region
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Region
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
Region resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] Textual description of the resource.
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#quotas ⇒ Array<Google::Apis::ComputeV1::Quota>
[Output Only] Quotas assigned to this region.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ String
[Output Only] Status of the region, either UP or DOWN.
-
#zones ⇒ Array<String>
[Output Only] A list of zones available in this region, in the form of resource URLs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Region
constructor
A new instance of Region.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ Region
Returns a new instance of Region.
6899 6900 6901 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6899 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
6850 6851 6852 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6850 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeV1::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
6855 6856 6857 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6855 def deprecated @deprecated end |
#description ⇒ String
[Output Only] Textual description of the resource.
Corresponds to the JSON property description
6860 6861 6862 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6860 def description @description end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
6866 6867 6868 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6866 def id @id end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#region for regions.
Corresponds to the JSON property kind
6871 6872 6873 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6871 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
6876 6877 6878 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6876 def name @name end |
#quotas ⇒ Array<Google::Apis::ComputeV1::Quota>
[Output Only] Quotas assigned to this region.
Corresponds to the JSON property quotas
6881 6882 6883 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6881 def quotas @quotas end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
6886 6887 6888 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6886 def self_link @self_link end |
#status ⇒ String
[Output Only] Status of the region, either UP or DOWN.
Corresponds to the JSON property status
6891 6892 6893 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6891 def status @status end |
#zones ⇒ Array<String>
[Output Only] A list of zones available in this region, in the form of
resource URLs.
Corresponds to the JSON property zones
6897 6898 6899 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6897 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6904 6905 6906 6907 6908 6909 6910 6911 6912 6913 6914 6915 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6904 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @quotas = args[:quotas] if args.key?(:quotas) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) @zones = args[:zones] if args.key?(:zones) end |