Class: Google::Apis::ComputeV1::RegionList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
Contains a list of region resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::Region>
[Output Only] A list of Region resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionList
constructor
A new instance of RegionList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ RegionList
Returns a new instance of RegionList.
7320 7321 7322 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7320 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
7294 7295 7296 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7294 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Region>
[Output Only] A list of Region resources.
Corresponds to the JSON property items
7299 7300 7301 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7299 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#regionList for lists of regions.
Corresponds to the JSON property kind
7304 7305 7306 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7304 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
7313 7314 7315 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7313 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
7318 7319 7320 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7318 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7325 7326 7327 7328 7329 7330 7331 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7325 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |