Class: Google::Apis::ComputeV1::Router

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

Router resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ Router

Returns a new instance of Router.



7672
7673
7674
# File 'generated/google/apis/compute_v1/classes.rb', line 7672

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bgpGoogle::Apis::ComputeV1::RouterBgp

BGP information specific to this router. Corresponds to the JSON property bgp



7610
7611
7612
# File 'generated/google/apis/compute_v1/classes.rb', line 7610

def bgp
  @bgp
end

#bgp_peersArray<Google::Apis::ComputeV1::RouterBgpPeer>

BGP information that needs to be configured into the routing stack to establish the BGP peering. It must specify peer ASN and either interface name, IP, or peer IP. Please refer to RFC4273. Corresponds to the JSON property bgpPeers



7617
7618
7619
# File 'generated/google/apis/compute_v1/classes.rb', line 7617

def bgp_peers
  @bgp_peers
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


7622
7623
7624
# File 'generated/google/apis/compute_v1/classes.rb', line 7622

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


7628
7629
7630
# File 'generated/google/apis/compute_v1/classes.rb', line 7628

def description
  @description
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


7634
7635
7636
# File 'generated/google/apis/compute_v1/classes.rb', line 7634

def id
  @id
end

#interfacesArray<Google::Apis::ComputeV1::RouterInterface>

Router interfaces. Each interface requires either one linked resource (e.g. linkedVpnTunnel), or IP address and IP address range (e.g. ipRange), or both. Corresponds to the JSON property interfaces



7640
7641
7642
# File 'generated/google/apis/compute_v1/classes.rb', line 7640

def interfaces
  @interfaces
end

#kindString

[Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


7645
7646
7647
# File 'generated/google/apis/compute_v1/classes.rb', line 7645

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


7655
7656
7657
# File 'generated/google/apis/compute_v1/classes.rb', line 7655

def name
  @name
end

#networkString

URI of the network to which this router belongs. Corresponds to the JSON property network

Returns:

  • (String)


7660
7661
7662
# File 'generated/google/apis/compute_v1/classes.rb', line 7660

def network
  @network
end

#regionString

[Output Only] URI of the region where the router resides. Corresponds to the JSON property region

Returns:

  • (String)


7665
7666
7667
# File 'generated/google/apis/compute_v1/classes.rb', line 7665

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


7670
7671
7672
# File 'generated/google/apis/compute_v1/classes.rb', line 7670

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
7688
7689
# File 'generated/google/apis/compute_v1/classes.rb', line 7677

def update!(**args)
  @bgp = args[:bgp] if args.key?(:bgp)
  @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @interfaces = args[:interfaces] if args.key?(:interfaces)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
end