Class: Google::Apis::ComputeV1::RouterAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterAggregatedList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
Contains a list of routers.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::RoutersScopedList>
A map of scoped router lists.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterAggregatedList
constructor
A new instance of RouterAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ RouterAggregatedList
Returns a new instance of RouterAggregatedList.
7726 7727 7728 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7726 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
7700 7701 7702 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7700 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::RoutersScopedList>
A map of scoped router lists.
Corresponds to the JSON property items
7705 7706 7707 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7705 def items @items end |
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
7710 7711 7712 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7710 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
7719 7720 7721 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7719 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
7724 7725 7726 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7724 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7731 7732 7733 7734 7735 7736 7737 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7731 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |