Class: Google::Apis::ComputeV1::RouterBgp

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ RouterBgp



7751
7752
7753
# File 'generated/google/apis/compute_v1/classes.rb', line 7751

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asnFixnum

Local BGP Autonomous System Number (ASN). Must be an RFC6996 private ASN, either 16-bit or 32-bit. The value will be fixed for this router resource. All VPN tunnels that link to this router will have the same local ASN. Corresponds to the JSON property asn



7749
7750
7751
# File 'generated/google/apis/compute_v1/classes.rb', line 7749

def asn
  @asn
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7756
7757
7758
# File 'generated/google/apis/compute_v1/classes.rb', line 7756

def update!(**args)
  @asn = args[:asn] if args.key?(:asn)
end