Class: Google::Apis::ComputeV1::RouterInterface
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterInterface
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#ip_range ⇒ String
IP address and range of the interface.
-
#linked_vpn_tunnel ⇒ String
URI of linked VPN tunnel.
-
#name ⇒ String
Name of this interface entry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterInterface
constructor
A new instance of RouterInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ RouterInterface
Returns a new instance of RouterInterface.
7839 7840 7841 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7839 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_range ⇒ String
IP address and range of the interface. The IP range must be in the RFC3927
link-local IP space. The value must be a CIDR-formatted string, for example:
169.254.0.1/30. NOTE: Do not truncate the address as it represents the IP
address of the interface.
Corresponds to the JSON property ipRange
7825 7826 7827 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7825 def ip_range @ip_range end |
#linked_vpn_tunnel ⇒ String
URI of linked VPN tunnel. It must be in the same region as the router. Each
interface can have at most one linked resource.
Corresponds to the JSON property linkedVpnTunnel
7831 7832 7833 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7831 def linked_vpn_tunnel @linked_vpn_tunnel end |
#name ⇒ String
Name of this interface entry. The name must be 1-63 characters long and comply
with RFC1035.
Corresponds to the JSON property name
7837 7838 7839 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7837 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7844 7845 7846 7847 7848 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7844 def update!(**args) @ip_range = args[:ip_range] if args.key?(:ip_range) @linked_vpn_tunnel = args[:linked_vpn_tunnel] if args.key?(:linked_vpn_tunnel) @name = args[:name] if args.key?(:name) end |