Class: Google::Apis::ComputeV1::Scheduling
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Scheduling
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
Sets the scheduling options for an Instance.
Instance Attribute Summary collapse
-
#automatic_restart ⇒ Boolean
(also: #automatic_restart?)
Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user).
-
#on_host_maintenance ⇒ String
Defines the maintenance behavior for this instance.
-
#preemptible ⇒ Boolean
(also: #preemptible?)
Whether the instance is preemptible.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Scheduling
constructor
A new instance of Scheduling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ Scheduling
Returns a new instance of Scheduling.
8216 8217 8218 |
# File 'generated/google/apis/compute_v1/classes.rb', line 8216 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automatic_restart ⇒ Boolean Also known as: automatic_restart?
Specifies whether the instance should be automatically restarted if it is
terminated by Compute Engine (not terminated by a user). You can only set the
automatic restart option for standard instances. Preemptible instances cannot
be automatically restarted.
Corresponds to the JSON property automaticRestart
8199 8200 8201 |
# File 'generated/google/apis/compute_v1/classes.rb', line 8199 def automatic_restart @automatic_restart end |
#on_host_maintenance ⇒ String
Defines the maintenance behavior for this instance. For standard instances,
the default behavior is MIGRATE. For preemptible instances, the default and
only possible behavior is TERMINATE. For more information, see Setting
Instance Scheduling Options.
Corresponds to the JSON property onHostMaintenance
8208 8209 8210 |
# File 'generated/google/apis/compute_v1/classes.rb', line 8208 def on_host_maintenance @on_host_maintenance end |
#preemptible ⇒ Boolean Also known as: preemptible?
Whether the instance is preemptible.
Corresponds to the JSON property preemptible
8213 8214 8215 |
# File 'generated/google/apis/compute_v1/classes.rb', line 8213 def preemptible @preemptible end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8221 8222 8223 8224 8225 |
# File 'generated/google/apis/compute_v1/classes.rb', line 8221 def update!(**args) @automatic_restart = args[:automatic_restart] if args.key?(:automatic_restart) @on_host_maintenance = args[:on_host_maintenance] if args.key?(:on_host_maintenance) @preemptible = args[:preemptible] if args.key?(:preemptible) end |