Class: Google::Apis::ComputeV1::SerialPortOutput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

An instance's serial console output.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ SerialPortOutput

Returns a new instance of SerialPortOutput.



8262
8263
8264
# File 'generated/google/apis/compute_v1/classes.rb', line 8262

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsString

[Output Only] The contents of the console output. Corresponds to the JSON property contents

Returns:

  • (String)


8235
8236
8237
# File 'generated/google/apis/compute_v1/classes.rb', line 8235

def contents
  @contents
end

#kindString

[Output Only] Type of the resource. Always compute#serialPortOutput for serial port output. Corresponds to the JSON property kind

Returns:

  • (String)


8241
8242
8243
# File 'generated/google/apis/compute_v1/classes.rb', line 8241

def kind
  @kind
end

#nextString

[Output Only] The position of the next byte of content from the serial console output. Use this value in the next request as the start parameter. Corresponds to the JSON property next

Returns:

  • (String)


8247
8248
8249
# File 'generated/google/apis/compute_v1/classes.rb', line 8247

def next
  @next
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8252
8253
8254
# File 'generated/google/apis/compute_v1/classes.rb', line 8252

def self_link
  @self_link
end

#startString

[Output Only] The starting byte position of the output that was returned. This should match the start parameter sent with the request. If the serial console output exceeds the size of the buffer, older output will be overwritten by newer content and the start values will be mismatched. Corresponds to the JSON property start

Returns:

  • (String)


8260
8261
8262
# File 'generated/google/apis/compute_v1/classes.rb', line 8260

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8267
8268
8269
8270
8271
8272
8273
# File 'generated/google/apis/compute_v1/classes.rb', line 8267

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @kind = args[:kind] if args.key?(:kind)
  @next = args[:next] if args.key?(:next)
  @self_link = args[:self_link] if args.key?(:self_link)
  @start = args[:start] if args.key?(:start)
end