Class: Google::Apis::ComputeV1::SslHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ SslHealthCheck

Returns a new instance of SslHealthCheck.



8175
8176
8177
# File 'generated/google/apis/compute_v1/classes.rb', line 8175

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#portFixnum

The TCP port number for the health check request. The default value is 443. Corresponds to the JSON property port

Returns:

  • (Fixnum)


8146
8147
8148
# File 'generated/google/apis/compute_v1/classes.rb', line 8146

def port
  @port
end

#port_nameString

Port name as defined in InstanceGroup#NamedPort#name. If both port and port_name are defined, port takes precedence. Corresponds to the JSON property portName

Returns:

  • (String)


8152
8153
8154
# File 'generated/google/apis/compute_v1/classes.rb', line 8152

def port_name
  @port_name
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


8158
8159
8160
# File 'generated/google/apis/compute_v1/classes.rb', line 8158

def proxy_header
  @proxy_header
end

#requestString

The application data to send once the SSL connection has been established ( default value is empty). If both request and response are empty, the connection establishment alone will indicate health. The request data can only be ASCII. Corresponds to the JSON property request

Returns:

  • (String)


8166
8167
8168
# File 'generated/google/apis/compute_v1/classes.rb', line 8166

def request
  @request
end

#responseString

The bytes to match against the beginning of the response data. If left empty ( the default value), any response will indicate health. The response data can only be ASCII. Corresponds to the JSON property response

Returns:

  • (String)


8173
8174
8175
# File 'generated/google/apis/compute_v1/classes.rb', line 8173

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8180
8181
8182
8183
8184
8185
8186
# File 'generated/google/apis/compute_v1/classes.rb', line 8180

def update!(**args)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @request = args[:request] if args.key?(:request)
  @response = args[:response] if args.key?(:response)
end