Class: Google::Apis::ComputeV1::Subnetwork

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

A Subnetwork resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ Subnetwork

Returns a new instance of Subnetwork.



8659
8660
8661
# File 'generated/google/apis/compute_v1/classes.rb', line 8659

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


8598
8599
8600
# File 'generated/google/apis/compute_v1/classes.rb', line 8598

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


8604
8605
8606
# File 'generated/google/apis/compute_v1/classes.rb', line 8604

def description
  @description
end

#gateway_addressString

[Output Only] The gateway address for default routes to reach destination addresses outside this subnetwork. Corresponds to the JSON property gatewayAddress

Returns:

  • (String)


8610
8611
8612
# File 'generated/google/apis/compute_v1/classes.rb', line 8610

def gateway_address
  @gateway_address
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


8616
8617
8618
# File 'generated/google/apis/compute_v1/classes.rb', line 8616

def id
  @id
end

#ip_cidr_rangeString

The range of internal addresses that are owned by this subnetwork. Provide this property when you create the subnetwork. For example, 10.0.0.0/8 or 192. 168.0.0/16. Ranges must be unique and non-overlapping within a network. Only IPv4 is supported. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


8624
8625
8626
# File 'generated/google/apis/compute_v1/classes.rb', line 8624

def ip_cidr_range
  @ip_cidr_range
end

#kindString

[Output Only] Type of the resource. Always compute#subnetwork for Subnetwork resources. Corresponds to the JSON property kind

Returns:

  • (String)


8630
8631
8632
# File 'generated/google/apis/compute_v1/classes.rb', line 8630

def kind
  @kind
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


8640
8641
8642
# File 'generated/google/apis/compute_v1/classes.rb', line 8640

def name
  @name
end

#networkString

The URL of the network to which this subnetwork belongs, provided by the client when initially creating the subnetwork. Only networks that are in the distributed mode can have subnetworks. Corresponds to the JSON property network

Returns:

  • (String)


8647
8648
8649
# File 'generated/google/apis/compute_v1/classes.rb', line 8647

def network
  @network
end

#regionString

URL of the region where the Subnetwork resides. Corresponds to the JSON property region

Returns:

  • (String)


8652
8653
8654
# File 'generated/google/apis/compute_v1/classes.rb', line 8652

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8657
8658
8659
# File 'generated/google/apis/compute_v1/classes.rb', line 8657

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8664
8665
8666
8667
8668
8669
8670
8671
8672
8673
8674
8675
# File 'generated/google/apis/compute_v1/classes.rb', line 8664

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @gateway_address = args[:gateway_address] if args.key?(:gateway_address)
  @id = args[:id] if args.key?(:id)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
end