Class: Google::Apis::ComputeV1::SubnetworkAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ SubnetworkAggregatedList

Returns a new instance of SubnetworkAggregatedList.



8713
8714
8715
# File 'generated/google/apis/compute_v1/classes.rb', line 8713

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


8686
8687
8688
# File 'generated/google/apis/compute_v1/classes.rb', line 8686

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeV1::SubnetworksScopedList>

[Output] A map of scoped Subnetwork lists. Corresponds to the JSON property items



8691
8692
8693
# File 'generated/google/apis/compute_v1/classes.rb', line 8691

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#subnetworkAggregatedList for aggregated lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


8697
8698
8699
# File 'generated/google/apis/compute_v1/classes.rb', line 8697

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8706
8707
8708
# File 'generated/google/apis/compute_v1/classes.rb', line 8706

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8711
8712
8713
# File 'generated/google/apis/compute_v1/classes.rb', line 8711

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8718
8719
8720
8721
8722
8723
8724
# File 'generated/google/apis/compute_v1/classes.rb', line 8718

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end