Class: Google::Apis::ComputeV1::SubnetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

Contains a list of Subnetwork resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ SubnetworkList

Returns a new instance of SubnetworkList.



8762
8763
8764
# File 'generated/google/apis/compute_v1/classes.rb', line 8762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


8735
8736
8737
# File 'generated/google/apis/compute_v1/classes.rb', line 8735

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::Subnetwork>

The Subnetwork resources. Corresponds to the JSON property items



8740
8741
8742
# File 'generated/google/apis/compute_v1/classes.rb', line 8740

def items
  @items
end

#kindString

[Output Only] Type of resource. Always compute#subnetworkList for lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


8746
8747
8748
# File 'generated/google/apis/compute_v1/classes.rb', line 8746

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8755
8756
8757
# File 'generated/google/apis/compute_v1/classes.rb', line 8755

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8760
8761
8762
# File 'generated/google/apis/compute_v1/classes.rb', line 8760

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8767
8768
8769
8770
8771
8772
8773
# File 'generated/google/apis/compute_v1/classes.rb', line 8767

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end