Class: Google::Apis::ComputeV1::TargetHttpsProxy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

A TargetHttpsProxy resource. This resource defines an HTTPS proxy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxy

Returns a new instance of TargetHttpsProxy.



9160
9161
9162
# File 'generated/google/apis/compute_v1/classes.rb', line 9160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


9108
9109
9110
# File 'generated/google/apis/compute_v1/classes.rb', line 9108

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


9114
9115
9116
# File 'generated/google/apis/compute_v1/classes.rb', line 9114

def description
  @description
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9120
9121
9122
# File 'generated/google/apis/compute_v1/classes.rb', line 9120

def id
  @id
end

#kindString

[Output Only] Type of resource. Always compute#targetHttpsProxy for target HTTPS proxies. Corresponds to the JSON property kind

Returns:

  • (String)


9126
9127
9128
# File 'generated/google/apis/compute_v1/classes.rb', line 9126

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


9136
9137
9138
# File 'generated/google/apis/compute_v1/classes.rb', line 9136

def name
  @name
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9141
9142
9143
# File 'generated/google/apis/compute_v1/classes.rb', line 9141

def self_link
  @self_link
end

#ssl_certificatesArray<String>

URLs to SslCertificate resources that are used to authenticate connections between users and the load balancer. Currently, exactly one SSL certificate must be specified. Corresponds to the JSON property sslCertificates

Returns:

  • (Array<String>)


9148
9149
9150
# File 'generated/google/apis/compute_v1/classes.rb', line 9148

def ssl_certificates
  @ssl_certificates
end

#url_mapString

A fully-qualified or valid partial URL to the UrlMap resource that defines the mapping from URL to the BackendService. For example, the following are all valid URLs for specifying a URL map:

Returns:

  • (String)


9158
9159
9160
# File 'generated/google/apis/compute_v1/classes.rb', line 9158

def url_map
  @url_map
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9165
9166
9167
9168
9169
9170
9171
9172
9173
9174
# File 'generated/google/apis/compute_v1/classes.rb', line 9165

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @ssl_certificates = args[:ssl_certificates] if args.key?(:ssl_certificates)
  @url_map = args[:url_map] if args.key?(:url_map)
end