Class: Google::Apis::ComputeV1::TargetPool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

A TargetPool resource. This resource defines a pool of instances, associated HttpHealthCheck resources, and the fallback target pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ TargetPool

Returns a new instance of TargetPool.



9597
9598
9599
# File 'generated/google/apis/compute_v1/classes.rb', line 9597

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_poolString

This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool, and its failoverRatio field is properly set to a value between [0, 1]. backupPool and failoverRatio together define the fallback behavior of the primary target pool: if the ratio of the healthy instances in the primary pool is at or below failoverRatio, traffic arriving at the load-balanced IP will be directed to the backup pool. In case where failoverRatio and backupPool are not set, or all the instances in the backup pool are unhealthy, the traffic will be directed back to the primary pool in the "force" mode, where traffic will be spread to the healthy instances with the best effort, or to all instances when no instance is healthy. Corresponds to the JSON property backupPool

Returns:

  • (String)


9515
9516
9517
# File 'generated/google/apis/compute_v1/classes.rb', line 9515

def backup_pool
  @backup_pool
end

#creation_timestampString

[Output Only] Creation timestamp in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


9520
9521
9522
# File 'generated/google/apis/compute_v1/classes.rb', line 9520

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


9526
9527
9528
# File 'generated/google/apis/compute_v1/classes.rb', line 9526

def description
  @description
end

#failover_ratioFloat

This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool (i.e., not as a backup pool to some other target pool). The value of the field must be in [0, 1]. If set, backupPool must also be set. They together define the fallback behavior of the primary target pool: if the ratio of the healthy instances in the primary pool is at or below this number, traffic arriving at the load- balanced IP will be directed to the backup pool. In case where failoverRatio is not set or all the instances in the backup pool are unhealthy, the traffic will be directed back to the primary pool in the " force" mode, where traffic will be spread to the healthy instances with the best effort, or to all instances when no instance is healthy. Corresponds to the JSON property failoverRatio

Returns:

  • (Float)


9541
9542
9543
# File 'generated/google/apis/compute_v1/classes.rb', line 9541

def failover_ratio
  @failover_ratio
end

#health_checksArray<String>

A list of URLs to the HttpHealthCheck resource. A member instance in this pool is considered healthy if and only if all specified health checks pass. An empty list means all member instances will be considered healthy at all times. Corresponds to the JSON property healthChecks

Returns:

  • (Array<String>)


9548
9549
9550
# File 'generated/google/apis/compute_v1/classes.rb', line 9548

def health_checks
  @health_checks
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9554
9555
9556
# File 'generated/google/apis/compute_v1/classes.rb', line 9554

def id
  @id
end

#instancesArray<String>

A list of resource URLs to the virtual machine instances serving this pool. They must live in zones contained in the same region as this pool. Corresponds to the JSON property instances

Returns:

  • (Array<String>)


9560
9561
9562
# File 'generated/google/apis/compute_v1/classes.rb', line 9560

def instances
  @instances
end

#kindString

[Output Only] Type of the resource. Always compute#targetPool for target pools. Corresponds to the JSON property kind

Returns:

  • (String)


9565
9566
9567
# File 'generated/google/apis/compute_v1/classes.rb', line 9565

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


9575
9576
9577
# File 'generated/google/apis/compute_v1/classes.rb', line 9575

def name
  @name
end

#regionString

[Output Only] URL of the region where the target pool resides. Corresponds to the JSON property region

Returns:

  • (String)


9580
9581
9582
# File 'generated/google/apis/compute_v1/classes.rb', line 9580

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9585
9586
9587
# File 'generated/google/apis/compute_v1/classes.rb', line 9585

def self_link
  @self_link
end

#session_affinityString

Sesssion affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy. Corresponds to the JSON property sessionAffinity

Returns:

  • (String)


9595
9596
9597
# File 'generated/google/apis/compute_v1/classes.rb', line 9595

def session_affinity
  @session_affinity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
9612
9613
9614
9615
# File 'generated/google/apis/compute_v1/classes.rb', line 9602

def update!(**args)
  @backup_pool = args[:backup_pool] if args.key?(:backup_pool)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @failover_ratio = args[:failover_ratio] if args.key?(:failover_ratio)
  @health_checks = args[:health_checks] if args.key?(:health_checks)
  @id = args[:id] if args.key?(:id)
  @instances = args[:instances] if args.key?(:instances)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @session_affinity = args[:session_affinity] if args.key?(:session_affinity)
end