Class: Google::Apis::ComputeV1::UrlMapList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb

Overview

Contains a list of UrlMap resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ UrlMapList



10562
10563
10564
# File 'generated/google/apis/compute_v1/classes.rb', line 10562

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource. Set by the server. Corresponds to the JSON property id



10536
10537
10538
# File 'generated/google/apis/compute_v1/classes.rb', line 10536

def id
  @id
end

#itemsArray<Google::Apis::ComputeV1::UrlMap>

A list of UrlMap resources. Corresponds to the JSON property items



10541
10542
10543
# File 'generated/google/apis/compute_v1/classes.rb', line 10541

def items
  @items
end

#kindString

Type of resource. Corresponds to the JSON property kind



10546
10547
10548
# File 'generated/google/apis/compute_v1/classes.rb', line 10546

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken



10555
10556
10557
# File 'generated/google/apis/compute_v1/classes.rb', line 10555

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink



10560
10561
10562
# File 'generated/google/apis/compute_v1/classes.rb', line 10560

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10567
10568
10569
10570
10571
10572
10573
# File 'generated/google/apis/compute_v1/classes.rb', line 10567

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
end