Class: Google::Apis::ContentV2::AccountStatusesBatchResponseEntry

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/content_v2/classes.rb,
generated/google/apis/content_v2/representations.rb,
generated/google/apis/content_v2/representations.rb

Overview

A batch entry encoding a single non-batch accountstatuses response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ AccountStatusesBatchResponseEntry

Returns a new instance of AccountStatusesBatchResponseEntry.



1315
1316
1317
# File 'generated/google/apis/content_v2/classes.rb', line 1315

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_statusGoogle::Apis::ContentV2::AccountStatus

The status of an account, i.e., information about its products, which is computed offline and not returned immediately at insertion time. Corresponds to the JSON property accountStatus



1303
1304
1305
# File 'generated/google/apis/content_v2/classes.rb', line 1303

def 
  @account_status
end

#batch_idFixnum

The ID of the request entry this entry responds to. Corresponds to the JSON property batchId

Returns:

  • (Fixnum)


1308
1309
1310
# File 'generated/google/apis/content_v2/classes.rb', line 1308

def batch_id
  @batch_id
end

#errorsGoogle::Apis::ContentV2::Errors

A list of errors returned by a failed batch entry. Corresponds to the JSON property errors



1313
1314
1315
# File 'generated/google/apis/content_v2/classes.rb', line 1313

def errors
  @errors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1320
1321
1322
1323
1324
# File 'generated/google/apis/content_v2/classes.rb', line 1320

def update!(**args)
  @account_status = args[:account_status] if args.key?(:account_status)
  @batch_id = args[:batch_id] if args.key?(:batch_id)
  @errors = args[:errors] if args.key?(:errors)
end