Class: Google::Apis::ContentV2::InventoryBatchRequestEntry

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/content_v2/classes.rb,
generated/google/apis/content_v2/representations.rb,
generated/google/apis/content_v2/representations.rb

Overview

A batch entry encoding a single non-batch inventory request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ InventoryBatchRequestEntry

Returns a new instance of InventoryBatchRequestEntry.



2523
2524
2525
# File 'generated/google/apis/content_v2/classes.rb', line 2523

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#batch_idFixnum

An entry ID, unique within the batch request. Corresponds to the JSON property batchId

Returns:

  • (Fixnum)


2500
2501
2502
# File 'generated/google/apis/content_v2/classes.rb', line 2500

def batch_id
  @batch_id
end

#inventoryGoogle::Apis::ContentV2::Inventory

Price and availability of the product. Corresponds to the JSON property inventory



2505
2506
2507
# File 'generated/google/apis/content_v2/classes.rb', line 2505

def inventory
  @inventory
end

#merchant_idString

The ID of the managing account. Corresponds to the JSON property merchantId

Returns:

  • (String)


2510
2511
2512
# File 'generated/google/apis/content_v2/classes.rb', line 2510

def merchant_id
  @merchant_id
end

#product_idString

The ID of the product for which to update price and availability. Corresponds to the JSON property productId

Returns:

  • (String)


2515
2516
2517
# File 'generated/google/apis/content_v2/classes.rb', line 2515

def product_id
  @product_id
end

#store_codeString

The code of the store for which to update price and availability. Use online to update price and availability of an online product. Corresponds to the JSON property storeCode

Returns:

  • (String)


2521
2522
2523
# File 'generated/google/apis/content_v2/classes.rb', line 2521

def store_code
  @store_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2528
2529
2530
2531
2532
2533
2534
# File 'generated/google/apis/content_v2/classes.rb', line 2528

def update!(**args)
  @batch_id = args[:batch_id] if args.key?(:batch_id)
  @inventory = args[:inventory] if args.key?(:inventory)
  @merchant_id = args[:merchant_id] if args.key?(:merchant_id)
  @product_id = args[:product_id] if args.key?(:product_id)
  @store_code = args[:store_code] if args.key?(:store_code)
end