Class: Google::Apis::ContentV2::OrderLineItem

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/content_v2/classes.rb,
generated/google/apis/content_v2/representations.rb,
generated/google/apis/content_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ OrderLineItem



3159
3160
3161
# File 'generated/google/apis/content_v2/classes.rb', line 3159

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cancellationsArray<Google::Apis::ContentV2::OrderCancellation>

Cancellations of the line item. Corresponds to the JSON property cancellations



3090
3091
3092
# File 'generated/google/apis/content_v2/classes.rb', line 3090

def cancellations
  @cancellations
end

#idString

The id of the line item. Corresponds to the JSON property id



3095
3096
3097
# File 'generated/google/apis/content_v2/classes.rb', line 3095

def id
  @id
end

#priceGoogle::Apis::ContentV2::Price

Total price for the line item. For example, if two items for $10 are purchased, the total price will be $20. Corresponds to the JSON property price



3101
3102
3103
# File 'generated/google/apis/content_v2/classes.rb', line 3101

def price
  @price
end

#productGoogle::Apis::ContentV2::OrderLineItemProduct

Product data from the time of the order placement. Corresponds to the JSON property product



3106
3107
3108
# File 'generated/google/apis/content_v2/classes.rb', line 3106

def product
  @product
end

#quantity_canceledFixnum

Number of items canceled. Corresponds to the JSON property quantityCanceled



3111
3112
3113
# File 'generated/google/apis/content_v2/classes.rb', line 3111

def quantity_canceled
  @quantity_canceled
end

#quantity_deliveredFixnum

Number of items delivered. Corresponds to the JSON property quantityDelivered



3116
3117
3118
# File 'generated/google/apis/content_v2/classes.rb', line 3116

def quantity_delivered
  @quantity_delivered
end

#quantity_orderedFixnum

Number of items ordered. Corresponds to the JSON property quantityOrdered



3121
3122
3123
# File 'generated/google/apis/content_v2/classes.rb', line 3121

def quantity_ordered
  @quantity_ordered
end

#quantity_pendingFixnum

Number of items pending. Corresponds to the JSON property quantityPending



3126
3127
3128
# File 'generated/google/apis/content_v2/classes.rb', line 3126

def quantity_pending
  @quantity_pending
end

#quantity_returnedFixnum

Number of items returned. Corresponds to the JSON property quantityReturned



3131
3132
3133
# File 'generated/google/apis/content_v2/classes.rb', line 3131

def quantity_returned
  @quantity_returned
end

#quantity_shippedFixnum

Number of items shipped. Corresponds to the JSON property quantityShipped



3136
3137
3138
# File 'generated/google/apis/content_v2/classes.rb', line 3136

def quantity_shipped
  @quantity_shipped
end

#return_infoGoogle::Apis::ContentV2::OrderLineItemReturnInfo

Details of the return policy for the line item. Corresponds to the JSON property returnInfo



3141
3142
3143
# File 'generated/google/apis/content_v2/classes.rb', line 3141

def return_info
  @return_info
end

#returnsArray<Google::Apis::ContentV2::OrderReturn>

Returns of the line item. Corresponds to the JSON property returns



3146
3147
3148
# File 'generated/google/apis/content_v2/classes.rb', line 3146

def returns
  @returns
end

#shipping_detailsGoogle::Apis::ContentV2::OrderLineItemShippingDetails

Details of the requested shipping for the line item. Corresponds to the JSON property shippingDetails



3151
3152
3153
# File 'generated/google/apis/content_v2/classes.rb', line 3151

def shipping_details
  @shipping_details
end

#taxGoogle::Apis::ContentV2::Price

Total tax amount for the line item. For example, if two items are purchased, and each have a cost tax of $2, the total tax amount will be $4. Corresponds to the JSON property tax



3157
3158
3159
# File 'generated/google/apis/content_v2/classes.rb', line 3157

def tax
  @tax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3164
3165
3166
3167
3168
3169
3170
3171
3172
3173
3174
3175
3176
3177
3178
3179
# File 'generated/google/apis/content_v2/classes.rb', line 3164

def update!(**args)
  @cancellations = args[:cancellations] if args.key?(:cancellations)
  @id = args[:id] if args.key?(:id)
  @price = args[:price] if args.key?(:price)
  @product = args[:product] if args.key?(:product)
  @quantity_canceled = args[:quantity_canceled] if args.key?(:quantity_canceled)
  @quantity_delivered = args[:quantity_delivered] if args.key?(:quantity_delivered)
  @quantity_ordered = args[:quantity_ordered] if args.key?(:quantity_ordered)
  @quantity_pending = args[:quantity_pending] if args.key?(:quantity_pending)
  @quantity_returned = args[:quantity_returned] if args.key?(:quantity_returned)
  @quantity_shipped = args[:quantity_shipped] if args.key?(:quantity_shipped)
  @return_info = args[:return_info] if args.key?(:return_info)
  @returns = args[:returns] if args.key?(:returns)
  @shipping_details = args[:shipping_details] if args.key?(:shipping_details)
  @tax = args[:tax] if args.key?(:tax)
end