Class: Google::Apis::ContentV2::OrderPromotion

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/content_v2/classes.rb,
generated/google/apis/content_v2/representations.rb,
generated/google/apis/content_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ OrderPromotion

Returns a new instance of OrderPromotion.



3507
3508
3509
# File 'generated/google/apis/content_v2/classes.rb', line 3507

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#benefitsArray<Google::Apis::ContentV2::OrderPromotionBenefit>

Corresponds to the JSON property benefits



3468
3469
3470
# File 'generated/google/apis/content_v2/classes.rb', line 3468

def benefits
  @benefits
end

#effective_datesString

The date and time frame when the promotion is active and ready for validation review. Note that the promotion live time may be delayed for a few hours due to the validation review. Start date and end date are separated by a forward slash (/). The start date is specified by the format (YYYY-MM-DD), followed by the letter ?T?, the time of the day when the sale starts (in Greenwich Mean Time, GMT), followed by an expression of the time zone for the sale. The end date is in the same format. Corresponds to the JSON property effectiveDates

Returns:

  • (String)


3479
3480
3481
# File 'generated/google/apis/content_v2/classes.rb', line 3479

def effective_dates
  @effective_dates
end

#generic_redemption_codeString

Optional. The text code that corresponds to the promotion when applied on the retailer?s website. Corresponds to the JSON property genericRedemptionCode

Returns:

  • (String)


3485
3486
3487
# File 'generated/google/apis/content_v2/classes.rb', line 3485

def generic_redemption_code
  @generic_redemption_code
end

#idString

The unique ID of the promotion. Corresponds to the JSON property id

Returns:

  • (String)


3490
3491
3492
# File 'generated/google/apis/content_v2/classes.rb', line 3490

def id
  @id
end

#long_titleString

The full title of the promotion. Corresponds to the JSON property longTitle

Returns:

  • (String)


3495
3496
3497
# File 'generated/google/apis/content_v2/classes.rb', line 3495

def long_title
  @long_title
end

#product_applicabilityString

Whether the promotion is applicable to all products or only specific products. Corresponds to the JSON property productApplicability

Returns:

  • (String)


3500
3501
3502
# File 'generated/google/apis/content_v2/classes.rb', line 3500

def product_applicability
  @product_applicability
end

#redemption_channelString

Indicates that the promotion is valid online. Corresponds to the JSON property redemptionChannel

Returns:

  • (String)


3505
3506
3507
# File 'generated/google/apis/content_v2/classes.rb', line 3505

def redemption_channel
  @redemption_channel
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3512
3513
3514
3515
3516
3517
3518
3519
3520
# File 'generated/google/apis/content_v2/classes.rb', line 3512

def update!(**args)
  @benefits = args[:benefits] if args.key?(:benefits)
  @effective_dates = args[:effective_dates] if args.key?(:effective_dates)
  @generic_redemption_code = args[:generic_redemption_code] if args.key?(:generic_redemption_code)
  @id = args[:id] if args.key?(:id)
  @long_title = args[:long_title] if args.key?(:long_title)
  @product_applicability = args[:product_applicability] if args.key?(:product_applicability)
  @redemption_channel = args[:redemption_channel] if args.key?(:redemption_channel)
end