Class: Google::Apis::ContentV2::PostalCodeGroup
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2::PostalCodeGroup
- Defined in:
- generated/google/apis/content_v2/classes.rb,
generated/google/apis/content_v2/representations.rb,
generated/google/apis/content_v2/representations.rb
Instance Attribute Summary collapse
-
#country ⇒ String
The CLDR territory code of the country the postal code group applies to.
-
#name ⇒ String
The name of the postal code group, referred to in headers.
-
#postal_code_ranges ⇒ Array<Google::Apis::ContentV2::PostalCodeRange>
A range of postal codes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PostalCodeGroup
constructor
A new instance of PostalCodeGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ PostalCodeGroup
4803 4804 4805 |
# File 'generated/google/apis/content_v2/classes.rb', line 4803 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country ⇒ String
The CLDR territory code of the country the postal code group applies to.
Required.
Corresponds to the JSON property country
4791 4792 4793 |
# File 'generated/google/apis/content_v2/classes.rb', line 4791 def country @country end |
#name ⇒ String
The name of the postal code group, referred to in headers. Required.
Corresponds to the JSON property name
4796 4797 4798 |
# File 'generated/google/apis/content_v2/classes.rb', line 4796 def name @name end |
#postal_code_ranges ⇒ Array<Google::Apis::ContentV2::PostalCodeRange>
A range of postal codes. Required.
Corresponds to the JSON property postalCodeRanges
4801 4802 4803 |
# File 'generated/google/apis/content_v2/classes.rb', line 4801 def postal_code_ranges @postal_code_ranges end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4808 4809 4810 4811 4812 |
# File 'generated/google/apis/content_v2/classes.rb', line 4808 def update!(**args) @country = args[:country] if args.key?(:country) @name = args[:name] if args.key?(:name) @postal_code_ranges = args[:postal_code_ranges] if args.key?(:postal_code_ranges) end |