Class: Google::Apis::ContentV2::ProductStatusDataQualityIssue

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
generated/google/apis/content_v2/classes.rb,
generated/google/apis/content_v2/representations.rb,
generated/google/apis/content_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Google::Apis::Core::JsonObjectSupport

#to_json

Methods included from Google::Apis::Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ ProductStatusDataQualityIssue



5684
5685
5686
# File 'generated/google/apis/content_v2/classes.rb', line 5684

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailString

A more detailed error string. Corresponds to the JSON property detail



5647
5648
5649
# File 'generated/google/apis/content_v2/classes.rb', line 5647

def detail
  @detail
end

#fetch_statusString

The fetch status for landing_page_errors. Corresponds to the JSON property fetchStatus



5652
5653
5654
# File 'generated/google/apis/content_v2/classes.rb', line 5652

def fetch_status
  @fetch_status
end

#idString

The id of the data quality issue. Corresponds to the JSON property id



5657
5658
5659
# File 'generated/google/apis/content_v2/classes.rb', line 5657

def id
  @id
end

#locationString

The attribute name that is relevant for the issue. Corresponds to the JSON property location



5662
5663
5664
# File 'generated/google/apis/content_v2/classes.rb', line 5662

def location
  @location
end

#severityString

The severity of the data quality issue. Corresponds to the JSON property severity



5667
5668
5669
# File 'generated/google/apis/content_v2/classes.rb', line 5667

def severity
  @severity
end

#timestampString

The time stamp of the data quality issue. Corresponds to the JSON property timestamp



5672
5673
5674
# File 'generated/google/apis/content_v2/classes.rb', line 5672

def timestamp
  @timestamp
end

#value_on_landing_pageString

The value of that attribute that was found on the landing page Corresponds to the JSON property valueOnLandingPage



5677
5678
5679
# File 'generated/google/apis/content_v2/classes.rb', line 5677

def value_on_landing_page
  @value_on_landing_page
end

#value_providedString

The value the attribute had at time of evaluation. Corresponds to the JSON property valueProvided



5682
5683
5684
# File 'generated/google/apis/content_v2/classes.rb', line 5682

def value_provided
  @value_provided
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5689
5690
5691
5692
5693
5694
5695
5696
5697
5698
# File 'generated/google/apis/content_v2/classes.rb', line 5689

def update!(**args)
  @detail = args[:detail] if args.key?(:detail)
  @fetch_status = args[:fetch_status] if args.key?(:fetch_status)
  @id = args[:id] if args.key?(:id)
  @location = args[:location] if args.key?(:location)
  @severity = args[:severity] if args.key?(:severity)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
  @value_on_landing_page = args[:value_on_landing_page] if args.key?(:value_on_landing_page)
  @value_provided = args[:value_provided] if args.key?(:value_provided)
end