Class: Google::Apis::ContentV2::TestOrderLineItem
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2::TestOrderLineItem
- Defined in:
- generated/google/apis/content_v2/classes.rb,
generated/google/apis/content_v2/representations.rb,
generated/google/apis/content_v2/representations.rb
Instance Attribute Summary collapse
-
#product ⇒ Google::Apis::ContentV2::TestOrderLineItemProduct
Product data from the time of the order placement.
-
#quantity_ordered ⇒ Fixnum
Number of items ordered.
-
#return_info ⇒ Google::Apis::ContentV2::OrderLineItemReturnInfo
Details of the return policy for the line item.
-
#shipping_details ⇒ Google::Apis::ContentV2::OrderLineItemShippingDetails
Details of the requested shipping for the line item.
-
#unit_tax ⇒ Google::Apis::ContentV2::Price
Unit tax for the line item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TestOrderLineItem
constructor
A new instance of TestOrderLineItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ TestOrderLineItem
Returns a new instance of TestOrderLineItem.
6662 6663 6664 |
# File 'generated/google/apis/content_v2/classes.rb', line 6662 def initialize(**args) update!(**args) end |
Instance Attribute Details
#product ⇒ Google::Apis::ContentV2::TestOrderLineItemProduct
Product data from the time of the order placement.
Corresponds to the JSON property product
6640 6641 6642 |
# File 'generated/google/apis/content_v2/classes.rb', line 6640 def product @product end |
#quantity_ordered ⇒ Fixnum
Number of items ordered.
Corresponds to the JSON property quantityOrdered
6645 6646 6647 |
# File 'generated/google/apis/content_v2/classes.rb', line 6645 def quantity_ordered @quantity_ordered end |
#return_info ⇒ Google::Apis::ContentV2::OrderLineItemReturnInfo
Details of the return policy for the line item.
Corresponds to the JSON property returnInfo
6650 6651 6652 |
# File 'generated/google/apis/content_v2/classes.rb', line 6650 def return_info @return_info end |
#shipping_details ⇒ Google::Apis::ContentV2::OrderLineItemShippingDetails
Details of the requested shipping for the line item.
Corresponds to the JSON property shippingDetails
6655 6656 6657 |
# File 'generated/google/apis/content_v2/classes.rb', line 6655 def shipping_details @shipping_details end |
#unit_tax ⇒ Google::Apis::ContentV2::Price
Unit tax for the line item.
Corresponds to the JSON property unitTax
6660 6661 6662 |
# File 'generated/google/apis/content_v2/classes.rb', line 6660 def unit_tax @unit_tax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6667 6668 6669 6670 6671 6672 6673 |
# File 'generated/google/apis/content_v2/classes.rb', line 6667 def update!(**args) @product = args[:product] if args.key?(:product) @quantity_ordered = args[:quantity_ordered] if args.key?(:quantity_ordered) @return_info = args[:return_info] if args.key?(:return_info) @shipping_details = args[:shipping_details] if args.key?(:shipping_details) @unit_tax = args[:unit_tax] if args.key?(:unit_tax) end |