Class: Google::Apis::DataflowV1b3::ApproximateReportedProgress
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::ApproximateReportedProgress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb
Overview
A progress measurement of a WorkItem by a worker.
Instance Attribute Summary collapse
-
#consumed_parallelism ⇒ Google::Apis::DataflowV1b3::ReportedParallelism
Represents the level of parallelism in a WorkItem's input, reported by the worker.
-
#fraction_consumed ⇒ Float
Completion as fraction of the input consumed, from 0.0 (beginning, nothing consumed), to 1.0 (end of the input, entire input consumed).
-
#position ⇒ Google::Apis::DataflowV1b3::Position
Position defines a position within a collection of data.
-
#remaining_parallelism ⇒ Google::Apis::DataflowV1b3::ReportedParallelism
Represents the level of parallelism in a WorkItem's input, reported by the worker.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApproximateReportedProgress
constructor
A new instance of ApproximateReportedProgress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ ApproximateReportedProgress
Returns a new instance of ApproximateReportedProgress.
1936 1937 1938 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1936 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumed_parallelism ⇒ Google::Apis::DataflowV1b3::ReportedParallelism
Represents the level of parallelism in a WorkItem's input, reported by the
worker.
Corresponds to the JSON property consumedParallelism
1934 1935 1936 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1934 def consumed_parallelism @consumed_parallelism end |
#fraction_consumed ⇒ Float
Completion as fraction of the input consumed, from 0.0 (beginning, nothing
consumed), to 1.0 (end of the input, entire input consumed).
Corresponds to the JSON property fractionConsumed
1922 1923 1924 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1922 def fraction_consumed @fraction_consumed end |
#position ⇒ Google::Apis::DataflowV1b3::Position
Position defines a position within a collection of data. The value can be
either the end position, a key (used with ordered collections), a byte offset,
or a record index.
Corresponds to the JSON property position
1916 1917 1918 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1916 def position @position end |
#remaining_parallelism ⇒ Google::Apis::DataflowV1b3::ReportedParallelism
Represents the level of parallelism in a WorkItem's input, reported by the
worker.
Corresponds to the JSON property remainingParallelism
1928 1929 1930 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1928 def remaining_parallelism @remaining_parallelism end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1941 1942 1943 1944 1945 1946 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1941 def update!(**args) @position = args[:position] if args.key?(:position) @fraction_consumed = args[:fraction_consumed] if args.key?(:fraction_consumed) @remaining_parallelism = args[:remaining_parallelism] if args.key?(:remaining_parallelism) @consumed_parallelism = args[:consumed_parallelism] if args.key?(:consumed_parallelism) end |