Class: Google::Apis::DataflowV1b3::ApproximateSplitRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::ApproximateSplitRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb
Overview
A suggestion by the service to the worker to dynamically split the WorkItem.
Instance Attribute Summary collapse
-
#fraction_consumed ⇒ Float
A fraction at which to split the work item, from 0.0 (beginning of the input) to 1.0 (end of the input).
-
#position ⇒ Google::Apis::DataflowV1b3::Position
Position defines a position within a collection of data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApproximateSplitRequest
constructor
A new instance of ApproximateSplitRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ ApproximateSplitRequest
Returns a new instance of ApproximateSplitRequest.
2510 2511 2512 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2510 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fraction_consumed ⇒ Float
A fraction at which to split the work item, from 0.0 (beginning of the input)
to 1.0 (end of the input).
Corresponds to the JSON property fractionConsumed
2508 2509 2510 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2508 def fraction_consumed @fraction_consumed end |
#position ⇒ Google::Apis::DataflowV1b3::Position
Position defines a position within a collection of data. The value can be
either the end position, a key (used with ordered collections), a byte offset,
or a record index.
Corresponds to the JSON property position
2502 2503 2504 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2502 def position @position end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2515 2516 2517 2518 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2515 def update!(**args) @position = args[:position] if args.key?(:position) @fraction_consumed = args[:fraction_consumed] if args.key?(:fraction_consumed) end |