Class: Google::Apis::DataflowV1b3::CounterStructuredName

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb

Overview

Identifies a counter within a per-job namespace. Counters whose structured names are the same get merged into a single value for the job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ CounterStructuredName

Returns a new instance of CounterStructuredName.



1670
1671
1672
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1670

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#component_step_nameString

Name of the optimized step being executed by the workers. Corresponds to the JSON property componentStepName

Returns:

  • (String)


1653
1654
1655
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1653

def component_step_name
  @component_step_name
end

#execution_step_nameString

Name of the stage. An execution step contains multiple component steps. Corresponds to the JSON property executionStepName

Returns:

  • (String)


1658
1659
1660
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1658

def execution_step_name
  @execution_step_name
end

#nameString

Counter name. Not necessarily globally-unique, but unique within the context of the other fields. Required. Corresponds to the JSON property name

Returns:

  • (String)


1632
1633
1634
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1632

def name
  @name
end

#original_step_nameString

System generated name of the original step in the user's graph, before optimization. Corresponds to the JSON property originalStepName

Returns:

  • (String)


1648
1649
1650
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1648

def original_step_name
  @original_step_name
end

#other_originString

A string containing the origin of the counter. Corresponds to the JSON property otherOrigin

Returns:

  • (String)


1642
1643
1644
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1642

def other_origin
  @other_origin
end

#portionString

Portion of this counter, either key or value. Corresponds to the JSON property portion

Returns:

  • (String)


1668
1669
1670
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1668

def portion
  @portion
end

#standard_originString

One of the standard Origins defined above. Corresponds to the JSON property standardOrigin

Returns:

  • (String)


1637
1638
1639
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1637

def standard_origin
  @standard_origin
end

#worker_idString

ID of a particular worker. Corresponds to the JSON property workerId

Returns:

  • (String)


1663
1664
1665
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1663

def worker_id
  @worker_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1675

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @standard_origin = args[:standard_origin] if args.key?(:standard_origin)
  @other_origin = args[:other_origin] if args.key?(:other_origin)
  @original_step_name = args[:original_step_name] if args.key?(:original_step_name)
  @component_step_name = args[:component_step_name] if args.key?(:component_step_name)
  @execution_step_name = args[:execution_step_name] if args.key?(:execution_step_name)
  @worker_id = args[:worker_id] if args.key?(:worker_id)
  @portion = args[:portion] if args.key?(:portion)
end