Class: Google::Apis::DataflowV1b3::CounterStructuredNameAndMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb

Overview

A single message which encapsulates structured name and metadata for a given counter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ CounterStructuredNameAndMetadata

Returns a new instance of CounterStructuredNameAndMetadata.



1612
1613
1614
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metadataGoogle::Apis::DataflowV1b3::CounterMetadata

CounterMetadata includes all static non-name non-value counter attributes. Corresponds to the JSON property metadata



1610
1611
1612
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1610

def 
  
end

#nameGoogle::Apis::DataflowV1b3::CounterStructuredName

Identifies a counter within a per-job namespace. Counters whose structured names are the same get merged into a single value for the job. Corresponds to the JSON property name



1605
1606
1607
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1605

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1617
1618
1619
1620
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1617

def update!(**args)
  @name = args[:name] if args.key?(:name)
   = args[:metadata] if args.key?(:metadata)
end