Class: Google::Apis::DataflowV1b3::CounterUpdate
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::CounterUpdate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb
Overview
An update to a Counter sent from a worker.
Instance Attribute Summary collapse
-
#boolean ⇒ Boolean
(also: #boolean?)
Boolean value for And, Or.
-
#cumulative ⇒ Boolean
(also: #cumulative?)
True if this counter is reported as the total cumulative aggregate value accumulated since the worker started working on this WorkItem.
-
#distribution ⇒ Google::Apis::DataflowV1b3::DistributionUpdate
A metric value representing a distribution.
-
#floating_point ⇒ Float
Floating point value for Sum, Max, Min.
-
#floating_point_list ⇒ Google::Apis::DataflowV1b3::FloatingPointList
A metric value representing a list of floating point numbers.
-
#floating_point_mean ⇒ Google::Apis::DataflowV1b3::FloatingPointMean
A representation of a floating point mean metric contribution.
-
#integer ⇒ Google::Apis::DataflowV1b3::SplitInt64
A representation of an int64, n, that is immune to precision loss when encoded in JSON.
-
#integer_list ⇒ Google::Apis::DataflowV1b3::IntegerList
A metric value representing a list of integers.
-
#integer_mean ⇒ Google::Apis::DataflowV1b3::IntegerMean
A representation of an integer mean metric contribution.
-
#internal ⇒ Object
Value for internally-defined counters used by the Dataflow service.
-
#name_and_kind ⇒ Google::Apis::DataflowV1b3::NameAndKind
Basic metadata about a counter.
-
#short_id ⇒ String
The service-generated short identifier for this counter.
-
#string_list ⇒ Google::Apis::DataflowV1b3::StringList
A metric value representing a list of strings.
-
#structured_name_and_metadata ⇒ Google::Apis::DataflowV1b3::CounterStructuredNameAndMetadata
A single message which encapsulates structured name and metadata for a given counter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CounterUpdate
constructor
A new instance of CounterUpdate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ CounterUpdate
Returns a new instance of CounterUpdate.
1548 1549 1550 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1548 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boolean ⇒ Boolean Also known as: boolean?
Boolean value for And, Or.
Corresponds to the JSON property boolean
1510 1511 1512 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1510 def boolean @boolean end |
#cumulative ⇒ Boolean Also known as: cumulative?
True if this counter is reported as the total cumulative aggregate value
accumulated since the worker started working on this WorkItem. By default this
is false, indicating that this counter is reported as a delta.
Corresponds to the JSON property cumulative
1493 1494 1495 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1493 def cumulative @cumulative end |
#distribution ⇒ Google::Apis::DataflowV1b3::DistributionUpdate
A metric value representing a distribution.
Corresponds to the JSON property distribution
1541 1542 1543 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1541 def distribution @distribution end |
#floating_point ⇒ Float
Floating point value for Sum, Max, Min.
Corresponds to the JSON property floatingPoint
1505 1506 1507 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1505 def floating_point @floating_point end |
#floating_point_list ⇒ Google::Apis::DataflowV1b3::FloatingPointList
A metric value representing a list of floating point numbers.
Corresponds to the JSON property floatingPointList
1531 1532 1533 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1531 def floating_point_list @floating_point_list end |
#floating_point_mean ⇒ Google::Apis::DataflowV1b3::FloatingPointMean
A representation of a floating point mean metric contribution.
Corresponds to the JSON property floatingPointMean
1521 1522 1523 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1521 def floating_point_mean @floating_point_mean end |
#integer ⇒ Google::Apis::DataflowV1b3::SplitInt64
A representation of an int64, n, that is immune to precision loss when encoded
in JSON.
Corresponds to the JSON property integer
1500 1501 1502 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1500 def integer @integer end |
#integer_list ⇒ Google::Apis::DataflowV1b3::IntegerList
A metric value representing a list of integers.
Corresponds to the JSON property integerList
1526 1527 1528 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1526 def integer_list @integer_list end |
#integer_mean ⇒ Google::Apis::DataflowV1b3::IntegerMean
A representation of an integer mean metric contribution.
Corresponds to the JSON property integerMean
1516 1517 1518 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1516 def integer_mean @integer_mean end |
#internal ⇒ Object
Value for internally-defined counters used by the Dataflow service.
Corresponds to the JSON property internal
1546 1547 1548 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1546 def internal @internal end |
#name_and_kind ⇒ Google::Apis::DataflowV1b3::NameAndKind
Basic metadata about a counter.
Corresponds to the JSON property nameAndKind
1474 1475 1476 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1474 def name_and_kind @name_and_kind end |
#short_id ⇒ String
The service-generated short identifier for this counter. The short_id -> (name,
metadata) mapping is constant for the lifetime of a job.
Corresponds to the JSON property shortId
1480 1481 1482 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1480 def short_id @short_id end |
#string_list ⇒ Google::Apis::DataflowV1b3::StringList
A metric value representing a list of strings.
Corresponds to the JSON property stringList
1536 1537 1538 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1536 def string_list @string_list end |
#structured_name_and_metadata ⇒ Google::Apis::DataflowV1b3::CounterStructuredNameAndMetadata
A single message which encapsulates structured name and metadata for a given
counter.
Corresponds to the JSON property structuredNameAndMetadata
1486 1487 1488 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1486 def @structured_name_and_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1553 def update!(**args) @name_and_kind = args[:name_and_kind] if args.key?(:name_and_kind) @short_id = args[:short_id] if args.key?(:short_id) @structured_name_and_metadata = args[:structured_name_and_metadata] if args.key?(:structured_name_and_metadata) @cumulative = args[:cumulative] if args.key?(:cumulative) @integer = args[:integer] if args.key?(:integer) @floating_point = args[:floating_point] if args.key?(:floating_point) @boolean = args[:boolean] if args.key?(:boolean) @integer_mean = args[:integer_mean] if args.key?(:integer_mean) @floating_point_mean = args[:floating_point_mean] if args.key?(:floating_point_mean) @integer_list = args[:integer_list] if args.key?(:integer_list) @floating_point_list = args[:floating_point_list] if args.key?(:floating_point_list) @string_list = args[:string_list] if args.key?(:string_list) @distribution = args[:distribution] if args.key?(:distribution) @internal = args[:internal] if args.key?(:internal) end |