Class: Google::Apis::DataflowV1b3::CreateJobFromTemplateRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::CreateJobFromTemplateRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb
Overview
A request to create a Cloud Dataflow job from a template.
Instance Attribute Summary collapse
-
#environment ⇒ Google::Apis::DataflowV1b3::RuntimeEnvironment
The environment values to set at runtime.
-
#gcs_path ⇒ String
Required.
-
#job_name ⇒ String
Required.
-
#parameters ⇒ Hash<String,String>
The runtime parameters to pass to the job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateJobFromTemplateRequest
constructor
A new instance of CreateJobFromTemplateRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ CreateJobFromTemplateRequest
Returns a new instance of CreateJobFromTemplateRequest.
1193 1194 1195 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1193 def initialize(**args) update!(**args) end |
Instance Attribute Details
#environment ⇒ Google::Apis::DataflowV1b3::RuntimeEnvironment
The environment values to set at runtime.
Corresponds to the JSON property environment
1191 1192 1193 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1191 def environment @environment end |
#gcs_path ⇒ String
Required. A Cloud Storage path to the template from which to create the job.
Must be a valid Cloud Storage URL, beginning with gs://.
Corresponds to the JSON property gcsPath
1181 1182 1183 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1181 def gcs_path @gcs_path end |
#job_name ⇒ String
Required. The job name to use for the created job.
Corresponds to the JSON property jobName
1175 1176 1177 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1175 def job_name @job_name end |
#parameters ⇒ Hash<String,String>
The runtime parameters to pass to the job.
Corresponds to the JSON property parameters
1186 1187 1188 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1186 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1198 1199 1200 1201 1202 1203 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1198 def update!(**args) @job_name = args[:job_name] if args.key?(:job_name) @gcs_path = args[:gcs_path] if args.key?(:gcs_path) @parameters = args[:parameters] if args.key?(:parameters) @environment = args[:environment] if args.key?(:environment) end |