Class: Google::Apis::DataflowV1b3::DistributionUpdate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb

Overview

A metric value representing a distribution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ DistributionUpdate

Returns a new instance of DistributionUpdate.



1893
1894
1895
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countGoogle::Apis::DataflowV1b3::SplitInt64

A representation of an int64, n, that is immune to precision loss when encoded in JSON. Corresponds to the JSON property count



1880
1881
1882
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1880

def count
  @count
end

#maxGoogle::Apis::DataflowV1b3::SplitInt64

A representation of an int64, n, that is immune to precision loss when encoded in JSON. Corresponds to the JSON property max



1874
1875
1876
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1874

def max
  @max
end

#minGoogle::Apis::DataflowV1b3::SplitInt64

A representation of an int64, n, that is immune to precision loss when encoded in JSON. Corresponds to the JSON property min



1868
1869
1870
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1868

def min
  @min
end

#sumGoogle::Apis::DataflowV1b3::SplitInt64

A representation of an int64, n, that is immune to precision loss when encoded in JSON. Corresponds to the JSON property sum



1886
1887
1888
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1886

def sum
  @sum
end

#sum_of_squaresFloat

Use a double since the sum of squares is likely to overflow int64. Corresponds to the JSON property sumOfSquares

Returns:

  • (Float)


1891
1892
1893
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1891

def sum_of_squares
  @sum_of_squares
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1898
1899
1900
1901
1902
1903
1904
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1898

def update!(**args)
  @min = args[:min] if args.key?(:min)
  @max = args[:max] if args.key?(:max)
  @count = args[:count] if args.key?(:count)
  @sum = args[:sum] if args.key?(:sum)
  @sum_of_squares = args[:sum_of_squares] if args.key?(:sum_of_squares)
end