Class: Google::Apis::DataflowV1b3::MapTask

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb

Overview

MapTask consists of an ordered set of instructions, each of which describes one particular low-level operation for the worker to perform in order to accomplish the MapTask's WorkItem. Each instruction must appear in the list before any instructions which depends on its output.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ MapTask

Returns a new instance of MapTask.



2751
2752
2753
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2751

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instructionsArray<Google::Apis::DataflowV1b3::ParallelInstruction>

The instructions in the MapTask. Corresponds to the JSON property instructions



2738
2739
2740
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2738

def instructions
  @instructions
end

#stage_nameString

System-defined name of the stage containing this MapTask. Unique across the workflow. Corresponds to the JSON property stageName

Returns:

  • (String)


2749
2750
2751
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2749

def stage_name
  @stage_name
end

#system_nameString

System-defined name of this MapTask. Unique across the workflow. Corresponds to the JSON property systemName

Returns:

  • (String)


2743
2744
2745
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2743

def system_name
  @system_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2756
2757
2758
2759
2760
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2756

def update!(**args)
  @instructions = args[:instructions] if args.key?(:instructions)
  @system_name = args[:system_name] if args.key?(:system_name)
  @stage_name = args[:stage_name] if args.key?(:stage_name)
end