Class: Google::Apis::DataflowV1b3::ParallelInstruction
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::ParallelInstruction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb
Overview
Describes a particular operation comprising a MapTask.
Instance Attribute Summary collapse
-
#flatten ⇒ Google::Apis::DataflowV1b3::FlattenInstruction
An instruction that copies its inputs (zero or more) to its (single) output.
-
#name ⇒ String
User-provided name of this operation.
-
#original_name ⇒ String
System-defined name for the operation in the original workflow graph.
-
#outputs ⇒ Array<Google::Apis::DataflowV1b3::InstructionOutput>
Describes the outputs of the instruction.
-
#par_do ⇒ Google::Apis::DataflowV1b3::ParDoInstruction
An instruction that does a ParDo operation.
-
#partial_group_by_key ⇒ Google::Apis::DataflowV1b3::PartialGroupByKeyInstruction
An instruction that does a partial group-by-key.
-
#read ⇒ Google::Apis::DataflowV1b3::ReadInstruction
An instruction that reads records.
-
#system_name ⇒ String
System-defined name of this operation.
-
#write ⇒ Google::Apis::DataflowV1b3::WriteInstruction
An instruction that writes records.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ParallelInstruction
constructor
A new instance of ParallelInstruction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ ParallelInstruction
Returns a new instance of ParallelInstruction.
2813 2814 2815 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2813 def initialize(**args) update!(**args) end |
Instance Attribute Details
#flatten ⇒ Google::Apis::DataflowV1b3::FlattenInstruction
An instruction that copies its inputs (zero or more) to its (single) output.
Corresponds to the JSON property flatten
2806 2807 2808 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2806 def flatten @flatten end |
#name ⇒ String
User-provided name of this operation.
Corresponds to the JSON property name
2775 2776 2777 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2775 def name @name end |
#original_name ⇒ String
System-defined name for the operation in the original workflow graph.
Corresponds to the JSON property originalName
2780 2781 2782 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2780 def original_name @original_name end |
#outputs ⇒ Array<Google::Apis::DataflowV1b3::InstructionOutput>
Describes the outputs of the instruction.
Corresponds to the JSON property outputs
2811 2812 2813 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2811 def outputs @outputs end |
#par_do ⇒ Google::Apis::DataflowV1b3::ParDoInstruction
An instruction that does a ParDo operation. Takes one main input and zero or
more side inputs, and produces zero or more outputs. Runs user code.
Corresponds to the JSON property parDo
2796 2797 2798 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2796 def par_do @par_do end |
#partial_group_by_key ⇒ Google::Apis::DataflowV1b3::PartialGroupByKeyInstruction
An instruction that does a partial group-by-key. One input and one output.
Corresponds to the JSON property partialGroupByKey
2801 2802 2803 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2801 def partial_group_by_key @partial_group_by_key end |
#read ⇒ Google::Apis::DataflowV1b3::ReadInstruction
An instruction that reads records. Takes no inputs, produces one output.
Corresponds to the JSON property read
2785 2786 2787 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2785 def read @read end |
#system_name ⇒ String
System-defined name of this operation. Unique across the workflow.
Corresponds to the JSON property systemName
2770 2771 2772 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2770 def system_name @system_name end |
#write ⇒ Google::Apis::DataflowV1b3::WriteInstruction
An instruction that writes records. Takes one input, produces no outputs.
Corresponds to the JSON property write
2790 2791 2792 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2790 def write @write end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2818 def update!(**args) @system_name = args[:system_name] if args.key?(:system_name) @name = args[:name] if args.key?(:name) @original_name = args[:original_name] if args.key?(:original_name) @read = args[:read] if args.key?(:read) @write = args[:write] if args.key?(:write) @par_do = args[:par_do] if args.key?(:par_do) @partial_group_by_key = args[:partial_group_by_key] if args.key?(:partial_group_by_key) @flatten = args[:flatten] if args.key?(:flatten) @outputs = args[:outputs] if args.key?(:outputs) end |