Class: Google::Apis::DataflowV1b3::ReportWorkItemStatusResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb

Overview

Response from a request to report the status of WorkItems.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ ReportWorkItemStatusResponse

Returns a new instance of ReportWorkItemStatusResponse.



2413
2414
2415
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2413

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#work_item_service_statesArray<Google::Apis::DataflowV1b3::WorkItemServiceState>

A set of messages indicating the service-side state for each WorkItem whose status was reported, in the same order as the WorkItemStatus messages in the ReportWorkItemStatusRequest which resulting in this response. Corresponds to the JSON property workItemServiceStates



2411
2412
2413
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2411

def work_item_service_states
  @work_item_service_states
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2418
2419
2420
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2418

def update!(**args)
  @work_item_service_states = args[:work_item_service_states] if args.key?(:work_item_service_states)
end