Class: Google::Apis::DataflowV1b3::ResourceUtilizationReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb

Overview

Worker metrics exported from workers. This contains resource utilization metrics accumulated from a variety of sources. For more information, see go/df- resource-signals. Note that this proto closely follows the structure of its DFE siblings in its contents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ ResourceUtilizationReport

Returns a new instance of ResourceUtilizationReport.



4134
4135
4136
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 4134

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metricsArray<Hash<String,Object>>

Each Struct must parallel DFE worker metrics protos (eg., cpu_time metric will have nested values “timestamp_ms, total_ms, rate”). Corresponds to the JSON property metrics

Returns:

  • (Array<Hash<String,Object>>)


4132
4133
4134
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 4132

def metrics
  @metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4139
4140
4141
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 4139

def update!(**args)
  @metrics = args[:metrics] if args.key?(:metrics)
end