Class: Google::Apis::DataflowV1b3::RuntimeEnvironment
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::RuntimeEnvironment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb
Overview
The environment values to set at runtime.
Instance Attribute Summary collapse
-
#bypass_temp_dir_validation ⇒ Boolean
(also: #bypass_temp_dir_validation?)
Whether to bypass the safety checks for the job's temporary directory.
-
#max_workers ⇒ Fixnum
The maximum number of Google Compute Engine instances to be made available to your pipeline during execution, from 1 to 1000.
-
#service_account_email ⇒ String
The email address of the service account to run the job as.
-
#temp_location ⇒ String
The Cloud Storage path to use for temporary files.
-
#zone ⇒ String
The Compute Engine availability zone for launching worker instances to run your pipeline.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RuntimeEnvironment
constructor
A new instance of RuntimeEnvironment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ RuntimeEnvironment
Returns a new instance of RuntimeEnvironment.
1241 1242 1243 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bypass_temp_dir_validation ⇒ Boolean Also known as: bypass_temp_dir_validation?
Whether to bypass the safety checks for the job's temporary directory. Use
with caution.
Corresponds to the JSON property bypassTempDirValidation
1238 1239 1240 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1238 def bypass_temp_dir_validation @bypass_temp_dir_validation end |
#max_workers ⇒ Fixnum
The maximum number of Google Compute Engine instances to be made available to
your pipeline during execution, from 1 to 1000.
Corresponds to the JSON property maxWorkers
1214 1215 1216 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1214 def max_workers @max_workers end |
#service_account_email ⇒ String
The email address of the service account to run the job as.
Corresponds to the JSON property serviceAccountEmail
1226 1227 1228 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1226 def service_account_email @service_account_email end |
#temp_location ⇒ String
The Cloud Storage path to use for temporary files. Must be a valid Cloud
Storage URL, beginning with gs://.
Corresponds to the JSON property tempLocation
1232 1233 1234 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1232 def temp_location @temp_location end |
#zone ⇒ String
The Compute Engine availability zone for launching worker instances to run your
pipeline.
Corresponds to the JSON property zone
1221 1222 1223 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1221 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1246 1247 1248 1249 1250 1251 1252 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1246 def update!(**args) @max_workers = args[:max_workers] if args.key?(:max_workers) @zone = args[:zone] if args.key?(:zone) @service_account_email = args[:service_account_email] if args.key?(:service_account_email) @temp_location = args[:temp_location] if args.key?(:temp_location) @bypass_temp_dir_validation = args[:bypass_temp_dir_validation] if args.key?(:bypass_temp_dir_validation) end |