Class: Google::Apis::DataflowV1b3::SourceMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb

Overview

Metadata about a Source useful for automatically optimizing and tuning the pipeline, etc.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ SourceMetadata

Returns a new instance of SourceMetadata.



2208
2209
2210
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#estimated_size_bytesString

An estimate of the total size (in bytes) of the data that would be read from this source. This estimate is in terms of external storage size, before any decompression or other processing done by the reader. Corresponds to the JSON property estimatedSizeBytes

Returns:

  • (String)


2206
2207
2208
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2206

def estimated_size_bytes
  @estimated_size_bytes
end

#infiniteBoolean Also known as: infinite?

Specifies that the size of this source is known to be infinite (this is a streaming source). Corresponds to the JSON property infinite

Returns:

  • (Boolean)


2198
2199
2200
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2198

def infinite
  @infinite
end

#produces_sorted_keysBoolean Also known as: produces_sorted_keys?

Whether this source is known to produce key/value pairs with the (encoded) keys in lexicographically sorted order. Corresponds to the JSON property producesSortedKeys

Returns:

  • (Boolean)


2191
2192
2193
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2191

def produces_sorted_keys
  @produces_sorted_keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2213
2214
2215
2216
2217
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2213

def update!(**args)
  @produces_sorted_keys = args[:produces_sorted_keys] if args.key?(:produces_sorted_keys)
  @infinite = args[:infinite] if args.key?(:infinite)
  @estimated_size_bytes = args[:estimated_size_bytes] if args.key?(:estimated_size_bytes)
end