Class: Google::Apis::DataflowV1b3::SourceSplitResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb

Overview

The response to a SourceSplitRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ SourceSplitResponse

Returns a new instance of SourceSplitResponse.



2271
2272
2273
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2271

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bundlesArray<Google::Apis::DataflowV1b3::DerivedSource>

If outcome is SPLITTING_HAPPENED, then this is a list of bundles into which the source was split. Otherwise this field is ignored. This list can be empty, which means the source represents an empty input. Corresponds to the JSON property bundles



2264
2265
2266
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2264

def bundles
  @bundles
end

#outcomeString

Indicates whether splitting happened and produced a list of bundles. If this is USE_CURRENT_SOURCE_AS_IS, the current source should be processed "as is" without splitting. "bundles" is ignored in this case. If this is SPLITTING_HAPPENED, then "bundles" contains a list of bundles into which the source was split. Corresponds to the JSON property outcome

Returns:

  • (String)


2257
2258
2259
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2257

def outcome
  @outcome
end

#shardsArray<Google::Apis::DataflowV1b3::SourceSplitShard>

DEPRECATED in favor of bundles. Corresponds to the JSON property shards



2269
2270
2271
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2269

def shards
  @shards
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2276
2277
2278
2279
2280
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2276

def update!(**args)
  @outcome = args[:outcome] if args.key?(:outcome)
  @bundles = args[:bundles] if args.key?(:bundles)
  @shards = args[:shards] if args.key?(:shards)
end