Class: Google::Apis::DataflowV1b3::Step

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb

Overview

Defines a particular step within a Cloud Dataflow job. A job consists of multiple steps, each of which performs some specific operation as part of the overall job. Data is typically passed from one step to another as part of the job. Here's an example of a sequence of steps which together implement a Map- Reduce job: * Read a collection of data from some source, parsing the collection's elements. * Validate the elements. * Apply a user-defined function to map each element to some value and extract an element-specific key value. * Group elements with the same key into a single element with that key, transforming a multiply-keyed collection into a uniquely-keyed collection. * Write the elements out to some data sink. Note that the Cloud Dataflow service may be used to run many different types of jobs, not just Map-Reduce.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ Step

Returns a new instance of Step.



851
852
853
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

The kind of step in the Cloud Dataflow job. Corresponds to the JSON property kind

Returns:



837
838
839
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 837

def kind
  @kind
end

#nameString

The name that identifies the step. This must be unique for each step with respect to all other steps in the Cloud Dataflow job. Corresponds to the JSON property name

Returns:



843
844
845
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 843

def name
  @name
end

#propertiesHash<String,Object>

Named properties associated with the step. Each kind of predefined step has its own required set of properties. Corresponds to the JSON property properties

Returns:



849
850
851
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 849

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



856
857
858
859
860
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 856

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @properties = args[:properties] if args.key?(:properties)
end