Class: Google::Apis::DataflowV1b3::TaskRunnerSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb

Overview

Taskrunner configuration settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ TaskRunnerSettings

Returns a new instance of TaskRunnerSettings.



666
667
668
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 666

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alsologtostderrBoolean Also known as: alsologtostderr?

Whether to also send taskrunner log info to stderr. Corresponds to the JSON property alsologtostderr

Returns:

  • (Boolean)


614
615
616
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 614

def alsologtostderr
  @alsologtostderr
end

#base_task_dirString

The location on the worker for task-specific subdirectories. Corresponds to the JSON property baseTaskDir

Returns:

  • (String)


597
598
599
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 597

def base_task_dir
  @base_task_dir
end

#base_urlString

The base URL for the taskrunner to use when accessing Google Cloud APIs. When workers access Google Cloud APIs, they logically do so via relative URLs. If this field is specified, it supplies the base URL to use for resolving these relative URLs. The normative algorithm used is defined by RFC 1808, "Relative Uniform Resource Locators". If not specified, the default value is "http://www. googleapis.com/" Corresponds to the JSON property baseUrl

Returns:

  • (String)


582
583
584
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 582

def base_url
  @base_url
end

#commandlines_file_nameString

The file to store preprocessing commands in. Corresponds to the JSON property commandlinesFileName

Returns:

  • (String)


649
650
651
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 649

def commandlines_file_name
  @commandlines_file_name
end

#continue_on_exceptionBoolean Also known as: continue_on_exception?

Whether to continue taskrunner if an exception is hit. Corresponds to the JSON property continueOnException

Returns:

  • (Boolean)


602
603
604
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 602

def continue_on_exception
  @continue_on_exception
end

#dataflow_api_versionString

The API version of endpoint, e.g. "v1b3" Corresponds to the JSON property dataflowApiVersion

Returns:

  • (String)


587
588
589
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 587

def dataflow_api_version
  @dataflow_api_version
end

#harness_commandString

The command to launch the worker harness. Corresponds to the JSON property harnessCommand

Returns:

  • (String)


639
640
641
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 639

def harness_command
  @harness_command
end

#language_hintString

The suggested backend language. Corresponds to the JSON property languageHint

Returns:

  • (String)


659
660
661
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 659

def language_hint
  @language_hint
end

#log_dirString

The directory on the VM to store logs. Corresponds to the JSON property logDir

Returns:

  • (String)


627
628
629
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 627

def log_dir
  @log_dir
end

#log_to_serialconsoleBoolean Also known as: log_to_serialconsole?

Whether to send taskrunner log info to Google Compute Engine VM serial console. Corresponds to the JSON property logToSerialconsole

Returns:

  • (Boolean)


608
609
610
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 608

def log_to_serialconsole
  @log_to_serialconsole
end

#log_upload_locationString

Indicates where to put logs. If this is not specified, the logs will not be uploaded. The supported resource type is: Google Cloud Storage: storage. googleapis.com/bucket/object bucket.storage.googleapis.com/object Corresponds to the JSON property logUploadLocation

Returns:

  • (String)


622
623
624
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 622

def log_upload_location
  @log_upload_location
end

#oauth_scopesArray<String>

The OAuth2 scopes to be requested by the taskrunner in order to access the Cloud Dataflow API. Corresponds to the JSON property oauthScopes

Returns:

  • (Array<String>)


572
573
574
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 572

def oauth_scopes
  @oauth_scopes
end

#parallel_worker_settingsGoogle::Apis::DataflowV1b3::WorkerSettings

Provides data to pass through to the worker harness. Corresponds to the JSON property parallelWorkerSettings



592
593
594
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 592

def parallel_worker_settings
  @parallel_worker_settings
end

#streaming_worker_main_classString

The streaming worker main class name. Corresponds to the JSON property streamingWorkerMainClass

Returns:

  • (String)


664
665
666
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 664

def streaming_worker_main_class
  @streaming_worker_main_class
end

#task_groupString

The UNIX group ID on the worker VM to use for tasks launched by taskrunner; e. g. "wheel". Corresponds to the JSON property taskGroup

Returns:

  • (String)


566
567
568
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 566

def task_group
  @task_group
end

#task_userString

The UNIX user ID on the worker VM to use for tasks launched by taskrunner; e.g. "root". Corresponds to the JSON property taskUser

Returns:

  • (String)


560
561
562
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 560

def task_user
  @task_user
end

#temp_storage_prefixString

The prefix of the resources the taskrunner should use for temporary storage. The supported resource type is: Google Cloud Storage: storage.googleapis.com/ bucket/object bucket.storage.googleapis.com/object Corresponds to the JSON property tempStoragePrefix

Returns:

  • (String)


634
635
636
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 634

def temp_storage_prefix
  @temp_storage_prefix
end

#vm_idString

The ID string of the VM. Corresponds to the JSON property vmId

Returns:

  • (String)


654
655
656
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 654

def vm_id
  @vm_id
end

#workflow_file_nameString

The file to store the workflow in. Corresponds to the JSON property workflowFileName

Returns:

  • (String)


644
645
646
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 644

def workflow_file_name
  @workflow_file_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 671

def update!(**args)
  @task_user = args[:task_user] if args.key?(:task_user)
  @task_group = args[:task_group] if args.key?(:task_group)
  @oauth_scopes = args[:oauth_scopes] if args.key?(:oauth_scopes)
  @base_url = args[:base_url] if args.key?(:base_url)
  @dataflow_api_version = args[:dataflow_api_version] if args.key?(:dataflow_api_version)
  @parallel_worker_settings = args[:parallel_worker_settings] if args.key?(:parallel_worker_settings)
  @base_task_dir = args[:base_task_dir] if args.key?(:base_task_dir)
  @continue_on_exception = args[:continue_on_exception] if args.key?(:continue_on_exception)
  @log_to_serialconsole = args[:log_to_serialconsole] if args.key?(:log_to_serialconsole)
  @alsologtostderr = args[:alsologtostderr] if args.key?(:alsologtostderr)
  @log_upload_location = args[:log_upload_location] if args.key?(:log_upload_location)
  @log_dir = args[:log_dir] if args.key?(:log_dir)
  @temp_storage_prefix = args[:temp_storage_prefix] if args.key?(:temp_storage_prefix)
  @harness_command = args[:harness_command] if args.key?(:harness_command)
  @workflow_file_name = args[:workflow_file_name] if args.key?(:workflow_file_name)
  @commandlines_file_name = args[:commandlines_file_name] if args.key?(:commandlines_file_name)
  @vm_id = args[:vm_id] if args.key?(:vm_id)
  @language_hint = args[:language_hint] if args.key?(:language_hint)
  @streaming_worker_main_class = args[:streaming_worker_main_class] if args.key?(:streaming_worker_main_class)
end