Class: Google::Apis::DataprocV1::DataprocService

Inherits:
Core::BaseService show all
Defined in:
generated/google/apis/dataproc_v1/service.rb

Overview

Google Cloud Dataproc API

An API for managing Hadoop-based clusters and jobs on Google Cloud Platform.

Examples:

require 'google/apis/dataproc_v1'

Dataproc = Google::Apis::DataprocV1 # Alias the module
service = Dataproc::DataprocService.new

See Also:

Instance Attribute Summary collapse

Attributes inherited from Core::BaseService

#authorization, #base_path, #batch_path, #client, #client_options, #request_options, #root_url, #upload_path

Instance Method Summary collapse

Methods inherited from Core::BaseService

#batch, #batch_upload, #fetch_all, #http

Constructor Details

#initializeDataprocService

Returns a new instance of DataprocService.



45
46
47
# File 'generated/google/apis/dataproc_v1/service.rb', line 45

def initialize
  super('https://dataproc.googleapis.com/', '')
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



38
39
40
# File 'generated/google/apis/dataproc_v1/service.rb', line 38

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



43
44
45
# File 'generated/google/apis/dataproc_v1/service.rb', line 43

def quota_user
  @quota_user
end

Instance Method Details

#cancel_job(project_id, region, job_id, cancel_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Job

Starts a job cancellation request. To access the job resource after cancellation, call regions/region/jobs.list or regions/region/jobs.get.

Parameters:

  • project_id (String)

    [Required] The ID of the Google Cloud Platform project that the job belongs to.

  • region (String)

    [Required] The Cloud Dataproc region in which to handle the request.

  • job_id (String)

    [Required] The job ID.

  • cancel_job_request_object (Google::Apis::DataprocV1::CancelJobRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



467
468
469
470
471
472
473
474
475
476
477
478
479
# File 'generated/google/apis/dataproc_v1/service.rb', line 467

def cancel_job(project_id, region, job_id, cancel_job_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:post, 'v1/projects/{projectId}/regions/{region}/jobs/{jobId}:cancel', options)
  command.request_representation = Google::Apis::DataprocV1::CancelJobRequest::Representation
  command.request_object = cancel_job_request_object
  command.response_representation = Google::Apis::DataprocV1::Job::Representation
  command.response_class = Google::Apis::DataprocV1::Job
  command.params['projectId'] = project_id unless project_id.nil?
  command.params['region'] = region unless region.nil?
  command.params['jobId'] = job_id unless job_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#cancel_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Empty

Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED.

Parameters:

  • name (String)

    The name of the operation resource to be cancelled.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



651
652
653
654
655
656
657
658
659
# File 'generated/google/apis/dataproc_v1/service.rb', line 651

def cancel_operation(name, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:post, 'v1/{+name}:cancel', options)
  command.response_representation = Google::Apis::DataprocV1::Empty::Representation
  command.response_class = Google::Apis::DataprocV1::Empty
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_cluster(project_id, region, cluster_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Operation

Creates a cluster in a project.

Parameters:

  • project_id (String)

    [Required] The ID of the Google Cloud Platform project that the cluster belongs to.

  • region (String)

    [Required] The Cloud Dataproc region in which to handle the request.

  • cluster_object (Google::Apis::DataprocV1::Cluster) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



73
74
75
76
77
78
79
80
81
82
83
84
# File 'generated/google/apis/dataproc_v1/service.rb', line 73

def create_cluster(project_id, region, cluster_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:post, 'v1/projects/{projectId}/regions/{region}/clusters', options)
  command.request_representation = Google::Apis::DataprocV1::Cluster::Representation
  command.request_object = cluster_object
  command.response_representation = Google::Apis::DataprocV1::Operation::Representation
  command.response_class = Google::Apis::DataprocV1::Operation
  command.params['projectId'] = project_id unless project_id.nil?
  command.params['region'] = region unless region.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_cluster(project_id, region, cluster_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Operation

Deletes a cluster in a project.

Parameters:

  • project_id (String)

    [Required] The ID of the Google Cloud Platform project that the cluster belongs to.

  • region (String)

    [Required] The Cloud Dataproc region in which to handle the request.

  • cluster_name (String)

    [Required] The cluster name.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



163
164
165
166
167
168
169
170
171
172
173
# File 'generated/google/apis/dataproc_v1/service.rb', line 163

def delete_cluster(project_id, region, cluster_name, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:delete, 'v1/projects/{projectId}/regions/{region}/clusters/{clusterName}', options)
  command.response_representation = Google::Apis::DataprocV1::Operation::Representation
  command.response_class = Google::Apis::DataprocV1::Operation
  command.params['projectId'] = project_id unless project_id.nil?
  command.params['region'] = region unless region.nil?
  command.params['clusterName'] = cluster_name unless cluster_name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_job(project_id, region, job_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Empty

Deletes the job from the project. If the job is active, the delete fails, and the response returns FAILED_PRECONDITION.

Parameters:

  • project_id (String)

    [Required] The ID of the Google Cloud Platform project that the job belongs to.

  • region (String)

    [Required] The Cloud Dataproc region in which to handle the request.

  • job_id (String)

    [Required] The job ID.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



506
507
508
509
510
511
512
513
514
515
516
# File 'generated/google/apis/dataproc_v1/service.rb', line 506

def delete_job(project_id, region, job_id, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:delete, 'v1/projects/{projectId}/regions/{region}/jobs/{jobId}', options)
  command.response_representation = Google::Apis::DataprocV1::Empty::Representation
  command.response_class = Google::Apis::DataprocV1::Empty
  command.params['projectId'] = project_id unless project_id.nil?
  command.params['region'] = region unless region.nil?
  command.params['jobId'] = job_id unless job_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Empty

Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns google.rpc.Code. UNIMPLEMENTED.

Parameters:

  • name (String)

    The name of the operation resource to be deleted.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



614
615
616
617
618
619
620
621
622
# File 'generated/google/apis/dataproc_v1/service.rb', line 614

def delete_operation(name, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:delete, 'v1/{+name}', options)
  command.response_representation = Google::Apis::DataprocV1::Empty::Representation
  command.response_class = Google::Apis::DataprocV1::Empty
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#diagnose_cluster(project_id, region, cluster_name, diagnose_cluster_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Operation

Gets cluster diagnostic information. After the operation completes, the Operation.response field contains DiagnoseClusterOutputLocation.

Parameters:

  • project_id (String)

    [Required] The ID of the Google Cloud Platform project that the cluster belongs to.

  • region (String)

    [Required] The Cloud Dataproc region in which to handle the request.

  • cluster_name (String)

    [Required] The cluster name.

  • diagnose_cluster_request_object (Google::Apis::DataprocV1::DiagnoseClusterRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'generated/google/apis/dataproc_v1/service.rb', line 294

def diagnose_cluster(project_id, region, cluster_name, diagnose_cluster_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:post, 'v1/projects/{projectId}/regions/{region}/clusters/{clusterName}:diagnose', options)
  command.request_representation = Google::Apis::DataprocV1::DiagnoseClusterRequest::Representation
  command.request_object = diagnose_cluster_request_object
  command.response_representation = Google::Apis::DataprocV1::Operation::Representation
  command.response_class = Google::Apis::DataprocV1::Operation
  command.params['projectId'] = project_id unless project_id.nil?
  command.params['region'] = region unless region.nil?
  command.params['clusterName'] = cluster_name unless cluster_name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_cluster(project_id, region, cluster_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Cluster

Gets the resource representation for a cluster in a project.

Parameters:

  • project_id (String)

    [Required] The ID of the Google Cloud Platform project that the cluster belongs to.

  • region (String)

    [Required] The Cloud Dataproc region in which to handle the request.

  • cluster_name (String)

    [Required] The cluster name.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



200
201
202
203
204
205
206
207
208
209
210
# File 'generated/google/apis/dataproc_v1/service.rb', line 200

def get_cluster(project_id, region, cluster_name, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:get, 'v1/projects/{projectId}/regions/{region}/clusters/{clusterName}', options)
  command.response_representation = Google::Apis::DataprocV1::Cluster::Representation
  command.response_class = Google::Apis::DataprocV1::Cluster
  command.params['projectId'] = project_id unless project_id.nil?
  command.params['region'] = region unless region.nil?
  command.params['clusterName'] = cluster_name unless cluster_name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_job(project_id, region, job_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Job

Gets the resource representation for a job in a project.

Parameters:

  • project_id (String)

    [Required] The ID of the Google Cloud Platform project that the job belongs to.

  • region (String)

    [Required] The Cloud Dataproc region in which to handle the request.

  • job_id (String)

    [Required] The job ID.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



368
369
370
371
372
373
374
375
376
377
378
# File 'generated/google/apis/dataproc_v1/service.rb', line 368

def get_job(project_id, region, job_id, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:get, 'v1/projects/{projectId}/regions/{region}/jobs/{jobId}', options)
  command.response_representation = Google::Apis::DataprocV1::Job::Representation
  command.response_class = Google::Apis::DataprocV1::Job
  command.params['projectId'] = project_id unless project_id.nil?
  command.params['region'] = region unless region.nil?
  command.params['jobId'] = job_id unless job_id.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Operation

Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.

Parameters:

  • name (String)

    The name of the operation resource.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



581
582
583
584
585
586
587
588
589
# File 'generated/google/apis/dataproc_v1/service.rb', line 581

def get_operation(name, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:get, 'v1/{+name}', options)
  command.response_representation = Google::Apis::DataprocV1::Operation::Representation
  command.response_class = Google::Apis::DataprocV1::Operation
  command.params['name'] = name unless name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_clusters(project_id, region, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::ListClustersResponse

Lists all regions/region/clusters in a project.

Parameters:

  • project_id (String)

    [Required] The ID of the Google Cloud Platform project that the cluster belongs to.

  • region (String)

    [Required] The Cloud Dataproc region in which to handle the request.

  • filter (String) (defaults to: nil)

    [Optional] A filter constraining the clusters to list. Filters are case- sensitive and have the following syntax: field:value [field:value] ... or field = value [AND [field = value]] ... where field is one of status. state, clusterName, or labels.[KEY], and [KEY] is a label key. value can be * to match all values. status.state can be one of the following: ACTIVE, INACTIVE, CREATING, RUNNING, ERROR, DELETING, or UPDATING. ACTIVE contains the CREATING, UPDATING, and RUNNING states. INACTIVE contains the DELETING and ERROR states. clusterName is the name of the cluster provided at creation time. Only the logical AND operator is supported; space-separated items are treated as having an implicit AND operator. Example valid filters are: status.state:ACTIVE clusterName:mycluster labels.env:staging \ labels.starred:* and status.state = ACTIVE AND clusterName = mycluster \ AND labels.env = staging AND labels.starred = *

  • page_size (Fixnum) (defaults to: nil)

    [Optional] The standard List page size.

  • page_token (String) (defaults to: nil)

    [Optional] The standard List page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'generated/google/apis/dataproc_v1/service.rb', line 253

def list_clusters(project_id, region, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:get, 'v1/projects/{projectId}/regions/{region}/clusters', options)
  command.response_representation = Google::Apis::DataprocV1::ListClustersResponse::Representation
  command.response_class = Google::Apis::DataprocV1::ListClustersResponse
  command.params['projectId'] = project_id unless project_id.nil?
  command.params['region'] = region unless region.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_jobs(project_id, region, page_size: nil, page_token: nil, cluster_name: nil, job_state_matcher: nil, filter: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::ListJobsResponse

Lists regions/region/jobs in a project.

Parameters:

  • project_id (String)

    [Required] The ID of the Google Cloud Platform project that the job belongs to.

  • region (String)

    [Required] The Cloud Dataproc region in which to handle the request.

  • page_size (Fixnum) (defaults to: nil)

    [Optional] The number of results to return in each response.

  • page_token (String) (defaults to: nil)

    [Optional] The page token, returned by a previous call, to request the next page of results.

  • cluster_name (String) (defaults to: nil)

    [Optional] If set, the returned jobs list includes only jobs that were submitted to the named cluster.

  • job_state_matcher (String) (defaults to: nil)

    [Optional] Specifies enumerated categories of jobs to list (default = match ALL jobs).

  • filter (String) (defaults to: nil)

    [Optional] A filter constraining the jobs to list. Filters are case-sensitive and have the following syntax: field:value] ... or [field = value] AND [field [ = value]] ... where field is status.state or labels.[KEY], and [KEY] is a label key. value can be * to match all values. status.state can be either ACTIVE or INACTIVE. Only the logical AND operator is supported; space-separated items are treated as having an implicit AND operator. Example valid filters are: status.state:ACTIVE labels.env:staging labels. starred:* and status.state = ACTIVE AND labels.env = staging AND labels. starred = *

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'generated/google/apis/dataproc_v1/service.rb', line 423

def list_jobs(project_id, region, page_size: nil, page_token: nil, cluster_name: nil, job_state_matcher: nil, filter: nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:get, 'v1/projects/{projectId}/regions/{region}/jobs', options)
  command.response_representation = Google::Apis::DataprocV1::ListJobsResponse::Representation
  command.response_class = Google::Apis::DataprocV1::ListJobsResponse
  command.params['projectId'] = project_id unless project_id.nil?
  command.params['region'] = region unless region.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['clusterName'] = cluster_name unless cluster_name.nil?
  command.query['jobStateMatcher'] = job_state_matcher unless job_state_matcher.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_operations(name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::ListOperationsResponse

Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns UNIMPLEMENTED. NOTE: the name binding below allows API services to override the binding to use different resource name schemes, such as users/*/operations.

Parameters:

  • name (String)

    The name of the operation collection.

  • filter (String) (defaults to: nil)

    The standard list filter.

  • page_size (Fixnum) (defaults to: nil)

    The standard list page size.

  • page_token (String) (defaults to: nil)

    The standard list page token.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



547
548
549
550
551
552
553
554
555
556
557
558
# File 'generated/google/apis/dataproc_v1/service.rb', line 547

def list_operations(name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:get, 'v1/{+name}', options)
  command.response_representation = Google::Apis::DataprocV1::ListOperationsResponse::Representation
  command.response_class = Google::Apis::DataprocV1::ListOperationsResponse
  command.params['name'] = name unless name.nil?
  command.query['filter'] = filter unless filter.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#patch_cluster(project_id, region, cluster_name, cluster_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Operation

Updates a cluster in a project.

Parameters:

  • project_id (String)

    [Required] The ID of the Google Cloud Platform project the cluster belongs to.

  • region (String)

    [Required] The Cloud Dataproc region in which to handle the request.

  • cluster_name (String)

    [Required] The cluster name.

  • cluster_object (Google::Apis::DataprocV1::Cluster) (defaults to: nil)
  • update_mask (String) (defaults to: nil)

    [Required] Specifies the path, relative to Cluster, of the field to update. For example, to change the number of workers in a cluster to 5, the update_mask parameter would be specified as config.worker_config.num_instances, and the PATCH request body would specify the new value, as follows: " config": "workerConfig":"numInstances":"5" Similarly, to change the number of preemptible workers in a cluster to 5, the update_mask parameter would be config.secondary_worker_config.num_instances, and the PATCH request body would be set as follows: "config": "secondaryWorkerConfig":" numInstances":"5" Note: Currently, config.worker_config.num_instances and config.secondary_worker_config.num_instances are the only fields that can be updated.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'generated/google/apis/dataproc_v1/service.rb', line 123

def patch_cluster(project_id, region, cluster_name, cluster_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:patch, 'v1/projects/{projectId}/regions/{region}/clusters/{clusterName}', options)
  command.request_representation = Google::Apis::DataprocV1::Cluster::Representation
  command.request_object = cluster_object
  command.response_representation = Google::Apis::DataprocV1::Operation::Representation
  command.response_class = Google::Apis::DataprocV1::Operation
  command.params['projectId'] = project_id unless project_id.nil?
  command.params['region'] = region unless region.nil?
  command.params['clusterName'] = cluster_name unless cluster_name.nil?
  command.query['updateMask'] = update_mask unless update_mask.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#submit_job(project_id, region, submit_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Job

Submits a job to a cluster.

Parameters:

  • project_id (String)

    [Required] The ID of the Google Cloud Platform project that the job belongs to.

  • region (String)

    [Required] The Cloud Dataproc region in which to handle the request.

  • submit_job_request_object (Google::Apis::DataprocV1::SubmitJobRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



331
332
333
334
335
336
337
338
339
340
341
342
# File 'generated/google/apis/dataproc_v1/service.rb', line 331

def submit_job(project_id, region, submit_job_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:post, 'v1/projects/{projectId}/regions/{region}/jobs:submit', options)
  command.request_representation = Google::Apis::DataprocV1::SubmitJobRequest::Representation
  command.request_object = submit_job_request_object
  command.response_representation = Google::Apis::DataprocV1::Job::Representation
  command.response_class = Google::Apis::DataprocV1::Job
  command.params['projectId'] = project_id unless project_id.nil?
  command.params['region'] = region unless region.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end