Class: Google::Apis::DataprocV1::DiskConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/dataproc_v1/classes.rb,
generated/google/apis/dataproc_v1/representations.rb,
generated/google/apis/dataproc_v1/representations.rb

Overview

Specifies the config of disk options for a group of VM instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ DiskConfig

Returns a new instance of DiskConfig.



327
328
329
# File 'generated/google/apis/dataproc_v1/classes.rb', line 327

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boot_disk_size_gbFixnum

[Optional] Size in GB of the boot disk (default is 500GB). Corresponds to the JSON property bootDiskSizeGb

Returns:

  • (Fixnum)


316
317
318
# File 'generated/google/apis/dataproc_v1/classes.rb', line 316

def boot_disk_size_gb
  @boot_disk_size_gb
end

#num_local_ssdsFixnum

[Optional] Number of attached SSDs, from 0 to 4 (default is 0). If SSDs are not attached, the boot disk is used to store runtime logs and HDFS data. If one or more SSDs are attached, this runtime bulk data is spread across them, and the boot disk contains only basic config and installed binaries. Corresponds to the JSON property numLocalSsds

Returns:

  • (Fixnum)


325
326
327
# File 'generated/google/apis/dataproc_v1/classes.rb', line 325

def num_local_ssds
  @num_local_ssds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



332
333
334
335
# File 'generated/google/apis/dataproc_v1/classes.rb', line 332

def update!(**args)
  @boot_disk_size_gb = args[:boot_disk_size_gb] if args.key?(:boot_disk_size_gb)
  @num_local_ssds = args[:num_local_ssds] if args.key?(:num_local_ssds)
end