Class: Google::Apis::DataprocV1::GceClusterConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/dataproc_v1/classes.rb,
generated/google/apis/dataproc_v1/representations.rb,
generated/google/apis/dataproc_v1/representations.rb

Overview

Common config settings for resources of Google Compute Engine cluster instances, applicable to all instances in the cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ GceClusterConfig



230
231
232
# File 'generated/google/apis/dataproc_v1/classes.rb', line 230

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#internal_ip_onlyBoolean Also known as: internal_ip_only?

[Optional] If true, all instances in the cluster will only have internal IP addresses. By default, clusters are not restricted to internal IP addresses, and will have ephemeral external IP addresses assigned to each instance. This internal_ip_only restriction can only be enabled for subnetwork enabled networks, and all off-cluster dependencies must be configured to be accessible without external IP addresses. Corresponds to the JSON property internalIpOnly



202
203
204
# File 'generated/google/apis/dataproc_v1/classes.rb', line 202

def internal_ip_only
  @internal_ip_only
end

#metadataHash<String,String>

The Google Compute Engine metadata entries to add to all instances (see Project and instance metadata). Corresponds to the JSON property metadata



228
229
230
# File 'generated/google/apis/dataproc_v1/classes.rb', line 228

def 
  
end

#network_uriString

[Optional] The Google Compute Engine network to be used for machine communications. Cannot be specified with subnetwork_uri. If neither network_uri nor subnetwork_uri is specified, the "default" network of the project is used, if it exists. Cannot be a "Custom Subnet Network" (see Using Subnetworks for more information). Example: https: //www.googleapis.com/compute/v1/projects/[project_id]/regions/global/default. Corresponds to the JSON property networkUri



185
186
187
# File 'generated/google/apis/dataproc_v1/classes.rb', line 185

def network_uri
  @network_uri
end

#service_account_scopesArray<String>

[Optional] The URIs of service account scopes to be included in Google Compute Engine instances. The following base set of scopes is always included: * https: //www.googleapis.com/auth/cloud.useraccounts.readonly * https://www.googleapis. com/auth/devstorage.read_write * https://www.googleapis.com/auth/logging.write If no scopes are specified, the following defaults are also provided: * https:/ /www.googleapis.com/auth/bigquery * https://www.googleapis.com/auth/bigtable. admin.table * https://www.googleapis.com/auth/bigtable.data * https://www. googleapis.com/auth/devstorage.full_control Corresponds to the JSON property serviceAccountScopes



215
216
217
# File 'generated/google/apis/dataproc_v1/classes.rb', line 215

def 
  
end

#subnetwork_uriString

[Optional] The Google Compute Engine subnetwork to be used for machine communications. Cannot be specified with network_uri. Example: https://www. googleapis.com/compute/v1/projects/[project_id]/regions/us-east1/sub0. Corresponds to the JSON property subnetworkUri



192
193
194
# File 'generated/google/apis/dataproc_v1/classes.rb', line 192

def subnetwork_uri
  @subnetwork_uri
end

#tagsArray<String>

The Google Compute Engine tags to add to all instances (see Tagging instances). Corresponds to the JSON property tags



221
222
223
# File 'generated/google/apis/dataproc_v1/classes.rb', line 221

def tags
  @tags
end

#zone_uriString

[Required] The zone where the Google Compute Engine cluster will be located. Example: https://www.googleapis.com/compute/v1/projects/[project_id]/zones/[ zone]. Corresponds to the JSON property zoneUri



175
176
177
# File 'generated/google/apis/dataproc_v1/classes.rb', line 175

def zone_uri
  @zone_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



235
236
237
238
239
240
241
242
243
# File 'generated/google/apis/dataproc_v1/classes.rb', line 235

def update!(**args)
  @zone_uri = args[:zone_uri] if args.key?(:zone_uri)
  @network_uri = args[:network_uri] if args.key?(:network_uri)
  @subnetwork_uri = args[:subnetwork_uri] if args.key?(:subnetwork_uri)
  @internal_ip_only = args[:internal_ip_only] if args.key?(:internal_ip_only)
   = args[:service_account_scopes] if args.key?(:service_account_scopes)
  @tags = args[:tags] if args.key?(:tags)
   = args[:metadata] if args.key?(:metadata)
end