Class: Google::Apis::DataprocV1::JobStatus
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::JobStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dataproc_v1/classes.rb,
generated/google/apis/dataproc_v1/representations.rb,
generated/google/apis/dataproc_v1/representations.rb
Overview
Cloud Dataproc job status.
Instance Attribute Summary collapse
-
#details ⇒ String
[Output-only] Optional job state details, such as an error description if the state is ERROR.
-
#state ⇒ String
[Output-only] A state message specifying the overall job state.
-
#state_start_time ⇒ String
[Output-only] The time when this state was entered.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobStatus
constructor
A new instance of JobStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ JobStatus
1324 1325 1326 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1324 def initialize(**args) update!(**args) end |
Instance Attribute Details
#details ⇒ String
[Output-only] Optional job state details, such as an error description if the
state is ERROR.
Corresponds to the JSON property details
1317 1318 1319 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1317 def details @details end |
#state ⇒ String
[Output-only] A state message specifying the overall job state.
Corresponds to the JSON property state
1311 1312 1313 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1311 def state @state end |
#state_start_time ⇒ String
[Output-only] The time when this state was entered.
Corresponds to the JSON property stateStartTime
1322 1323 1324 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1322 def state_start_time @state_start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1329 1330 1331 1332 1333 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1329 def update!(**args) @state = args[:state] if args.key?(:state) @details = args[:details] if args.key?(:details) @state_start_time = args[:state_start_time] if args.key?(:state_start_time) end |