Class: Google::Apis::DataprocV1::NodeInitializationAction
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::NodeInitializationAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dataproc_v1/classes.rb,
generated/google/apis/dataproc_v1/representations.rb,
generated/google/apis/dataproc_v1/representations.rb
Overview
Specifies an executable to run on a fully configured node and a timeout period for executable completion.
Instance Attribute Summary collapse
-
#executable_file ⇒ String
[Required] Google Cloud Storage URI of executable file.
-
#execution_timeout ⇒ String
[Optional] Amount of time executable has to complete.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeInitializationAction
constructor
A new instance of NodeInitializationAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ NodeInitializationAction
Returns a new instance of NodeInitializationAction.
413 414 415 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 413 def initialize(**args) update!(**args) end |
Instance Attribute Details
#executable_file ⇒ String
[Required] Google Cloud Storage URI of executable file.
Corresponds to the JSON property executableFile
403 404 405 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 403 def executable_file @executable_file end |
#execution_timeout ⇒ String
[Optional] Amount of time executable has to complete. Default is 10 minutes.
Cluster creation fails with an explanatory error message (the name of the
executable that caused the error and the exceeded timeout period) if the
executable is not completed at end of the timeout period.
Corresponds to the JSON property executionTimeout
411 412 413 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 411 def execution_timeout @execution_timeout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
418 419 420 421 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 418 def update!(**args) @executable_file = args[:executable_file] if args.key?(:executable_file) @execution_timeout = args[:execution_timeout] if args.key?(:execution_timeout) end |