Class: Google::Apis::DataprocV1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dataproc_v1/classes.rb,
generated/google/apis/dataproc_v1/representations.rb,
generated/google/apis/dataproc_v1/representations.rb
Overview
Metadata describing the operation.
Instance Attribute Summary collapse
-
#cluster_name ⇒ String
Name of the cluster for the operation.
-
#cluster_uuid ⇒ String
Cluster UUId for the operation.
-
#description ⇒ String
[Output-only] Short description of operation.
-
#details ⇒ String
A message containing any operation metadata details.
-
#end_time ⇒ String
The time that the operation completed.
-
#inner_state ⇒ String
A message containing the detailed operation state.
-
#insert_time ⇒ String
The time that the operation was requested.
-
#operation_type ⇒ String
[Output-only] The operation type.
-
#start_time ⇒ String
The time that the operation was started by the server.
-
#state ⇒ String
A message containing the operation state.
-
#status ⇒ Google::Apis::DataprocV1::OperationStatus
The status of the operation.
-
#status_history ⇒ Array<Google::Apis::DataprocV1::OperationStatus>
[Output-only] Previous operation status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
1657 1658 1659 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1657 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_name ⇒ String
Name of the cluster for the operation.
Corresponds to the JSON property clusterName
1630 1631 1632 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1630 def cluster_name @cluster_name end |
#cluster_uuid ⇒ String
Cluster UUId for the operation.
Corresponds to the JSON property clusterUuid
1635 1636 1637 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1635 def cluster_uuid @cluster_uuid end |
#description ⇒ String
[Output-only] Short description of operation.
Corresponds to the JSON property description
1655 1656 1657 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1655 def description @description end |
#details ⇒ String
A message containing any operation metadata details.
Corresponds to the JSON property details
1610 1611 1612 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1610 def details @details end |
#end_time ⇒ String
The time that the operation completed.
Corresponds to the JSON property endTime
1625 1626 1627 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1625 def end_time @end_time end |
#inner_state ⇒ String
A message containing the detailed operation state.
Corresponds to the JSON property innerState
1605 1606 1607 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1605 def inner_state @inner_state end |
#insert_time ⇒ String
The time that the operation was requested.
Corresponds to the JSON property insertTime
1615 1616 1617 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1615 def insert_time @insert_time end |
#operation_type ⇒ String
[Output-only] The operation type.
Corresponds to the JSON property operationType
1650 1651 1652 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1650 def operation_type @operation_type end |
#start_time ⇒ String
The time that the operation was started by the server.
Corresponds to the JSON property startTime
1620 1621 1622 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1620 def start_time @start_time end |
#state ⇒ String
A message containing the operation state.
Corresponds to the JSON property state
1600 1601 1602 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1600 def state @state end |
#status ⇒ Google::Apis::DataprocV1::OperationStatus
The status of the operation.
Corresponds to the JSON property status
1640 1641 1642 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1640 def status @status end |
#status_history ⇒ Array<Google::Apis::DataprocV1::OperationStatus>
[Output-only] Previous operation status.
Corresponds to the JSON property statusHistory
1645 1646 1647 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1645 def status_history @status_history end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1662 def update!(**args) @state = args[:state] if args.key?(:state) @inner_state = args[:inner_state] if args.key?(:inner_state) @details = args[:details] if args.key?(:details) @insert_time = args[:insert_time] if args.key?(:insert_time) @start_time = args[:start_time] if args.key?(:start_time) @end_time = args[:end_time] if args.key?(:end_time) @cluster_name = args[:cluster_name] if args.key?(:cluster_name) @cluster_uuid = args[:cluster_uuid] if args.key?(:cluster_uuid) @status = args[:status] if args.key?(:status) @status_history = args[:status_history] if args.key?(:status_history) @operation_type = args[:operation_type] if args.key?(:operation_type) @description = args[:description] if args.key?(:description) end |