Class: Google::Apis::DataprocV1::PySparkJob
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::PySparkJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dataproc_v1/classes.rb,
generated/google/apis/dataproc_v1/representations.rb,
generated/google/apis/dataproc_v1/representations.rb
Overview
A Cloud Dataproc job for running Apache PySpark applications on YARN.
Instance Attribute Summary collapse
-
#archive_uris ⇒ Array<String>
[Optional] HCFS URIs of archives to be extracted in the working directory of .
-
#args ⇒ Array<String>
[Optional] The arguments to pass to the driver.
-
#file_uris ⇒ Array<String>
[Optional] HCFS URIs of files to be copied to the working directory of Python drivers and distributed tasks.
-
#jar_file_uris ⇒ Array<String>
[Optional] HCFS URIs of jar files to add to the CLASSPATHs of the Python driver and tasks.
-
#logging_config ⇒ Google::Apis::DataprocV1::LoggingConfig
The runtime logging config of the job.
-
#main_python_file_uri ⇒ String
[Required] The HCFS URI of the main Python file to use as the driver.
-
#properties ⇒ Hash<String,String>
[Optional] A mapping of property names to values, used to configure PySpark.
-
#python_file_uris ⇒ Array<String>
[Optional] HCFS file URIs of Python files to pass to the PySpark framework.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PySparkJob
constructor
A new instance of PySparkJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ PySparkJob
Returns a new instance of PySparkJob.
1089 1090 1091 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1089 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive_uris ⇒ Array<String>
[Optional] HCFS URIs of archives to be extracted in the working directory of .
jar, .tar, .tar.gz, .tgz, and .zip.
Corresponds to the JSON property archiveUris
1074 1075 1076 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1074 def archive_uris @archive_uris end |
#args ⇒ Array<String>
[Optional] The arguments to pass to the driver. Do not include arguments, such
as --conf, that can be set as job properties, since a collision may occur
that causes an incorrect job submission.
Corresponds to the JSON property args
1050 1051 1052 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1050 def args @args end |
#file_uris ⇒ Array<String>
[Optional] HCFS URIs of files to be copied to the working directory of Python
drivers and distributed tasks. Useful for naively parallel tasks.
Corresponds to the JSON property fileUris
1068 1069 1070 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1068 def file_uris @file_uris end |
#jar_file_uris ⇒ Array<String>
[Optional] HCFS URIs of jar files to add to the CLASSPATHs of the Python
driver and tasks.
Corresponds to the JSON property jarFileUris
1062 1063 1064 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1062 def jar_file_uris @jar_file_uris end |
#logging_config ⇒ Google::Apis::DataprocV1::LoggingConfig
The runtime logging config of the job.
Corresponds to the JSON property loggingConfig
1087 1088 1089 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1087 def logging_config @logging_config end |
#main_python_file_uri ⇒ String
[Required] The HCFS URI of the main Python file to use as the driver. Must be
a .py file.
Corresponds to the JSON property mainPythonFileUri
1043 1044 1045 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1043 def main_python_file_uri @main_python_file_uri end |
#properties ⇒ Hash<String,String>
[Optional] A mapping of property names to values, used to configure PySpark.
Properties that conflict with values set by the Cloud Dataproc API may be
overwritten. Can include properties set in /etc/spark/conf/spark-defaults.conf
and classes in user code.
Corresponds to the JSON property properties
1082 1083 1084 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1082 def properties @properties end |
#python_file_uris ⇒ Array<String>
[Optional] HCFS file URIs of Python files to pass to the PySpark framework.
Supported file types: .py, .egg, and .zip.
Corresponds to the JSON property pythonFileUris
1056 1057 1058 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1056 def python_file_uris @python_file_uris end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 1094 def update!(**args) @main_python_file_uri = args[:main_python_file_uri] if args.key?(:main_python_file_uri) @args = args[:args] if args.key?(:args) @python_file_uris = args[:python_file_uris] if args.key?(:python_file_uris) @jar_file_uris = args[:jar_file_uris] if args.key?(:jar_file_uris) @file_uris = args[:file_uris] if args.key?(:file_uris) @archive_uris = args[:archive_uris] if args.key?(:archive_uris) @properties = args[:properties] if args.key?(:properties) @logging_config = args[:logging_config] if args.key?(:logging_config) end |