Class: Google::Apis::DeploymentmanagerV2::AuditLogConfig
- Inherits:
-
Object
- Object
- Google::Apis::DeploymentmanagerV2::AuditLogConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/deploymentmanager_v2/classes.rb,
generated/google/apis/deploymentmanager_v2/representations.rb,
generated/google/apis/deploymentmanager_v2/representations.rb
Overview
Provides the configuration for a sub-type of logging.
Instance Attribute Summary collapse
-
#exempted_members ⇒ Array<String>
Specifies the identities that are exempted from this type of logging Follows the same format of Binding.members.
-
#log_type ⇒ String
The log type that this config enables.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuditLogConfig
constructor
A new instance of AuditLogConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ AuditLogConfig
Returns a new instance of AuditLogConfig.
75 76 77 |
# File 'generated/google/apis/deploymentmanager_v2/classes.rb', line 75 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exempted_members ⇒ Array<String>
Specifies the identities that are exempted from this type of logging Follows
the same format of Binding.members.
Corresponds to the JSON property exemptedMembers
68 69 70 |
# File 'generated/google/apis/deploymentmanager_v2/classes.rb', line 68 def exempted_members @exempted_members end |
#log_type ⇒ String
The log type that this config enables.
Corresponds to the JSON property logType
73 74 75 |
# File 'generated/google/apis/deploymentmanager_v2/classes.rb', line 73 def log_type @log_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
80 81 82 83 |
# File 'generated/google/apis/deploymentmanager_v2/classes.rb', line 80 def update!(**args) @exempted_members = args[:exempted_members] if args.key?(:exempted_members) @log_type = args[:log_type] if args.key?(:log_type) end |