Class: Google::Apis::DfareportingV2_7::ConnectionType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/dfareporting_v2_7/classes.rb,
generated/google/apis/dfareporting_v2_7/representations.rb,
generated/google/apis/dfareporting_v2_7/representations.rb

Overview

Contains information about an internet connection type that can be targeted by ads. Clients can use the connection type to target mobile vs. broadband users.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ ConnectionType

Returns a new instance of ConnectionType.



2163
2164
2165
# File 'generated/google/apis/dfareporting_v2_7/classes.rb', line 2163

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

ID of this connection type. Corresponds to the JSON property id

Returns:

  • (String)


2150
2151
2152
# File 'generated/google/apis/dfareporting_v2_7/classes.rb', line 2150

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " dfareporting#connectionType". Corresponds to the JSON property kind

Returns:

  • (String)


2156
2157
2158
# File 'generated/google/apis/dfareporting_v2_7/classes.rb', line 2156

def kind
  @kind
end

#nameString

Name of this connection type. Corresponds to the JSON property name

Returns:

  • (String)


2161
2162
2163
# File 'generated/google/apis/dfareporting_v2_7/classes.rb', line 2161

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2168
2169
2170
2171
2172
# File 'generated/google/apis/dfareporting_v2_7/classes.rb', line 2168

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
end