Class: Google::Apis::GenomicsV1::AnnotationSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/genomics_v1/classes.rb,
generated/google/apis/genomics_v1/representations.rb,
generated/google/apis/genomics_v1/representations.rb

Overview

An annotation set is a logical grouping of annotations that share consistent type information and provenance. Examples of annotation sets include 'all genes from refseq', and 'all variant annotations from ClinVar'.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ AnnotationSet

Returns a new instance of AnnotationSet.



822
823
824
# File 'generated/google/apis/genomics_v1/classes.rb', line 822

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataset_idString

The dataset to which this annotation set belongs. Corresponds to the JSON property datasetId

Returns:

  • (String)


787
788
789
# File 'generated/google/apis/genomics_v1/classes.rb', line 787

def dataset_id
  @dataset_id
end

#idString

The server-generated annotation set ID, unique across all annotation sets. Corresponds to the JSON property id

Returns:

  • (String)


820
821
822
# File 'generated/google/apis/genomics_v1/classes.rb', line 820

def id
  @id
end

#infoHash<String,Array<Object>>

A map of additional read alignment information. This must be of the form map (string key mapping to a list of string values). Corresponds to the JSON property info

Returns:

  • (Hash<String,Array<Object>>)


810
811
812
# File 'generated/google/apis/genomics_v1/classes.rb', line 810

def info
  @info
end

#nameString

The display name for this annotation set. Corresponds to the JSON property name

Returns:

  • (String)


798
799
800
# File 'generated/google/apis/genomics_v1/classes.rb', line 798

def name
  @name
end

#reference_set_idString

The ID of the reference set that defines the coordinate space for this set's annotations. Corresponds to the JSON property referenceSetId

Returns:

  • (String)


804
805
806
# File 'generated/google/apis/genomics_v1/classes.rb', line 804

def reference_set_id
  @reference_set_id
end

#source_uriString

The source URI describing the file from which this annotation set was generated, if any. Corresponds to the JSON property sourceUri

Returns:

  • (String)


793
794
795
# File 'generated/google/apis/genomics_v1/classes.rb', line 793

def source_uri
  @source_uri
end

#typeString

The type of annotations contained within this set. Corresponds to the JSON property type

Returns:

  • (String)


815
816
817
# File 'generated/google/apis/genomics_v1/classes.rb', line 815

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



827
828
829
830
831
832
833
834
835
# File 'generated/google/apis/genomics_v1/classes.rb', line 827

def update!(**args)
  @dataset_id = args[:dataset_id] if args.key?(:dataset_id)
  @source_uri = args[:source_uri] if args.key?(:source_uri)
  @name = args[:name] if args.key?(:name)
  @reference_set_id = args[:reference_set_id] if args.key?(:reference_set_id)
  @info = args[:info] if args.key?(:info)
  @type = args[:type] if args.key?(:type)
  @id = args[:id] if args.key?(:id)
end