Class: Google::Apis::GenomicsV1::ExportReadGroupSetRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/genomics_v1/classes.rb,
generated/google/apis/genomics_v1/representations.rb,
generated/google/apis/genomics_v1/representations.rb

Overview

The read group set export request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ ExportReadGroupSetRequest

Returns a new instance of ExportReadGroupSetRequest.



1013
1014
1015
# File 'generated/google/apis/genomics_v1/classes.rb', line 1013

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_uriString

Required. A Google Cloud Storage URI for the exported BAM file. The currently authenticated user must have write access to the new file. An error will be returned if the URI already contains data. Corresponds to the JSON property exportUri

Returns:

  • (String)


998
999
1000
# File 'generated/google/apis/genomics_v1/classes.rb', line 998

def export_uri
  @export_uri
end

#project_idString

Required. The Google Cloud project ID that owns this export. The caller must have WRITE access to this project. Corresponds to the JSON property projectId

Returns:

  • (String)


1011
1012
1013
# File 'generated/google/apis/genomics_v1/classes.rb', line 1011

def project_id
  @project_id
end

#reference_namesArray<String>

The reference names to export. If this is not specified, all reference sequences, including unmapped reads, are exported. Use * to export only unmapped reads. Corresponds to the JSON property referenceNames

Returns:

  • (Array<String>)


1005
1006
1007
# File 'generated/google/apis/genomics_v1/classes.rb', line 1005

def reference_names
  @reference_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1018
1019
1020
1021
1022
# File 'generated/google/apis/genomics_v1/classes.rb', line 1018

def update!(**args)
  @export_uri = args[:export_uri] if args.key?(:export_uri)
  @reference_names = args[:reference_names] if args.key?(:reference_names)
  @project_id = args[:project_id] if args.key?(:project_id)
end