Class: Google::Apis::GenomicsV1::ExportVariantSetRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/genomics_v1/classes.rb,
generated/google/apis/genomics_v1/representations.rb,
generated/google/apis/genomics_v1/representations.rb

Overview

The variant data export request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ ExportVariantSetRequest

Returns a new instance of ExportVariantSetRequest.



1350
1351
1352
# File 'generated/google/apis/genomics_v1/classes.rb', line 1350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_datasetString

Required. The BigQuery dataset to export data to. This dataset must already exist. Note that this is distinct from the Genomics concept of "dataset". Corresponds to the JSON property bigqueryDataset

Returns:

  • (String)


1328
1329
1330
# File 'generated/google/apis/genomics_v1/classes.rb', line 1328

def bigquery_dataset
  @bigquery_dataset
end

#bigquery_tableString

Required. The BigQuery table to export data to. If the table doesn't exist, it will be created. If it already exists, it will be overwritten. Corresponds to the JSON property bigqueryTable

Returns:

  • (String)


1335
1336
1337
# File 'generated/google/apis/genomics_v1/classes.rb', line 1335

def bigquery_table
  @bigquery_table
end

#call_set_idsArray<String>

If provided, only variant call information from the specified call sets will be exported. By default all variant calls are exported. Corresponds to the JSON property callSetIds

Returns:

  • (Array<String>)


1341
1342
1343
# File 'generated/google/apis/genomics_v1/classes.rb', line 1341

def call_set_ids
  @call_set_ids
end

#formatString

The format for the exported data. Corresponds to the JSON property format

Returns:

  • (String)


1322
1323
1324
# File 'generated/google/apis/genomics_v1/classes.rb', line 1322

def format
  @format
end

#project_idString

Required. The Google Cloud project ID that owns the destination BigQuery dataset. The caller must have WRITE access to this project. This project will also own the resulting export job. Corresponds to the JSON property projectId

Returns:

  • (String)


1348
1349
1350
# File 'generated/google/apis/genomics_v1/classes.rb', line 1348

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1355
1356
1357
1358
1359
1360
1361
# File 'generated/google/apis/genomics_v1/classes.rb', line 1355

def update!(**args)
  @format = args[:format] if args.key?(:format)
  @bigquery_dataset = args[:bigquery_dataset] if args.key?(:bigquery_dataset)
  @bigquery_table = args[:bigquery_table] if args.key?(:bigquery_table)
  @call_set_ids = args[:call_set_ids] if args.key?(:call_set_ids)
  @project_id = args[:project_id] if args.key?(:project_id)
end