Class: Google::Apis::GenomicsV1::ImportVariantsRequest
- Inherits:
-
Object
- Object
- Google::Apis::GenomicsV1::ImportVariantsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/genomics_v1/classes.rb,
generated/google/apis/genomics_v1/representations.rb,
generated/google/apis/genomics_v1/representations.rb
Overview
The variant data import request.
Instance Attribute Summary collapse
-
#format ⇒ String
The format of the variant data being imported.
-
#info_merge_config ⇒ Hash<String,String>
A mapping between info field keys and the InfoMergeOperations to be performed on them.
-
#normalize_reference_names ⇒ Boolean
(also: #normalize_reference_names?)
Convert reference names to the canonical representation.
-
#source_uris ⇒ Array<String>
A list of URIs referencing variant files in Google Cloud Storage.
-
#variant_set_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportVariantsRequest
constructor
A new instance of ImportVariantsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ ImportVariantsRequest
Returns a new instance of ImportVariantsRequest.
1199 1200 1201 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1199 def initialize(**args) update!(**args) end |
Instance Attribute Details
#format ⇒ String
The format of the variant data being imported. If unspecified, defaults to
to VCF.
Corresponds to the JSON property format
1197 1198 1199 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1197 def format @format end |
#info_merge_config ⇒ Hash<String,String>
A mapping between info field keys and the InfoMergeOperations to
be performed on them. This is plumbed down to the MergeVariantRequests
generated by the resulting import job.
Corresponds to the JSON property infoMergeConfig
1165 1166 1167 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1165 def info_merge_config @info_merge_config end |
#normalize_reference_names ⇒ Boolean Also known as: normalize_reference_names?
Convert reference names to the canonical representation.
hg19 haploytypes (those reference names containing "_hap")
are not modified in any way.
All other reference names are modified according to the following rules:
The reference name is capitalized.
The "chr" prefix is dropped for all autosomes and sex chromsomes.
For example "chr17" becomes "17" and "chrX" becomes "X".
All mitochondrial chromosomes ("chrM", "chrMT", etc) become "MT".
Corresponds to the JSON property normalizeReferenceNames
1190 1191 1192 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1190 def normalize_reference_names @normalize_reference_names end |
#source_uris ⇒ Array<String>
A list of URIs referencing variant files in Google Cloud Storage. URIs can
include wildcards as described
here.
Note that recursive wildcards ('**') are not supported.
Corresponds to the JSON property sourceUris
1178 1179 1180 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1178 def source_uris @source_uris end |
#variant_set_id ⇒ String
Required. The variant set to which variant data should be imported.
Corresponds to the JSON property variantSetId
1170 1171 1172 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1170 def variant_set_id @variant_set_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1204 1205 1206 1207 1208 1209 1210 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1204 def update!(**args) @info_merge_config = args[:info_merge_config] if args.key?(:info_merge_config) @variant_set_id = args[:variant_set_id] if args.key?(:variant_set_id) @source_uris = args[:source_uris] if args.key?(:source_uris) @normalize_reference_names = args[:normalize_reference_names] if args.key?(:normalize_reference_names) @format = args[:format] if args.key?(:format) end |