Class: Google::Apis::GenomicsV1::LinearAlignment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/genomics_v1/classes.rb,
generated/google/apis/genomics_v1/representations.rb,
generated/google/apis/genomics_v1/representations.rb

Overview

A linear alignment can be represented by one CIGAR string. Describes the mapped position and local alignment of the read to the reference.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ LinearAlignment

Returns a new instance of LinearAlignment.



1663
1664
1665
# File 'generated/google/apis/genomics_v1/classes.rb', line 1663

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cigarArray<Google::Apis::GenomicsV1::CigarUnit>

Represents the local alignment of this sequence (alignment matches, indels, etc) against the reference. Corresponds to the JSON property cigar



1653
1654
1655
# File 'generated/google/apis/genomics_v1/classes.rb', line 1653

def cigar
  @cigar
end

#mapping_qualityFixnum

The mapping quality of this alignment. Represents how likely the read maps to this position as opposed to other locations. Specifically, this is -10 log10 Pr(mapping position is wrong), rounded to the nearest integer. Corresponds to the JSON property mappingQuality

Returns:

  • (Fixnum)


1661
1662
1663
# File 'generated/google/apis/genomics_v1/classes.rb', line 1661

def mapping_quality
  @mapping_quality
end

#positionGoogle::Apis::GenomicsV1::Position

An abstraction for referring to a genomic position, in relation to some already known reference. For now, represents a genomic position as a reference name, a base number on that reference (0-based), and a determination of forward or reverse strand. Corresponds to the JSON property position



1647
1648
1649
# File 'generated/google/apis/genomics_v1/classes.rb', line 1647

def position
  @position
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1668
1669
1670
1671
1672
# File 'generated/google/apis/genomics_v1/classes.rb', line 1668

def update!(**args)
  @position = args[:position] if args.key?(:position)
  @cigar = args[:cigar] if args.key?(:cigar)
  @mapping_quality = args[:mapping_quality] if args.key?(:mapping_quality)
end