Class: Google::Apis::GenomicsV1::ReferenceSet
- Inherits:
-
Object
- Object
- Google::Apis::GenomicsV1::ReferenceSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/genomics_v1/classes.rb,
generated/google/apis/genomics_v1/representations.rb,
generated/google/apis/genomics_v1/representations.rb
Overview
A reference set is a set of references which typically comprise a reference
assembly for a species, such as GRCh38 which is representative
of the human genome. A reference set defines a common coordinate space for
comparing reference-aligned experimental data. A reference set contains 1 or
more references.
For more genomics resource definitions, see Fundamentals of Google
Genomics
Instance Attribute Summary collapse
-
#assembly_id ⇒ String
Public id of this reference set, such as
GRCh37. -
#description ⇒ String
Free text description of this reference set.
-
#id ⇒ String
The server-generated reference set ID, unique across all reference sets.
-
#md5checksum ⇒ String
Order-independent MD5 checksum which identifies this reference set.
-
#ncbi_taxon_id ⇒ Fixnum
ID from http://www.ncbi.nlm.nih.gov/taxonomy (for example, 9606 for human) indicating the species which this reference set is intended to model.
-
#reference_ids ⇒ Array<String>
The IDs of the reference objects that are part of this set.
-
#source_accessions ⇒ Array<String>
All known corresponding accession IDs in INSDC (GenBank/ENA/DDBJ) ideally with a version number, for example
NC_000001.11. -
#source_uri ⇒ String
The URI from which the references were obtained.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReferenceSet
constructor
A new instance of ReferenceSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ ReferenceSet
Returns a new instance of ReferenceSet.
727 728 729 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 727 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assembly_id ⇒ String
Public id of this reference set, such as GRCh37.
Corresponds to the JSON property assemblyId
711 712 713 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 711 def assembly_id @assembly_id end |
#description ⇒ String
Free text description of this reference set.
Corresponds to the JSON property description
686 687 688 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 686 def description @description end |
#id ⇒ String
The server-generated reference set ID, unique across all reference sets.
Corresponds to the JSON property id
725 726 727 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 725 def id @id end |
#md5checksum ⇒ String
Order-independent MD5 checksum which identifies this reference set. The
checksum is computed by sorting all lower case hexidecimal string
reference.md5checksum (for all reference in this set) in
ascending lexicographic order, concatenating, and taking the MD5 of that
value. The resulting value is represented in lower case hexadecimal format.
Corresponds to the JSON property md5checksum
720 721 722 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 720 def md5checksum @md5checksum end |
#ncbi_taxon_id ⇒ Fixnum
ID from http://www.ncbi.nlm.nih.gov/taxonomy (for example, 9606 for human)
indicating the species which this reference set is intended to model. Note
that contained references may specify a different ncbiTaxonId, as
assemblies may contain reference sequences which do not belong to the
modeled species, for example EBV in a human reference genome.
Corresponds to the JSON property ncbiTaxonId
700 701 702 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 700 def ncbi_taxon_id @ncbi_taxon_id end |
#reference_ids ⇒ Array<String>
The IDs of the reference objects that are part of this set.
Reference.md5checksum must be unique within this set.
Corresponds to the JSON property referenceIds
706 707 708 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 706 def reference_ids @reference_ids end |
#source_accessions ⇒ Array<String>
All known corresponding accession IDs in INSDC (GenBank/ENA/DDBJ) ideally
with a version number, for example NC_000001.11.
Corresponds to the JSON property sourceAccessions
681 682 683 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 681 def source_accessions @source_accessions end |
#source_uri ⇒ String
The URI from which the references were obtained.
Corresponds to the JSON property sourceUri
691 692 693 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 691 def source_uri @source_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
732 733 734 735 736 737 738 739 740 741 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 732 def update!(**args) @source_accessions = args[:source_accessions] if args.key?(:source_accessions) @description = args[:description] if args.key?(:description) @source_uri = args[:source_uri] if args.key?(:source_uri) @ncbi_taxon_id = args[:ncbi_taxon_id] if args.key?(:ncbi_taxon_id) @reference_ids = args[:reference_ids] if args.key?(:reference_ids) @assembly_id = args[:assembly_id] if args.key?(:assembly_id) @md5checksum = args[:md5checksum] if args.key?(:md5checksum) @id = args[:id] if args.key?(:id) end |