Class: Google::Apis::GenomicsV1::VariantCall

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/genomics_v1/classes.rb,
generated/google/apis/genomics_v1/representations.rb,
generated/google/apis/genomics_v1/representations.rb

Overview

A call represents the determination of genotype with respect to a particular variant. It may include associated information such as quality and phasing. For example, a call might assign a probability of 0.32 to the occurrence of a SNP named rs1234 in a call set with the name NA12345.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ VariantCall

Returns a new instance of VariantCall.



2631
2632
2633
# File 'generated/google/apis/genomics_v1/classes.rb', line 2631

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#call_set_idString

The ID of the call set this variant call belongs to. Corresponds to the JSON property callSetId

Returns:

  • (String)


2613
2614
2615
# File 'generated/google/apis/genomics_v1/classes.rb', line 2613

def call_set_id
  @call_set_id
end

#call_set_nameString

The name of the call set this variant call belongs to. Corresponds to the JSON property callSetName

Returns:

  • (String)


2598
2599
2600
# File 'generated/google/apis/genomics_v1/classes.rb', line 2598

def call_set_name
  @call_set_name
end

#genotypeArray<Fixnum>

The genotype of this variant call. Each value represents either the value of the referenceBases field or a 1-based index into alternateBases. If a variant had a referenceBases value of T and an alternateBases value of ["A", "C"], and the genotype was [2, 1], that would mean the call represented the heterozygous value CA for this variant. If the genotype was instead [0, 1], the represented value would be TA. Ordering of the genotype values is important if the phaseset is present. If a genotype is not called (that is, a . is present in the GT string) -1 is returned. Corresponds to the JSON property genotype

Returns:

  • (Array<Fixnum>)


2629
2630
2631
# File 'generated/google/apis/genomics_v1/classes.rb', line 2629

def genotype
  @genotype
end

#genotype_likelihoodArray<Float>

The genotype likelihoods for this variant call. Each array entry represents how likely a specific genotype is for this call. The value ordering is defined by the GL tag in the VCF spec. If Phred-scaled genotype likelihood scores (PL) are available and log10(P) genotype likelihood scores (GL) are not, PL scores are converted to GL scores. If both are available, PL scores are stored in info. Corresponds to the JSON property genotypeLikelihood

Returns:

  • (Array<Float>)


2608
2609
2610
# File 'generated/google/apis/genomics_v1/classes.rb', line 2608

def genotype_likelihood
  @genotype_likelihood
end

#infoHash<String,Array<Object>>

A map of additional variant call information. This must be of the form map (string key mapping to a list of string values). Corresponds to the JSON property info

Returns:

  • (Hash<String,Array<Object>>)


2593
2594
2595
# File 'generated/google/apis/genomics_v1/classes.rb', line 2593

def info
  @info
end

#phasesetString

If this field is present, this variant call's genotype ordering implies the phase of the bases and is consistent with any other variant calls in the same reference sequence which have the same phaseset value. When importing data from VCF, if the genotype data was phased but no phase set was specified this field will be set to *. Corresponds to the JSON property phaseset

Returns:

  • (String)


2587
2588
2589
# File 'generated/google/apis/genomics_v1/classes.rb', line 2587

def phaseset
  @phaseset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2636
2637
2638
2639
2640
2641
2642
2643
# File 'generated/google/apis/genomics_v1/classes.rb', line 2636

def update!(**args)
  @phaseset = args[:phaseset] if args.key?(:phaseset)
  @info = args[:info] if args.key?(:info)
  @call_set_name = args[:call_set_name] if args.key?(:call_set_name)
  @genotype_likelihood = args[:genotype_likelihood] if args.key?(:genotype_likelihood)
  @call_set_id = args[:call_set_id] if args.key?(:call_set_id)
  @genotype = args[:genotype] if args.key?(:genotype)
end