Class: Google::Apis::GenomicsV1::VariantSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/genomics_v1/classes.rb,
generated/google/apis/genomics_v1/representations.rb,
generated/google/apis/genomics_v1/representations.rb

Overview

A variant set is a collection of call sets and variants. It contains summary statistics of those contents. A variant set belongs to a dataset. For more genomics resource definitions, see Fundamentals of Google Genomics

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ VariantSet

Returns a new instance of VariantSet.



2916
2917
2918
# File 'generated/google/apis/genomics_v1/classes.rb', line 2916

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataset_idString

The dataset to which this variant set belongs. Corresponds to the JSON property datasetId

Returns:

  • (String)


2896
2897
2898
# File 'generated/google/apis/genomics_v1/classes.rb', line 2896

def dataset_id
  @dataset_id
end

#descriptionString

A textual description of this variant set. Corresponds to the JSON property description

Returns:

  • (String)


2891
2892
2893
# File 'generated/google/apis/genomics_v1/classes.rb', line 2891

def description
  @description
end

#idString

The server-generated variant set ID, unique across all variant sets. Corresponds to the JSON property id

Returns:

  • (String)


2886
2887
2888
# File 'generated/google/apis/genomics_v1/classes.rb', line 2886

def id
  @id
end

#metadataArray<Google::Apis::GenomicsV1::VariantSetMetadata>

The metadata associated with this variant set. Corresponds to the JSON property metadata



2875
2876
2877
# File 'generated/google/apis/genomics_v1/classes.rb', line 2875

def 
  
end

#nameString

User-specified, mutable name. Corresponds to the JSON property name

Returns:

  • (String)


2901
2902
2903
# File 'generated/google/apis/genomics_v1/classes.rb', line 2901

def name
  @name
end

#reference_boundsArray<Google::Apis::GenomicsV1::ReferenceBound>

A list of all references used by the variants in a variant set with associated coordinate upper bounds for each one. Corresponds to the JSON property referenceBounds



2881
2882
2883
# File 'generated/google/apis/genomics_v1/classes.rb', line 2881

def reference_bounds
  @reference_bounds
end

#reference_set_idString

The reference set to which the variant set is mapped. The reference set describes the alignment provenance of the variant set, while the referenceBounds describe the shape of the actual variant data. The reference set's reference names are a superset of those found in the referenceBounds. For example, given a variant set that is mapped to the GRCh38 reference set and contains a single variant on reference 'X', referenceBounds would contain only an entry for 'X', while the associated reference set enumerates all possible references: '1', '2', 'X', 'Y', 'MT', etc. Corresponds to the JSON property referenceSetId

Returns:

  • (String)


2914
2915
2916
# File 'generated/google/apis/genomics_v1/classes.rb', line 2914

def reference_set_id
  @reference_set_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2921
2922
2923
2924
2925
2926
2927
2928
2929
# File 'generated/google/apis/genomics_v1/classes.rb', line 2921

def update!(**args)
   = args[:metadata] if args.key?(:metadata)
  @reference_bounds = args[:reference_bounds] if args.key?(:reference_bounds)
  @id = args[:id] if args.key?(:id)
  @description = args[:description] if args.key?(:description)
  @dataset_id = args[:dataset_id] if args.key?(:dataset_id)
  @name = args[:name] if args.key?(:name)
  @reference_set_id = args[:reference_set_id] if args.key?(:reference_set_id)
end