Class: Google::Apis::GenomicsV1::VariantSetMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/genomics_v1/classes.rb,
generated/google/apis/genomics_v1/representations.rb,
generated/google/apis/genomics_v1/representations.rb

Overview

Metadata describes a single piece of variant call metadata. These data include a top level key and either a single value string (value) or a list of key-value pairs (info.) Value and info are mutually exclusive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ VariantSetMetadata

Returns a new instance of VariantSetMetadata.



226
227
228
# File 'generated/google/apis/genomics_v1/classes.rb', line 226

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A textual description of this metadata. Corresponds to the JSON property description

Returns:

  • (String)


212
213
214
# File 'generated/google/apis/genomics_v1/classes.rb', line 212

def description
  @description
end

#idString

User-provided ID field, not enforced by this API. Two or more pieces of structured metadata with identical id and key fields are considered equivalent. Corresponds to the JSON property id

Returns:

  • (String)


197
198
199
# File 'generated/google/apis/genomics_v1/classes.rb', line 197

def id
  @id
end

#infoHash<String,Array<Object>>

Remaining structured metadata key-value pairs. This must be of the form map (string key mapping to a list of string values). Corresponds to the JSON property info

Returns:

  • (Hash<String,Array<Object>>)


218
219
220
# File 'generated/google/apis/genomics_v1/classes.rb', line 218

def info
  @info
end

#keyString

The top-level key. Corresponds to the JSON property key

Returns:

  • (String)


207
208
209
# File 'generated/google/apis/genomics_v1/classes.rb', line 207

def key
  @key
end

#numberString

The number of values that can be included in a field described by this metadata. Corresponds to the JSON property number

Returns:

  • (String)


190
191
192
# File 'generated/google/apis/genomics_v1/classes.rb', line 190

def number
  @number
end

#typeString

The type of data. Possible types include: Integer, Float, Flag, Character, and String. Corresponds to the JSON property type

Returns:

  • (String)


224
225
226
# File 'generated/google/apis/genomics_v1/classes.rb', line 224

def type
  @type
end

#valueString

The value field for simple metadata Corresponds to the JSON property value

Returns:

  • (String)


202
203
204
# File 'generated/google/apis/genomics_v1/classes.rb', line 202

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



231
232
233
234
235
236
237
238
239
# File 'generated/google/apis/genomics_v1/classes.rb', line 231

def update!(**args)
  @number = args[:number] if args.key?(:number)
  @id = args[:id] if args.key?(:id)
  @value = args[:value] if args.key?(:value)
  @key = args[:key] if args.key?(:key)
  @description = args[:description] if args.key?(:description)
  @info = args[:info] if args.key?(:info)
  @type = args[:type] if args.key?(:type)
end