Class: Google::Apis::LoggingV2beta1::HttpRequest
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2beta1::HttpRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/logging_v2beta1/classes.rb,
generated/google/apis/logging_v2beta1/representations.rb,
generated/google/apis/logging_v2beta1/representations.rb
Overview
A common proto for logging HTTP requests. Only contains semantics defined by the HTTP specification. Product-specific logging information MUST be defined in a separate message.
Instance Attribute Summary collapse
-
#cache_fill_bytes ⇒ String
The number of HTTP response bytes inserted into cache.
-
#cache_hit ⇒ Boolean
(also: #cache_hit?)
Whether or not an entity was served from cache (with or without validation).
-
#cache_lookup ⇒ Boolean
(also: #cache_lookup?)
Whether or not a cache lookup was attempted.
-
#cache_validated_with_origin_server ⇒ Boolean
(also: #cache_validated_with_origin_server?)
Whether or not the response was validated with the origin server before being served from cache.
-
#latency ⇒ String
The request processing latency on the server, from the time the request was received until the response was sent.
-
#referer ⇒ String
The referer URL of the request, as defined in HTTP/1.1 Header Field Definitions (http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html).
-
#remote_ip ⇒ String
The IP address (IPv4 or IPv6) of the client that issued the HTTP request.
-
#request_method ⇒ String
The request method.
-
#request_size ⇒ String
The size of the HTTP request message in bytes, including the request headers and the request body.
-
#request_url ⇒ String
The scheme (http, https), the host name, the path and the query portion of the URL that was requested.
-
#response_size ⇒ String
The size of the HTTP response message sent back to the client, in bytes, including the response headers and the response body.
-
#server_ip ⇒ String
The IP address (IPv4 or IPv6) of the origin server that the request was sent to.
-
#status ⇒ Fixnum
The response code indicating the status of response.
-
#user_agent ⇒ String
The user agent sent by the client.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRequest
constructor
A new instance of HttpRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ HttpRequest
Returns a new instance of HttpRequest.
1040 1041 1042 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 1040 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cache_fill_bytes ⇒ String
The number of HTTP response bytes inserted into cache. Set only when a cache
fill was attempted.
Corresponds to the JSON property cacheFillBytes
1015 1016 1017 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 1015 def cache_fill_bytes @cache_fill_bytes end |
#cache_hit ⇒ Boolean Also known as: cache_hit?
Whether or not an entity was served from cache (with or without validation).
Corresponds to the JSON property cacheHit
978 979 980 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 978 def cache_hit @cache_hit end |
#cache_lookup ⇒ Boolean Also known as: cache_lookup?
Whether or not a cache lookup was attempted.
Corresponds to the JSON property cacheLookup
972 973 974 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 972 def cache_lookup @cache_lookup end |
#cache_validated_with_origin_server ⇒ Boolean Also known as: cache_validated_with_origin_server?
Whether or not the response was validated with the origin server before being
served from cache. This field is only meaningful if cache_hit is True.
Corresponds to the JSON property cacheValidatedWithOriginServer
985 986 987 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 985 def cache_validated_with_origin_server @cache_validated_with_origin_server end |
#latency ⇒ String
The request processing latency on the server, from the time the request was
received until the response was sent.
Corresponds to the JSON property latency
1009 1010 1011 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 1009 def latency @latency end |
#referer ⇒ String
The referer URL of the request, as defined in HTTP/1.1 Header Field
Definitions (http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html).
Corresponds to the JSON property referer
997 998 999 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 997 def referer @referer end |
#remote_ip ⇒ String
The IP address (IPv4 or IPv6) of the client that issued the HTTP request.
Examples: "192.168.1.1", "FE80::0202:B3FF:FE1E:8329".
Corresponds to the JSON property remoteIp
967 968 969 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 967 def remote_ip @remote_ip end |
#request_method ⇒ String
The request method. Examples: "GET", "HEAD", "PUT", "POST".
Corresponds to the JSON property requestMethod
1020 1021 1022 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 1020 def request_method @request_method end |
#request_size ⇒ String
The size of the HTTP request message in bytes, including the request headers
and the request body.
Corresponds to the JSON property requestSize
1026 1027 1028 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 1026 def request_size @request_size end |
#request_url ⇒ String
The scheme (http, https), the host name, the path and the query portion of the
URL that was requested. Example: "http://example.com/some/info?color=red".
Corresponds to the JSON property requestUrl
1038 1039 1040 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 1038 def request_url @request_url end |
#response_size ⇒ String
The size of the HTTP response message sent back to the client, in bytes,
including the response headers and the response body.
Corresponds to the JSON property responseSize
1032 1033 1034 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 1032 def response_size @response_size end |
#server_ip ⇒ String
The IP address (IPv4 or IPv6) of the origin server that the request was sent
to.
Corresponds to the JSON property serverIp
961 962 963 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 961 def server_ip @server_ip end |
#status ⇒ Fixnum
The response code indicating the status of response. Examples: 200, 404.
Corresponds to the JSON property status
991 992 993 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 991 def status @status end |
#user_agent ⇒ String
The user agent sent by the client. Example: "Mozilla/4.0 (compatible; MSIE 6.0;
Windows 98; Q312461; .NET CLR 1.0.3705)".
Corresponds to the JSON property userAgent
1003 1004 1005 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 1003 def user_agent @user_agent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 1045 def update!(**args) @server_ip = args[:server_ip] if args.key?(:server_ip) @remote_ip = args[:remote_ip] if args.key?(:remote_ip) @cache_lookup = args[:cache_lookup] if args.key?(:cache_lookup) @cache_hit = args[:cache_hit] if args.key?(:cache_hit) @cache_validated_with_origin_server = args[:cache_validated_with_origin_server] if args.key?(:cache_validated_with_origin_server) @status = args[:status] if args.key?(:status) @referer = args[:referer] if args.key?(:referer) @user_agent = args[:user_agent] if args.key?(:user_agent) @latency = args[:latency] if args.key?(:latency) @cache_fill_bytes = args[:cache_fill_bytes] if args.key?(:cache_fill_bytes) @request_method = args[:request_method] if args.key?(:request_method) @request_size = args[:request_size] if args.key?(:request_size) @response_size = args[:response_size] if args.key?(:response_size) @request_url = args[:request_url] if args.key?(:request_url) end |