Class: Google::Apis::LoggingV2beta1::LogEntrySourceLocation
- Inherits:
-
Object
- Object
- Google::Apis::LoggingV2beta1::LogEntrySourceLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/logging_v2beta1/classes.rb,
generated/google/apis/logging_v2beta1/representations.rb,
generated/google/apis/logging_v2beta1/representations.rb
Overview
Additional information about the source code location that produced the log entry.
Instance Attribute Summary collapse
-
#file ⇒ String
Optional.
-
#function ⇒ String
Optional.
-
#line ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LogEntrySourceLocation
constructor
A new instance of LogEntrySourceLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ LogEntrySourceLocation
Returns a new instance of LogEntrySourceLocation.
1208 1209 1210 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 1208 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file ⇒ String
Optional. Source file name. Depending on the runtime environment, this might
be a simple name or a fully-qualified name.
Corresponds to the JSON property file
1191 1192 1193 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 1191 def file @file end |
#function ⇒ String
Optional. Human-readable name of the function or method being invoked, with
optional context such as the class or package name. This information may be
used in contexts such as the logs viewer, where a file and line number are
less meaningful. The format can vary by language. For example: qual.if.ied.
Class.method (Java), dir/package.func (Go), function (Python).
Corresponds to the JSON property function
1200 1201 1202 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 1200 def function @function end |
#line ⇒ String
Optional. Line within the source file. 1-based; 0 indicates no line number
available.
Corresponds to the JSON property line
1206 1207 1208 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 1206 def line @line end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1213 1214 1215 1216 1217 |
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 1213 def update!(**args) @file = args[:file] if args.key?(:file) @function = args[:function] if args.key?(:function) @line = args[:line] if args.key?(:line) end |