Class: Google::Apis::LoggingV2beta1::LoggingService

Inherits:
Core::BaseService show all
Defined in:
generated/google/apis/logging_v2beta1/service.rb

Overview

Stackdriver Logging API

Writes log entries and manages your Stackdriver Logging configuration.

Examples:

require 'google/apis/logging_v2beta1'

Logging = Google::Apis::LoggingV2beta1 # Alias the module
service = Logging::LoggingService.new

See Also:

Instance Attribute Summary collapse

Attributes inherited from Core::BaseService

#authorization, #base_path, #batch_path, #client, #client_options, #request_options, #root_url, #upload_path

Instance Method Summary collapse

Methods inherited from Core::BaseService

#batch, #batch_upload, #fetch_all, #http

Constructor Details

#initializeLoggingService

Returns a new instance of LoggingService.



45
46
47
# File 'generated/google/apis/logging_v2beta1/service.rb', line 45

def initialize
  super('https://logging.googleapis.com/', '')
end

Instance Attribute Details

#keyString

Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.

Returns:

  • (String)

    API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.



38
39
40
# File 'generated/google/apis/logging_v2beta1/service.rb', line 38

def key
  @key
end

#quota_userString

Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

Returns:

  • (String)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.



43
44
45
# File 'generated/google/apis/logging_v2beta1/service.rb', line 43

def quota_user
  @quota_user
end

Instance Method Details

#create_project_metric(parent, log_metric_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogMetric

Creates a logs-based metric.

Parameters:

  • parent (String)

    The resource name of the project in which to create the metric: "projects/[PROJECT_ID]" The new metric must be provided in the request.

  • log_metric_object (Google::Apis::LoggingV2beta1::LogMetric) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



134
135
136
137
138
139
140
141
142
143
144
# File 'generated/google/apis/logging_v2beta1/service.rb', line 134

def create_project_metric(parent, log_metric_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:post, 'v2beta1/{+parent}/metrics', options)
  command.request_representation = Google::Apis::LoggingV2beta1::LogMetric::Representation
  command.request_object = log_metric_object
  command.response_representation = Google::Apis::LoggingV2beta1::LogMetric::Representation
  command.response_class = Google::Apis::LoggingV2beta1::LogMetric
  command.params['parent'] = parent unless parent.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#create_project_sink(parent, log_sink_object = nil, unique_writer_identity: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogSink

Creates a sink that exports specified log entries to a destination. The export of newly-ingested log entries begins immediately, unless the current time is outside the sink's start and end times or the sink's writer_identity is not permitted to write to the destination. A sink can export log entries only from the resource owning the sink.

Parameters:

  • parent (String)

    Required. The resource in which to create the sink: "projects/[PROJECT_ID]" "organizations/[ORGANIZATION_ID]" Examples: "projects/my-logging-project", "organizations/123456789".

  • log_sink_object (Google::Apis::LoggingV2beta1::LogSink) (defaults to: nil)
  • unique_writer_identity (Boolean) (defaults to: nil)

    Optional. Determines the kind of IAM identity returned as writer_identity in the new sink. If this value is omitted or set to false, and if the sink's parent is a project, then the value returned as writer_identity is cloud-logs@ system.gserviceaccount.com, the same identity used before the addition of writer identities to this API. The sink's destination must be in the same project as the sink itself.If this field is set to true, or if the sink is owned by a non-project resource such as an organization, then the value of writer_identity will be a unique service account used only for exports from the new sink. For more information, see writer_identity in LogSink.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



568
569
570
571
572
573
574
575
576
577
578
579
# File 'generated/google/apis/logging_v2beta1/service.rb', line 568

def create_project_sink(parent, log_sink_object = nil, unique_writer_identity: nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:post, 'v2beta1/{+parent}/sinks', options)
  command.request_representation = Google::Apis::LoggingV2beta1::LogSink::Representation
  command.request_object = log_sink_object
  command.response_representation = Google::Apis::LoggingV2beta1::LogSink::Representation
  command.response_class = Google::Apis::LoggingV2beta1::LogSink
  command.params['parent'] = parent unless parent.nil?
  command.query['uniqueWriterIdentity'] = unique_writer_identity unless unique_writer_identity.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_billing_account_log(log_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::Empty

Deletes all the log entries in a log. The log reappears if it receives new entries.

Parameters:

  • log_name (String)

    Required. The resource name of the log to delete: "projects/[PROJECT_ID]/logs/[LOG_ID]" "organizations/[ORGANIZATION_ID]/logs/[LOG_ID]" [LOG_ID] must be URL-encoded. For example, "projects/my-project-id/logs/syslog" , "organizations/1234567890/logs/cloudresourcemanager.googleapis.com% 2Factivity". For more information about log names, see LogEntry.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



607
608
609
610
611
612
613
614
615
# File 'generated/google/apis/logging_v2beta1/service.rb', line 607

def (log_name, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:delete, 'v2beta1/{+logName}', options)
  command.response_representation = Google::Apis::LoggingV2beta1::Empty::Representation
  command.response_class = Google::Apis::LoggingV2beta1::Empty
  command.params['logName'] = log_name unless log_name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_log(log_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::Empty

Deletes all the log entries in a log. The log reappears if it receives new entries.

Parameters:

  • log_name (String)

    Required. The resource name of the log to delete: "projects/[PROJECT_ID]/logs/[LOG_ID]" "organizations/[ORGANIZATION_ID]/logs/[LOG_ID]" [LOG_ID] must be URL-encoded. For example, "projects/my-project-id/logs/syslog" , "organizations/1234567890/logs/cloudresourcemanager.googleapis.com% 2Factivity". For more information about log names, see LogEntry.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



313
314
315
316
317
318
319
320
321
# File 'generated/google/apis/logging_v2beta1/service.rb', line 313

def delete_log(log_name, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:delete, 'v2beta1/{+logName}', options)
  command.response_representation = Google::Apis::LoggingV2beta1::Empty::Representation
  command.response_class = Google::Apis::LoggingV2beta1::Empty
  command.params['logName'] = log_name unless log_name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_organization_log(log_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::Empty

Deletes all the log entries in a log. The log reappears if it receives new entries.

Parameters:

  • log_name (String)

    Required. The resource name of the log to delete: "projects/[PROJECT_ID]/logs/[LOG_ID]" "organizations/[ORGANIZATION_ID]/logs/[LOG_ID]" [LOG_ID] must be URL-encoded. For example, "projects/my-project-id/logs/syslog" , "organizations/1234567890/logs/cloudresourcemanager.googleapis.com% 2Factivity". For more information about log names, see LogEntry.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



725
726
727
728
729
730
731
732
733
# File 'generated/google/apis/logging_v2beta1/service.rb', line 725

def delete_organization_log(log_name, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:delete, 'v2beta1/{+logName}', options)
  command.response_representation = Google::Apis::LoggingV2beta1::Empty::Representation
  command.response_class = Google::Apis::LoggingV2beta1::Empty
  command.params['logName'] = log_name unless log_name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_project_metric(metric_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::Empty

Deletes a logs-based metric.

Parameters:

  • metric_name (String)

    The resource name of the metric to delete: "projects/[PROJECT_ID]/metrics/[METRIC_ID]"

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



167
168
169
170
171
172
173
174
175
# File 'generated/google/apis/logging_v2beta1/service.rb', line 167

def delete_project_metric(metric_name, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:delete, 'v2beta1/{+metricName}', options)
  command.response_representation = Google::Apis::LoggingV2beta1::Empty::Representation
  command.response_class = Google::Apis::LoggingV2beta1::Empty
  command.params['metricName'] = metric_name unless metric_name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#delete_project_sink(sink_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::Empty

Deletes a sink. If the sink has a unique writer_identity, then that service account is also deleted.

Parameters:

  • sink_name (String)

    Required. The full resource name of the sink to delete, including the parent resource and the sink identifier: "projects/[PROJECT_ID]/sinks/[SINK_ID]" "organizations/[ORGANIZATION_ID]/sinks/[SINK_ID]" It is an error if the sink does not exist. Example: "projects/my-project-id/ sinks/my-sink-id". It is an error if the sink does not exist.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



393
394
395
396
397
398
399
400
401
# File 'generated/google/apis/logging_v2beta1/service.rb', line 393

def delete_project_sink(sink_name, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:delete, 'v2beta1/{+sinkName}', options)
  command.response_representation = Google::Apis::LoggingV2beta1::Empty::Representation
  command.response_class = Google::Apis::LoggingV2beta1::Empty
  command.params['sinkName'] = sink_name unless sink_name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_metric(metric_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogMetric

Gets a logs-based metric.

Parameters:

  • metric_name (String)

    The resource name of the desired metric: "projects/[PROJECT_ID]/metrics/[METRIC_ID]"

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



240
241
242
243
244
245
246
247
248
# File 'generated/google/apis/logging_v2beta1/service.rb', line 240

def get_project_metric(metric_name, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:get, 'v2beta1/{+metricName}', options)
  command.response_representation = Google::Apis::LoggingV2beta1::LogMetric::Representation
  command.response_class = Google::Apis::LoggingV2beta1::LogMetric
  command.params['metricName'] = metric_name unless metric_name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#get_project_sink(sink_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogSink

Gets a sink.

Parameters:

  • sink_name (String)

    Required. The parent resource name of the sink: "projects/[PROJECT_ID]/sinks/[SINK_ID]" "organizations/[ORGANIZATION_ID]/sinks/[SINK_ID]" Example: "projects/my-project-id/sinks/my-sink-id".

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



468
469
470
471
472
473
474
475
476
# File 'generated/google/apis/logging_v2beta1/service.rb', line 468

def get_project_sink(sink_name, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:get, 'v2beta1/{+sinkName}', options)
  command.response_representation = Google::Apis::LoggingV2beta1::LogSink::Representation
  command.response_class = Google::Apis::LoggingV2beta1::LogSink
  command.params['sinkName'] = sink_name unless sink_name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_billing_account_logs(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListLogsResponse

Lists the logs in projects or organizations. Only logs that have entries are listed.

Parameters:

  • parent (String)

    Required. The resource name that owns the logs: "projects/[PROJECT_ID]" "organizations/[ORGANIZATION_ID]"

  • page_token (String) (defaults to: nil)

    Optional. If present, then retrieve the next batch of results from the preceding call to this method. pageToken must be the value of nextPageToken from the previous response. The values of other method parameters should be identical to those in the previous call.

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of results to return from this request. Non- positive values are ignored. The presence of nextPageToken in the response indicates that more results might be available.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



649
650
651
652
653
654
655
656
657
658
659
# File 'generated/google/apis/logging_v2beta1/service.rb', line 649

def (parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:get, 'v2beta1/{+parent}/logs', options)
  command.response_representation = Google::Apis::LoggingV2beta1::ListLogsResponse::Representation
  command.response_class = Google::Apis::LoggingV2beta1::ListLogsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_entry_log_entries(list_log_entries_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListLogEntriesResponse

Lists log entries. Use this method to retrieve log entries from Stackdriver Logging. For ways to export log entries, see Exporting Logs.

Parameters:

  • list_log_entries_request_object (Google::Apis::LoggingV2beta1::ListLogEntriesRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



69
70
71
72
73
74
75
76
77
78
# File 'generated/google/apis/logging_v2beta1/service.rb', line 69

def list_entry_log_entries(list_log_entries_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:post, 'v2beta1/entries:list', options)
  command.request_representation = Google::Apis::LoggingV2beta1::ListLogEntriesRequest::Representation
  command.request_object = list_log_entries_request_object
  command.response_representation = Google::Apis::LoggingV2beta1::ListLogEntriesResponse::Representation
  command.response_class = Google::Apis::LoggingV2beta1::ListLogEntriesResponse
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_logs(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListLogsResponse

Lists the logs in projects or organizations. Only logs that have entries are listed.

Parameters:

  • parent (String)

    Required. The resource name that owns the logs: "projects/[PROJECT_ID]" "organizations/[ORGANIZATION_ID]"

  • page_token (String) (defaults to: nil)

    Optional. If present, then retrieve the next batch of results from the preceding call to this method. pageToken must be the value of nextPageToken from the previous response. The values of other method parameters should be identical to those in the previous call.

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of results to return from this request. Non- positive values are ignored. The presence of nextPageToken in the response indicates that more results might be available.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



355
356
357
358
359
360
361
362
363
364
365
# File 'generated/google/apis/logging_v2beta1/service.rb', line 355

def list_logs(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:get, 'v2beta1/{+parent}/logs', options)
  command.response_representation = Google::Apis::LoggingV2beta1::ListLogsResponse::Representation
  command.response_class = Google::Apis::LoggingV2beta1::ListLogsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_monitored_resource_descriptors(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListMonitoredResourceDescriptorsResponse

Lists the descriptors for monitored resource types used by Stackdriver Logging.

Parameters:

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of results to return from this request. Non- positive values are ignored. The presence of nextPageToken in the response indicates that more results might be available.

  • page_token (String) (defaults to: nil)

    Optional. If present, then retrieve the next batch of results from the preceding call to this method. pageToken must be the value of nextPageToken from the previous response. The values of other method parameters should be identical to those in the previous call.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



688
689
690
691
692
693
694
695
696
697
# File 'generated/google/apis/logging_v2beta1/service.rb', line 688

def list_monitored_resource_descriptors(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:get, 'v2beta1/monitoredResourceDescriptors', options)
  command.response_representation = Google::Apis::LoggingV2beta1::ListMonitoredResourceDescriptorsResponse::Representation
  command.response_class = Google::Apis::LoggingV2beta1::ListMonitoredResourceDescriptorsResponse
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_organization_logs(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListLogsResponse

Lists the logs in projects or organizations. Only logs that have entries are listed.

Parameters:

  • parent (String)

    Required. The resource name that owns the logs: "projects/[PROJECT_ID]" "organizations/[ORGANIZATION_ID]"

  • page_token (String) (defaults to: nil)

    Optional. If present, then retrieve the next batch of results from the preceding call to this method. pageToken must be the value of nextPageToken from the previous response. The values of other method parameters should be identical to those in the previous call.

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of results to return from this request. Non- positive values are ignored. The presence of nextPageToken in the response indicates that more results might be available.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



767
768
769
770
771
772
773
774
775
776
777
# File 'generated/google/apis/logging_v2beta1/service.rb', line 767

def list_organization_logs(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:get, 'v2beta1/{+parent}/logs', options)
  command.response_representation = Google::Apis::LoggingV2beta1::ListLogsResponse::Representation
  command.response_class = Google::Apis::LoggingV2beta1::ListLogsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_metrics(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListLogMetricsResponse

Lists logs-based metrics.

Parameters:

  • parent (String)

    Required. The name of the project containing the metrics: "projects/[PROJECT_ID]"

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of results to return from this request. Non- positive values are ignored. The presence of nextPageToken in the response indicates that more results might be available.

  • page_token (String) (defaults to: nil)

    Optional. If present, then retrieve the next batch of results from the preceding call to this method. pageToken must be the value of nextPageToken from the previous response. The values of other method parameters should be identical to those in the previous call.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



207
208
209
210
211
212
213
214
215
216
217
# File 'generated/google/apis/logging_v2beta1/service.rb', line 207

def list_project_metrics(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:get, 'v2beta1/{+parent}/metrics', options)
  command.response_representation = Google::Apis::LoggingV2beta1::ListLogMetricsResponse::Representation
  command.response_class = Google::Apis::LoggingV2beta1::ListLogMetricsResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#list_project_sinks(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListSinksResponse

Lists sinks.

Parameters:

  • parent (String)

    Required. The parent resource whose sinks are to be listed. Examples: " projects/my-logging-project", "organizations/123456789".

  • page_token (String) (defaults to: nil)

    Optional. If present, then retrieve the next batch of results from the preceding call to this method. pageToken must be the value of nextPageToken from the previous response. The values of other method parameters should be identical to those in the previous call.

  • page_size (Fixnum) (defaults to: nil)

    Optional. The maximum number of results to return from this request. Non- positive values are ignored. The presence of nextPageToken in the response indicates that more results might be available.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



433
434
435
436
437
438
439
440
441
442
443
# File 'generated/google/apis/logging_v2beta1/service.rb', line 433

def list_project_sinks(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:get, 'v2beta1/{+parent}/sinks', options)
  command.response_representation = Google::Apis::LoggingV2beta1::ListSinksResponse::Representation
  command.response_class = Google::Apis::LoggingV2beta1::ListSinksResponse
  command.params['parent'] = parent unless parent.nil?
  command.query['pageToken'] = page_token unless page_token.nil?
  command.query['pageSize'] = page_size unless page_size.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#update_project_metric(metric_name, log_metric_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogMetric

Creates or updates a logs-based metric.

Parameters:

  • metric_name (String)

    The resource name of the metric to update: "projects/[PROJECT_ID]/metrics/[METRIC_ID]" The updated metric must be provided in the request and it's name field must be the same as [METRIC_ID] If the metric does not exist in [PROJECT_ID], then a new metric is created.

  • log_metric_object (Google::Apis::LoggingV2beta1::LogMetric) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



275
276
277
278
279
280
281
282
283
284
285
# File 'generated/google/apis/logging_v2beta1/service.rb', line 275

def update_project_metric(metric_name, log_metric_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:put, 'v2beta1/{+metricName}', options)
  command.request_representation = Google::Apis::LoggingV2beta1::LogMetric::Representation
  command.request_object = log_metric_object
  command.response_representation = Google::Apis::LoggingV2beta1::LogMetric::Representation
  command.response_class = Google::Apis::LoggingV2beta1::LogMetric
  command.params['metricName'] = metric_name unless metric_name.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#update_project_sink(sink_name, log_sink_object = nil, unique_writer_identity: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogSink

Updates a sink. If the named sink doesn't exist, then this method is identical to sinks.create. If the named sink does exist, then this method replaces the following fields in the existing sink with values from the new sink: destination, filter, output_version_format, start_time, and end_time. The updated filter might also have a new writer_identity; see the unique_writer_identity field.

Parameters:

  • sink_name (String)

    Required. The full resource name of the sink to update, including the parent resource and the sink identifier: "projects/[PROJECT_ID]/sinks/[SINK_ID]" "organizations/[ORGANIZATION_ID]/sinks/[SINK_ID]" Example: "projects/my-project-id/sinks/my-sink-id".

  • log_sink_object (Google::Apis::LoggingV2beta1::LogSink) (defaults to: nil)
  • unique_writer_identity (Boolean) (defaults to: nil)

    Optional. See sinks.create for a description of this field. When updating a sink, the effect of this field on the value of writer_identity in the updated sink depends on both the old and new values of this field: If the old and new values of this field are both false or both true, then there is no change to the sink's writer_identity. If the old value was false and the new value is true, then writer_identity is changed to a unique service account. It is an error if the old value was true and the new value is false.

  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



517
518
519
520
521
522
523
524
525
526
527
528
# File 'generated/google/apis/logging_v2beta1/service.rb', line 517

def update_project_sink(sink_name, log_sink_object = nil, unique_writer_identity: nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:put, 'v2beta1/{+sinkName}', options)
  command.request_representation = Google::Apis::LoggingV2beta1::LogSink::Representation
  command.request_object = log_sink_object
  command.response_representation = Google::Apis::LoggingV2beta1::LogSink::Representation
  command.response_class = Google::Apis::LoggingV2beta1::LogSink
  command.params['sinkName'] = sink_name unless sink_name.nil?
  command.query['uniqueWriterIdentity'] = unique_writer_identity unless unique_writer_identity.nil?
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end

#write_entry_log_entries(write_log_entries_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::WriteLogEntriesResponse

Writes log entries to Stackdriver Logging. All log entries are written by this method.

Parameters:

  • write_log_entries_request_object (Google::Apis::LoggingV2beta1::WriteLogEntriesRequest) (defaults to: nil)
  • fields (String) (defaults to: nil)

    Selector specifying which fields to include in a partial response.

  • quota_user (String) (defaults to: nil)

    Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.

  • options (Google::Apis::RequestOptions) (defaults to: nil)

    Request-specific options

Yields:

  • (result, err)

    Result & error if block supplied

Yield Parameters:

Returns:

Raises:



100
101
102
103
104
105
106
107
108
109
# File 'generated/google/apis/logging_v2beta1/service.rb', line 100

def write_entry_log_entries(write_log_entries_request_object = nil, fields: nil, quota_user: nil, options: nil, &block)
  command =  make_simple_command(:post, 'v2beta1/entries:write', options)
  command.request_representation = Google::Apis::LoggingV2beta1::WriteLogEntriesRequest::Representation
  command.request_object = write_log_entries_request_object
  command.response_representation = Google::Apis::LoggingV2beta1::WriteLogEntriesResponse::Representation
  command.response_class = Google::Apis::LoggingV2beta1::WriteLogEntriesResponse
  command.query['fields'] = fields unless fields.nil?
  command.query['quotaUser'] = quota_user unless quota_user.nil?
  execute_or_queue_command(command, &block)
end