Class: Google::Apis::LoggingV2beta1::WriteLogEntriesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/logging_v2beta1/classes.rb,
generated/google/apis/logging_v2beta1/representations.rb,
generated/google/apis/logging_v2beta1/representations.rb

Overview

The parameters to WriteLogEntries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ WriteLogEntriesRequest

Returns a new instance of WriteLogEntriesRequest.



823
824
825
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 823

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entriesArray<Google::Apis::LoggingV2beta1::LogEntry>

Required. The log entries to write. Values supplied for the fields log_name, resource, and labels in this entries.write request are added to those log entries that do not provide their own values for the fields.To improve throughput and to avoid exceeding the quota limit for calls to entries.write, you should write multiple log entries at once rather than calling this method for each individual log entry. Corresponds to the JSON property entries



788
789
790
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 788

def entries
  @entries
end

#labelsHash<String,String>

Optional. Default labels that are added to the labels field of all log entries in entries. If a log entry already has a label with the same key as a label in this parameter, then the log entry's label is not changed. See LogEntry. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


805
806
807
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 805

def labels
  @labels
end

#log_nameString

Optional. A default log resource name that is assigned to all log entries in entries that do not specify a value for log_name: "projects/[PROJECT_ID]/logs/[LOG_ID]" "organizations/[ORGANIZATION_ID]/logs/[LOG_ID]" [LOG_ID] must be URL-encoded. For example, "projects/my-project-id/logs/syslog" or "organizations/1234567890/logs/cloudresourcemanager.googleapis.com% 2Factivity". For more information about log names, see LogEntry. Corresponds to the JSON property logName

Returns:

  • (String)


778
779
780
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 778

def log_name
  @log_name
end

#partial_successBoolean Also known as: partial_success?

Optional. Whether valid entries should be written even if some other entries fail due to INVALID_ARGUMENT or PERMISSION_DENIED errors. If any entry is not written, the response status will be the error associated with one of the failed entries and include error details in the form of WriteLogEntriesPartialErrors. Corresponds to the JSON property partialSuccess

Returns:

  • (Boolean)


797
798
799
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 797

def partial_success
  @partial_success
end

#resourceGoogle::Apis::LoggingV2beta1::MonitoredResource

An object representing a resource that can be used for monitoring, logging, billing, or other purposes. Examples include virtual machine instances, databases, and storage devices such as disks. The type field identifies a MonitoredResourceDescriptor object that describes the resource's schema. Information in the labels field identifies the actual resource and its attributes according to the schema. For example, a particular Compute Engine VM instance could be represented by the following object, because the MonitoredResourceDescriptor for "gce_instance" has labels "instance_id" and " zone": "type": "gce_instance", "labels": "instance_id": "12345678901234", "zone": "us-central1-a" ` Corresponds to the JSON propertyresource`



821
822
823
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 821

def resource
  @resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



828
829
830
831
832
833
834
# File 'generated/google/apis/logging_v2beta1/classes.rb', line 828

def update!(**args)
  @log_name = args[:log_name] if args.key?(:log_name)
  @entries = args[:entries] if args.key?(:entries)
  @partial_success = args[:partial_success] if args.key?(:partial_success)
  @labels = args[:labels] if args.key?(:labels)
  @resource = args[:resource] if args.key?(:resource)
end