Class: Google::Apis::MonitoringV3::CreateTimeSeriesRequest
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV3::CreateTimeSeriesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/monitoring_v3/classes.rb,
generated/google/apis/monitoring_v3/representations.rb,
generated/google/apis/monitoring_v3/representations.rb
Overview
The CreateTimeSeries request.
Instance Attribute Summary collapse
-
#time_series ⇒ Array<Google::Apis::MonitoringV3::TimeSeries>
The new data to be added to a list of time series.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateTimeSeriesRequest
constructor
A new instance of CreateTimeSeriesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ CreateTimeSeriesRequest
508 509 510 |
# File 'generated/google/apis/monitoring_v3/classes.rb', line 508 def initialize(**args) update!(**args) end |
Instance Attribute Details
#time_series ⇒ Array<Google::Apis::MonitoringV3::TimeSeries>
The new data to be added to a list of time series. Adds at most one data point
to each of several time series. The new data point must be more recent than
any other point in its time series. Each TimeSeries value must fully specify a
unique time series by supplying all label values for the metric and the
monitored resource.
Corresponds to the JSON property timeSeries
506 507 508 |
# File 'generated/google/apis/monitoring_v3/classes.rb', line 506 def time_series @time_series end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
513 514 515 |
# File 'generated/google/apis/monitoring_v3/classes.rb', line 513 def update!(**args) @time_series = args[:time_series] if args.key?(:time_series) end |