Class: Google::Apis::MonitoringV3::Explicit
- Inherits:
-
Object
- Object
- Google::Apis::MonitoringV3::Explicit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/monitoring_v3/classes.rb,
generated/google/apis/monitoring_v3/representations.rb,
generated/google/apis/monitoring_v3/representations.rb
Overview
A set of buckets with arbitrary widths.Defines size(bounds) + 1 (= N) buckets with these boundaries for bucket i:Upper bound (0 <= i < N-1): boundsi Lower bound (1 <= i < N); boundsi - 1There must be at least one element in bounds. If bounds has only one element, there are no finite buckets, and that single element is the common boundary of the overflow and underflow buckets.
Instance Attribute Summary collapse
-
#bounds ⇒ Array<Float>
The values must be monotonically increasing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Explicit
constructor
A new instance of Explicit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ Explicit
Returns a new instance of Explicit.
980 981 982 |
# File 'generated/google/apis/monitoring_v3/classes.rb', line 980 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bounds ⇒ Array<Float>
The values must be monotonically increasing.
Corresponds to the JSON property bounds
978 979 980 |
# File 'generated/google/apis/monitoring_v3/classes.rb', line 978 def bounds @bounds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
985 986 987 |
# File 'generated/google/apis/monitoring_v3/classes.rb', line 985 def update!(**args) @bounds = args[:bounds] if args.key?(:bounds) end |