Class: Google::Apis::MonitoringV3::TimeInterval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/monitoring_v3/classes.rb,
generated/google/apis/monitoring_v3/representations.rb,
generated/google/apis/monitoring_v3/representations.rb

Overview

A time interval extending just after a start time through an end time. If the start time is the same as the end time, then the interval represents a single point in time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ TimeInterval

Returns a new instance of TimeInterval.



956
957
958
# File 'generated/google/apis/monitoring_v3/classes.rb', line 956

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Required. The end of the time interval. Corresponds to the JSON property endTime

Returns:

  • (String)


954
955
956
# File 'generated/google/apis/monitoring_v3/classes.rb', line 954

def end_time
  @end_time
end

#start_timeString

Optional. The beginning of the time interval. The default value for the start time is the end time. The start time must not be later than the end time. Corresponds to the JSON property startTime

Returns:

  • (String)


949
950
951
# File 'generated/google/apis/monitoring_v3/classes.rb', line 949

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



961
962
963
964
# File 'generated/google/apis/monitoring_v3/classes.rb', line 961

def update!(**args)
  @start_time = args[:start_time] if args.key?(:start_time)
  @end_time = args[:end_time] if args.key?(:end_time)
end