Class: Google::Apis::SheetsV4::BasicChartSeries

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/sheets_v4/classes.rb,
generated/google/apis/sheets_v4/representations.rb,
generated/google/apis/sheets_v4/representations.rb

Overview

A single series of data in a chart. For example, if charting stock prices over time, multiple series may exist, one for the "Open Price", "High Price", "Low Price" and "Close Price".

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ BasicChartSeries

Returns a new instance of BasicChartSeries.



2760
2761
2762
# File 'generated/google/apis/sheets_v4/classes.rb', line 2760

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#seriesGoogle::Apis::SheetsV4::ChartData

The data included in a domain or series. Corresponds to the JSON property series



2737
2738
2739
# File 'generated/google/apis/sheets_v4/classes.rb', line 2737

def series
  @series
end

#target_axisString

The minor axis that will specify the range of values for this series. For example, if charting stocks over time, the "Volume" series may want to be pinned to the right with the prices pinned to the left, because the scale of trading volume is different than the scale of prices. It is an error to specify an axis that isn't a valid minor axis for the chart's type. Corresponds to the JSON property targetAxis

Returns:

  • (String)


2758
2759
2760
# File 'generated/google/apis/sheets_v4/classes.rb', line 2758

def target_axis
  @target_axis
end

#typeString

The type of this series. Valid only if the chartType is COMBO. Different types will change the way the series is visualized. Only LINE, AREA, and COLUMN are supported. Corresponds to the JSON property type

Returns:

  • (String)


2747
2748
2749
# File 'generated/google/apis/sheets_v4/classes.rb', line 2747

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2765
2766
2767
2768
2769
# File 'generated/google/apis/sheets_v4/classes.rb', line 2765

def update!(**args)
  @series = args[:series] if args.key?(:series)
  @type = args[:type] if args.key?(:type)
  @target_axis = args[:target_axis] if args.key?(:target_axis)
end