Class: Google::Apis::SheetsV4::BasicChartSpec
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::BasicChartSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/sheets_v4/classes.rb,
generated/google/apis/sheets_v4/representations.rb,
generated/google/apis/sheets_v4/representations.rb
Overview
The specification for a basic chart. See BasicChartType for the list of charts this supports.
Instance Attribute Summary collapse
-
#axis ⇒ Array<Google::Apis::SheetsV4::BasicChartAxis>
The axis on the chart.
-
#chart_type ⇒ String
The type of the chart.
-
#domains ⇒ Array<Google::Apis::SheetsV4::BasicChartDomain>
The domain of data this is charting.
-
#header_count ⇒ Fixnum
The number of rows or columns in the data that are "headers".
-
#legend_position ⇒ String
The position of the chart legend.
-
#series ⇒ Array<Google::Apis::SheetsV4::BasicChartSeries>
The data this chart is visualizing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BasicChartSpec
constructor
A new instance of BasicChartSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ BasicChartSpec
Returns a new instance of BasicChartSpec.
5582 5583 5584 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5582 def initialize(**args) update!(**args) end |
Instance Attribute Details
#axis ⇒ Array<Google::Apis::SheetsV4::BasicChartAxis>
The axis on the chart.
Corresponds to the JSON property axis
5570 5571 5572 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5570 def axis @axis end |
#chart_type ⇒ String
The type of the chart.
Corresponds to the JSON property chartType
5575 5576 5577 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5575 def chart_type @chart_type end |
#domains ⇒ Array<Google::Apis::SheetsV4::BasicChartDomain>
The domain of data this is charting.
Only a single domain is currently supported.
Corresponds to the JSON property domains
5556 5557 5558 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5556 def domains @domains end |
#header_count ⇒ Fixnum
The number of rows or columns in the data that are "headers".
If not set, Google Sheets will guess how many rows are headers based
on the data.
(Note that BasicChartAxis.title may override the axis title
inferred from the header values.)
Corresponds to the JSON property headerCount
5565 5566 5567 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5565 def header_count @header_count end |
#legend_position ⇒ String
The position of the chart legend.
Corresponds to the JSON property legendPosition
5550 5551 5552 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5550 def legend_position @legend_position end |
#series ⇒ Array<Google::Apis::SheetsV4::BasicChartSeries>
The data this chart is visualizing.
Corresponds to the JSON property series
5580 5581 5582 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5580 def series @series end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5587 5588 5589 5590 5591 5592 5593 5594 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5587 def update!(**args) @legend_position = args[:legend_position] if args.key?(:legend_position) @domains = args[:domains] if args.key?(:domains) @header_count = args[:header_count] if args.key?(:header_count) @axis = args[:axis] if args.key?(:axis) @chart_type = args[:chart_type] if args.key?(:chart_type) @series = args[:series] if args.key?(:series) end |