Class: Google::Apis::SheetsV4::BasicFilter
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::BasicFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/sheets_v4/classes.rb,
generated/google/apis/sheets_v4/representations.rb,
generated/google/apis/sheets_v4/representations.rb
Overview
The default filter associated with a sheet.
Instance Attribute Summary collapse
-
#criteria ⇒ Hash<String,Google::Apis::SheetsV4::FilterCriteria>
The criteria for showing/hiding values per column.
-
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
-
#sort_specs ⇒ Array<Google::Apis::SheetsV4::SortSpec>
The sort order per column.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BasicFilter
constructor
A new instance of BasicFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ BasicFilter
Returns a new instance of BasicFilter.
939 940 941 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 939 def initialize(**args) update!(**args) end |
Instance Attribute Details
#criteria ⇒ Hash<String,Google::Apis::SheetsV4::FilterCriteria>
The criteria for showing/hiding values per column.
The map's key is the column index, and the value is the criteria for
that column.
Corresponds to the JSON property criteria
931 932 933 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 931 def criteria @criteria end |
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
All indexes are zero-based.
Indexes are half open, e.g the start index is inclusive
and the end index is exclusive -- [start_index, end_index).
Missing indexes indicate the range is unbounded on that side.
For example, if "Sheet1" is sheet ID 0, then:
Sheet1!A1:A1 == sheet_id: 0,
start_row_index: 0, end_row_index: 1,
start_column_index: 0, end_column_index: 1
Sheet1!A3:B4 == sheet_id: 0,
start_row_index: 2, end_row_index: 4,
start_column_index: 0, end_column_index: 2
Sheet1!A:B == sheet_id: 0,
start_column_index: 0, end_column_index: 2
Sheet1!A5:B == sheet_id: 0,
start_row_index: 4,
start_column_index: 0, end_column_index: 2
Sheet1 == sheet_id:0
The start index must always be less than or equal to the end index.
If the start index equals the end index, then the range is empty.
Empty ranges are typically not meaningful and are usually rendered in the
UI as #REF!.
Corresponds to the JSON property range
924 925 926 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 924 def range @range end |
#sort_specs ⇒ Array<Google::Apis::SheetsV4::SortSpec>
The sort order per column. Later specifications are used when values
are equal in the earlier specifications.
Corresponds to the JSON property sortSpecs
937 938 939 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 937 def sort_specs @sort_specs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
944 945 946 947 948 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 944 def update!(**args) @range = args[:range] if args.key?(:range) @criteria = args[:criteria] if args.key?(:criteria) @sort_specs = args[:sort_specs] if args.key?(:sort_specs) end |