Class: Google::Apis::SheetsV4::BatchUpdateValuesRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::BatchUpdateValuesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/sheets_v4/classes.rb,
generated/google/apis/sheets_v4/representations.rb,
generated/google/apis/sheets_v4/representations.rb
Overview
The request for updating more than one range of values in a spreadsheet.
Instance Attribute Summary collapse
-
#data ⇒ Array<Google::Apis::SheetsV4::ValueRange>
The new values to apply to the spreadsheet.
-
#include_values_in_response ⇒ Boolean
(also: #include_values_in_response?)
Determines if the update response should include the values of the cells that were updated.
-
#response_date_time_render_option ⇒ String
Determines how dates, times, and durations in the response should be rendered.
-
#response_value_render_option ⇒ String
Determines how values in the response should be rendered.
-
#value_input_option ⇒ String
How the input data should be interpreted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchUpdateValuesRequest
constructor
A new instance of BatchUpdateValuesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ BatchUpdateValuesRequest
Returns a new instance of BatchUpdateValuesRequest.
2496 2497 2498 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 2496 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ Array<Google::Apis::SheetsV4::ValueRange>
The new values to apply to the spreadsheet.
Corresponds to the JSON property data
2468 2469 2470 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 2468 def data @data end |
#include_values_in_response ⇒ Boolean Also known as: include_values_in_response?
Determines if the update response should include the values
of the cells that were updated. By default, responses
do not include the updated values. The updatedData field within
each of the BatchUpdateValuesResponse.responses will contain
the updated values. If the range to write was larger than than the range
actually written, the response will include all values in the requested
range (excluding trailing empty rows and columns).
Corresponds to the JSON property includeValuesInResponse
2493 2494 2495 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 2493 def include_values_in_response @include_values_in_response end |
#response_date_time_render_option ⇒ String
Determines how dates, times, and durations in the response should be
rendered. This is ignored if response_value_render_option is
FORMATTED_VALUE.
The default dateTime render option is [DateTimeRenderOption.SERIAL_NUMBER].
Corresponds to the JSON property responseDateTimeRenderOption
2476 2477 2478 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 2476 def response_date_time_render_option @response_date_time_render_option end |
#response_value_render_option ⇒ String
Determines how values in the response should be rendered.
The default render option is ValueRenderOption.FORMATTED_VALUE.
Corresponds to the JSON property responseValueRenderOption
2482 2483 2484 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 2482 def response_value_render_option @response_value_render_option end |
#value_input_option ⇒ String
How the input data should be interpreted.
Corresponds to the JSON property valueInputOption
2463 2464 2465 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 2463 def value_input_option @value_input_option end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2501 2502 2503 2504 2505 2506 2507 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 2501 def update!(**args) @value_input_option = args[:value_input_option] if args.key?(:value_input_option) @data = args[:data] if args.key?(:data) @response_date_time_render_option = args[:response_date_time_render_option] if args.key?(:response_date_time_render_option) @response_value_render_option = args[:response_value_render_option] if args.key?(:response_value_render_option) @include_values_in_response = args[:include_values_in_response] if args.key?(:include_values_in_response) end |