Class: Google::Apis::SheetsV4::BooleanCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/sheets_v4/classes.rb,
generated/google/apis/sheets_v4/representations.rb,
generated/google/apis/sheets_v4/representations.rb

Overview

A condition that can evaluate to true or false. BooleanConditions are used by conditional formatting, data validation, and the criteria in filters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ BooleanCondition

Returns a new instance of BooleanCondition.



5467
5468
5469
# File 'generated/google/apis/sheets_v4/classes.rb', line 5467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#typeString

The type of condition. Corresponds to the JSON property type

Returns:

  • (String)


5457
5458
5459
# File 'generated/google/apis/sheets_v4/classes.rb', line 5457

def type
  @type
end

#valuesArray<Google::Apis::SheetsV4::ConditionValue>

The values of the condition. The number of supported values depends on the condition type. Some support zero values, others one or two values, and ConditionType.ONE_OF_LIST supports an arbitrary number of values. Corresponds to the JSON property values



5465
5466
5467
# File 'generated/google/apis/sheets_v4/classes.rb', line 5465

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5472
5473
5474
5475
# File 'generated/google/apis/sheets_v4/classes.rb', line 5472

def update!(**args)
  @type = args[:type] if args.key?(:type)
  @values = args[:values] if args.key?(:values)
end