Class: Google::Apis::SheetsV4::GradientRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/sheets_v4/classes.rb,
generated/google/apis/sheets_v4/representations.rb,
generated/google/apis/sheets_v4/representations.rb

Overview

A rule that applies a gradient color scale format, based on the interpolation points listed. The format of a cell will vary based on its contents as compared to the values of the interpolation points.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ GradientRule

Returns a new instance of GradientRule.



1279
1280
1281
# File 'generated/google/apis/sheets_v4/classes.rb', line 1279

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#maxpointGoogle::Apis::SheetsV4::InterpolationPoint

A single interpolation point on a gradient conditional format. These pin the gradient color scale according to the color, type and value chosen. Corresponds to the JSON property maxpoint



1270
1271
1272
# File 'generated/google/apis/sheets_v4/classes.rb', line 1270

def maxpoint
  @maxpoint
end

#midpointGoogle::Apis::SheetsV4::InterpolationPoint

A single interpolation point on a gradient conditional format. These pin the gradient color scale according to the color, type and value chosen. Corresponds to the JSON property midpoint



1277
1278
1279
# File 'generated/google/apis/sheets_v4/classes.rb', line 1277

def midpoint
  @midpoint
end

#minpointGoogle::Apis::SheetsV4::InterpolationPoint

A single interpolation point on a gradient conditional format. These pin the gradient color scale according to the color, type and value chosen. Corresponds to the JSON property minpoint



1263
1264
1265
# File 'generated/google/apis/sheets_v4/classes.rb', line 1263

def minpoint
  @minpoint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1284
1285
1286
1287
1288
# File 'generated/google/apis/sheets_v4/classes.rb', line 1284

def update!(**args)
  @minpoint = args[:minpoint] if args.key?(:minpoint)
  @maxpoint = args[:maxpoint] if args.key?(:maxpoint)
  @midpoint = args[:midpoint] if args.key?(:midpoint)
end