Class: Google::Apis::SheetsV4::ProtectedRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/sheets_v4/classes.rb,
generated/google/apis/sheets_v4/representations.rb,
generated/google/apis/sheets_v4/representations.rb

Overview

A protected range.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ ProtectedRange

Returns a new instance of ProtectedRange.



2439
2440
2441
# File 'generated/google/apis/sheets_v4/classes.rb', line 2439

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

The description of this protected range. Corresponds to the JSON property description

Returns:

  • (String)


2366
2367
2368
# File 'generated/google/apis/sheets_v4/classes.rb', line 2366

def description
  @description
end

#editorsGoogle::Apis::SheetsV4::Editors

The editors of a protected range. Corresponds to the JSON property editors



2437
2438
2439
# File 'generated/google/apis/sheets_v4/classes.rb', line 2437

def editors
  @editors
end

#named_range_idString

The named range this protected range is backed by, if any. When writing, only one of range or named_range_id may be set. Corresponds to the JSON property namedRangeId

Returns:

  • (String)


2379
2380
2381
# File 'generated/google/apis/sheets_v4/classes.rb', line 2379

def named_range_id
  @named_range_id
end

#protected_range_idFixnum

The ID of the protected range. This field is read-only. Corresponds to the JSON property protectedRangeId

Returns:

  • (Fixnum)


2385
2386
2387
# File 'generated/google/apis/sheets_v4/classes.rb', line 2385

def protected_range_id
  @protected_range_id
end

#rangeGoogle::Apis::SheetsV4::GridRange

A range on a sheet. All indexes are zero-based. Indexes are half open, e.g the start index is inclusive and the end index is exclusive -- [start_index, end_index). Missing indexes indicate the range is unbounded on that side. For example, if "Sheet1" is sheet ID 0, then: Sheet1!A1:A1 == sheet_id: 0, start_row_index: 0, end_row_index: 1, start_column_index: 0, end_column_index: 1 Sheet1!A3:B4 == sheet_id: 0, start_row_index: 2, end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B == sheet_id: 0, start_column_index: 0, end_column_index: 2 Sheet1!A5:B == sheet_id: 0, start_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1 == sheet_id:0 The start index must always be less than or equal to the end index. If the start index equals the end index, then the range is empty. Empty ranges are typically not meaningful and are usually rendered in the UI as #REF!. Corresponds to the JSON property range



2432
2433
2434
# File 'generated/google/apis/sheets_v4/classes.rb', line 2432

def range
  @range
end

#requesting_user_can_editBoolean Also known as: requesting_user_can_edit?

True if the user who requested this protected range can edit the protected area. This field is read-only. Corresponds to the JSON property requestingUserCanEdit

Returns:

  • (Boolean)


2405
2406
2407
# File 'generated/google/apis/sheets_v4/classes.rb', line 2405

def requesting_user_can_edit
  @requesting_user_can_edit
end

#unprotected_rangesArray<Google::Apis::SheetsV4::GridRange>

The list of unprotected ranges within a protected sheet. Unprotected ranges are only supported on protected sheets. Corresponds to the JSON property unprotectedRanges



2372
2373
2374
# File 'generated/google/apis/sheets_v4/classes.rb', line 2372

def unprotected_ranges
  @unprotected_ranges
end

#warning_onlyBoolean Also known as: warning_only?

True if this protected range will show a warning when editing. Warning-based protection means that every user can edit data in the protected range, except editing will prompt a warning asking the user to confirm the edit. When writing: if this field is true, then editors is ignored. Additionally, if this field is changed from true to false and the editors field is not set (nor included in the field mask), then the editors will be set to all the editors in the document. Corresponds to the JSON property warningOnly

Returns:

  • (Boolean)


2397
2398
2399
# File 'generated/google/apis/sheets_v4/classes.rb', line 2397

def warning_only
  @warning_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2444
2445
2446
2447
2448
2449
2450
2451
2452
2453
# File 'generated/google/apis/sheets_v4/classes.rb', line 2444

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @unprotected_ranges = args[:unprotected_ranges] if args.key?(:unprotected_ranges)
  @named_range_id = args[:named_range_id] if args.key?(:named_range_id)
  @protected_range_id = args[:protected_range_id] if args.key?(:protected_range_id)
  @warning_only = args[:warning_only] if args.key?(:warning_only)
  @requesting_user_can_edit = args[:requesting_user_can_edit] if args.key?(:requesting_user_can_edit)
  @range = args[:range] if args.key?(:range)
  @editors = args[:editors] if args.key?(:editors)
end