Class: Google::Apis::SheetsV4::SetDataValidationRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::SetDataValidationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/sheets_v4/classes.rb,
generated/google/apis/sheets_v4/representations.rb,
generated/google/apis/sheets_v4/representations.rb
Overview
Sets a data validation rule to every cell in the range. To clear validation in a range, call this with no rule specified.
Instance Attribute Summary collapse
-
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
-
#rule ⇒ Google::Apis::SheetsV4::DataValidationRule
A data validation rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetDataValidationRequest
constructor
A new instance of SetDataValidationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ SetDataValidationRequest
Returns a new instance of SetDataValidationRequest.
5633 5634 5635 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5633 def initialize(**args) update!(**args) end |
Instance Attribute Details
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
All indexes are zero-based.
Indexes are half open, e.g the start index is inclusive
and the end index is exclusive -- [start_index, end_index).
Missing indexes indicate the range is unbounded on that side.
For example, if "Sheet1" is sheet ID 0, then:
Sheet1!A1:A1 == sheet_id: 0,
start_row_index: 0, end_row_index: 1,
start_column_index: 0, end_column_index: 1
Sheet1!A3:B4 == sheet_id: 0,
start_row_index: 2, end_row_index: 4,
start_column_index: 0, end_column_index: 2
Sheet1!A:B == sheet_id: 0,
start_column_index: 0, end_column_index: 2
Sheet1!A5:B == sheet_id: 0,
start_row_index: 4,
start_column_index: 0, end_column_index: 2
Sheet1 == sheet_id:0
The start index must always be less than or equal to the end index.
If the start index equals the end index, then the range is empty.
Empty ranges are typically not meaningful and are usually rendered in the
UI as #REF!.
Corresponds to the JSON property range
5631 5632 5633 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5631 def range @range end |
#rule ⇒ Google::Apis::SheetsV4::DataValidationRule
A data validation rule.
Corresponds to the JSON property rule
5605 5606 5607 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5605 def rule @rule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5638 5639 5640 5641 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5638 def update!(**args) @rule = args[:rule] if args.key?(:rule) @range = args[:range] if args.key?(:range) end |