Class: Google::Apis::SheetsV4::UpdateCellsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/sheets_v4/classes.rb,
generated/google/apis/sheets_v4/representations.rb,
generated/google/apis/sheets_v4/representations.rb

Overview

Updates all cells in a range with new data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ UpdateCellsRequest

Returns a new instance of UpdateCellsRequest.



4230
4231
4232
# File 'generated/google/apis/sheets_v4/classes.rb', line 4230

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsString

The fields of CellData that should be updated. At least one field must be specified. The root is the CellData; 'row.values.' should not be specified. A single "*" can be used as short-hand for listing every field. Corresponds to the JSON property fields

Returns:

  • (String)


4196
4197
4198
# File 'generated/google/apis/sheets_v4/classes.rb', line 4196

def fields
  @fields
end

#rangeGoogle::Apis::SheetsV4::GridRange

A range on a sheet. All indexes are zero-based. Indexes are half open, e.g the start index is inclusive and the end index is exclusive -- [start_index, end_index). Missing indexes indicate the range is unbounded on that side. For example, if "Sheet1" is sheet ID 0, then: Sheet1!A1:A1 == sheet_id: 0, start_row_index: 0, end_row_index: 1, start_column_index: 0, end_column_index: 1 Sheet1!A3:B4 == sheet_id: 0, start_row_index: 2, end_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1!A:B == sheet_id: 0, start_column_index: 0, end_column_index: 2 Sheet1!A5:B == sheet_id: 0, start_row_index: 4, start_column_index: 0, end_column_index: 2 Sheet1 == sheet_id:0 The start index must always be less than or equal to the end index. If the start index equals the end index, then the range is empty. Empty ranges are typically not meaningful and are usually rendered in the UI as #REF!. Corresponds to the JSON property range



4228
4229
4230
# File 'generated/google/apis/sheets_v4/classes.rb', line 4228

def range
  @range
end

#rowsArray<Google::Apis::SheetsV4::RowData>

The data to write. Corresponds to the JSON property rows



4188
4189
4190
# File 'generated/google/apis/sheets_v4/classes.rb', line 4188

def rows
  @rows
end

#startGoogle::Apis::SheetsV4::GridCoordinate

A coordinate in a sheet. All indexes are zero-based. Corresponds to the JSON property start



4202
4203
4204
# File 'generated/google/apis/sheets_v4/classes.rb', line 4202

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4235
4236
4237
4238
4239
4240
# File 'generated/google/apis/sheets_v4/classes.rb', line 4235

def update!(**args)
  @rows = args[:rows] if args.key?(:rows)
  @fields = args[:fields] if args.key?(:fields)
  @start = args[:start] if args.key?(:start)
  @range = args[:range] if args.key?(:range)
end