Class: Google::Apis::SheetsV4::UpdateValuesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/sheets_v4/classes.rb,
generated/google/apis/sheets_v4/representations.rb,
generated/google/apis/sheets_v4/representations.rb

Overview

The response when updating a range of values in a spreadsheet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ UpdateValuesResponse

Returns a new instance of UpdateValuesResponse.



1004
1005
1006
# File 'generated/google/apis/sheets_v4/classes.rb', line 1004

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#spreadsheet_idString

The spreadsheet the updates were applied to. Corresponds to the JSON property spreadsheetId

Returns:

  • (String)


992
993
994
# File 'generated/google/apis/sheets_v4/classes.rb', line 992

def spreadsheet_id
  @spreadsheet_id
end

#updated_cellsFixnum

The number of cells updated. Corresponds to the JSON property updatedCells

Returns:

  • (Fixnum)


1002
1003
1004
# File 'generated/google/apis/sheets_v4/classes.rb', line 1002

def updated_cells
  @updated_cells
end

#updated_columnsFixnum

The number of columns where at least one cell in the column was updated. Corresponds to the JSON property updatedColumns

Returns:

  • (Fixnum)


987
988
989
# File 'generated/google/apis/sheets_v4/classes.rb', line 987

def updated_columns
  @updated_columns
end

#updated_dataGoogle::Apis::SheetsV4::ValueRange

Data within a range of the spreadsheet. Corresponds to the JSON property updatedData



982
983
984
# File 'generated/google/apis/sheets_v4/classes.rb', line 982

def updated_data
  @updated_data
end

#updated_rangeString

The range (in A1 notation) that updates were applied to. Corresponds to the JSON property updatedRange

Returns:

  • (String)


997
998
999
# File 'generated/google/apis/sheets_v4/classes.rb', line 997

def updated_range
  @updated_range
end

#updated_rowsFixnum

The number of rows where at least one cell in the row was updated. Corresponds to the JSON property updatedRows

Returns:

  • (Fixnum)


977
978
979
# File 'generated/google/apis/sheets_v4/classes.rb', line 977

def updated_rows
  @updated_rows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1009
1010
1011
1012
1013
1014
1015
1016
# File 'generated/google/apis/sheets_v4/classes.rb', line 1009

def update!(**args)
  @updated_rows = args[:updated_rows] if args.key?(:updated_rows)
  @updated_data = args[:updated_data] if args.key?(:updated_data)
  @updated_columns = args[:updated_columns] if args.key?(:updated_columns)
  @spreadsheet_id = args[:spreadsheet_id] if args.key?(:spreadsheet_id)
  @updated_range = args[:updated_range] if args.key?(:updated_range)
  @updated_cells = args[:updated_cells] if args.key?(:updated_cells)
end