Class: Google::Apis::SlidesV1::AutoText
- Inherits:
-
Object
- Object
- Google::Apis::SlidesV1::AutoText
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/slides_v1/classes.rb,
generated/google/apis/slides_v1/representations.rb,
generated/google/apis/slides_v1/representations.rb
Overview
A TextElement kind that represents auto text.
Instance Attribute Summary collapse
-
#content ⇒ String
The rendered content of this auto text, if available.
-
#style ⇒ Google::Apis::SlidesV1::TextStyle
Represents the styling that can be applied to a TextRun.
-
#type ⇒ String
The type of this auto text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoText
constructor
A new instance of AutoText.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ AutoText
Returns a new instance of AutoText.
2716 2717 2718 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2716 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ String
The rendered content of this auto text, if available.
Corresponds to the JSON property content
2714 2715 2716 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2714 def content @content end |
#style ⇒ Google::Apis::SlidesV1::TextStyle
Represents the styling that can be applied to a TextRun. If this text is contained in a shape with a parent placeholder, then these text styles may be inherited from the parent. Which text styles are inherited depend on the nesting level of lists:
- A text run in a paragraph that is not in a list will inherit its text style from the the newline character in the paragraph at the 0 nesting level of the list inside the parent placeholder.
- A text run in a paragraph that is in a list will inherit its text style
from the newline character in the paragraph at its corresponding nesting
level of the list inside the parent placeholder.
Inherited text styles are represented as unset fields in this message. If
text is contained in a shape without a parent placeholder, unsetting these
fields will revert the style to a value matching the defaults in the Slides
editor.
Corresponds to the JSON property
style
2704 2705 2706 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2704 def style @style end |
#type ⇒ String
The type of this auto text.
Corresponds to the JSON property type
2709 2710 2711 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2709 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2721 2722 2723 2724 2725 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2721 def update!(**args) @style = args[:style] if args.key?(:style) @type = args[:type] if args.key?(:type) @content = args[:content] if args.key?(:content) end |