Class: Google::Apis::SlidesV1::CreateImageRequest
- Inherits:
-
Object
- Object
- Google::Apis::SlidesV1::CreateImageRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/slides_v1/classes.rb,
generated/google/apis/slides_v1/representations.rb,
generated/google/apis/slides_v1/representations.rb
Overview
Creates an image.
Instance Attribute Summary collapse
-
#element_properties ⇒ Google::Apis::SlidesV1::PageElementProperties
Common properties for a page element.
-
#object_id_prop ⇒ String
A user-supplied object ID.
-
#url ⇒ String
The image URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateImageRequest
constructor
A new instance of CreateImageRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ CreateImageRequest
Returns a new instance of CreateImageRequest.
743 744 745 |
# File 'generated/google/apis/slides_v1/classes.rb', line 743 def initialize(**args) update!(**args) end |
Instance Attribute Details
#element_properties ⇒ Google::Apis::SlidesV1::PageElementProperties
Common properties for a page element.
Note: When you initially create a
PageElement, the API may modify
the values of both size and transform, but the
visual size will be unchanged.
Corresponds to the JSON property elementProperties
741 742 743 |
# File 'generated/google/apis/slides_v1/classes.rb', line 741 def element_properties @element_properties end |
#object_id_prop ⇒ String
A user-supplied object ID.
If you specify an ID, it must be unique among all pages and page elements
in the presentation. The ID must start with an alphanumeric character or an
underscore (matches regex [a-zA-Z0-9_]); remaining characters
may include those as well as a hyphen or colon (matches regex
[a-zA-Z0-9_-:]).
The length of the ID must not be less than 5 or greater than 50.
If you don't specify an ID, a unique one is generated.
Corresponds to the JSON property objectId
732 733 734 |
# File 'generated/google/apis/slides_v1/classes.rb', line 732 def object_id_prop @object_id_prop end |
#url ⇒ String
The image URL.
The image is fetched once at insertion time and a copy is stored for
display inside the presentation. Images must be less than 50MB in size,
cannot exceed 25 megapixels, and must be in either in PNG, JPEG, or GIF
format.
Corresponds to the JSON property url
720 721 722 |
# File 'generated/google/apis/slides_v1/classes.rb', line 720 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
748 749 750 751 752 |
# File 'generated/google/apis/slides_v1/classes.rb', line 748 def update!(**args) @url = args[:url] if args.key?(:url) @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop) @element_properties = args[:element_properties] if args.key?(:element_properties) end |