Class: Google::Apis::SlidesV1::CreateLineRequest
- Inherits:
-
Object
- Object
- Google::Apis::SlidesV1::CreateLineRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/slides_v1/classes.rb,
generated/google/apis/slides_v1/representations.rb,
generated/google/apis/slides_v1/representations.rb
Overview
Creates a line.
Instance Attribute Summary collapse
-
#element_properties ⇒ Google::Apis::SlidesV1::PageElementProperties
Common properties for a page element.
-
#line_category ⇒ String
The category of line to be created.
-
#object_id_prop ⇒ String
A user-supplied object ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateLineRequest
constructor
A new instance of CreateLineRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ CreateLineRequest
Returns a new instance of CreateLineRequest.
2908 2909 2910 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2908 def initialize(**args) update!(**args) end |
Instance Attribute Details
#element_properties ⇒ Google::Apis::SlidesV1::PageElementProperties
Common properties for a page element.
Note: When you initially create a
PageElement, the API may modify
the values of both size and transform, but the
visual size will be unchanged.
Corresponds to the JSON property elementProperties
2901 2902 2903 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2901 def element_properties @element_properties end |
#line_category ⇒ String
The category of line to be created.
Corresponds to the JSON property lineCategory
2906 2907 2908 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2906 def line_category @line_category end |
#object_id_prop ⇒ String
A user-supplied object ID.
If you specify an ID, it must be unique among all pages and page elements
in the presentation. The ID must start with an alphanumeric character or an
underscore (matches regex [a-zA-Z0-9_]); remaining characters
may include those as well as a hyphen or colon (matches regex
[a-zA-Z0-9_-:]).
The length of the ID must not be less than 5 or greater than 50.
If you don't specify an ID, a unique one is generated.
Corresponds to the JSON property objectId
2892 2893 2894 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2892 def object_id_prop @object_id_prop end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2913 2914 2915 2916 2917 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2913 def update!(**args) @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop) @element_properties = args[:element_properties] if args.key?(:element_properties) @line_category = args[:line_category] if args.key?(:line_category) end |