Class: Google::Apis::SlidesV1::CreateShapeRequest
- Inherits:
-
Object
- Object
- Google::Apis::SlidesV1::CreateShapeRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/slides_v1/classes.rb,
generated/google/apis/slides_v1/representations.rb,
generated/google/apis/slides_v1/representations.rb
Overview
Creates a new shape.
Instance Attribute Summary collapse
-
#element_properties ⇒ Google::Apis::SlidesV1::PageElementProperties
Common properties for a page element.
-
#object_id_prop ⇒ String
A user-supplied object ID.
-
#shape_type ⇒ String
The shape type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateShapeRequest
constructor
A new instance of CreateShapeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ CreateShapeRequest
Returns a new instance of CreateShapeRequest.
2592 2593 2594 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2592 def initialize(**args) update!(**args) end |
Instance Attribute Details
#element_properties ⇒ Google::Apis::SlidesV1::PageElementProperties
Common properties for a page element.
Note: When you initially create a
PageElement, the API may modify
the values of both size and transform, but the
visual size will be unchanged.
Corresponds to the JSON property elementProperties
2590 2591 2592 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2590 def element_properties @element_properties end |
#object_id_prop ⇒ String
A user-supplied object ID.
If you specify an ID, it must be unique among all pages and page elements
in the presentation. The ID must start with an alphanumeric character or an
underscore (matches regex [a-zA-Z0-9_]); remaining characters
may include those as well as a hyphen or colon (matches regex
[a-zA-Z0-9_-:]).
The length of the ID must not be less than 5 or greater than 50.
If empty, a unique identifier will be generated.
Corresponds to the JSON property objectId
2576 2577 2578 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2576 def object_id_prop @object_id_prop end |
#shape_type ⇒ String
The shape type.
Corresponds to the JSON property shapeType
2581 2582 2583 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2581 def shape_type @shape_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2597 2598 2599 2600 2601 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2597 def update!(**args) @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop) @shape_type = args[:shape_type] if args.key?(:shape_type) @element_properties = args[:element_properties] if args.key?(:element_properties) end |