Class: Google::Apis::SlidesV1::CreateSheetsChartRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/slides_v1/classes.rb,
generated/google/apis/slides_v1/representations.rb,
generated/google/apis/slides_v1/representations.rb

Overview

Creates an embedded Google Sheets chart. NOTE: Chart creation requires at least one of the spreadsheets.readonly, spreadsheets, drive.readonly, or drive OAuth scopes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ CreateSheetsChartRequest

Returns a new instance of CreateSheetsChartRequest.



1589
1590
1591
# File 'generated/google/apis/slides_v1/classes.rb', line 1589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chart_idFixnum

The ID of the specific chart in the Google Sheets spreadsheet. Corresponds to the JSON property chartId

Returns:

  • (Fixnum)


1557
1558
1559
# File 'generated/google/apis/slides_v1/classes.rb', line 1557

def chart_id
  @chart_id
end

#element_propertiesGoogle::Apis::SlidesV1::PageElementProperties

Common properties for a page element. Note: When you initially create a PageElement, the API may modify the values of both size and transform, but the visual size will be unchanged. Corresponds to the JSON property elementProperties



1581
1582
1583
# File 'generated/google/apis/slides_v1/classes.rb', line 1581

def element_properties
  @element_properties
end

#linking_modeString

The mode with which the chart is linked to the source spreadsheet. When not specified, the chart will be an image that is not linked. Corresponds to the JSON property linkingMode

Returns:

  • (String)


1587
1588
1589
# File 'generated/google/apis/slides_v1/classes.rb', line 1587

def linking_mode
  @linking_mode
end

#object_id_propString

A user-supplied object ID. If specified, the ID must be unique among all pages and page elements in the presentation. The ID should start with a word character [a-zA-Z0-9_] and then followed by any number of the following characters [a-zA-Z0-9_-:]. The length of the ID should not be less than 5 or greater than 50. If empty, a unique identifier will be generated. Corresponds to the JSON property objectId

Returns:

  • (String)


1567
1568
1569
# File 'generated/google/apis/slides_v1/classes.rb', line 1567

def object_id_prop
  @object_id_prop
end

#spreadsheet_idString

The ID of the Google Sheets spreadsheet that contains the chart. Corresponds to the JSON property spreadsheetId

Returns:

  • (String)


1572
1573
1574
# File 'generated/google/apis/slides_v1/classes.rb', line 1572

def spreadsheet_id
  @spreadsheet_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1594
1595
1596
1597
1598
1599
1600
# File 'generated/google/apis/slides_v1/classes.rb', line 1594

def update!(**args)
  @chart_id = args[:chart_id] if args.key?(:chart_id)
  @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop)
  @spreadsheet_id = args[:spreadsheet_id] if args.key?(:spreadsheet_id)
  @element_properties = args[:element_properties] if args.key?(:element_properties)
  @linking_mode = args[:linking_mode] if args.key?(:linking_mode)
end