Class: Google::Apis::SlidesV1::LayoutProperties
- Inherits:
-
Object
- Object
- Google::Apis::SlidesV1::LayoutProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/slides_v1/classes.rb,
generated/google/apis/slides_v1/representations.rb,
generated/google/apis/slides_v1/representations.rb
Overview
The properties of Page are only relevant for pages with page_type LAYOUT.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The human readable name of the layout in the presentation's locale.
-
#master_object_id ⇒ String
The object ID of the master that this layout is based on.
-
#name ⇒ String
The name of the layout.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LayoutProperties
constructor
A new instance of LayoutProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ LayoutProperties
Returns a new instance of LayoutProperties.
2392 2393 2394 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2392 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The human readable name of the layout in the presentation's locale.
Corresponds to the JSON property displayName
2380 2381 2382 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2380 def display_name @display_name end |
#master_object_id ⇒ String
The object ID of the master that this layout is based on.
Corresponds to the JSON property masterObjectId
2385 2386 2387 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2385 def master_object_id @master_object_id end |
#name ⇒ String
The name of the layout.
Corresponds to the JSON property name
2390 2391 2392 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2390 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2397 2398 2399 2400 2401 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2397 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @master_object_id = args[:master_object_id] if args.key?(:master_object_id) @name = args[:name] if args.key?(:name) end |