Class: Google::Apis::SlidesV1::NestingLevel
- Inherits:
-
Object
- Object
- Google::Apis::SlidesV1::NestingLevel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/slides_v1/classes.rb,
generated/google/apis/slides_v1/representations.rb,
generated/google/apis/slides_v1/representations.rb
Overview
Contains properties describing the look and feel of a list bullet at a given level of nesting.
Instance Attribute Summary collapse
-
#bullet_style ⇒ Google::Apis::SlidesV1::TextStyle
Represents the styling that can be applied to a TextRun.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NestingLevel
constructor
A new instance of NestingLevel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ NestingLevel
1160 1161 1162 |
# File 'generated/google/apis/slides_v1/classes.rb', line 1160 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bullet_style ⇒ Google::Apis::SlidesV1::TextStyle
Represents the styling that can be applied to a TextRun. If this text is contained in a shape with a parent placeholder, then these text styles may be inherited from the parent. Which text styles are inherited depend on the nesting level of lists:
- A text run in a paragraph that is not in a list will inherit its text style from the the newline character in the paragraph at the 0 nesting level of the list inside the parent placeholder.
- A text run in a paragraph that is in a list will inherit its text style
from the newline character in the paragraph at its corresponding nesting
level of the list inside the parent placeholder.
Inherited text styles are represented as unset fields in this message. If
text is contained in a shape without a parent placeholder, unsetting these
fields will revert the style to a value matching the defaults in the Slides
editor.
Corresponds to the JSON property
bulletStyle
1158 1159 1160 |
# File 'generated/google/apis/slides_v1/classes.rb', line 1158 def bullet_style @bullet_style end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1165 1166 1167 |
# File 'generated/google/apis/slides_v1/classes.rb', line 1165 def update!(**args) @bullet_style = args[:bullet_style] if args.key?(:bullet_style) end |