Class: Google::Apis::SlidesV1::TextStyle
- Inherits:
-
Object
- Object
- Google::Apis::SlidesV1::TextStyle
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/slides_v1/classes.rb,
generated/google/apis/slides_v1/representations.rb,
generated/google/apis/slides_v1/representations.rb
Overview
Represents the styling that can be applied to a TextRun. If this text is contained in a shape with a parent placeholder, then these text styles may be inherited from the parent. Which text styles are inherited depend on the nesting level of lists:
- A text run in a paragraph that is not in a list will inherit its text style from the the newline character in the paragraph at the 0 nesting level of the list inside the parent placeholder.
- A text run in a paragraph that is in a list will inherit its text style from the newline character in the paragraph at its corresponding nesting level of the list inside the parent placeholder. Inherited text styles are represented as unset fields in this message. If text is contained in a shape without a parent placeholder, unsetting these fields will revert the style to a value matching the defaults in the Slides editor.
Instance Attribute Summary collapse
-
#background_color ⇒ Google::Apis::SlidesV1::OptionalColor
A color that can either be fully opaque or fully transparent.
-
#baseline_offset ⇒ String
The text's vertical offset from its normal position.
-
#bold ⇒ Boolean
(also: #bold?)
Whether or not the text is bold.
-
#font_family ⇒ String
The font family of the text.
-
#font_size ⇒ Google::Apis::SlidesV1::Dimension
A magnitude in a single direction in the specified units.
-
#foreground_color ⇒ Google::Apis::SlidesV1::OptionalColor
A color that can either be fully opaque or fully transparent.
-
#italic ⇒ Boolean
(also: #italic?)
Whether or not the text is italicized.
-
#link ⇒ Google::Apis::SlidesV1::Link
A hypertext link.
-
#small_caps ⇒ Boolean
(also: #small_caps?)
Whether or not the text is in small capital letters.
-
#strikethrough ⇒ Boolean
(also: #strikethrough?)
Whether or not the text is struck through.
-
#underline ⇒ Boolean
(also: #underline?)
Whether or not the text is underlined.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TextStyle
constructor
A new instance of TextStyle.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ TextStyle
Returns a new instance of TextStyle.
1990 1991 1992 |
# File 'generated/google/apis/slides_v1/classes.rb', line 1990 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background_color ⇒ Google::Apis::SlidesV1::OptionalColor
A color that can either be fully opaque or fully transparent.
Corresponds to the JSON property backgroundColor
1977 1978 1979 |
# File 'generated/google/apis/slides_v1/classes.rb', line 1977 def background_color @background_color end |
#baseline_offset ⇒ String
The text's vertical offset from its normal position.
Text with SUPERSCRIPT or SUBSCRIPT baseline offsets is automatically
rendered in a smaller font size, computed based on the font_size field.
The font_size itself is not affected by changes in this field.
Corresponds to the JSON property baselineOffset
1939 1940 1941 |
# File 'generated/google/apis/slides_v1/classes.rb', line 1939 def baseline_offset @baseline_offset end |
#bold ⇒ Boolean Also known as: bold?
Whether or not the text is bold.
Corresponds to the JSON property bold
1924 1925 1926 |
# File 'generated/google/apis/slides_v1/classes.rb', line 1924 def bold @bold end |
#font_family ⇒ String
The font family of the text.
The font family can be any font from the Font menu in Slides or from
Google Fonts. If the font name is
unrecognized, the text is rendered in Arial.
Some fonts can affect the weight of the text. If an update request
specifies values for both font_family and bold, the explicitly-set
bold value is used.
Corresponds to the JSON property fontFamily
1955 1956 1957 |
# File 'generated/google/apis/slides_v1/classes.rb', line 1955 def font_family @font_family end |
#font_size ⇒ Google::Apis::SlidesV1::Dimension
A magnitude in a single direction in the specified units.
Corresponds to the JSON property fontSize
1982 1983 1984 |
# File 'generated/google/apis/slides_v1/classes.rb', line 1982 def font_size @font_size end |
#foreground_color ⇒ Google::Apis::SlidesV1::OptionalColor
A color that can either be fully opaque or fully transparent.
Corresponds to the JSON property foregroundColor
1944 1945 1946 |
# File 'generated/google/apis/slides_v1/classes.rb', line 1944 def foreground_color @foreground_color end |
#italic ⇒ Boolean Also known as: italic?
Whether or not the text is italicized.
Corresponds to the JSON property italic
1930 1931 1932 |
# File 'generated/google/apis/slides_v1/classes.rb', line 1930 def italic @italic end |
#link ⇒ Google::Apis::SlidesV1::Link
A hypertext link.
Corresponds to the JSON property link
1966 1967 1968 |
# File 'generated/google/apis/slides_v1/classes.rb', line 1966 def link @link end |
#small_caps ⇒ Boolean Also known as: small_caps?
Whether or not the text is in small capital letters.
Corresponds to the JSON property smallCaps
1971 1972 1973 |
# File 'generated/google/apis/slides_v1/classes.rb', line 1971 def small_caps @small_caps end |
#strikethrough ⇒ Boolean Also known as: strikethrough?
Whether or not the text is struck through.
Corresponds to the JSON property strikethrough
1960 1961 1962 |
# File 'generated/google/apis/slides_v1/classes.rb', line 1960 def strikethrough @strikethrough end |
#underline ⇒ Boolean Also known as: underline?
Whether or not the text is underlined.
Corresponds to the JSON property underline
1987 1988 1989 |
# File 'generated/google/apis/slides_v1/classes.rb', line 1987 def underline @underline end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 |
# File 'generated/google/apis/slides_v1/classes.rb', line 1995 def update!(**args) @bold = args[:bold] if args.key?(:bold) @italic = args[:italic] if args.key?(:italic) @baseline_offset = args[:baseline_offset] if args.key?(:baseline_offset) @foreground_color = args[:foreground_color] if args.key?(:foreground_color) @font_family = args[:font_family] if args.key?(:font_family) @strikethrough = args[:strikethrough] if args.key?(:strikethrough) @link = args[:link] if args.key?(:link) @small_caps = args[:small_caps] if args.key?(:small_caps) @background_color = args[:background_color] if args.key?(:background_color) @font_size = args[:font_size] if args.key?(:font_size) @underline = args[:underline] if args.key?(:underline) end |