Class: Google::Apis::SlidesV1::UpdateLinePropertiesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/slides_v1/classes.rb,
generated/google/apis/slides_v1/representations.rb,
generated/google/apis/slides_v1/representations.rb

Overview

Updates the properties of a Line.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ UpdateLinePropertiesRequest

Returns a new instance of UpdateLinePropertiesRequest.



2038
2039
2040
# File 'generated/google/apis/slides_v1/classes.rb', line 2038

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsString

The fields that should be updated. At least one field must be specified. The root lineProperties is implied and should not be specified. A single "*" can be used as short-hand for listing every field. For example to update the line solid fill color, set fields to "lineFill.solidFill.color". To reset a property to its default value, include its field name in the field mask but leave the field itself unset. Corresponds to the JSON property fields

Returns:

  • (String)


2036
2037
2038
# File 'generated/google/apis/slides_v1/classes.rb', line 2036

def fields
  @fields
end

#line_propertiesGoogle::Apis::SlidesV1::LineProperties

The properties of the Line. When unset, these fields default to values that match the appearance of new lines created in the Slides editor. Corresponds to the JSON property lineProperties



2024
2025
2026
# File 'generated/google/apis/slides_v1/classes.rb', line 2024

def line_properties
  @line_properties
end

#object_id_propString

The object ID of the line the update is applied to. Corresponds to the JSON property objectId

Returns:

  • (String)


2017
2018
2019
# File 'generated/google/apis/slides_v1/classes.rb', line 2017

def object_id_prop
  @object_id_prop
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2043
2044
2045
2046
2047
# File 'generated/google/apis/slides_v1/classes.rb', line 2043

def update!(**args)
  @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop)
  @line_properties = args[:line_properties] if args.key?(:line_properties)
  @fields = args[:fields] if args.key?(:fields)
end