Class: Google::Apis::SlidesV1::UpdateSlidesPositionRequest
- Inherits:
-
Object
- Object
- Google::Apis::SlidesV1::UpdateSlidesPositionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/slides_v1/classes.rb,
generated/google/apis/slides_v1/representations.rb,
generated/google/apis/slides_v1/representations.rb
Overview
Updates the position of slides in the presentation.
Instance Attribute Summary collapse
-
#insertion_index ⇒ Fixnum
The index where the slides should be inserted, based on the slide arrangement before the move takes place.
-
#slide_object_ids ⇒ Array<String>
The IDs of the slides in the presentation that should be moved.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateSlidesPositionRequest
constructor
A new instance of UpdateSlidesPositionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ UpdateSlidesPositionRequest
Returns a new instance of UpdateSlidesPositionRequest.
2792 2793 2794 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2792 def initialize(**args) update!(**args) end |
Instance Attribute Details
#insertion_index ⇒ Fixnum
The index where the slides should be inserted, based on the slide
arrangement before the move takes place. Must be between zero and the
number of slides in the presentation, inclusive.
Corresponds to the JSON property insertionIndex
2783 2784 2785 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2783 def insertion_index @insertion_index end |
#slide_object_ids ⇒ Array<String>
The IDs of the slides in the presentation that should be moved.
The slides in this list must be in existing presentation order, without
duplicates.
Corresponds to the JSON property slideObjectIds
2790 2791 2792 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2790 def end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2797 2798 2799 2800 |
# File 'generated/google/apis/slides_v1/classes.rb', line 2797 def update!(**args) @insertion_index = args[:insertion_index] if args.key?(:insertion_index) = args[:slide_object_ids] if args.key?(:slide_object_ids) end |