Class: Google::Apis::SlidesV1::UpdateTextStyleRequest
- Inherits:
-
Object
- Object
- Google::Apis::SlidesV1::UpdateTextStyleRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/slides_v1/classes.rb,
generated/google/apis/slides_v1/representations.rb,
generated/google/apis/slides_v1/representations.rb
Overview
Update the styling of text in a Shape or Table.
Instance Attribute Summary collapse
-
#cell_location ⇒ Google::Apis::SlidesV1::TableCellLocation
A location of a single table cell within a table.
-
#fields ⇒ String
The fields that should be updated.
-
#object_id_prop ⇒ String
The object ID of the shape or table with the text to be styled.
-
#style ⇒ Google::Apis::SlidesV1::TextStyle
Represents the styling that can be applied to a TextRun.
-
#text_range ⇒ Google::Apis::SlidesV1::Range
Specifies a contiguous range of an indexed collection, such as characters in text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateTextStyleRequest
constructor
A new instance of UpdateTextStyleRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ UpdateTextStyleRequest
Returns a new instance of UpdateTextStyleRequest.
272 273 274 |
# File 'generated/google/apis/slides_v1/classes.rb', line 272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cell_location ⇒ Google::Apis::SlidesV1::TableCellLocation
A location of a single table cell within a table.
Corresponds to the JSON property cellLocation
270 271 272 |
# File 'generated/google/apis/slides_v1/classes.rb', line 270 def cell_location @cell_location end |
#fields ⇒ String
The fields that should be updated.
At least one field must be specified. The root style is implied and
should not be specified. A single "*" can be used as short-hand for
listing every field.
For example to update the text style to bold, set fields to "bold".
To reset a property to its default value,
include its field name in the field mask but leave the field itself unset.
Corresponds to the JSON property fields
259 260 261 |
# File 'generated/google/apis/slides_v1/classes.rb', line 259 def fields @fields end |
#object_id_prop ⇒ String
The object ID of the shape or table with the text to be styled.
Corresponds to the JSON property objectId
248 249 250 |
# File 'generated/google/apis/slides_v1/classes.rb', line 248 def object_id_prop @object_id_prop end |
#style ⇒ Google::Apis::SlidesV1::TextStyle
Represents the styling that can be applied to a TextRun. If this text is contained in a shape with a parent placeholder, then these text styles may be inherited from the parent. Which text styles are inherited depend on the nesting level of lists:
- A text run in a paragraph that is not in a list will inherit its text style from the the newline character in the paragraph at the 0 nesting level of the list inside the parent placeholder.
- A text run in a paragraph that is in a list will inherit its text style
from the newline character in the paragraph at its corresponding nesting
level of the list inside the parent placeholder.
Inherited text styles are represented as unset fields in this message. If
text is contained in a shape without a parent placeholder, unsetting these
fields will revert the style to a value matching the defaults in the Slides
editor.
Corresponds to the JSON property
style
243 244 245 |
# File 'generated/google/apis/slides_v1/classes.rb', line 243 def style @style end |
#text_range ⇒ Google::Apis::SlidesV1::Range
Specifies a contiguous range of an indexed collection, such as characters in
text.
Corresponds to the JSON property textRange
265 266 267 |
# File 'generated/google/apis/slides_v1/classes.rb', line 265 def text_range @text_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
277 278 279 280 281 282 283 |
# File 'generated/google/apis/slides_v1/classes.rb', line 277 def update!(**args) @style = args[:style] if args.key?(:style) @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop) @fields = args[:fields] if args.key?(:fields) @text_range = args[:text_range] if args.key?(:text_range) @cell_location = args[:cell_location] if args.key?(:cell_location) end |