Class: Google::Apis::VisionV1::FaceAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1::FaceAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/vision_v1/classes.rb,
generated/google/apis/vision_v1/representations.rb,
generated/google/apis/vision_v1/representations.rb
Overview
A face annotation object contains the results of face detection.
Instance Attribute Summary collapse
-
#anger_likelihood ⇒ String
Anger likelihood.
-
#blurred_likelihood ⇒ String
Blurred likelihood.
-
#bounding_poly ⇒ Google::Apis::VisionV1::BoundingPoly
A bounding polygon for the detected image annotation.
-
#detection_confidence ⇒ Float
Detection confidence.
-
#fd_bounding_poly ⇒ Google::Apis::VisionV1::BoundingPoly
A bounding polygon for the detected image annotation.
-
#headwear_likelihood ⇒ String
Headwear likelihood.
-
#joy_likelihood ⇒ String
Joy likelihood.
-
#landmarking_confidence ⇒ Float
Face landmarking confidence.
-
#landmarks ⇒ Array<Google::Apis::VisionV1::Landmark>
Detected face landmarks.
-
#pan_angle ⇒ Float
Yaw angle, which indicates the leftward/rightward angle that the face is pointing relative to the vertical plane perpendicular to the image.
-
#roll_angle ⇒ Float
Roll angle, which indicates the amount of clockwise/anti-clockwise rotation of the face relative to the image vertical about the axis perpendicular to the face.
-
#sorrow_likelihood ⇒ String
Sorrow likelihood.
-
#surprise_likelihood ⇒ String
Surprise likelihood.
-
#tilt_angle ⇒ Float
Pitch angle, which indicates the upwards/downwards angle that the face is pointing relative to the image's horizontal plane.
-
#under_exposed_likelihood ⇒ String
Under-exposed likelihood.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FaceAnnotation
constructor
A new instance of FaceAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ FaceAnnotation
Returns a new instance of FaceAnnotation.
1159 1160 1161 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1159 def initialize(**args) update!(**args) end |
Instance Attribute Details
#anger_likelihood ⇒ String
Anger likelihood.
Corresponds to the JSON property angerLikelihood
1087 1088 1089 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1087 def anger_likelihood @anger_likelihood end |
#blurred_likelihood ⇒ String
Blurred likelihood.
Corresponds to the JSON property blurredLikelihood
1129 1130 1131 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1129 def end |
#bounding_poly ⇒ Google::Apis::VisionV1::BoundingPoly
A bounding polygon for the detected image annotation.
Corresponds to the JSON property boundingPoly
1139 1140 1141 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1139 def bounding_poly @bounding_poly end |
#detection_confidence ⇒ Float
Detection confidence. Range [0, 1].
Corresponds to the JSON property detectionConfidence
1124 1125 1126 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1124 def detection_confidence @detection_confidence end |
#fd_bounding_poly ⇒ Google::Apis::VisionV1::BoundingPoly
A bounding polygon for the detected image annotation.
Corresponds to the JSON property fdBoundingPoly
1082 1083 1084 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1082 def fd_bounding_poly @fd_bounding_poly end |
#headwear_likelihood ⇒ String
Headwear likelihood.
Corresponds to the JSON property headwearLikelihood
1134 1135 1136 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1134 def headwear_likelihood @headwear_likelihood end |
#joy_likelihood ⇒ String
Joy likelihood.
Corresponds to the JSON property joyLikelihood
1107 1108 1109 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1107 def joy_likelihood @joy_likelihood end |
#landmarking_confidence ⇒ Float
Face landmarking confidence. Range [0, 1].
Corresponds to the JSON property landmarkingConfidence
1102 1103 1104 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1102 def landmarking_confidence @landmarking_confidence end |
#landmarks ⇒ Array<Google::Apis::VisionV1::Landmark>
Detected face landmarks.
Corresponds to the JSON property landmarks
1092 1093 1094 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1092 def landmarks @landmarks end |
#pan_angle ⇒ Float
Yaw angle, which indicates the leftward/rightward angle that the face is
pointing relative to the vertical plane perpendicular to the image. Range
[-180,180].
Corresponds to the JSON property panAngle
1119 1120 1121 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1119 def pan_angle @pan_angle end |
#roll_angle ⇒ Float
Roll angle, which indicates the amount of clockwise/anti-clockwise rotation
of the face relative to the image vertical about the axis perpendicular to
the face. Range [-180,180].
Corresponds to the JSON property rollAngle
1146 1147 1148 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1146 def roll_angle @roll_angle end |
#sorrow_likelihood ⇒ String
Sorrow likelihood.
Corresponds to the JSON property sorrowLikelihood
1151 1152 1153 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1151 def sorrow_likelihood @sorrow_likelihood end |
#surprise_likelihood ⇒ String
Surprise likelihood.
Corresponds to the JSON property surpriseLikelihood
1097 1098 1099 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1097 def surprise_likelihood @surprise_likelihood end |
#tilt_angle ⇒ Float
Pitch angle, which indicates the upwards/downwards angle that the face is
pointing relative to the image's horizontal plane. Range [-180,180].
Corresponds to the JSON property tiltAngle
1157 1158 1159 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1157 def tilt_angle @tilt_angle end |
#under_exposed_likelihood ⇒ String
Under-exposed likelihood.
Corresponds to the JSON property underExposedLikelihood
1112 1113 1114 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1112 def under_exposed_likelihood @under_exposed_likelihood end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 |
# File 'generated/google/apis/vision_v1/classes.rb', line 1164 def update!(**args) @fd_bounding_poly = args[:fd_bounding_poly] if args.key?(:fd_bounding_poly) @anger_likelihood = args[:anger_likelihood] if args.key?(:anger_likelihood) @landmarks = args[:landmarks] if args.key?(:landmarks) @surprise_likelihood = args[:surprise_likelihood] if args.key?(:surprise_likelihood) @landmarking_confidence = args[:landmarking_confidence] if args.key?(:landmarking_confidence) @joy_likelihood = args[:joy_likelihood] if args.key?(:joy_likelihood) @under_exposed_likelihood = args[:under_exposed_likelihood] if args.key?(:under_exposed_likelihood) @pan_angle = args[:pan_angle] if args.key?(:pan_angle) @detection_confidence = args[:detection_confidence] if args.key?(:detection_confidence) = args[:blurred_likelihood] if args.key?(:blurred_likelihood) @headwear_likelihood = args[:headwear_likelihood] if args.key?(:headwear_likelihood) @bounding_poly = args[:bounding_poly] if args.key?(:bounding_poly) @roll_angle = args[:roll_angle] if args.key?(:roll_angle) @sorrow_likelihood = args[:sorrow_likelihood] if args.key?(:sorrow_likelihood) @tilt_angle = args[:tilt_angle] if args.key?(:tilt_angle) end |