Class: Google::Apis::VisionV1::SafeSearchAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/vision_v1/classes.rb,
generated/google/apis/vision_v1/representations.rb,
generated/google/apis/vision_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ SafeSearchAnnotation

Returns a new instance of SafeSearchAnnotation.



471
472
473
# File 'generated/google/apis/vision_v1/classes.rb', line 471

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adultString

Represents the adult content likelihood for the image. Corresponds to the JSON property adult

Returns:

  • (String)


469
470
471
# File 'generated/google/apis/vision_v1/classes.rb', line 469

def adult
  @adult
end

#medicalString

Likelihood that this is a medical image. Corresponds to the JSON property medical

Returns:

  • (String)


459
460
461
# File 'generated/google/apis/vision_v1/classes.rb', line 459

def medical
  @medical
end

#spoofString

Spoof likelihood. The likelihood that an modification was made to the image's canonical version to make it appear funny or offensive. Corresponds to the JSON property spoof

Returns:

  • (String)


454
455
456
# File 'generated/google/apis/vision_v1/classes.rb', line 454

def spoof
  @spoof
end

#violenceString

Violence likelihood. Corresponds to the JSON property violence

Returns:

  • (String)


464
465
466
# File 'generated/google/apis/vision_v1/classes.rb', line 464

def violence
  @violence
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



476
477
478
479
480
481
# File 'generated/google/apis/vision_v1/classes.rb', line 476

def update!(**args)
  @spoof = args[:spoof] if args.key?(:spoof)
  @medical = args[:medical] if args.key?(:medical)
  @violence = args[:violence] if args.key?(:violence)
  @adult = args[:adult] if args.key?(:adult)
end