Class: Google::Apis::YoutubeV3::VideoFileDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/youtube_v3/classes.rb,
generated/google/apis/youtube_v3/representations.rb,
generated/google/apis/youtube_v3/representations.rb

Overview

Describes original video file properties, including technical details about audio and video streams, but also metadata information like content length, digitization time, or geotagging information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ VideoFileDetails



7451
7452
7453
# File 'generated/google/apis/youtube_v3/classes.rb', line 7451

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_streamsArray<Google::Apis::YoutubeV3::VideoFileDetailsAudioStream>

A list of audio streams contained in the uploaded video file. Each item in the list contains detailed metadata about an audio stream. Corresponds to the JSON property audioStreams



7398
7399
7400
# File 'generated/google/apis/youtube_v3/classes.rb', line 7398

def audio_streams
  @audio_streams
end

#bitrate_bpsString

The uploaded video file's combined (video and audio) bitrate in bits per second. Corresponds to the JSON property bitrateBps



7404
7405
7406
# File 'generated/google/apis/youtube_v3/classes.rb', line 7404

def bitrate_bps
  @bitrate_bps
end

#containerString

The uploaded video file's container format. Corresponds to the JSON property container



7409
7410
7411
# File 'generated/google/apis/youtube_v3/classes.rb', line 7409

def container
  @container
end

#creation_timeString

The date and time when the uploaded video file was created. The value is specified in ISO 8601 format. Currently, the following ISO 8601 formats are supported:

  • Date only: YYYY-MM-DD
  • Naive time: YYYY-MM-DDTHH:MM:SS
  • Time with timezone: YYYY-MM-DDTHH:MM:SS+HH:MM Corresponds to the JSON property creationTime


7419
7420
7421
# File 'generated/google/apis/youtube_v3/classes.rb', line 7419

def creation_time
  @creation_time
end

#duration_msString

The length of the uploaded video in milliseconds. Corresponds to the JSON property durationMs



7424
7425
7426
# File 'generated/google/apis/youtube_v3/classes.rb', line 7424

def duration_ms
  @duration_ms
end

#file_nameString

The uploaded file's name. This field is present whether a video file or another type of file was uploaded. Corresponds to the JSON property fileName



7430
7431
7432
# File 'generated/google/apis/youtube_v3/classes.rb', line 7430

def file_name
  @file_name
end

#file_sizeString

The uploaded file's size in bytes. This field is present whether a video file or another type of file was uploaded. Corresponds to the JSON property fileSize



7436
7437
7438
# File 'generated/google/apis/youtube_v3/classes.rb', line 7436

def file_size
  @file_size
end

#file_typeString

The uploaded file's type as detected by YouTube's video processing engine. Currently, YouTube only processes video files, but this field is present whether a video file or another type of file was uploaded. Corresponds to the JSON property fileType



7443
7444
7445
# File 'generated/google/apis/youtube_v3/classes.rb', line 7443

def file_type
  @file_type
end

#video_streamsArray<Google::Apis::YoutubeV3::VideoFileDetailsVideoStream>

A list of video streams contained in the uploaded video file. Each item in the list contains detailed metadata about a video stream. Corresponds to the JSON property videoStreams



7449
7450
7451
# File 'generated/google/apis/youtube_v3/classes.rb', line 7449

def video_streams
  @video_streams
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7456
7457
7458
7459
7460
7461
7462
7463
7464
7465
7466
# File 'generated/google/apis/youtube_v3/classes.rb', line 7456

def update!(**args)
  @audio_streams = args[:audio_streams] if args.key?(:audio_streams)
  @bitrate_bps = args[:bitrate_bps] if args.key?(:bitrate_bps)
  @container = args[:container] if args.key?(:container)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @duration_ms = args[:duration_ms] if args.key?(:duration_ms)
  @file_name = args[:file_name] if args.key?(:file_name)
  @file_size = args[:file_size] if args.key?(:file_size)
  @file_type = args[:file_type] if args.key?(:file_type)
  @video_streams = args[:video_streams] if args.key?(:video_streams)
end