Class: Google::Apis::YoutubeV3::VideoProcessingDetailsProcessingProgress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
generated/google/apis/youtube_v3/classes.rb,
generated/google/apis/youtube_v3/representations.rb,
generated/google/apis/youtube_v3/representations.rb

Overview

Video processing progress and completion time estimate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Core::JsonObjectSupport

#to_json

Methods included from Core::Hashable

process_value, #to_h

Constructor Details

#initialize(**args) ⇒ VideoProcessingDetailsProcessingProgress

Returns a new instance of VideoProcessingDetailsProcessingProgress.



7934
7935
7936
# File 'generated/google/apis/youtube_v3/classes.rb', line 7934

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parts_processedString

The number of parts of the video that YouTube has already processed. You can estimate the percentage of the video that YouTube has already processed by calculating: 100 * parts_processed / parts_total Note that since the estimated number of parts could increase without a corresponding increase in the number of parts that have already been processed, it is possible that the calculated progress could periodically decrease while YouTube processes a video. Corresponds to the JSON property partsProcessed

Returns:

  • (String)


7919
7920
7921
# File 'generated/google/apis/youtube_v3/classes.rb', line 7919

def parts_processed
  @parts_processed
end

#parts_totalString

An estimate of the total number of parts that need to be processed for the video. The number may be updated with more precise estimates while YouTube processes the video. Corresponds to the JSON property partsTotal

Returns:

  • (String)


7926
7927
7928
# File 'generated/google/apis/youtube_v3/classes.rb', line 7926

def parts_total
  @parts_total
end

#time_left_msString

An estimate of the amount of time, in millseconds, that YouTube needs to finish processing the video. Corresponds to the JSON property timeLeftMs

Returns:

  • (String)


7932
7933
7934
# File 'generated/google/apis/youtube_v3/classes.rb', line 7932

def time_left_ms
  @time_left_ms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7939
7940
7941
7942
7943
# File 'generated/google/apis/youtube_v3/classes.rb', line 7939

def update!(**args)
  @parts_processed = args[:parts_processed] if args.key?(:parts_processed)
  @parts_total = args[:parts_total] if args.key?(:parts_total)
  @time_left_ms = args[:time_left_ms] if args.key?(:time_left_ms)
end