Class: Google::Apis::ComputeBeta::DeprecationStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DeprecationStatus
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Deprecation status for a public resource.
Instance Attribute Summary collapse
-
#deleted ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED.
-
#deprecated ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED.
-
#obsolete ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE.
-
#replacement ⇒ String
The URL of the suggested replacement for a deprecated resource.
-
#state ⇒ String
The deprecation state of this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeprecationStatus
constructor
A new instance of DeprecationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ DeprecationStatus
Returns a new instance of DeprecationStatus.
2008 2009 2010 |
# File 'generated/google/apis/compute_beta/classes.rb', line 2008 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deleted ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is
intended to change to DELETED. This is only informational and the status will
not change unless the client explicitly changes it.
Corresponds to the JSON property deleted
1976 1977 1978 |
# File 'generated/google/apis/compute_beta/classes.rb', line 1976 def deleted @deleted end |
#deprecated ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is
intended to change to DEPRECATED. This is only informational and the status
will not change unless the client explicitly changes it.
Corresponds to the JSON property deprecated
1983 1984 1985 |
# File 'generated/google/apis/compute_beta/classes.rb', line 1983 def deprecated @deprecated end |
#obsolete ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is
intended to change to OBSOLETE. This is only informational and the status will
not change unless the client explicitly changes it.
Corresponds to the JSON property obsolete
1990 1991 1992 |
# File 'generated/google/apis/compute_beta/classes.rb', line 1990 def obsolete @obsolete end |
#replacement ⇒ String
The URL of the suggested replacement for a deprecated resource. The suggested
replacement resource must be the same kind of resource as the deprecated
resource.
Corresponds to the JSON property replacement
1997 1998 1999 |
# File 'generated/google/apis/compute_beta/classes.rb', line 1997 def replacement @replacement end |
#state ⇒ String
The deprecation state of this resource. This can be DEPRECATED, OBSOLETE, or
DELETED. Operations which create a new resource using a DEPRECATED resource
will return successfully, but with a warning indicating the deprecated
resource and recommending its replacement. Operations which use OBSOLETE or
DELETED resources will be rejected and result in an error.
Corresponds to the JSON property state
2006 2007 2008 |
# File 'generated/google/apis/compute_beta/classes.rb', line 2006 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2013 2014 2015 2016 2017 2018 2019 |
# File 'generated/google/apis/compute_beta/classes.rb', line 2013 def update!(**args) @deleted = args[:deleted] if args.key?(:deleted) @deprecated = args[:deprecated] if args.key?(:deprecated) @obsolete = args[:obsolete] if args.key?(:obsolete) @replacement = args[:replacement] if args.key?(:replacement) @state = args[:state] if args.key?(:state) end |