Class: Google::Apis::ComputeBeta::ForwardingRuleAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ForwardingRuleAggregatedList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::ForwardingRulesScopedList>
A map of scoped forwarding rule lists.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleAggregatedList
constructor
A new instance of ForwardingRuleAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ ForwardingRuleAggregatedList
Returns a new instance of ForwardingRuleAggregatedList.
3121 3122 3123 |
# File 'generated/google/apis/compute_beta/classes.rb', line 3121 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
3094 3095 3096 |
# File 'generated/google/apis/compute_beta/classes.rb', line 3094 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::ForwardingRulesScopedList>
A map of scoped forwarding rule lists.
Corresponds to the JSON property items
3099 3100 3101 |
# File 'generated/google/apis/compute_beta/classes.rb', line 3099 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#forwardingRuleAggregatedList
for lists of forwarding rules.
Corresponds to the JSON property kind
3105 3106 3107 |
# File 'generated/google/apis/compute_beta/classes.rb', line 3105 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
3114 3115 3116 |
# File 'generated/google/apis/compute_beta/classes.rb', line 3114 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
3119 3120 3121 |
# File 'generated/google/apis/compute_beta/classes.rb', line 3119 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3126 3127 3128 3129 3130 3131 3132 |
# File 'generated/google/apis/compute_beta/classes.rb', line 3126 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |