Class: Google::Apis::ComputeBeta::Image
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Image
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
An Image resource.
Defined Under Namespace
Classes: RawDisk
Instance Attribute Summary collapse
-
#archive_size_bytes ⇒ String
Size of the image tar.gz archive stored in Google Cloud Storage (in bytes).
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
An optional description of this resource.
-
#disk_size_gb ⇒ String
Size of the image when restored onto a persistent disk (in GB).
-
#family ⇒ String
The name of the image family to which this image belongs.
-
#guest_os_features ⇒ Array<Google::Apis::ComputeBeta::GuestOsFeature>
A list of features to enable on the guest OS.
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#image_encryption_key ⇒ Google::Apis::ComputeBeta::CustomerEncryptionKey
Represents a customer-supplied encryption key Corresponds to the JSON property
imageEncryptionKey. -
#kind ⇒ String
[Output Only] Type of the resource.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this image, which is essentially a hash of the labels used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this image.
-
#licenses ⇒ Array<String>
Any applicable license URI.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#raw_disk ⇒ Google::Apis::ComputeBeta::Image::RawDisk
The parameters of the raw disk image.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#source_disk ⇒ String
URL of the source disk used to create this image.
-
#source_disk_encryption_key ⇒ Google::Apis::ComputeBeta::CustomerEncryptionKey
Represents a customer-supplied encryption key Corresponds to the JSON property
sourceDiskEncryptionKey. -
#source_disk_id ⇒ String
The ID value of the disk used to create this image.
-
#source_type ⇒ String
The type of the image used to create this disk.
-
#status ⇒ String
[Output Only] The status of the image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Image
constructor
A new instance of Image.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ Image
4145 4146 4147 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4145 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive_size_bytes ⇒ String
Size of the image tar.gz archive stored in Google Cloud Storage (in bytes).
Corresponds to the JSON property archiveSizeBytes
4006 4007 4008 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4006 def archive_size_bytes @archive_size_bytes end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
4011 4012 4013 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4011 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
4016 4017 4018 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4016 def deprecated @deprecated end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
4022 4023 4024 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4022 def description @description end |
#disk_size_gb ⇒ String
Size of the image when restored onto a persistent disk (in GB).
Corresponds to the JSON property diskSizeGb
4027 4028 4029 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4027 def disk_size_gb @disk_size_gb end |
#family ⇒ String
The name of the image family to which this image belongs. You can create disks
by specifying an image family instead of a specific image name. The image
family always returns its latest image that is not deprecated. The name of the
image family must comply with RFC1035.
Corresponds to the JSON property family
4035 4036 4037 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4035 def family @family end |
#guest_os_features ⇒ Array<Google::Apis::ComputeBeta::GuestOsFeature>
A list of features to enable on the guest OS. Applicable for bootable images
only. Currently, only one feature can be enabled, VIRTIO_SCSCI_MULTIQUEUE,
which allows each virtual CPU to have its own queue. For Windows images, you
can only enable VIRTIO_SCSCI_MULTIQUEUE on images with driver version 1.2.0.
1621 or higher. Linux images with kernel versions 3.17 and higher will support
VIRTIO_SCSCI_MULTIQUEUE.
For new Windows images, the server might also populate this field with the
value WINDOWS, to indicate that this is a Windows image. This value is purely
informational and does not enable or disable any features.
Corresponds to the JSON property guestOsFeatures
4048 4049 4050 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4048 def guest_os_features @guest_os_features end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
4054 4055 4056 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4054 def id @id end |
#image_encryption_key ⇒ Google::Apis::ComputeBeta::CustomerEncryptionKey
Represents a customer-supplied encryption key
Corresponds to the JSON property imageEncryptionKey
4059 4060 4061 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4059 def image_encryption_key @image_encryption_key end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#image for images.
Corresponds to the JSON property kind
4064 4065 4066 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4064 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this image, which is essentially
a hash of the labels used for optimistic locking. The fingerprint is initially
generated by Compute Engine and changes after every request to modify or
update labels. You must always provide an up-to-date fingerprint hash in order
to update or change labels.
To see the latest fingerprint, make a get() request to retrieve an image.
Corresponds to the JSON property labelFingerprint
4074 4075 4076 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4074 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this image. These can be later modified by the setLabels
method. Each label key/value pair must comply with RFC1035. Label values may
be empty.
Corresponds to the JSON property labels
4081 4082 4083 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4081 def labels @labels end |
#licenses ⇒ Array<String>
Any applicable license URI.
Corresponds to the JSON property licenses
4086 4087 4088 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4086 def licenses @licenses end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
4096 4097 4098 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4096 def name @name end |
#raw_disk ⇒ Google::Apis::ComputeBeta::Image::RawDisk
The parameters of the raw disk image.
Corresponds to the JSON property rawDisk
4101 4102 4103 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4101 def raw_disk @raw_disk end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
4106 4107 4108 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4106 def self_link @self_link end |
#source_disk ⇒ String
URL of the source disk used to create this image. This can be a full or valid partial URL. You must provide either this property or the rawDisk.source property but not both to create an image. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/disk
- projects/project/zones/zone/disks/disk
- zones/zone/disks/disk
Corresponds to the JSON property
sourceDisk
4117 4118 4119 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4117 def source_disk @source_disk end |
#source_disk_encryption_key ⇒ Google::Apis::ComputeBeta::CustomerEncryptionKey
Represents a customer-supplied encryption key
Corresponds to the JSON property sourceDiskEncryptionKey
4122 4123 4124 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4122 def source_disk_encryption_key @source_disk_encryption_key end |
#source_disk_id ⇒ String
The ID value of the disk used to create this image. This value may be used to
determine whether the image was taken from the current or a previous instance
of a given disk name.
Corresponds to the JSON property sourceDiskId
4129 4130 4131 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4129 def source_disk_id @source_disk_id end |
#source_type ⇒ String
The type of the image used to create this disk. The default and only value is
RAW
Corresponds to the JSON property sourceType
4135 4136 4137 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4135 def source_type @source_type end |
#status ⇒ String
[Output Only] The status of the image. An image can be used to create other
resources, such as instances, only after the image has been successfully
created and the status is set to READY. Possible values are FAILED, PENDING,
or READY.
Corresponds to the JSON property status
4143 4144 4145 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4143 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4150 4151 4152 4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 4166 4167 4168 4169 4170 4171 4172 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4150 def update!(**args) @archive_size_bytes = args[:archive_size_bytes] if args.key?(:archive_size_bytes) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @family = args[:family] if args.key?(:family) @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features) @id = args[:id] if args.key?(:id) @image_encryption_key = args[:image_encryption_key] if args.key?(:image_encryption_key) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @licenses = args[:licenses] if args.key?(:licenses) @name = args[:name] if args.key?(:name) @raw_disk = args[:raw_disk] if args.key?(:raw_disk) @self_link = args[:self_link] if args.key?(:self_link) @source_disk = args[:source_disk] if args.key?(:source_disk) @source_disk_encryption_key = args[:source_disk_encryption_key] if args.key?(:source_disk_encryption_key) @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id) @source_type = args[:source_type] if args.key?(:source_type) @status = args[:status] if args.key?(:status) end |