Class: Google::Apis::ComputeBeta::InstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceAggregatedList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::InstancesScopedList>
[Output Only] A map of scoped instance lists.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceAggregatedList
constructor
A new instance of InstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InstanceAggregatedList
Returns a new instance of InstanceAggregatedList.
4463 4464 4465 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
4436 4437 4438 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4436 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::InstancesScopedList>
[Output Only] A map of scoped instance lists.
Corresponds to the JSON property items
4441 4442 4443 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4441 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#instanceAggregatedList for
aggregated lists of Instance resources.
Corresponds to the JSON property kind
4447 4448 4449 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4447 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
4456 4457 4458 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4456 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
4461 4462 4463 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4461 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4468 4469 4470 4471 4472 4473 4474 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4468 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |