Class: Google::Apis::ComputeBeta::InstanceGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroup
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] The creation timestamp for this instance group in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
[Output Only] The fingerprint of the named ports.
-
#id ⇒ String
[Output Only] A unique identifier for this instance group, generated by the server.
-
#kind ⇒ String
[Output Only] The resource type, which is always compute#instanceGroup for instance groups.
-
#name ⇒ String
The name of the instance group.
-
#named_ports ⇒ Array<Google::Apis::ComputeBeta::NamedPort>
Assigns a name to a port number.
-
#network ⇒ String
The URL of the network to which all instances in the instance group belong.
-
#region ⇒ String
The URL of the region where the instance group is located (for regional resources).
-
#self_link ⇒ String
[Output Only] The URL for this instance group.
-
#size ⇒ Fixnum
[Output Only] The total number of instances in the instance group.
-
#subnetwork ⇒ String
The URL of the subnetwork to which all instances in the instance group belong.
-
#zone ⇒ String
[Output Only] The URL of the zone where the instance group is located (for zonal resources).
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroup
constructor
A new instance of InstanceGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InstanceGroup
4559 4560 4561 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4559 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] The creation timestamp for this instance group in RFC3339 text
format.
Corresponds to the JSON property creationTimestamp
4485 4486 4487 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4485 def end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
4491 4492 4493 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4491 def description @description end |
#fingerprint ⇒ String
[Output Only] The fingerprint of the named ports. The system uses this
fingerprint to detect conflicts when multiple users change the named ports
concurrently.
Corresponds to the JSON property fingerprint
4498 4499 4500 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4498 def fingerprint @fingerprint end |
#id ⇒ String
[Output Only] A unique identifier for this instance group, generated by the
server.
Corresponds to the JSON property id
4504 4505 4506 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4504 def id @id end |
#kind ⇒ String
[Output Only] The resource type, which is always compute#instanceGroup for
instance groups.
Corresponds to the JSON property kind
4510 4511 4512 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4510 def kind @kind end |
#name ⇒ String
The name of the instance group. The name must be 1-63 characters long, and
comply with RFC1035.
Corresponds to the JSON property name
4516 4517 4518 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4516 def name @name end |
#named_ports ⇒ Array<Google::Apis::ComputeBeta::NamedPort>
Assigns a name to a port number. For example: name: "http", port: 80
This allows the system to reference ports by the assigned name instead of a
port number. Named ports can also contain multiple ports. For example: [name:
"http", port: 80,name: "http", port: 8080]
Named ports apply to all instances in this instance group.
Corresponds to the JSON property namedPorts
4525 4526 4527 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4525 def named_ports @named_ports end |
#network ⇒ String
The URL of the network to which all instances in the instance group belong.
Corresponds to the JSON property network
4530 4531 4532 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4530 def network @network end |
#region ⇒ String
The URL of the region where the instance group is located (for regional
resources).
Corresponds to the JSON property region
4536 4537 4538 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4536 def region @region end |
#self_link ⇒ String
[Output Only] The URL for this instance group. The server generates this URL.
Corresponds to the JSON property selfLink
4541 4542 4543 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4541 def self_link @self_link end |
#size ⇒ Fixnum
[Output Only] The total number of instances in the instance group.
Corresponds to the JSON property size
4546 4547 4548 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4546 def size @size end |
#subnetwork ⇒ String
The URL of the subnetwork to which all instances in the instance group belong.
Corresponds to the JSON property subnetwork
4551 4552 4553 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4551 def subnetwork @subnetwork end |
#zone ⇒ String
[Output Only] The URL of the zone where the instance group is located (for
zonal resources).
Corresponds to the JSON property zone
4557 4558 4559 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4557 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 4578 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4564 def update!(**args) = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @named_ports = args[:named_ports] if args.key?(:named_ports) @network = args[:network] if args.key?(:network) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @size = args[:size] if args.key?(:size) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @zone = args[:zone] if args.key?(:zone) end |