Class: Google::Apis::ComputeBeta::InstanceGroupAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupAggregatedList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] A unique identifier for this aggregated list of instance groups.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::InstanceGroupsScopedList>
A map of scoped instance group lists.
-
#kind ⇒ String
[Output Only] The resource type, which is always compute# instanceGroupAggregatedList for aggregated lists of instance groups.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] The URL for this resource type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupAggregatedList
constructor
A new instance of InstanceGroupAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InstanceGroupAggregatedList
Returns a new instance of InstanceGroupAggregatedList.
4616 4617 4618 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] A unique identifier for this aggregated list of instance groups.
The server generates this identifier.
Corresponds to the JSON property id
4589 4590 4591 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4589 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::InstanceGroupsScopedList>
A map of scoped instance group lists.
Corresponds to the JSON property items
4594 4595 4596 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4594 def items @items end |
#kind ⇒ String
[Output Only] The resource type, which is always compute#
instanceGroupAggregatedList for aggregated lists of instance groups.
Corresponds to the JSON property kind
4600 4601 4602 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4600 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
4609 4610 4611 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4609 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] The URL for this resource type. The server generates this URL.
Corresponds to the JSON property selfLink
4614 4615 4616 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4614 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4621 4622 4623 4624 4625 4626 4627 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4621 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |