Class: Google::Apis::ComputeBeta::InstanceGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
A list of InstanceGroup resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] A unique identifier for this list of instance groups.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceGroup>
A list of instance groups.
-
#kind ⇒ String
[Output Only] The resource type, which is always compute#instanceGroupList for instance group lists.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] The URL for this resource type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupList
constructor
A new instance of InstanceGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InstanceGroupList
Returns a new instance of InstanceGroupList.
4665 4666 4667 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4665 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] A unique identifier for this list of instance groups. The server
generates this identifier.
Corresponds to the JSON property id
4638 4639 4640 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4638 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceGroup>
A list of instance groups.
Corresponds to the JSON property items
4643 4644 4645 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4643 def items @items end |
#kind ⇒ String
[Output Only] The resource type, which is always compute#instanceGroupList for
instance group lists.
Corresponds to the JSON property kind
4649 4650 4651 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4649 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
4658 4659 4660 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4658 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] The URL for this resource type. The server generates this URL.
Corresponds to the JSON property selfLink
4663 4664 4665 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4663 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4670 4671 4672 4673 4674 4675 4676 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4670 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |