Class: Google::Apis::ComputeBeta::InstanceGroupManagerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
[Output Only] A list of managed instance groups.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] A unique identifier for this resource type.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManager>
[Output Only] A list of managed instance groups.
-
#kind ⇒ String
[Output Only] The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerList
constructor
A new instance of InstanceGroupManagerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerList
Returns a new instance of InstanceGroupManagerList.
5025 5026 5027 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5025 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] A unique identifier for this resource type. The server generates
this identifier.
Corresponds to the JSON property id
4998 4999 5000 |
# File 'generated/google/apis/compute_beta/classes.rb', line 4998 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManager>
[Output Only] A list of managed instance groups.
Corresponds to the JSON property items
5003 5004 5005 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5003 def items @items end |
#kind ⇒ String
[Output Only] The resource type, which is always compute#
instanceGroupManagerList for a list of managed instance groups.
Corresponds to the JSON property kind
5009 5010 5011 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5009 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
5018 5019 5020 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5018 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
5023 5024 5025 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5023 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5030 5031 5032 5033 5034 5035 5036 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5030 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |