Class: Google::Apis::ComputeBeta::InstanceGroupsListInstancesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupsListInstancesRequest
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#instance_state ⇒ String
A filter for the state of the instances in the instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupsListInstancesRequest
constructor
A new instance of InstanceGroupsListInstancesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InstanceGroupsListInstancesRequest
Returns a new instance of InstanceGroupsListInstancesRequest.
5405 5406 5407 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5405 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_state ⇒ String
A filter for the state of the instances in the instance group. Valid options
are ALL or RUNNING. If you do not specify this parameter the list includes all
instances regardless of their state.
Corresponds to the JSON property instanceState
5403 5404 5405 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5403 def instance_state @instance_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5410 5411 5412 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5410 def update!(**args) @instance_state = args[:instance_state] if args.key?(:instance_state) end |