Class: Google::Apis::ComputeBeta::InstanceGroupsSetNamedPortsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupsSetNamedPortsRequest
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
The fingerprint of the named ports information for this instance group.
-
#named_ports ⇒ Array<Google::Apis::ComputeBeta::NamedPort>
The list of named ports to set for this instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupsSetNamedPortsRequest
constructor
A new instance of InstanceGroupsSetNamedPortsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InstanceGroupsSetNamedPortsRequest
Returns a new instance of InstanceGroupsSetNamedPortsRequest.
5544 5545 5546 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5544 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
The fingerprint of the named ports information for this instance group. Use
this optional property to prevent conflicts when multiple users change the
named ports settings concurrently. Obtain the fingerprint with the
instanceGroups.get method. Then, include the fingerprint in your request to
ensure that you do not overwrite changes that were applied from another
concurrent request.
Corresponds to the JSON property fingerprint
5537 5538 5539 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5537 def fingerprint @fingerprint end |
#named_ports ⇒ Array<Google::Apis::ComputeBeta::NamedPort>
The list of named ports to set for this instance group.
Corresponds to the JSON property namedPorts
5542 5543 5544 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5542 def named_ports @named_ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5549 5550 5551 5552 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5549 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @named_ports = args[:named_ports] if args.key?(:named_ports) end |