Class: Google::Apis::ComputeBeta::InstanceTemplateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceTemplateList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
A list of instance templates.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] A unique identifier for this instance template.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceTemplate>
[Output Only] list of InstanceTemplate resources.
-
#kind ⇒ String
[Output Only] The resource type, which is always compute# instanceTemplatesListResponse for instance template lists.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] The URL for this instance template list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceTemplateList
constructor
A new instance of InstanceTemplateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InstanceTemplateList
Returns a new instance of InstanceTemplateList.
5841 5842 5843 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5841 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] A unique identifier for this instance template. The server
defines this identifier.
Corresponds to the JSON property id
5813 5814 5815 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5813 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceTemplate>
[Output Only] list of InstanceTemplate resources.
Corresponds to the JSON property items
5818 5819 5820 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5818 def items @items end |
#kind ⇒ String
[Output Only] The resource type, which is always compute#
instanceTemplatesListResponse for instance template lists.
Corresponds to the JSON property kind
5824 5825 5826 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5824 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
5833 5834 5835 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5833 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] The URL for this instance template list. The server defines this
URL.
Corresponds to the JSON property selfLink
5839 5840 5841 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5839 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5846 5847 5848 5849 5850 5851 5852 |
# File 'generated/google/apis/compute_beta/classes.rb', line 5846 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |