Class: Google::Apis::ComputeBeta::MachineTypeAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::MachineTypeAggregatedList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::MachineTypesScopedList>
[Output Only] A map of scoped machine type lists.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MachineTypeAggregatedList
constructor
A new instance of MachineTypeAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ MachineTypeAggregatedList
Returns a new instance of MachineTypeAggregatedList.
6297 6298 6299 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6297 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
6270 6271 6272 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6270 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::MachineTypesScopedList>
[Output Only] A map of scoped machine type lists.
Corresponds to the JSON property items
6275 6276 6277 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6275 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#machineTypeAggregatedList for
aggregated lists of machine types.
Corresponds to the JSON property kind
6281 6282 6283 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6281 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
6290 6291 6292 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6290 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
6295 6296 6297 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6295 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6302 6303 6304 6305 6306 6307 6308 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6302 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |