Class: Google::Apis::ComputeBeta::MachineTypeList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::MachineTypeList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Contains a list of machine types.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::MachineType>
[Output Only] A list of Machine Type resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MachineTypeList
constructor
A new instance of MachineTypeList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ MachineTypeList
Returns a new instance of MachineTypeList.
6346 6347 6348 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6346 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
6319 6320 6321 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6319 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::MachineType>
[Output Only] A list of Machine Type resources.
Corresponds to the JSON property items
6324 6325 6326 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6324 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#machineTypeList for lists of
machine types.
Corresponds to the JSON property kind
6330 6331 6332 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6330 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
6339 6340 6341 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6339 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
6344 6345 6346 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6344 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6351 6352 6353 6354 6355 6356 6357 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6351 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |