Class: Google::Apis::ComputeBeta::NetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Contains a list of networks.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Network>
[Output Only] A list of Network resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkList
constructor
A new instance of NetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ NetworkList
6877 6878 6879 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6877 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
6850 6851 6852 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6850 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Network>
[Output Only] A list of Network resources.
Corresponds to the JSON property items
6855 6856 6857 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6855 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#networkList for lists of
networks.
Corresponds to the JSON property kind
6861 6862 6863 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6861 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
6870 6871 6872 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6870 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
6875 6876 6877 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6875 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6882 6883 6884 6885 6886 6887 6888 |
# File 'generated/google/apis/compute_beta/classes.rb', line 6882 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |