Class: Google::Apis::ComputeBeta::OperationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::OperationList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Contains a list of Operation resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Operation>
[Output Only] A list of Operation resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationList
constructor
A new instance of OperationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ OperationList
Returns a new instance of OperationList.
7264 7265 7266 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7264 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
7237 7238 7239 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7237 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Operation>
[Output Only] A list of Operation resources.
Corresponds to the JSON property items
7242 7243 7244 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7242 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#operations for Operations
resource.
Corresponds to the JSON property kind
7248 7249 7250 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7248 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
7257 7258 7259 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7257 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
7262 7263 7264 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7262 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7269 7270 7271 7272 7273 7274 7275 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7269 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |