Class: Google::Apis::ComputeBeta::Policy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Policy
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Defines an Identity and Access Management (IAM) policy. It is used to specify
access control policies for Cloud Platform resources.
A Policy consists of a list of bindings. A Binding binds a list of
members to a role, where the members can be user accounts, Google groups,
Google domains, and service accounts. A role is a named list of permissions
defined by IAM.
Example
"bindings": [ "role": "roles/owner", "members": [ "user:[email protected]",
"group:[email protected]", "domain:google.com", "serviceAccount:my-other-app@
appspot.gserviceaccount.com", ] , "role": "roles/viewer", "members": ["user:
[email protected]"] ]
For a description of IAM and its features, see the IAM developer's guide.
Instance Attribute Summary collapse
-
#audit_configs ⇒ Array<Google::Apis::ComputeBeta::AuditConfig>
Specifies audit logging configs for "data access".
-
#bindings ⇒ Array<Google::Apis::ComputeBeta::Binding>
Associates a list of
membersto arole. -
#etag ⇒ String
etagis used for optimistic concurrency control as a way to help prevent simultaneous updates of a policy from overwriting each other. -
#iam_owned ⇒ Boolean
(also: #iam_owned?)
Corresponds to the JSON property
iamOwned. -
#rules ⇒ Array<Google::Apis::ComputeBeta::Rule>
If more than one rule is specified, the rules are applied in the following manner: - All matching LOG rules are always applied.
-
#version ⇒ Fixnum
Version of the
Policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Policy
constructor
A new instance of Policy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ Policy
Returns a new instance of Policy.
7512 7513 7514 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7512 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audit_configs ⇒ Array<Google::Apis::ComputeBeta::AuditConfig>
Specifies audit logging configs for "data access". "data access": generally
refers to data reads/writes and admin reads. "admin activity": generally
refers to admin writes.
Note: AuditConfig doesn't apply to "admin activity", which always enables
audit logging.
Corresponds to the JSON property auditConfigs
7468 7469 7470 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7468 def audit_configs @audit_configs end |
#bindings ⇒ Array<Google::Apis::ComputeBeta::Binding>
Associates a list of members to a role. Multiple bindings must not be
specified for the same role. bindings with no members will result in an
error.
Corresponds to the JSON property bindings
7475 7476 7477 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7475 def bindings @bindings end |
#etag ⇒ String
etag is used for optimistic concurrency control as a way to help prevent
simultaneous updates of a policy from overwriting each other. It is strongly
suggested that systems make use of the etag in the read-modify-write cycle
to perform policy updates in order to avoid race conditions: An etag is
returned in the response to getIamPolicy, and systems are expected to put
that etag in the request to setIamPolicy to ensure that their change will be
applied to the same version of the policy.
If no etag is provided in the call to setIamPolicy, then the existing
policy is overwritten blindly.
Corresponds to the JSON property etag
7488 7489 7490 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7488 def etag @etag end |
#iam_owned ⇒ Boolean Also known as: iam_owned?
Corresponds to the JSON property iamOwned
7493 7494 7495 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7493 def iam_owned @iam_owned end |
#rules ⇒ Array<Google::Apis::ComputeBeta::Rule>
If more than one rule is specified, the rules are applied in the following
manner: - All matching LOG rules are always applied. - If any DENY/
DENY_WITH_LOG rule matches, permission is denied. Logging will be applied if
one or more matching rule requires logging. - Otherwise, if any ALLOW/
ALLOW_WITH_LOG rule matches, permission is granted. Logging will be applied if
one or more matching rule requires logging. - Otherwise, if no rule applies,
permission is denied.
Corresponds to the JSON property rules
7505 7506 7507 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7505 def rules @rules end |
#version ⇒ Fixnum
Version of the Policy. The default version is 0.
Corresponds to the JSON property version
7510 7511 7512 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7510 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7517 7518 7519 7520 7521 7522 7523 7524 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7517 def update!(**args) @audit_configs = args[:audit_configs] if args.key?(:audit_configs) @bindings = args[:bindings] if args.key?(:bindings) @etag = args[:etag] if args.key?(:etag) @iam_owned = args[:iam_owned] if args.key?(:iam_owned) @rules = args[:rules] if args.key?(:rules) @version = args[:version] if args.key?(:version) end |