Class: Google::Apis::ComputeBeta::ProjectsListXpnHostsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ProjectsListXpnHostsRequest
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#organization ⇒ String
Optional organization ID managed by Cloud Resource Manager, for which to list XPN host projects.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProjectsListXpnHostsRequest
constructor
A new instance of ProjectsListXpnHostsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ ProjectsListXpnHostsRequest
Returns a new instance of ProjectsListXpnHostsRequest.
7629 7630 7631 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7629 def initialize(**args) update!(**args) end |
Instance Attribute Details
#organization ⇒ String
Optional organization ID managed by Cloud Resource Manager, for which to list
XPN host projects. If not specified, the organization will be inferred from
the project.
Corresponds to the JSON property organization
7627 7628 7629 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7627 def organization @organization end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7634 7635 7636 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7634 def update!(**args) @organization = args[:organization] if args.key?(:organization) end |