Class: Google::Apis::ComputeBeta::RegionInstanceGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RegionInstanceGroupList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Contains a list of InstanceGroup resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceGroup>
A list of InstanceGroup resources.
-
#kind ⇒ String
The resource type.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] The URL for this resource type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupList
constructor
A new instance of RegionInstanceGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupList
Returns a new instance of RegionInstanceGroupList.
7823 7824 7825 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7823 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
7797 7798 7799 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7797 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceGroup>
A list of InstanceGroup resources.
Corresponds to the JSON property items
7802 7803 7804 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7802 def items @items end |
#kind ⇒ String
The resource type.
Corresponds to the JSON property kind
7807 7808 7809 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7807 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
7816 7817 7818 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7816 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] The URL for this resource type. The server generates this URL.
Corresponds to the JSON property selfLink
7821 7822 7823 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7821 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7828 7829 7830 7831 7832 7833 7834 |
# File 'generated/google/apis/compute_beta/classes.rb', line 7828 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |