Class: Google::Apis::ComputeBeta::RegionList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RegionList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Contains a list of region resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Region>
[Output Only] A list of Region resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionList
constructor
A new instance of RegionList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ RegionList
Returns a new instance of RegionList.
8166 8167 8168 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8166 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
8140 8141 8142 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8140 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Region>
[Output Only] A list of Region resources.
Corresponds to the JSON property items
8145 8146 8147 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8145 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#regionList for lists of regions.
Corresponds to the JSON property kind
8150 8151 8152 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8150 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
8159 8160 8161 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8159 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
8164 8165 8166 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8164 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8171 8172 8173 8174 8175 8176 8177 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8171 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |