Class: Google::Apis::ComputeBeta::Router
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Router
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Router resource.
Instance Attribute Summary collapse
-
#bgp ⇒ Google::Apis::ComputeBeta::RouterBgp
BGP information specific to this router.
-
#bgp_peers ⇒ Array<Google::Apis::ComputeBeta::RouterBgpPeer>
BGP information that needs to be configured into the routing stack to establish the BGP peering.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#interfaces ⇒ Array<Google::Apis::ComputeBeta::RouterInterface>
Router interfaces.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#name ⇒ String
Name of the resource.
-
#network ⇒ String
URI of the network to which this router belongs.
-
#region ⇒ String
[Output Only] URI of the region where the router resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Router
constructor
A new instance of Router.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ Router
8518 8519 8520 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8518 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bgp ⇒ Google::Apis::ComputeBeta::RouterBgp
BGP information specific to this router.
Corresponds to the JSON property bgp
8456 8457 8458 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8456 def bgp @bgp end |
#bgp_peers ⇒ Array<Google::Apis::ComputeBeta::RouterBgpPeer>
BGP information that needs to be configured into the routing stack to
establish the BGP peering. It must specify peer ASN and either interface name,
IP, or peer IP. Please refer to RFC4273.
Corresponds to the JSON property bgpPeers
8463 8464 8465 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8463 def bgp_peers @bgp_peers end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
8468 8469 8470 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8468 def end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
8474 8475 8476 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8474 def description @description end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
8480 8481 8482 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8480 def id @id end |
#interfaces ⇒ Array<Google::Apis::ComputeBeta::RouterInterface>
Router interfaces. Each interface requires either one linked resource (e.g.
linkedVpnTunnel), or IP address and IP address range (e.g. ipRange), or both.
Corresponds to the JSON property interfaces
8486 8487 8488 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8486 def interfaces @interfaces end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#router for routers.
Corresponds to the JSON property kind
8491 8492 8493 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8491 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
8501 8502 8503 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8501 def name @name end |
#network ⇒ String
URI of the network to which this router belongs.
Corresponds to the JSON property network
8506 8507 8508 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8506 def network @network end |
#region ⇒ String
[Output Only] URI of the region where the router resides.
Corresponds to the JSON property region
8511 8512 8513 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8511 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
8516 8517 8518 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8516 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 |
# File 'generated/google/apis/compute_beta/classes.rb', line 8523 def update!(**args) @bgp = args[:bgp] if args.key?(:bgp) @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers) = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @interfaces = args[:interfaces] if args.key?(:interfaces) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) end |