Class: Google::Apis::ComputeBeta::Scheduling
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Scheduling
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
Sets the scheduling options for an Instance.
Instance Attribute Summary collapse
-
#automatic_restart ⇒ Boolean
(also: #automatic_restart?)
Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user).
-
#on_host_maintenance ⇒ String
Defines the maintenance behavior for this instance.
-
#preemptible ⇒ Boolean
(also: #preemptible?)
Whether the instance is preemptible.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Scheduling
constructor
A new instance of Scheduling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ Scheduling
Returns a new instance of Scheduling.
9122 9123 9124 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9122 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automatic_restart ⇒ Boolean Also known as: automatic_restart?
Specifies whether the instance should be automatically restarted if it is
terminated by Compute Engine (not terminated by a user). You can only set the
automatic restart option for standard instances. Preemptible instances cannot
be automatically restarted.
Corresponds to the JSON property automaticRestart
9105 9106 9107 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9105 def automatic_restart @automatic_restart end |
#on_host_maintenance ⇒ String
Defines the maintenance behavior for this instance. For standard instances,
the default behavior is MIGRATE. For preemptible instances, the default and
only possible behavior is TERMINATE. For more information, see Setting
Instance Scheduling Options.
Corresponds to the JSON property onHostMaintenance
9114 9115 9116 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9114 def on_host_maintenance @on_host_maintenance end |
#preemptible ⇒ Boolean Also known as: preemptible?
Whether the instance is preemptible.
Corresponds to the JSON property preemptible
9119 9120 9121 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9119 def preemptible @preemptible end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9127 9128 9129 9130 9131 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9127 def update!(**args) @automatic_restart = args[:automatic_restart] if args.key?(:automatic_restart) @on_host_maintenance = args[:on_host_maintenance] if args.key?(:on_host_maintenance) @preemptible = args[:preemptible] if args.key?(:preemptible) end |