Class: Google::Apis::ComputeBeta::SerialPortOutput
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SerialPortOutput
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
An instance's serial console output.
Instance Attribute Summary collapse
-
#contents ⇒ String
[Output Only] The contents of the console output.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#next ⇒ String
[Output Only] The position of the next byte of content from the serial console output.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#start ⇒ String
[Output Only] The starting byte position of the output that was returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SerialPortOutput
constructor
A new instance of SerialPortOutput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ SerialPortOutput
Returns a new instance of SerialPortOutput.
9168 9169 9170 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9168 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ String
[Output Only] The contents of the console output.
Corresponds to the JSON property contents
9141 9142 9143 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9141 def contents @contents end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#serialPortOutput for serial
port output.
Corresponds to the JSON property kind
9147 9148 9149 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9147 def kind @kind end |
#next ⇒ String
[Output Only] The position of the next byte of content from the serial console
output. Use this value in the next request as the start parameter.
Corresponds to the JSON property next
9153 9154 9155 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9153 def next @next end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
9158 9159 9160 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9158 def self_link @self_link end |
#start ⇒ String
[Output Only] The starting byte position of the output that was returned. This
should match the start parameter sent with the request. If the serial console
output exceeds the size of the buffer, older output will be overwritten by
newer content and the start values will be mismatched.
Corresponds to the JSON property start
9166 9167 9168 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9166 def start @start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9173 9174 9175 9176 9177 9178 9179 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9173 def update!(**args) @contents = args[:contents] if args.key?(:contents) @kind = args[:kind] if args.key?(:kind) @next = args[:next] if args.key?(:next) @self_link = args[:self_link] if args.key?(:self_link) @start = args[:start] if args.key?(:start) end |