Class: Google::Apis::ComputeBeta::Snapshot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Snapshot
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Overview
A persistent disk snapshot resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#disk_size_gb ⇒ String
[Output Only] Size of the snapshot, specified in GB.
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this snapshot, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this snapshot.
-
#licenses ⇒ Array<String>
[Output Only] A list of public visible licenses that apply to this snapshot.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#snapshot_encryption_key ⇒ Google::Apis::ComputeBeta::CustomerEncryptionKey
Represents a customer-supplied encryption key Corresponds to the JSON property
snapshotEncryptionKey. -
#source_disk ⇒ String
[Output Only] The source disk used to create this snapshot.
-
#source_disk_encryption_key ⇒ Google::Apis::ComputeBeta::CustomerEncryptionKey
Represents a customer-supplied encryption key Corresponds to the JSON property
sourceDiskEncryptionKey. -
#source_disk_id ⇒ String
[Output Only] The ID value of the disk used to create this snapshot.
-
#status ⇒ String
[Output Only] The status of the snapshot.
-
#storage_bytes ⇒ String
[Output Only] A size of the the storage used by the snapshot.
-
#storage_bytes_status ⇒ String
[Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Snapshot
constructor
A new instance of Snapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ Snapshot
Returns a new instance of Snapshot.
9321 9322 9323 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9321 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
9214 9215 9216 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9214 def end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
9220 9221 9222 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9220 def description @description end |
#disk_size_gb ⇒ String
[Output Only] Size of the snapshot, specified in GB.
Corresponds to the JSON property diskSizeGb
9225 9226 9227 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9225 def disk_size_gb @disk_size_gb end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
9231 9232 9233 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9231 def id @id end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#snapshot for Snapshot
resources.
Corresponds to the JSON property kind
9237 9238 9239 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9237 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this snapshot, which is
essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after every
request to modify or update labels. You must always provide an up-to-date
fingerprint hash in order to update or change labels.
To see the latest fingerprint, make a get() request to retrieve a snapshot.
Corresponds to the JSON property labelFingerprint
9247 9248 9249 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9247 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this snapshot. These can be later modified by the setLabels
method. Each label key/value pair must comply with RFC1035. Label values may
be empty.
Corresponds to the JSON property labels
9254 9255 9256 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9254 def labels @labels end |
#licenses ⇒ Array<String>
[Output Only] A list of public visible licenses that apply to this snapshot.
This can be because the original image had licenses attached (such as a
Windows image).
Corresponds to the JSON property licenses
9261 9262 9263 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9261 def licenses @licenses end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
9271 9272 9273 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9271 def name @name end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
9276 9277 9278 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9276 def self_link @self_link end |
#snapshot_encryption_key ⇒ Google::Apis::ComputeBeta::CustomerEncryptionKey
Represents a customer-supplied encryption key
Corresponds to the JSON property snapshotEncryptionKey
9281 9282 9283 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9281 def snapshot_encryption_key @snapshot_encryption_key end |
#source_disk ⇒ String
[Output Only] The source disk used to create this snapshot.
Corresponds to the JSON property sourceDisk
9286 9287 9288 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9286 def source_disk @source_disk end |
#source_disk_encryption_key ⇒ Google::Apis::ComputeBeta::CustomerEncryptionKey
Represents a customer-supplied encryption key
Corresponds to the JSON property sourceDiskEncryptionKey
9291 9292 9293 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9291 def source_disk_encryption_key @source_disk_encryption_key end |
#source_disk_id ⇒ String
[Output Only] The ID value of the disk used to create this snapshot. This
value may be used to determine whether the snapshot was taken from the current
or a previous instance of a given disk name.
Corresponds to the JSON property sourceDiskId
9298 9299 9300 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9298 def source_disk_id @source_disk_id end |
#status ⇒ String
[Output Only] The status of the snapshot. This can be CREATING, DELETING,
FAILED, READY, or UPLOADING.
Corresponds to the JSON property status
9304 9305 9306 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9304 def status @status end |
#storage_bytes ⇒ String
[Output Only] A size of the the storage used by the snapshot. As snapshots
share storage, this number is expected to change with snapshot creation/
deletion.
Corresponds to the JSON property storageBytes
9311 9312 9313 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9311 def storage_bytes @storage_bytes end |
#storage_bytes_status ⇒ String
[Output Only] An indicator whether storageBytes is in a stable state or it is
being adjusted as a result of shared storage reallocation. This status can
either be UPDATING, meaning the size of the snapshot is being updated, or
UP_TO_DATE, meaning the size of the snapshot is up-to-date.
Corresponds to the JSON property storageBytesStatus
9319 9320 9321 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9319 def storage_bytes_status @storage_bytes_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 9337 9338 9339 9340 9341 9342 9343 9344 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9326 def update!(**args) = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @licenses = args[:licenses] if args.key?(:licenses) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @snapshot_encryption_key = args[:snapshot_encryption_key] if args.key?(:snapshot_encryption_key) @source_disk = args[:source_disk] if args.key?(:source_disk) @source_disk_encryption_key = args[:source_disk_encryption_key] if args.key?(:source_disk_encryption_key) @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id) @status = args[:status] if args.key?(:status) @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes) @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status) end |