Class: Google::Apis::ComputeBeta::SubnetworkAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SubnetworkAggregatedList
- Defined in:
- generated/google/apis/compute_beta/classes.rb,
generated/google/apis/compute_beta/representations.rb,
generated/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::SubnetworksScopedList>
[Output] A map of scoped Subnetwork lists.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkAggregatedList
constructor
A new instance of SubnetworkAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ SubnetworkAggregatedList
Returns a new instance of SubnetworkAggregatedList.
9638 9639 9640 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9638 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
9611 9612 9613 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9611 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::SubnetworksScopedList>
[Output] A map of scoped Subnetwork lists.
Corresponds to the JSON property items
9616 9617 9618 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9616 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#subnetworkAggregatedList for
aggregated lists of subnetworks.
Corresponds to the JSON property kind
9622 9623 9624 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9622 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
9631 9632 9633 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9631 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
9636 9637 9638 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9636 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9643 9644 9645 9646 9647 9648 9649 |
# File 'generated/google/apis/compute_beta/classes.rb', line 9643 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |