Class: Google::Apis::ComputeV1::DiskTypeAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::DiskTypeAggregatedList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::DiskTypesScopedList>
[Output Only] A map of scoped disk type lists.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskTypeAggregatedList
constructor
A new instance of DiskTypeAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ DiskTypeAggregatedList
Returns a new instance of DiskTypeAggregatedList.
2003 2004 2005 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2003 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
1977 1978 1979 |
# File 'generated/google/apis/compute_v1/classes.rb', line 1977 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::DiskTypesScopedList>
[Output Only] A map of scoped disk type lists.
Corresponds to the JSON property items
1982 1983 1984 |
# File 'generated/google/apis/compute_v1/classes.rb', line 1982 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#diskTypeAggregatedList.
Corresponds to the JSON property kind
1987 1988 1989 |
# File 'generated/google/apis/compute_v1/classes.rb', line 1987 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
1996 1997 1998 |
# File 'generated/google/apis/compute_v1/classes.rb', line 1996 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
2001 2002 2003 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2001 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2008 2009 2010 2011 2012 2013 2014 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2008 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |