Class: Google::Apis::ComputeV1::DiskTypeList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::DiskTypeList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
Contains a list of disk types.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::DiskType>
[Output Only] A list of Disk Type resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskTypeList
constructor
A new instance of DiskTypeList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ DiskTypeList
Returns a new instance of DiskTypeList.
2051 2052 2053 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2051 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
2025 2026 2027 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2025 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::DiskType>
[Output Only] A list of Disk Type resources.
Corresponds to the JSON property items
2030 2031 2032 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2030 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#diskTypeList for disk types.
Corresponds to the JSON property kind
2035 2036 2037 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2035 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
2044 2045 2046 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2044 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
2049 2050 2051 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2049 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2056 2057 2058 2059 2060 2061 2062 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2056 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |