Class: Google::Apis::ComputeV1::FirewallList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::FirewallList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
Contains a list of firewalls.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::Firewall>
[Output Only] A list of Firewall resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallList
constructor
A new instance of FirewallList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ FirewallList
Returns a new instance of FirewallList.
2443 2444 2445 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2443 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
2416 2417 2418 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2416 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Firewall>
[Output Only] A list of Firewall resources.
Corresponds to the JSON property items
2421 2422 2423 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2421 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#firewallList for lists of
firewalls.
Corresponds to the JSON property kind
2427 2428 2429 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2427 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
2436 2437 2438 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2436 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
2441 2442 2443 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2441 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2448 2449 2450 2451 2452 2453 2454 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2448 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |