Class: Google::Apis::ComputeV1::ForwardingRuleAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ForwardingRuleAggregatedList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::ForwardingRulesScopedList>
A map of scoped forwarding rule lists.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleAggregatedList
constructor
A new instance of ForwardingRuleAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ ForwardingRuleAggregatedList
Returns a new instance of ForwardingRuleAggregatedList.
2651 2652 2653 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2651 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
2624 2625 2626 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2624 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::ForwardingRulesScopedList>
A map of scoped forwarding rule lists.
Corresponds to the JSON property items
2629 2630 2631 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2629 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#forwardingRuleAggregatedList
for lists of forwarding rules.
Corresponds to the JSON property kind
2635 2636 2637 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2635 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
2644 2645 2646 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2644 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
2649 2650 2651 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2649 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2656 2657 2658 2659 2660 2661 2662 |
# File 'generated/google/apis/compute_v1/classes.rb', line 2656 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |