Class: Google::Apis::ComputeV1::ImageList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::ImageList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
Contains a list of images.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::Image>
[Output Only] A list of Image resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageList
constructor
A new instance of ImageList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ ImageList
3714 3715 3716 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3714 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
3688 3689 3690 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3688 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Image>
[Output Only] A list of Image resources.
Corresponds to the JSON property items
3693 3694 3695 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3693 def items @items end |
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
3698 3699 3700 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3698 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
3707 3708 3709 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3707 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
3712 3713 3714 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3712 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3719 3720 3721 3722 3723 3724 3725 |
# File 'generated/google/apis/compute_v1/classes.rb', line 3719 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |