Class: Google::Apis::ComputeV1::InstanceGroupsListInstances
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceGroupsListInstances
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] A unique identifier for this list of instances in the specified instance group.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstanceWithNamedPorts>
[Output Only] A list of instances and any named ports that are assigned to those instances.
-
#kind ⇒ String
[Output Only] The resource type, which is always compute# instanceGroupsListInstances for the list of instances in the specified instance group.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] The URL for this list of instances in the specified instance groups.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupsListInstances
constructor
A new instance of InstanceGroupsListInstances.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InstanceGroupsListInstances
Returns a new instance of InstanceGroupsListInstances.
4716 4717 4718 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4716 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] A unique identifier for this list of instances in the specified
instance group. The server generates this identifier.
Corresponds to the JSON property id
4686 4687 4688 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4686 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstanceWithNamedPorts>
[Output Only] A list of instances and any named ports that are assigned to
those instances.
Corresponds to the JSON property items
4692 4693 4694 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4692 def items @items end |
#kind ⇒ String
[Output Only] The resource type, which is always compute#
instanceGroupsListInstances for the list of instances in the specified
instance group.
Corresponds to the JSON property kind
4699 4700 4701 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4699 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
4708 4709 4710 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4708 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] The URL for this list of instances in the specified instance
groups. The server generates this URL.
Corresponds to the JSON property selfLink
4714 4715 4716 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4714 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4721 4722 4723 4724 4725 4726 4727 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4721 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |