Class: Google::Apis::ComputeV1::InstanceProperties
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::InstanceProperties
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#can_ip_forward ⇒ Boolean
(also: #can_ip_forward?)
Enables instances created based on this template to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own.
-
#description ⇒ String
An optional text description for the instances that are created from this instance template.
-
#disks ⇒ Array<Google::Apis::ComputeV1::AttachedDisk>
An array of disks that are associated with the instances that are created from this template.
-
#machine_type ⇒ String
The machine type to use for instances that are created from this template.
-
#metadata ⇒ Google::Apis::ComputeV1::Metadata
A metadata key/value entry.
-
#network_interfaces ⇒ Array<Google::Apis::ComputeV1::NetworkInterface>
An array of network access configurations for this interface.
-
#scheduling ⇒ Google::Apis::ComputeV1::Scheduling
Sets the scheduling options for an Instance.
-
#service_accounts ⇒ Array<Google::Apis::ComputeV1::ServiceAccount>
A list of service accounts with specified scopes.
-
#tags ⇒ Google::Apis::ComputeV1::Tags
A set of instance tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceProperties
constructor
A new instance of InstanceProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InstanceProperties
Returns a new instance of InstanceProperties.
5033 5034 5035 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5033 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_ip_forward ⇒ Boolean Also known as: can_ip_forward?
Enables instances created based on this template to send packets with source
IP addresses other than their own and receive packets with destination IP
addresses other than their own. If these instances will be used as an IP
gateway or it will be set as the next-hop in a Route resource, specify true.
If unsure, leave this set to false. See the Enable IP forwarding for instances
documentation for more information.
Corresponds to the JSON property canIpForward
4986 4987 4988 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4986 def can_ip_forward @can_ip_forward end |
#description ⇒ String
An optional text description for the instances that are created from this
instance template.
Corresponds to the JSON property description
4993 4994 4995 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4993 def description @description end |
#disks ⇒ Array<Google::Apis::ComputeV1::AttachedDisk>
An array of disks that are associated with the instances that are created from
this template.
Corresponds to the JSON property disks
4999 5000 5001 |
# File 'generated/google/apis/compute_v1/classes.rb', line 4999 def disks @disks end |
#machine_type ⇒ String
The machine type to use for instances that are created from this template.
Corresponds to the JSON property machineType
5004 5005 5006 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5004 def machine_type @machine_type end |
#metadata ⇒ Google::Apis::ComputeV1::Metadata
A metadata key/value entry.
Corresponds to the JSON property metadata
5009 5010 5011 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5009 def @metadata end |
#network_interfaces ⇒ Array<Google::Apis::ComputeV1::NetworkInterface>
An array of network access configurations for this interface.
Corresponds to the JSON property networkInterfaces
5014 5015 5016 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5014 def network_interfaces @network_interfaces end |
#scheduling ⇒ Google::Apis::ComputeV1::Scheduling
Sets the scheduling options for an Instance.
Corresponds to the JSON property scheduling
5019 5020 5021 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5019 def scheduling @scheduling end |
#service_accounts ⇒ Array<Google::Apis::ComputeV1::ServiceAccount>
A list of service accounts with specified scopes. Access tokens for these
service accounts are available to the instances that are created from this
template. Use metadata queries to obtain the access tokens for these instances.
Corresponds to the JSON property serviceAccounts
5026 5027 5028 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5026 def service_accounts @service_accounts end |
#tags ⇒ Google::Apis::ComputeV1::Tags
A set of instance tags.
Corresponds to the JSON property tags
5031 5032 5033 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5031 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5038 5039 5040 5041 5042 5043 5044 5045 5046 5047 5048 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5038 def update!(**args) @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward) @description = args[:description] if args.key?(:description) @disks = args[:disks] if args.key?(:disks) @machine_type = args[:machine_type] if args.key?(:machine_type) @metadata = args[:metadata] if args.key?(:metadata) @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces) @scheduling = args[:scheduling] if args.key?(:scheduling) @service_accounts = args[:service_accounts] if args.key?(:service_accounts) @tags = args[:tags] if args.key?(:tags) end |