Class: Google::Apis::ComputeV1::Network
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Network
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
Represents a Network resource. Read Networks and Firewalls for more information.
Instance Attribute Summary collapse
-
#auto_create_subnetworks ⇒ Boolean
(also: #auto_create_subnetworks?)
When set to true, the network is created in "auto subnet mode".
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#gateway_i_pv4 ⇒ String
A gateway address for default routing to other networks.
-
#i_pv4_range ⇒ String
The range of internal addresses that are legal on this network.
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#name ⇒ String
Name of the resource.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#subnetworks ⇒ Array<String>
[Output Only] Server-defined fully-qualified URLs for all subnetworks in this network.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Network
constructor
A new instance of Network.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ Network
Returns a new instance of Network.
6034 6035 6036 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6034 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_create_subnetworks ⇒ Boolean Also known as: auto_create_subnetworks?
When set to true, the network is created in "auto subnet mode". When set to
false, the network is in "custom subnet mode".
In "auto subnet mode", a newly created network is assigned the default CIDR of
10.128.0.0/9 and it automatically creates one subnetwork per region.
Corresponds to the JSON property autoCreateSubnetworks
5981 5982 5983 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5981 def auto_create_subnetworks @auto_create_subnetworks end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
5987 5988 5989 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5987 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
5993 5994 5995 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5993 def description @description end |
#gateway_i_pv4 ⇒ String
A gateway address for default routing to other networks. This value is read
only and is selected by the Google Compute Engine, typically as the first
usable address in the IPv4Range.
Corresponds to the JSON property gatewayIPv4
6000 6001 6002 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6000 def gateway_i_pv4 @gateway_i_pv4 end |
#i_pv4_range ⇒ String
The range of internal addresses that are legal on this network. This range is
a CIDR specification, for example: 192.168.0.0/16. Provided by the client when
the network is created.
Corresponds to the JSON property IPv4Range
5973 5974 5975 |
# File 'generated/google/apis/compute_v1/classes.rb', line 5973 def i_pv4_range @i_pv4_range end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
6006 6007 6008 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6006 def id @id end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#network for networks.
Corresponds to the JSON property kind
6011 6012 6013 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6011 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
6021 6022 6023 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6021 def name @name end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
6026 6027 6028 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6026 def self_link @self_link end |
#subnetworks ⇒ Array<String>
[Output Only] Server-defined fully-qualified URLs for all subnetworks in this
network.
Corresponds to the JSON property subnetworks
6032 6033 6034 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6032 def subnetworks @subnetworks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6039 6040 6041 6042 6043 6044 6045 6046 6047 6048 6049 6050 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6039 def update!(**args) @i_pv4_range = args[:i_pv4_range] if args.key?(:i_pv4_range) @auto_create_subnetworks = args[:auto_create_subnetworks] if args.key?(:auto_create_subnetworks) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @gateway_i_pv4 = args[:gateway_i_pv4] if args.key?(:gateway_i_pv4) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @subnetworks = args[:subnetworks] if args.key?(:subnetworks) end |