Class: Google::Apis::ComputeV1::NetworkInterface
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::NetworkInterface
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
A network interface resource attached to an instance.
Instance Attribute Summary collapse
-
#access_configs ⇒ Array<Google::Apis::ComputeV1::AccessConfig>
An array of configurations for this interface.
-
#kind ⇒ String
[Output Only] Type of the resource.
-
#name ⇒ String
[Output Only] The name of the network interface, generated by the server.
-
#network ⇒ String
URL of the network resource for this instance.
-
#network_ip ⇒ String
An IPv4 internal network address to assign to the instance for this network interface.
-
#subnetwork ⇒ String
The URL of the Subnetwork resource for this instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkInterface
constructor
A new instance of NetworkInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ NetworkInterface
Returns a new instance of NetworkInterface.
6110 6111 6112 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6110 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_configs ⇒ Array<Google::Apis::ComputeV1::AccessConfig>
An array of configurations for this interface. Currently, only one access
config, ONE_TO_ONE_NAT, is supported. If there are no accessConfigs specified,
then this instance will have no external internet access.
Corresponds to the JSON property accessConfigs
6062 6063 6064 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6062 def access_configs @access_configs end |
#kind ⇒ String
[Output Only] Type of the resource. Always compute#networkInterface for
network interfaces.
Corresponds to the JSON property kind
6068 6069 6070 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6068 def kind @kind end |
#name ⇒ String
[Output Only] The name of the network interface, generated by the server. For
network devices, these are eth0, eth1, etc.
Corresponds to the JSON property name
6074 6075 6076 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6074 def name @name end |
#network ⇒ String
URL of the network resource for this instance. This is required for creating an instance but optional when creating a firewall rule. If not specified when creating a firewall rule, the default network is used: global/networks/default If you specify this property, you can specify the network as a full or partial URL. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/global/networks/ network
- projects/project/global/networks/network
- global/networks/default
Corresponds to the JSON property
network
6088 6089 6090 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6088 def network @network end |
#network_ip ⇒ String
An IPv4 internal network address to assign to the instance for this network
interface. If not specified by the user, an unused internal IP is assigned by
the system.
Corresponds to the JSON property networkIP
6095 6096 6097 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6095 def network_ip @network_ip end |
#subnetwork ⇒ String
The URL of the Subnetwork resource for this instance. If the network resource is in legacy mode, do not provide this property. If the network is in auto subnet mode, providing the subnetwork is optional. If the network is in custom subnet mode, then this field should be specified. If you specify this property, you can specify the subnetwork as a full or partial URL. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/regions/region/ subnetworks/subnetwork
- regions/region/subnetworks/subnetwork
Corresponds to the JSON property
subnetwork
6108 6109 6110 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6108 def subnetwork @subnetwork end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6115 6116 6117 6118 6119 6120 6121 6122 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6115 def update!(**args) @access_configs = args[:access_configs] if args.key?(:access_configs) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @network_ip = args[:network_ip] if args.key?(:network_ip) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) end |