Class: Google::Apis::ComputeV1::PathMatcher
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::PathMatcher
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
A matcher for the path portion of the URL. The BackendService from the longest- matched rule will serve the URL. If no rule was matched, the default service will be used.
Instance Attribute Summary collapse
-
#default_service ⇒ String
The full or partial URL to the BackendService resource.
-
#description ⇒ String
An optional description of this resource.
-
#name ⇒ String
The name to which this PathMatcher is referred by the HostRule.
-
#path_rules ⇒ Array<Google::Apis::ComputeV1::PathRule>
The list of path rules.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PathMatcher
constructor
A new instance of PathMatcher.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ PathMatcher
Returns a new instance of PathMatcher.
6686 6687 6688 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6686 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_service ⇒ String
The full or partial URL to the BackendService resource. This will be used if none of the pathRules defined by this PathMatcher is matched by the URL's path portion. For example, the following are all valid URLs to a BackendService resource:
- https://www.googleapis.com/compute/v1/projects/project/global/ backendServices/backendService
- compute/v1/projects/project/global/backendServices/backendService
- global/backendServices/backendService
Corresponds to the JSON property
defaultService
6668 6669 6670 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6668 def default_service @default_service end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
6674 6675 6676 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6674 def description @description end |
#name ⇒ String
The name to which this PathMatcher is referred by the HostRule.
Corresponds to the JSON property name
6679 6680 6681 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6679 def name @name end |
#path_rules ⇒ Array<Google::Apis::ComputeV1::PathRule>
The list of path rules.
Corresponds to the JSON property pathRules
6684 6685 6686 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6684 def path_rules @path_rules end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6691 6692 6693 6694 6695 6696 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6691 def update!(**args) @default_service = args[:default_service] if args.key?(:default_service) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @path_rules = args[:path_rules] if args.key?(:path_rules) end |