Class: Google::Apis::ComputeV1::RegionInstanceGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RegionInstanceGroupList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
Contains a list of InstanceGroup resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::InstanceGroup>
A list of InstanceGroup resources.
-
#kind ⇒ String
The resource type.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] The URL for this resource type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupList
constructor
A new instance of RegionInstanceGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupList
Returns a new instance of RegionInstanceGroupList.
6996 6997 6998 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6996 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
6970 6971 6972 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6970 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::InstanceGroup>
A list of InstanceGroup resources.
Corresponds to the JSON property items
6975 6976 6977 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6975 def items @items end |
#kind ⇒ String
The resource type.
Corresponds to the JSON property kind
6980 6981 6982 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6980 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
6989 6990 6991 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6989 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] The URL for this resource type. The server generates this URL.
Corresponds to the JSON property selfLink
6994 6995 6996 |
# File 'generated/google/apis/compute_v1/classes.rb', line 6994 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7001 7002 7003 7004 7005 7006 7007 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7001 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |