Class: Google::Apis::ComputeV1::RouteList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouteList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
Contains a list of Route resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::Route>
[Output Only] A list of Route resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouteList
constructor
A new instance of RouteList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ RouteList
Returns a new instance of RouteList.
7589 7590 7591 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7589 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource. Defined by the server.
Corresponds to the JSON property id
7563 7564 7565 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7563 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Route>
[Output Only] A list of Route resources.
Corresponds to the JSON property items
7568 7569 7570 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7568 def items @items end |
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
7573 7574 7575 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7573 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
7582 7583 7584 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7582 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
7587 7588 7589 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7587 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7594 7595 7596 7597 7598 7599 7600 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7594 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |