Class: Google::Apis::ComputeV1::RouterList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::RouterList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
Contains a list of Router resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::Router>
A list of Router resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterList
constructor
A new instance of RouterList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ RouterList
Returns a new instance of RouterList.
7885 7886 7887 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7885 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
7859 7860 7861 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7859 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::Router>
A list of Router resources.
Corresponds to the JSON property items
7864 7865 7866 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7864 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#router for routers.
Corresponds to the JSON property kind
7869 7870 7871 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7869 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
7878 7879 7880 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7878 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
7883 7884 7885 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7883 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7890 7891 7892 7893 7894 7895 7896 |
# File 'generated/google/apis/compute_v1/classes.rb', line 7890 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |