Class: Google::Apis::ComputeV1::Tags
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::Tags
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
A set of instance tags.
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
Specifies a fingerprint for this request, which is essentially a hash of the metadata's contents and used for optimistic locking.
-
#items ⇒ Array<String>
An array of tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Tags
constructor
A new instance of Tags.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ Tags
Returns a new instance of Tags.
8957 8958 8959 |
# File 'generated/google/apis/compute_v1/classes.rb', line 8957 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
Specifies a fingerprint for this request, which is essentially a hash of the
metadata's contents and used for optimistic locking. The fingerprint is
initially generated by Compute Engine and changes after every request to
modify or update metadata. You must always provide an up-to-date fingerprint
hash in order to update or change metadata.
To see the latest fingerprint, make get() request to the instance.
Corresponds to the JSON property fingerprint
8949 8950 8951 |
# File 'generated/google/apis/compute_v1/classes.rb', line 8949 def fingerprint @fingerprint end |
#items ⇒ Array<String>
An array of tags. Each tag must be 1-63 characters long, and comply with
RFC1035.
Corresponds to the JSON property items
8955 8956 8957 |
# File 'generated/google/apis/compute_v1/classes.rb', line 8955 def items @items end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8962 8963 8964 8965 |
# File 'generated/google/apis/compute_v1/classes.rb', line 8962 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @items = args[:items] if args.key?(:items) end |