Class: Google::Apis::ComputeV1::TargetHttpsProxy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetHttpsProxy
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
A TargetHttpsProxy resource. This resource defines an HTTPS proxy.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#name ⇒ String
Name of the resource.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#ssl_certificates ⇒ Array<String>
URLs to SslCertificate resources that are used to authenticate connections between users and the load balancer.
-
#url_map ⇒ String
A fully-qualified or valid partial URL to the UrlMap resource that defines the mapping from URL to the BackendService.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpsProxy
constructor
A new instance of TargetHttpsProxy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ TargetHttpsProxy
Returns a new instance of TargetHttpsProxy.
9160 9161 9162 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9160 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp in RFC3339 text format.
Corresponds to the JSON property creationTimestamp
9108 9109 9110 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9108 def end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
9114 9115 9116 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9114 def description @description end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
9120 9121 9122 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9120 def id @id end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#targetHttpsProxy for target
HTTPS proxies.
Corresponds to the JSON property kind
9126 9127 9128 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9126 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created. The
name must be 1-63 characters long, and comply with RFC1035. Specifically, the
name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter,
and all following characters must be a dash, lowercase letter, or digit,
except the last character, which cannot be a dash.
Corresponds to the JSON property name
9136 9137 9138 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9136 def name @name end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
9141 9142 9143 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9141 def self_link @self_link end |
#ssl_certificates ⇒ Array<String>
URLs to SslCertificate resources that are used to authenticate connections
between users and the load balancer. Currently, exactly one SSL certificate
must be specified.
Corresponds to the JSON property sslCertificates
9148 9149 9150 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9148 def ssl_certificates @ssl_certificates end |
#url_map ⇒ String
A fully-qualified or valid partial URL to the UrlMap resource that defines the mapping from URL to the BackendService. For example, the following are all valid URLs for specifying a URL map:
- https://www.googleapis.compute/v1/projects/project/global/urlMaps/url-map
- projects/project/global/urlMaps/url-map
- global/urlMaps/url-map
Corresponds to the JSON property
urlMap
9158 9159 9160 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9158 def url_map @url_map end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9165 9166 9167 9168 9169 9170 9171 9172 9173 9174 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9165 def update!(**args) = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @ssl_certificates = args[:ssl_certificates] if args.key?(:ssl_certificates) @url_map = args[:url_map] if args.key?(:url_map) end |