Class: Google::Apis::ComputeV1::TargetInstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetInstanceList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
Contains a list of TargetInstance resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetInstance>
A list of TargetInstance resources.
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceList
constructor
A new instance of TargetInstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ TargetInstanceList
Returns a new instance of TargetInstanceList.
9391 9392 9393 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9391 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
9365 9366 9367 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9365 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetInstance>
A list of TargetInstance resources.
Corresponds to the JSON property items
9370 9371 9372 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9370 def items @items end |
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
9375 9376 9377 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9375 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
9384 9385 9386 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9384 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
9389 9390 9391 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9389 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9396 9397 9398 9399 9400 9401 9402 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9396 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |