Class: Google::Apis::ComputeV1::TargetPoolAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetPoolAggregatedList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource.
-
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetPoolsScopedList>
[Output Only] A map of scoped target pool lists.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPoolAggregatedList
constructor
A new instance of TargetPoolAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ TargetPoolAggregatedList
Returns a new instance of TargetPoolAggregatedList.
9652 9653 9654 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9652 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource. Defined by the server.
Corresponds to the JSON property id
9625 9626 9627 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9625 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeV1::TargetPoolsScopedList>
[Output Only] A map of scoped target pool lists.
Corresponds to the JSON property items
9630 9631 9632 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9630 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#targetPoolAggregatedList for
aggregated lists of target pools.
Corresponds to the JSON property kind
9636 9637 9638 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9636 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
9645 9646 9647 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9645 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
9650 9651 9652 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9650 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9657 9658 9659 9660 9661 9662 9663 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9657 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |