Class: Google::Apis::ComputeV1::TargetPoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TargetPoolList
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Overview
Contains a list of TargetPool resources.
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeV1::TargetPool>
A list of TargetPool resources.
-
#kind ⇒ String
[Output Only] Type of resource.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPoolList
constructor
A new instance of TargetPoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ TargetPoolList
9726 9727 9728 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9726 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource. Defined by the server.
Corresponds to the JSON property id
9699 9700 9701 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9699 def id @id end |
#items ⇒ Array<Google::Apis::ComputeV1::TargetPool>
A list of TargetPool resources.
Corresponds to the JSON property items
9704 9705 9706 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9704 def items @items end |
#kind ⇒ String
[Output Only] Type of resource. Always compute#targetPoolList for lists of
target pools.
Corresponds to the JSON property kind
9710 9711 9712 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9710 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list
requests. If the number of results is larger than maxResults, use the
nextPageToken as a value for the query parameter pageToken in the next list
request. Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
9719 9720 9721 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9719 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
9724 9725 9726 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9724 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9731 9732 9733 9734 9735 9736 9737 |
# File 'generated/google/apis/compute_v1/classes.rb', line 9731 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) end |