Class: Google::Apis::ComputeV1::TcpHealthCheck
- Inherits:
-
Object
- Object
- Google::Apis::ComputeV1::TcpHealthCheck
- Defined in:
- generated/google/apis/compute_v1/classes.rb,
generated/google/apis/compute_v1/representations.rb,
generated/google/apis/compute_v1/representations.rb
Instance Attribute Summary collapse
-
#port ⇒ Fixnum
The TCP port number for the health check request.
-
#port_name ⇒ String
Port name as defined in InstanceGroup#NamedPort#name.
-
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1.
-
#request ⇒ String
The application data to send once the TCP connection has been established ( default value is empty).
-
#response ⇒ String
The bytes to match against the beginning of the response data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TcpHealthCheck
constructor
A new instance of TcpHealthCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ TcpHealthCheck
Returns a new instance of TcpHealthCheck.
8923 8924 8925 |
# File 'generated/google/apis/compute_v1/classes.rb', line 8923 def initialize(**args) update!(**args) end |
Instance Attribute Details
#port ⇒ Fixnum
The TCP port number for the health check request. The default value is 80.
Corresponds to the JSON property port
8894 8895 8896 |
# File 'generated/google/apis/compute_v1/classes.rb', line 8894 def port @port end |
#port_name ⇒ String
Port name as defined in InstanceGroup#NamedPort#name. If both port and
port_name are defined, port takes precedence.
Corresponds to the JSON property portName
8900 8901 8902 |
# File 'generated/google/apis/compute_v1/classes.rb', line 8900 def port_name @port_name end |
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the
backend, either NONE or PROXY_V1. The default is NONE.
Corresponds to the JSON property proxyHeader
8906 8907 8908 |
# File 'generated/google/apis/compute_v1/classes.rb', line 8906 def proxy_header @proxy_header end |
#request ⇒ String
The application data to send once the TCP connection has been established (
default value is empty). If both request and response are empty, the
connection establishment alone will indicate health. The request data can only
be ASCII.
Corresponds to the JSON property request
8914 8915 8916 |
# File 'generated/google/apis/compute_v1/classes.rb', line 8914 def request @request end |
#response ⇒ String
The bytes to match against the beginning of the response data. If left empty (
the default value), any response will indicate health. The response data can
only be ASCII.
Corresponds to the JSON property response
8921 8922 8923 |
# File 'generated/google/apis/compute_v1/classes.rb', line 8921 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8928 8929 8930 8931 8932 8933 8934 |
# File 'generated/google/apis/compute_v1/classes.rb', line 8928 def update!(**args) @port = args[:port] if args.key?(:port) @port_name = args[:port_name] if args.key?(:port_name) @proxy_header = args[:proxy_header] if args.key?(:proxy_header) @request = args[:request] if args.key?(:request) @response = args[:response] if args.key?(:response) end |