Class: Google::Apis::ContentV2::AccountStatusesBatchResponseEntry
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2::AccountStatusesBatchResponseEntry
- Defined in:
- generated/google/apis/content_v2/classes.rb,
generated/google/apis/content_v2/representations.rb,
generated/google/apis/content_v2/representations.rb
Overview
A batch entry encoding a single non-batch accountstatuses response.
Instance Attribute Summary collapse
-
#account_status ⇒ Google::Apis::ContentV2::AccountStatus
The status of an account, i.e., information about its products, which is computed offline and not returned immediately at insertion time.
-
#batch_id ⇒ Fixnum
The ID of the request entry this entry responds to.
-
#errors ⇒ Google::Apis::ContentV2::Errors
A list of errors returned by a failed batch entry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AccountStatusesBatchResponseEntry
constructor
A new instance of AccountStatusesBatchResponseEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ AccountStatusesBatchResponseEntry
Returns a new instance of AccountStatusesBatchResponseEntry.
1315 1316 1317 |
# File 'generated/google/apis/content_v2/classes.rb', line 1315 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_status ⇒ Google::Apis::ContentV2::AccountStatus
The status of an account, i.e., information about its products, which is
computed offline and not returned immediately at insertion time.
Corresponds to the JSON property accountStatus
1303 1304 1305 |
# File 'generated/google/apis/content_v2/classes.rb', line 1303 def account_status @account_status end |
#batch_id ⇒ Fixnum
The ID of the request entry this entry responds to.
Corresponds to the JSON property batchId
1308 1309 1310 |
# File 'generated/google/apis/content_v2/classes.rb', line 1308 def batch_id @batch_id end |
#errors ⇒ Google::Apis::ContentV2::Errors
A list of errors returned by a failed batch entry.
Corresponds to the JSON property errors
1313 1314 1315 |
# File 'generated/google/apis/content_v2/classes.rb', line 1313 def errors @errors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1320 1321 1322 1323 1324 |
# File 'generated/google/apis/content_v2/classes.rb', line 1320 def update!(**args) @account_status = args[:account_status] if args.key?(:account_status) @batch_id = args[:batch_id] if args.key?(:batch_id) @errors = args[:errors] if args.key?(:errors) end |