Class: Google::Apis::ContentV2::DatafeedFetchSchedule
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2::DatafeedFetchSchedule
- Defined in:
- generated/google/apis/content_v2/classes.rb,
generated/google/apis/content_v2/representations.rb,
generated/google/apis/content_v2/representations.rb
Overview
The required fields vary based on the frequency of fetching. For a monthly fetch schedule, day_of_month and hour are required. For a weekly fetch schedule, weekday and hour are required. For a daily fetch schedule, only hour is required.
Instance Attribute Summary collapse
-
#day_of_month ⇒ Fixnum
The day of the month the feed file should be fetched (1-31).
-
#fetch_url ⇒ String
The URL where the feed file can be fetched.
-
#hour ⇒ Fixnum
The hour of the day the feed file should be fetched (0-23).
-
#minute_of_hour ⇒ Fixnum
The minute of the hour the feed file should be fetched (0-59).
-
#password ⇒ String
An optional password for fetch_url.
-
#time_zone ⇒ String
Time zone used for schedule.
-
#username ⇒ String
An optional user name for fetch_url.
-
#weekday ⇒ String
The day of the week the feed file should be fetched.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatafeedFetchSchedule
constructor
A new instance of DatafeedFetchSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ DatafeedFetchSchedule
Returns a new instance of DatafeedFetchSchedule.
1741 1742 1743 |
# File 'generated/google/apis/content_v2/classes.rb', line 1741 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day_of_month ⇒ Fixnum
The day of the month the feed file should be fetched (1-31).
Corresponds to the JSON property dayOfMonth
1701 1702 1703 |
# File 'generated/google/apis/content_v2/classes.rb', line 1701 def day_of_month @day_of_month end |
#fetch_url ⇒ String
The URL where the feed file can be fetched. Google Merchant Center will
support automatic scheduled uploads using the HTTP, HTTPS, FTP, or SFTP
protocols, so the value will need to be a valid link using one of those four
protocols.
Corresponds to the JSON property fetchUrl
1709 1710 1711 |
# File 'generated/google/apis/content_v2/classes.rb', line 1709 def fetch_url @fetch_url end |
#hour ⇒ Fixnum
The hour of the day the feed file should be fetched (0-23).
Corresponds to the JSON property hour
1714 1715 1716 |
# File 'generated/google/apis/content_v2/classes.rb', line 1714 def hour @hour end |
#minute_of_hour ⇒ Fixnum
The minute of the hour the feed file should be fetched (0-59). Read-only.
Corresponds to the JSON property minuteOfHour
1719 1720 1721 |
# File 'generated/google/apis/content_v2/classes.rb', line 1719 def minute_of_hour @minute_of_hour end |
#password ⇒ String
An optional password for fetch_url.
Corresponds to the JSON property password
1724 1725 1726 |
# File 'generated/google/apis/content_v2/classes.rb', line 1724 def password @password end |
#time_zone ⇒ String
Time zone used for schedule. UTC by default. E.g., "America/Los_Angeles".
Corresponds to the JSON property timeZone
1729 1730 1731 |
# File 'generated/google/apis/content_v2/classes.rb', line 1729 def time_zone @time_zone end |
#username ⇒ String
An optional user name for fetch_url.
Corresponds to the JSON property username
1734 1735 1736 |
# File 'generated/google/apis/content_v2/classes.rb', line 1734 def username @username end |
#weekday ⇒ String
The day of the week the feed file should be fetched.
Corresponds to the JSON property weekday
1739 1740 1741 |
# File 'generated/google/apis/content_v2/classes.rb', line 1739 def weekday @weekday end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 |
# File 'generated/google/apis/content_v2/classes.rb', line 1746 def update!(**args) @day_of_month = args[:day_of_month] if args.key?(:day_of_month) @fetch_url = args[:fetch_url] if args.key?(:fetch_url) @hour = args[:hour] if args.key?(:hour) @minute_of_hour = args[:minute_of_hour] if args.key?(:minute_of_hour) @password = args[:password] if args.key?(:password) @time_zone = args[:time_zone] if args.key?(:time_zone) @username = args[:username] if args.key?(:username) @weekday = args[:weekday] if args.key?(:weekday) end |