Class: Google::Apis::ContentV2::InventoryBatchRequestEntry
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2::InventoryBatchRequestEntry
- Defined in:
- generated/google/apis/content_v2/classes.rb,
generated/google/apis/content_v2/representations.rb,
generated/google/apis/content_v2/representations.rb
Overview
A batch entry encoding a single non-batch inventory request.
Instance Attribute Summary collapse
-
#batch_id ⇒ Fixnum
An entry ID, unique within the batch request.
-
#inventory ⇒ Google::Apis::ContentV2::Inventory
Price and availability of the product.
-
#merchant_id ⇒ String
The ID of the managing account.
-
#product_id ⇒ String
The ID of the product for which to update price and availability.
-
#store_code ⇒ String
The code of the store for which to update price and availability.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InventoryBatchRequestEntry
constructor
A new instance of InventoryBatchRequestEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Google::Apis::Core::JsonObjectSupport
Methods included from Google::Apis::Core::Hashable
Constructor Details
#initialize(**args) ⇒ InventoryBatchRequestEntry
Returns a new instance of InventoryBatchRequestEntry.
2523 2524 2525 |
# File 'generated/google/apis/content_v2/classes.rb', line 2523 def initialize(**args) update!(**args) end |
Instance Attribute Details
#batch_id ⇒ Fixnum
An entry ID, unique within the batch request.
Corresponds to the JSON property batchId
2500 2501 2502 |
# File 'generated/google/apis/content_v2/classes.rb', line 2500 def batch_id @batch_id end |
#inventory ⇒ Google::Apis::ContentV2::Inventory
Price and availability of the product.
Corresponds to the JSON property inventory
2505 2506 2507 |
# File 'generated/google/apis/content_v2/classes.rb', line 2505 def inventory @inventory end |
#merchant_id ⇒ String
The ID of the managing account.
Corresponds to the JSON property merchantId
2510 2511 2512 |
# File 'generated/google/apis/content_v2/classes.rb', line 2510 def merchant_id @merchant_id end |
#product_id ⇒ String
The ID of the product for which to update price and availability.
Corresponds to the JSON property productId
2515 2516 2517 |
# File 'generated/google/apis/content_v2/classes.rb', line 2515 def product_id @product_id end |
#store_code ⇒ String
The code of the store for which to update price and availability. Use online
to update price and availability of an online product.
Corresponds to the JSON property storeCode
2521 2522 2523 |
# File 'generated/google/apis/content_v2/classes.rb', line 2521 def store_code @store_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2528 2529 2530 2531 2532 2533 2534 |
# File 'generated/google/apis/content_v2/classes.rb', line 2528 def update!(**args) @batch_id = args[:batch_id] if args.key?(:batch_id) @inventory = args[:inventory] if args.key?(:inventory) @merchant_id = args[:merchant_id] if args.key?(:merchant_id) @product_id = args[:product_id] if args.key?(:product_id) @store_code = args[:store_code] if args.key?(:store_code) end |