Class: Google::Apis::DataflowV1b3::DataflowService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::DataflowV1b3::DataflowService
- Defined in:
- generated/google/apis/dataflow_v1b3/service.rb
Overview
Google Dataflow API
Manages Google Cloud Dataflow projects on Google Cloud Platform.
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Attributes inherited from Core::BaseService
#authorization, #base_path, #batch_path, #client, #client_options, #request_options, #root_url, #upload_path
Instance Method Summary collapse
-
#create_job_from_template(project_id, create_job_from_template_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::Job
Creates a Cloud Dataflow job from a template.
-
#create_project_job(project_id, job_object = nil, view: nil, replace_job_id: nil, location: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::Job
Creates a Cloud Dataflow job.
-
#create_project_location_job(project_id, location, job_object = nil, view: nil, replace_job_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::Job
Creates a Cloud Dataflow job.
-
#get_project_job(project_id, job_id, view: nil, location: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::Job
Gets the state of the specified Cloud Dataflow job.
-
#get_project_job_debug_config(project_id, job_id, get_debug_config_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::GetDebugConfigResponse
Get encoded debug configuration for component.
-
#get_project_job_metrics(project_id, job_id, start_time: nil, location: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::JobMetrics
Request the job status.
-
#get_project_location_job(project_id, location, job_id, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::Job
Gets the state of the specified Cloud Dataflow job.
-
#get_project_location_job_metrics(project_id, location, job_id, start_time: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::JobMetrics
Request the job status.
-
#initialize ⇒ DataflowService
constructor
A new instance of DataflowService.
-
#lease_project_location_work_item(project_id, location, job_id, lease_work_item_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::LeaseWorkItemResponse
Leases a dataflow WorkItem to run.
-
#lease_project_work_item(project_id, job_id, lease_work_item_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::LeaseWorkItemResponse
Leases a dataflow WorkItem to run.
-
#list_project_job_messages(project_id, job_id, minimum_importance: nil, page_size: nil, page_token: nil, start_time: nil, end_time: nil, location: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::ListJobMessagesResponse
Request the job status.
-
#list_project_jobs(project_id, filter: nil, view: nil, page_size: nil, page_token: nil, location: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::ListJobsResponse
List the jobs of a project.
-
#list_project_location_job_messages(project_id, location, job_id, minimum_importance: nil, page_size: nil, page_token: nil, start_time: nil, end_time: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::ListJobMessagesResponse
Request the job status.
-
#list_project_location_jobs(project_id, location, filter: nil, view: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::ListJobsResponse
List the jobs of a project.
-
#report_project_job_work_item_status(project_id, job_id, report_work_item_status_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::ReportWorkItemStatusResponse
Reports the status of dataflow WorkItems leased by a worker.
-
#report_project_location_job_work_item_status(project_id, location, job_id, report_work_item_status_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::ReportWorkItemStatusResponse
Reports the status of dataflow WorkItems leased by a worker.
-
#send_project_job_debug_capture(project_id, job_id, send_debug_capture_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::SendDebugCaptureResponse
Send encoded debug capture data for component.
-
#update_project_job(project_id, job_id, job_object = nil, location: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::Job
Updates the state of an existing Cloud Dataflow job.
-
#update_project_location_job(project_id, location, job_id, job_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::Job
Updates the state of an existing Cloud Dataflow job.
-
#worker_project_messages(project_id, send_worker_messages_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::SendWorkerMessagesResponse
Send a worker_message to the service.
Methods inherited from Core::BaseService
#batch, #batch_upload, #fetch_all, #http
Constructor Details
#initialize ⇒ DataflowService
45 46 47 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 45 def initialize super('https://dataflow.googleapis.com/', '') end |
Instance Attribute Details
#key ⇒ String
38 39 40 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 38 def key @key end |
#quota_user ⇒ String
43 44 45 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 43 def quota_user @quota_user end |
Instance Method Details
#create_job_from_template(project_id, create_job_from_template_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::Job
Creates a Cloud Dataflow job from a template.
853 854 855 856 857 858 859 860 861 862 863 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 853 def create_job_from_template(project_id, create_job_from_template_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1b3/projects/{projectId}/templates', ) command.request_representation = Google::Apis::DataflowV1b3::CreateJobFromTemplateRequest::Representation command.request_object = create_job_from_template_request_object command.response_representation = Google::Apis::DataflowV1b3::Job::Representation command.response_class = Google::Apis::DataflowV1b3::Job command.params['projectId'] = project_id unless project_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_job(project_id, job_object = nil, view: nil, replace_job_id: nil, location: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::Job
Creates a Cloud Dataflow job.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 109 def create_project_job(project_id, job_object = nil, view: nil, replace_job_id: nil, location: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1b3/projects/{projectId}/jobs', ) command.request_representation = Google::Apis::DataflowV1b3::Job::Representation command.request_object = job_object command.response_representation = Google::Apis::DataflowV1b3::Job::Representation command.response_class = Google::Apis::DataflowV1b3::Job command.params['projectId'] = project_id unless project_id.nil? command.query['view'] = view unless view.nil? command.query['replaceJobId'] = replace_job_id unless replace_job_id.nil? command.query['location'] = location unless location.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_job(project_id, location, job_object = nil, view: nil, replace_job_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::Job
Creates a Cloud Dataflow job.
517 518 519 520 521 522 523 524 525 526 527 528 529 530 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 517 def create_project_location_job(project_id, location, job_object = nil, view: nil, replace_job_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1b3/projects/{projectId}/locations/{location}/jobs', ) command.request_representation = Google::Apis::DataflowV1b3::Job::Representation command.request_object = job_object command.response_representation = Google::Apis::DataflowV1b3::Job::Representation command.response_class = Google::Apis::DataflowV1b3::Job command.params['projectId'] = project_id unless project_id.nil? command.params['location'] = location unless location.nil? command.query['view'] = view unless view.nil? command.query['replaceJobId'] = replace_job_id unless replace_job_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_job(project_id, job_id, view: nil, location: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::Job
Gets the state of the specified Cloud Dataflow job.
150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 150 def get_project_job(project_id, job_id, view: nil, location: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1b3/projects/{projectId}/jobs/{jobId}', ) command.response_representation = Google::Apis::DataflowV1b3::Job::Representation command.response_class = Google::Apis::DataflowV1b3::Job command.params['projectId'] = project_id unless project_id.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['view'] = view unless view.nil? command.query['location'] = location unless location.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_job_debug_config(project_id, job_id, get_debug_config_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::GetDebugConfigResponse
Get encoded debug configuration for component. Not cacheable.
313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 313 def get_project_job_debug_config(project_id, job_id, get_debug_config_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1b3/projects/{projectId}/jobs/{jobId}/debug/getConfig', ) command.request_representation = Google::Apis::DataflowV1b3::GetDebugConfigRequest::Representation command.request_object = get_debug_config_request_object command.response_representation = Google::Apis::DataflowV1b3::GetDebugConfigResponse::Representation command.response_class = Google::Apis::DataflowV1b3::GetDebugConfigResponse command.params['projectId'] = project_id unless project_id.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_job_metrics(project_id, job_id, start_time: nil, location: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::JobMetrics
Request the job status.
277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 277 def get_project_job_metrics(project_id, job_id, start_time: nil, location: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1b3/projects/{projectId}/jobs/{jobId}/metrics', ) command.response_representation = Google::Apis::DataflowV1b3::JobMetrics::Representation command.response_class = Google::Apis::DataflowV1b3::JobMetrics command.params['projectId'] = project_id unless project_id.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['startTime'] = start_time unless start_time.nil? command.query['location'] = location unless location.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_job(project_id, location, job_id, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::Job
Gets the state of the specified Cloud Dataflow job.
558 559 560 561 562 563 564 565 566 567 568 569 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 558 def get_project_location_job(project_id, location, job_id, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1b3/projects/{projectId}/locations/{location}/jobs/{jobId}', ) command.response_representation = Google::Apis::DataflowV1b3::Job::Representation command.response_class = Google::Apis::DataflowV1b3::Job command.params['projectId'] = project_id unless project_id.nil? command.params['location'] = location unless location.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_job_metrics(project_id, location, job_id, start_time: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::JobMetrics
Request the job status.
685 686 687 688 689 690 691 692 693 694 695 696 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 685 def get_project_location_job_metrics(project_id, location, job_id, start_time: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1b3/projects/{projectId}/locations/{location}/jobs/{jobId}/metrics', ) command.response_representation = Google::Apis::DataflowV1b3::JobMetrics::Representation command.response_class = Google::Apis::DataflowV1b3::JobMetrics command.params['projectId'] = project_id unless project_id.nil? command.params['location'] = location unless location.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['startTime'] = start_time unless start_time.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#lease_project_location_work_item(project_id, location, job_id, lease_work_item_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::LeaseWorkItemResponse
Leases a dataflow WorkItem to run.
818 819 820 821 822 823 824 825 826 827 828 829 830 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 818 def lease_project_location_work_item(project_id, location, job_id, lease_work_item_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1b3/projects/{projectId}/locations/{location}/jobs/{jobId}/workItems:lease', ) command.request_representation = Google::Apis::DataflowV1b3::LeaseWorkItemRequest::Representation command.request_object = lease_work_item_request_object command.response_representation = Google::Apis::DataflowV1b3::LeaseWorkItemResponse::Representation command.response_class = Google::Apis::DataflowV1b3::LeaseWorkItemResponse command.params['projectId'] = project_id unless project_id.nil? command.params['location'] = location unless location.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#lease_project_work_item(project_id, job_id, lease_work_item_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::LeaseWorkItemResponse
Leases a dataflow WorkItem to run.
477 478 479 480 481 482 483 484 485 486 487 488 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 477 def lease_project_work_item(project_id, job_id, lease_work_item_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1b3/projects/{projectId}/jobs/{jobId}/workItems:lease', ) command.request_representation = Google::Apis::DataflowV1b3::LeaseWorkItemRequest::Representation command.request_object = lease_work_item_request_object command.response_representation = Google::Apis::DataflowV1b3::LeaseWorkItemResponse::Representation command.response_class = Google::Apis::DataflowV1b3::LeaseWorkItemResponse command.params['projectId'] = project_id unless project_id.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_job_messages(project_id, job_id, minimum_importance: nil, page_size: nil, page_token: nil, start_time: nil, end_time: nil, location: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::ListJobMessagesResponse
Request the job status.
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 401 def (project_id, job_id, minimum_importance: nil, page_size: nil, page_token: nil, start_time: nil, end_time: nil, location: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1b3/projects/{projectId}/jobs/{jobId}/messages', ) command.response_representation = Google::Apis::DataflowV1b3::ListJobMessagesResponse::Representation command.response_class = Google::Apis::DataflowV1b3::ListJobMessagesResponse command.params['projectId'] = project_id unless project_id.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['minimumImportance'] = minimum_importance unless minimum_importance.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['startTime'] = start_time unless start_time.nil? command.query['endTime'] = end_time unless end_time.nil? command.query['location'] = location unless location.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_jobs(project_id, filter: nil, view: nil, page_size: nil, page_token: nil, location: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::ListJobsResponse
List the jobs of a project.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 235 def list_project_jobs(project_id, filter: nil, view: nil, page_size: nil, page_token: nil, location: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1b3/projects/{projectId}/jobs', ) command.response_representation = Google::Apis::DataflowV1b3::ListJobsResponse::Representation command.response_class = Google::Apis::DataflowV1b3::ListJobsResponse command.params['projectId'] = project_id unless project_id.nil? command.query['filter'] = filter unless filter.nil? command.query['view'] = view unless view.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['location'] = location unless location.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_job_messages(project_id, location, job_id, minimum_importance: nil, page_size: nil, page_token: nil, start_time: nil, end_time: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::ListJobMessagesResponse
Request the job status.
737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 737 def (project_id, location, job_id, minimum_importance: nil, page_size: nil, page_token: nil, start_time: nil, end_time: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1b3/projects/{projectId}/locations/{location}/jobs/{jobId}/messages', ) command.response_representation = Google::Apis::DataflowV1b3::ListJobMessagesResponse::Representation command.response_class = Google::Apis::DataflowV1b3::ListJobMessagesResponse command.params['projectId'] = project_id unless project_id.nil? command.params['location'] = location unless location.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['minimumImportance'] = minimum_importance unless minimum_importance.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['startTime'] = start_time unless start_time.nil? command.query['endTime'] = end_time unless end_time.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_jobs(project_id, location, filter: nil, view: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::ListJobsResponse
List the jobs of a project.
643 644 645 646 647 648 649 650 651 652 653 654 655 656 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 643 def list_project_location_jobs(project_id, location, filter: nil, view: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1b3/projects/{projectId}/locations/{location}/jobs', ) command.response_representation = Google::Apis::DataflowV1b3::ListJobsResponse::Representation command.response_class = Google::Apis::DataflowV1b3::ListJobsResponse command.params['projectId'] = project_id unless project_id.nil? command.params['location'] = location unless location.nil? command.query['filter'] = filter unless filter.nil? command.query['view'] = view unless view.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#report_project_job_work_item_status(project_id, job_id, report_work_item_status_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::ReportWorkItemStatusResponse
Reports the status of dataflow WorkItems leased by a worker.
441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 441 def report_project_job_work_item_status(project_id, job_id, report_work_item_status_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1b3/projects/{projectId}/jobs/{jobId}/workItems:reportStatus', ) command.request_representation = Google::Apis::DataflowV1b3::ReportWorkItemStatusRequest::Representation command.request_object = report_work_item_status_request_object command.response_representation = Google::Apis::DataflowV1b3::ReportWorkItemStatusResponse::Representation command.response_class = Google::Apis::DataflowV1b3::ReportWorkItemStatusResponse command.params['projectId'] = project_id unless project_id.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#report_project_location_job_work_item_status(project_id, location, job_id, report_work_item_status_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::ReportWorkItemStatusResponse
Reports the status of dataflow WorkItems leased by a worker.
779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 779 def report_project_location_job_work_item_status(project_id, location, job_id, report_work_item_status_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1b3/projects/{projectId}/locations/{location}/jobs/{jobId}/workItems:reportStatus', ) command.request_representation = Google::Apis::DataflowV1b3::ReportWorkItemStatusRequest::Representation command.request_object = report_work_item_status_request_object command.response_representation = Google::Apis::DataflowV1b3::ReportWorkItemStatusResponse::Representation command.response_class = Google::Apis::DataflowV1b3::ReportWorkItemStatusResponse command.params['projectId'] = project_id unless project_id.nil? command.params['location'] = location unless location.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#send_project_job_debug_capture(project_id, job_id, send_debug_capture_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::SendDebugCaptureResponse
Send encoded debug capture data for component.
349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 349 def send_project_job_debug_capture(project_id, job_id, send_debug_capture_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1b3/projects/{projectId}/jobs/{jobId}/debug/sendCapture', ) command.request_representation = Google::Apis::DataflowV1b3::SendDebugCaptureRequest::Representation command.request_object = send_debug_capture_request_object command.response_representation = Google::Apis::DataflowV1b3::SendDebugCaptureResponse::Representation command.response_class = Google::Apis::DataflowV1b3::SendDebugCaptureResponse command.params['projectId'] = project_id unless project_id.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_project_job(project_id, job_id, job_object = nil, location: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::Job
Updates the state of an existing Cloud Dataflow job.
188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 188 def update_project_job(project_id, job_id, job_object = nil, location: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'v1b3/projects/{projectId}/jobs/{jobId}', ) command.request_representation = Google::Apis::DataflowV1b3::Job::Representation command.request_object = job_object command.response_representation = Google::Apis::DataflowV1b3::Job::Representation command.response_class = Google::Apis::DataflowV1b3::Job command.params['projectId'] = project_id unless project_id.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['location'] = location unless location.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_project_location_job(project_id, location, job_id, job_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::Job
Updates the state of an existing Cloud Dataflow job.
596 597 598 599 600 601 602 603 604 605 606 607 608 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 596 def update_project_location_job(project_id, location, job_id, job_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'v1b3/projects/{projectId}/locations/{location}/jobs/{jobId}', ) command.request_representation = Google::Apis::DataflowV1b3::Job::Representation command.request_object = job_object command.response_representation = Google::Apis::DataflowV1b3::Job::Representation command.response_class = Google::Apis::DataflowV1b3::Job command.params['projectId'] = project_id unless project_id.nil? command.params['location'] = location unless location.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#worker_project_messages(project_id, send_worker_messages_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataflowV1b3::SendWorkerMessagesResponse
Send a worker_message to the service.
70 71 72 73 74 75 76 77 78 79 80 |
# File 'generated/google/apis/dataflow_v1b3/service.rb', line 70 def (project_id, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1b3/projects/{projectId}/WorkerMessages', ) command.request_representation = Google::Apis::DataflowV1b3::SendWorkerMessagesRequest::Representation command.request_object = command.response_representation = Google::Apis::DataflowV1b3::SendWorkerMessagesResponse::Representation command.response_class = Google::Apis::DataflowV1b3::SendWorkerMessagesResponse command.params['projectId'] = project_id unless project_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |