Class: Google::Apis::DataflowV1b3::KeyRangeDataDiskAssignment
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::KeyRangeDataDiskAssignment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb
Overview
Data disk assignment information for a specific key-range of a sharded computation. Currently we only support UTF-8 character splits to simplify encoding into JSON.
Instance Attribute Summary collapse
-
#data_disk ⇒ String
The name of the data disk where data for this range is stored.
-
#end ⇒ String
The end (exclusive) of the key range.
-
#start ⇒ String
The start (inclusive) of the key range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KeyRangeDataDiskAssignment
constructor
A new instance of KeyRangeDataDiskAssignment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ KeyRangeDataDiskAssignment
Returns a new instance of KeyRangeDataDiskAssignment.
3883 3884 3885 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 3883 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_disk ⇒ String
The name of the data disk where data for this range is stored. This name is
local to the Google Cloud Platform project and uniquely identifies the disk
within that project, for example "myproject-1014-104817-4c2-harness-0-disk-1".
Corresponds to the JSON property dataDisk
3881 3882 3883 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 3881 def data_disk @data_disk end |
#end ⇒ String
The end (exclusive) of the key range.
Corresponds to the JSON property end
3874 3875 3876 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 3874 def end @end end |
#start ⇒ String
The start (inclusive) of the key range.
Corresponds to the JSON property start
3869 3870 3871 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 3869 def start @start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3888 3889 3890 3891 3892 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 3888 def update!(**args) @start = args[:start] if args.key?(:start) @end = args[:end] if args.key?(:end) @data_disk = args[:data_disk] if args.key?(:data_disk) end |