Class: Google::Apis::DataflowV1b3::ReportWorkItemStatusRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::ReportWorkItemStatusRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb
Overview
Request to report the status of WorkItems.
Instance Attribute Summary collapse
-
#current_worker_time ⇒ String
The current timestamp at the worker.
-
#location ⇒ String
The location which contains the WorkItem's job.
-
#work_item_statuses ⇒ Array<Google::Apis::DataflowV1b3::WorkItemStatus>
The order is unimportant, except that the order of the WorkItemServiceState messages in the ReportWorkItemStatusResponse corresponds to the order of WorkItemStatus messages here.
-
#worker_id ⇒ String
The ID of the worker reporting the WorkItem status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportWorkItemStatusRequest
constructor
A new instance of ReportWorkItemStatusRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ ReportWorkItemStatusRequest
Returns a new instance of ReportWorkItemStatusRequest.
1283 1284 1285 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1283 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_worker_time ⇒ String
The current timestamp at the worker.
Corresponds to the JSON property currentWorkerTime
1276 1277 1278 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1276 def current_worker_time @current_worker_time end |
#location ⇒ String
The location which contains the WorkItem's job.
Corresponds to the JSON property location
1281 1282 1283 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1281 def location @location end |
#work_item_statuses ⇒ Array<Google::Apis::DataflowV1b3::WorkItemStatus>
The order is unimportant, except that the order of the WorkItemServiceState
messages in the ReportWorkItemStatusResponse corresponds to the order of
WorkItemStatus messages here.
Corresponds to the JSON property workItemStatuses
1271 1272 1273 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1271 def work_item_statuses @work_item_statuses end |
#worker_id ⇒ String
The ID of the worker reporting the WorkItem status. If this does not match the
ID of the worker which the Dataflow service believes currently has the lease
on the WorkItem, the report will be dropped (with an error response).
Corresponds to the JSON property workerId
1264 1265 1266 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1264 def worker_id @worker_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1288 1289 1290 1291 1292 1293 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 1288 def update!(**args) @worker_id = args[:worker_id] if args.key?(:worker_id) @work_item_statuses = args[:work_item_statuses] if args.key?(:work_item_statuses) @current_worker_time = args[:current_worker_time] if args.key?(:current_worker_time) @location = args[:location] if args.key?(:location) end |