Class: Google::Apis::DataflowV1b3::SideInputInfo
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::SideInputInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb
Overview
Information about a side input of a DoFn or an input of a SeqDoFn.
Instance Attribute Summary collapse
-
#kind ⇒ Hash<String,Object>
How to interpret the source element(s) as a side input value.
-
#sources ⇒ Array<Google::Apis::DataflowV1b3::Source>
The source(s) to read element(s) from to get the value of this side input.
-
#tag ⇒ String
The id of the tag the user code will access this side input by; this should correspond to the tag of some MultiOutputInfo.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SideInputInfo
constructor
A new instance of SideInputInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ SideInputInfo
Returns a new instance of SideInputInfo.
2996 2997 2998 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2996 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ Hash<String,Object>
How to interpret the source element(s) as a side input value.
Corresponds to the JSON property kind
2988 2989 2990 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2988 def kind @kind end |
#sources ⇒ Array<Google::Apis::DataflowV1b3::Source>
The source(s) to read element(s) from to get the value of this side input. If
more than one source, then the elements are taken from the sources, in the
specified order if order matters. At least one source is required.
Corresponds to the JSON property sources
2983 2984 2985 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2983 def sources @sources end |
#tag ⇒ String
The id of the tag the user code will access this side input by; this should
correspond to the tag of some MultiOutputInfo.
Corresponds to the JSON property tag
2994 2995 2996 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 2994 def tag @tag end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3001 3002 3003 3004 3005 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 3001 def update!(**args) @sources = args[:sources] if args.key?(:sources) @kind = args[:kind] if args.key?(:kind) @tag = args[:tag] if args.key?(:tag) end |