Class: Google::Apis::DataflowV1b3::WorkerMessage
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::WorkerMessage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dataflow_v1b3/classes.rb,
generated/google/apis/dataflow_v1b3/representations.rb,
generated/google/apis/dataflow_v1b3/representations.rb
Overview
WorkerMessage provides information to the backend about a worker.
Instance Attribute Summary collapse
-
#labels ⇒ Hash<String,String>
Labels are used to group WorkerMessages.
-
#time ⇒ String
The timestamp of the worker_message.
-
#worker_health_report ⇒ Google::Apis::DataflowV1b3::WorkerHealthReport
WorkerHealthReport contains information about the health of a worker.
-
#worker_message_code ⇒ Google::Apis::DataflowV1b3::WorkerMessageCode
A message code is used to report status and error messages to the service.
-
#worker_metrics ⇒ Google::Apis::DataflowV1b3::ResourceUtilizationReport
Worker metrics exported from workers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkerMessage
constructor
A new instance of WorkerMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ WorkerMessage
Returns a new instance of WorkerMessage.
4019 4020 4021 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 4019 def initialize(**args) update!(**args) end |
Instance Attribute Details
#labels ⇒ Hash<String,String>
Labels are used to group WorkerMessages. For example, a worker_message about a
particular container might have the labels: "JOB_ID": "2015-04-22", "
WORKER_ID": "wordcount-vm-2015…" "CONTAINER_TYPE": "worker", "CONTAINER_ID": "
ac1234def" Label tags typically correspond to Label enum values. However, for
ease of development other strings can be used as tags. LABEL_UNSPECIFIED
should not be used here.
Corresponds to the JSON property labels
3988 3989 3990 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 3988 def labels @labels end |
#time ⇒ String
The timestamp of the worker_message.
Corresponds to the JSON property time
3993 3994 3995 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 3993 def time @time end |
#worker_health_report ⇒ Google::Apis::DataflowV1b3::WorkerHealthReport
WorkerHealthReport contains information about the health of a worker. The VM
should be identified by the labels attached to the WorkerMessage that this
health ping belongs to.
Corresponds to the JSON property workerHealthReport
4000 4001 4002 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 4000 def worker_health_report @worker_health_report end |
#worker_message_code ⇒ Google::Apis::DataflowV1b3::WorkerMessageCode
A message code is used to report status and error messages to the service. The
message codes are intended to be machine readable. The service will take care
of translating these into user understandable messages if necessary. Example
use cases: 1. Worker processes reporting successful startup. 2. Worker
processes reporting specific errors (e.g. package staging failure).
Corresponds to the JSON property workerMessageCode
4009 4010 4011 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 4009 def @worker_message_code end |
#worker_metrics ⇒ Google::Apis::DataflowV1b3::ResourceUtilizationReport
Worker metrics exported from workers. This contains resource utilization
metrics accumulated from a variety of sources. For more information, see go/df-
resource-signals. Note that this proto closely follows the structure of its
DFE siblings in its contents.
Corresponds to the JSON property workerMetrics
4017 4018 4019 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 4017 def worker_metrics @worker_metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4024 4025 4026 4027 4028 4029 4030 |
# File 'generated/google/apis/dataflow_v1b3/classes.rb', line 4024 def update!(**args) @labels = args[:labels] if args.key?(:labels) @time = args[:time] if args.key?(:time) @worker_health_report = args[:worker_health_report] if args.key?(:worker_health_report) @worker_message_code = args[:worker_message_code] if args.key?(:worker_message_code) @worker_metrics = args[:worker_metrics] if args.key?(:worker_metrics) end |