Class: Google::Apis::DataprocV1::ClusterConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataprocV1::ClusterConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dataproc_v1/classes.rb,
generated/google/apis/dataproc_v1/representations.rb,
generated/google/apis/dataproc_v1/representations.rb
Overview
The cluster config.
Instance Attribute Summary collapse
-
#config_bucket ⇒ String
[Optional] A Google Cloud Storage staging bucket used for sharing generated SSH keys and config.
-
#gce_cluster_config ⇒ Google::Apis::DataprocV1::GceClusterConfig
Common config settings for resources of Google Compute Engine cluster instances, applicable to all instances in the cluster.
-
#initialization_actions ⇒ Array<Google::Apis::DataprocV1::NodeInitializationAction>
[Optional] Commands to execute on each node after config is completed.
-
#master_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
[Optional] The config settings for Google Compute Engine resources in an instance group, such as a master or worker group.
-
#secondary_worker_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
[Optional] The config settings for Google Compute Engine resources in an instance group, such as a master or worker group.
-
#software_config ⇒ Google::Apis::DataprocV1::SoftwareConfig
Specifies the selection and config of software inside the cluster.
-
#worker_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
[Optional] The config settings for Google Compute Engine resources in an instance group, such as a master or worker group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClusterConfig
constructor
A new instance of ClusterConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ ClusterConfig
Returns a new instance of ClusterConfig.
149 150 151 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 149 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config_bucket ⇒ String
[Optional] A Google Cloud Storage staging bucket used for sharing generated
SSH keys and config. If you do not specify a staging bucket, Cloud Dataproc
will determine an appropriate Cloud Storage location (US, ASIA, or EU) for
your cluster's staging bucket according to the Google Compute Engine zone
where your cluster is deployed, and then it will create and manage this
project-level, per-location bucket for you.
Corresponds to the JSON property configBucket
107 108 109 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 107 def config_bucket @config_bucket end |
#gce_cluster_config ⇒ Google::Apis::DataprocV1::GceClusterConfig
Common config settings for resources of Google Compute Engine cluster
instances, applicable to all instances in the cluster.
Corresponds to the JSON property gceClusterConfig
113 114 115 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 113 def gce_cluster_config @gce_cluster_config end |
#initialization_actions ⇒ Array<Google::Apis::DataprocV1::NodeInitializationAction>
[Optional] Commands to execute on each node after config is completed. By
default, executables are run on master and all worker nodes. You can test a
node's role metadata to run an executable on a master or worker node, as shown
below using curl (you can also use wget): ROLE=$(curl -H Metadata-Flavor:
Google http://metadata/computeMetadata/v1/instance/attributes/dataproc-role)
if [[ "$ROLE" == 'Master' ]]; then ... master specific actions ... else ...
worker specific actions ... fi
Corresponds to the JSON property initializationActions
147 148 149 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 147 def initialization_actions @initialization_actions end |
#master_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
[Optional] The config settings for Google Compute Engine resources in an
instance group, such as a master or worker group.
Corresponds to the JSON property masterConfig
119 120 121 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 119 def master_config @master_config end |
#secondary_worker_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
[Optional] The config settings for Google Compute Engine resources in an
instance group, such as a master or worker group.
Corresponds to the JSON property secondaryWorkerConfig
131 132 133 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 131 def secondary_worker_config @secondary_worker_config end |
#software_config ⇒ Google::Apis::DataprocV1::SoftwareConfig
Specifies the selection and config of software inside the cluster.
Corresponds to the JSON property softwareConfig
136 137 138 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 136 def software_config @software_config end |
#worker_config ⇒ Google::Apis::DataprocV1::InstanceGroupConfig
[Optional] The config settings for Google Compute Engine resources in an
instance group, such as a master or worker group.
Corresponds to the JSON property workerConfig
125 126 127 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 125 def worker_config @worker_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
154 155 156 157 158 159 160 161 162 |
# File 'generated/google/apis/dataproc_v1/classes.rb', line 154 def update!(**args) @config_bucket = args[:config_bucket] if args.key?(:config_bucket) @gce_cluster_config = args[:gce_cluster_config] if args.key?(:gce_cluster_config) @master_config = args[:master_config] if args.key?(:master_config) @worker_config = args[:worker_config] if args.key?(:worker_config) @secondary_worker_config = args[:secondary_worker_config] if args.key?(:secondary_worker_config) @software_config = args[:software_config] if args.key?(:software_config) @initialization_actions = args[:initialization_actions] if args.key?(:initialization_actions) end |