Class: Google::Apis::DataprocV1::DataprocService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::DataprocV1::DataprocService
- Defined in:
- generated/google/apis/dataproc_v1/service.rb
Overview
Google Cloud Dataproc API
An API for managing Hadoop-based clusters and jobs on Google Cloud Platform.
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Attributes inherited from Core::BaseService
#authorization, #base_path, #batch_path, #client, #client_options, #request_options, #root_url, #upload_path
Instance Method Summary collapse
-
#cancel_job(project_id, region, job_id, cancel_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Job
Starts a job cancellation request.
-
#cancel_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_cluster(project_id, region, cluster_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Operation
Creates a cluster in a project.
-
#delete_cluster(project_id, region, cluster_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Operation
Deletes a cluster in a project.
-
#delete_job(project_id, region, job_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Empty
Deletes the job from the project.
-
#delete_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Empty
Deletes a long-running operation.
-
#diagnose_cluster(project_id, region, cluster_name, diagnose_cluster_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Operation
Gets cluster diagnostic information.
-
#get_cluster(project_id, region, cluster_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Cluster
Gets the resource representation for a cluster in a project.
-
#get_job(project_id, region, job_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Job
Gets the resource representation for a job in a project.
-
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ DataprocService
constructor
A new instance of DataprocService.
-
#list_clusters(project_id, region, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::ListClustersResponse
Lists all regions/
region/clusters in a project. -
#list_jobs(project_id, region, page_size: nil, page_token: nil, cluster_name: nil, job_state_matcher: nil, filter: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::ListJobsResponse
Lists regions/
region/jobs in a project. -
#list_operations(name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#patch_cluster(project_id, region, cluster_name, cluster_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Operation
Updates a cluster in a project.
-
#submit_job(project_id, region, submit_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Job
Submits a job to a cluster.
Methods inherited from Core::BaseService
#batch, #batch_upload, #fetch_all, #http
Constructor Details
#initialize ⇒ DataprocService
Returns a new instance of DataprocService.
45 46 47 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 45 def initialize super('https://dataproc.googleapis.com/', '') end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
38 39 40 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 38 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
43 44 45 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 43 def quota_user @quota_user end |
Instance Method Details
#cancel_job(project_id, region, job_id, cancel_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Job
Starts a job cancellation request. To access the job resource after
cancellation, call regions/region/jobs.list or regions/region/jobs.get.
467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 467 def cancel_job(project_id, region, job_id, cancel_job_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/projects/{projectId}/regions/{region}/jobs/{jobId}:cancel', ) command.request_representation = Google::Apis::DataprocV1::CancelJobRequest::Representation command.request_object = cancel_job_request_object command.response_representation = Google::Apis::DataprocV1::Job::Representation command.response_class = Google::Apis::DataprocV1::Job command.params['projectId'] = project_id unless project_id.nil? command.params['region'] = region unless region.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1,
corresponding to Code.CANCELLED.
651 652 653 654 655 656 657 658 659 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 651 def cancel_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.response_representation = Google::Apis::DataprocV1::Empty::Representation command.response_class = Google::Apis::DataprocV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_cluster(project_id, region, cluster_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Operation
Creates a cluster in a project.
73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 73 def create_cluster(project_id, region, cluster_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/projects/{projectId}/regions/{region}/clusters', ) command.request_representation = Google::Apis::DataprocV1::Cluster::Representation command.request_object = cluster_object command.response_representation = Google::Apis::DataprocV1::Operation::Representation command.response_class = Google::Apis::DataprocV1::Operation command.params['projectId'] = project_id unless project_id.nil? command.params['region'] = region unless region.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_cluster(project_id, region, cluster_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Operation
Deletes a cluster in a project.
163 164 165 166 167 168 169 170 171 172 173 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 163 def delete_cluster(project_id, region, cluster_name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/projects/{projectId}/regions/{region}/clusters/{clusterName}', ) command.response_representation = Google::Apis::DataprocV1::Operation::Representation command.response_class = Google::Apis::DataprocV1::Operation command.params['projectId'] = project_id unless project_id.nil? command.params['region'] = region unless region.nil? command.params['clusterName'] = cluster_name unless cluster_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_job(project_id, region, job_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Empty
Deletes the job from the project. If the job is active, the delete fails, and
the response returns FAILED_PRECONDITION.
506 507 508 509 510 511 512 513 514 515 516 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 506 def delete_job(project_id, region, job_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/projects/{projectId}/regions/{region}/jobs/{jobId}', ) command.response_representation = Google::Apis::DataprocV1::Empty::Representation command.response_class = Google::Apis::DataprocV1::Empty command.params['projectId'] = project_id unless project_id.nil? command.params['region'] = region unless region.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
614 615 616 617 618 619 620 621 622 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 614 def delete_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::DataprocV1::Empty::Representation command.response_class = Google::Apis::DataprocV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#diagnose_cluster(project_id, region, cluster_name, diagnose_cluster_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Operation
Gets cluster diagnostic information. After the operation completes, the
Operation.response field contains DiagnoseClusterOutputLocation.
294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 294 def diagnose_cluster(project_id, region, cluster_name, diagnose_cluster_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/projects/{projectId}/regions/{region}/clusters/{clusterName}:diagnose', ) command.request_representation = Google::Apis::DataprocV1::DiagnoseClusterRequest::Representation command.request_object = diagnose_cluster_request_object command.response_representation = Google::Apis::DataprocV1::Operation::Representation command.response_class = Google::Apis::DataprocV1::Operation command.params['projectId'] = project_id unless project_id.nil? command.params['region'] = region unless region.nil? command.params['clusterName'] = cluster_name unless cluster_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_cluster(project_id, region, cluster_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Cluster
Gets the resource representation for a cluster in a project.
200 201 202 203 204 205 206 207 208 209 210 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 200 def get_cluster(project_id, region, cluster_name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/projects/{projectId}/regions/{region}/clusters/{clusterName}', ) command.response_representation = Google::Apis::DataprocV1::Cluster::Representation command.response_class = Google::Apis::DataprocV1::Cluster command.params['projectId'] = project_id unless project_id.nil? command.params['region'] = region unless region.nil? command.params['clusterName'] = cluster_name unless cluster_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_job(project_id, region, job_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Job
Gets the resource representation for a job in a project.
368 369 370 371 372 373 374 375 376 377 378 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 368 def get_job(project_id, region, job_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/projects/{projectId}/regions/{region}/jobs/{jobId}', ) command.response_representation = Google::Apis::DataprocV1::Job::Representation command.response_class = Google::Apis::DataprocV1::Job command.params['projectId'] = project_id unless project_id.nil? command.params['region'] = region unless region.nil? command.params['jobId'] = job_id unless job_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
581 582 583 584 585 586 587 588 589 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 581 def get_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DataprocV1::Operation::Representation command.response_class = Google::Apis::DataprocV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_clusters(project_id, region, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::ListClustersResponse
Lists all regions/region/clusters in a project.
253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 253 def list_clusters(project_id, region, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/projects/{projectId}/regions/{region}/clusters', ) command.response_representation = Google::Apis::DataprocV1::ListClustersResponse::Representation command.response_class = Google::Apis::DataprocV1::ListClustersResponse command.params['projectId'] = project_id unless project_id.nil? command.params['region'] = region unless region.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_jobs(project_id, region, page_size: nil, page_token: nil, cluster_name: nil, job_state_matcher: nil, filter: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::ListJobsResponse
Lists regions/region/jobs in a project.
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 423 def list_jobs(project_id, region, page_size: nil, page_token: nil, cluster_name: nil, job_state_matcher: nil, filter: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/projects/{projectId}/regions/{region}/jobs', ) command.response_representation = Google::Apis::DataprocV1::ListJobsResponse::Representation command.response_class = Google::Apis::DataprocV1::ListJobsResponse command.params['projectId'] = project_id unless project_id.nil? command.params['region'] = region unless region.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['clusterName'] = cluster_name unless cluster_name.nil? command.query['jobStateMatcher'] = job_state_matcher unless job_state_matcher.nil? command.query['filter'] = filter unless filter.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_operations(name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED. NOTE: the name
binding below allows API services to override the binding to use different
resource name schemes, such as users/*/operations.
547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 547 def list_operations(name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DataprocV1::ListOperationsResponse::Representation command.response_class = Google::Apis::DataprocV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_cluster(project_id, region, cluster_name, cluster_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Operation
Updates a cluster in a project.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 123 def patch_cluster(project_id, region, cluster_name, cluster_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/projects/{projectId}/regions/{region}/clusters/{clusterName}', ) command.request_representation = Google::Apis::DataprocV1::Cluster::Representation command.request_object = cluster_object command.response_representation = Google::Apis::DataprocV1::Operation::Representation command.response_class = Google::Apis::DataprocV1::Operation command.params['projectId'] = project_id unless project_id.nil? command.params['region'] = region unless region.nil? command.params['clusterName'] = cluster_name unless cluster_name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#submit_job(project_id, region, submit_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DataprocV1::Job
Submits a job to a cluster.
331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'generated/google/apis/dataproc_v1/service.rb', line 331 def submit_job(project_id, region, submit_job_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/projects/{projectId}/regions/{region}/jobs:submit', ) command.request_representation = Google::Apis::DataprocV1::SubmitJobRequest::Representation command.request_object = submit_job_request_object command.response_representation = Google::Apis::DataprocV1::Job::Representation command.response_class = Google::Apis::DataprocV1::Job command.params['projectId'] = project_id unless project_id.nil? command.params['region'] = region unless region.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |