Class: Google::Apis::DfareportingV2_7::DefaultClickThroughEventTagProperties
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV2_7::DefaultClickThroughEventTagProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dfareporting_v2_7/classes.rb,
generated/google/apis/dfareporting_v2_7/representations.rb,
generated/google/apis/dfareporting_v2_7/representations.rb
Overview
Properties of inheriting and overriding the default click-through event tag. A campaign may override the event tag defined at the advertiser level, and an ad may also override the campaign's setting further.
Instance Attribute Summary collapse
-
#default_click_through_event_tag_id ⇒ String
ID of the click-through event tag to apply to all ads in this entity's scope.
-
#override_inherited_event_tag ⇒ Boolean
(also: #override_inherited_event_tag?)
Whether this entity should override the inherited default click-through event tag with its own defined value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DefaultClickThroughEventTagProperties
constructor
A new instance of DefaultClickThroughEventTagProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ DefaultClickThroughEventTagProperties
Returns a new instance of DefaultClickThroughEventTagProperties.
4469 4470 4471 |
# File 'generated/google/apis/dfareporting_v2_7/classes.rb', line 4469 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_click_through_event_tag_id ⇒ String
ID of the click-through event tag to apply to all ads in this entity's scope.
Corresponds to the JSON property defaultClickThroughEventTagId
4460 4461 4462 |
# File 'generated/google/apis/dfareporting_v2_7/classes.rb', line 4460 def default_click_through_event_tag_id @default_click_through_event_tag_id end |
#override_inherited_event_tag ⇒ Boolean Also known as: override_inherited_event_tag?
Whether this entity should override the inherited default click-through event
tag with its own defined value.
Corresponds to the JSON property overrideInheritedEventTag
4466 4467 4468 |
# File 'generated/google/apis/dfareporting_v2_7/classes.rb', line 4466 def override_inherited_event_tag @override_inherited_event_tag end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4474 4475 4476 4477 |
# File 'generated/google/apis/dfareporting_v2_7/classes.rb', line 4474 def update!(**args) @default_click_through_event_tag_id = args[:default_click_through_event_tag_id] if args.key?(:default_click_through_event_tag_id) @override_inherited_event_tag = args[:override_inherited_event_tag] if args.key?(:override_inherited_event_tag) end |