Class: Google::Apis::DfareportingV2_7::ObjectFilter
- Inherits:
-
Object
- Object
- Google::Apis::DfareportingV2_7::ObjectFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/dfareporting_v2_7/classes.rb,
generated/google/apis/dfareporting_v2_7/representations.rb,
generated/google/apis/dfareporting_v2_7/representations.rb
Overview
Object Filter.
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#object_ids ⇒ Array<String>
Applicable when status is ASSIGNED.
-
#status ⇒ String
Status of the filter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ObjectFilter
constructor
A new instance of ObjectFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ ObjectFilter
Returns a new instance of ObjectFilter.
7228 7229 7230 |
# File 'generated/google/apis/dfareporting_v2_7/classes.rb', line 7228 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
dfareporting#objectFilter".
Corresponds to the JSON property kind
7213 7214 7215 |
# File 'generated/google/apis/dfareporting_v2_7/classes.rb', line 7213 def kind @kind end |
#object_ids ⇒ Array<String>
Applicable when status is ASSIGNED. The user has access to objects with these
object IDs.
Corresponds to the JSON property objectIds
7219 7220 7221 |
# File 'generated/google/apis/dfareporting_v2_7/classes.rb', line 7219 def object_ids @object_ids end |
#status ⇒ String
Status of the filter. NONE means the user has access to none of the objects.
ALL means the user has access to all objects. ASSIGNED means the user has
access to the objects with IDs in the objectIds list.
Corresponds to the JSON property status
7226 7227 7228 |
# File 'generated/google/apis/dfareporting_v2_7/classes.rb', line 7226 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7233 7234 7235 7236 7237 |
# File 'generated/google/apis/dfareporting_v2_7/classes.rb', line 7233 def update!(**args) @kind = args[:kind] if args.key?(:kind) @object_ids = args[:object_ids] if args.key?(:object_ids) @status = args[:status] if args.key?(:status) end |