Class: Google::Apis::GenomicsV1::Annotation
- Inherits:
-
Object
- Object
- Google::Apis::GenomicsV1::Annotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/genomics_v1/classes.rb,
generated/google/apis/genomics_v1/representations.rb,
generated/google/apis/genomics_v1/representations.rb
Overview
An annotation describes a region of reference genome. The value of an
annotation may be one of several canonical types, supplemented by arbitrary
info tags. An annotation is not inherently associated with a specific
sample or individual (though a client could choose to use annotations in
this way). Example canonical annotation types are GENE and
VARIANT.
Instance Attribute Summary collapse
-
#annotation_set_id ⇒ String
The annotation set to which this annotation belongs.
-
#end ⇒ String
The end position of the range on the reference, 0-based exclusive.
-
#id ⇒ String
The server-generated annotation ID, unique across all annotations.
-
#info ⇒ Hash<String,Array<Object>>
A map of additional read alignment information.
-
#name ⇒ String
The display name of this annotation.
-
#reference_id ⇒ String
The ID of the Google Genomics reference associated with this range.
-
#reference_name ⇒ String
The display name corresponding to the reference specified by
referenceId, for examplechr1,1, orchrX. -
#reverse_strand ⇒ Boolean
(also: #reverse_strand?)
Whether this range refers to the reverse strand, as opposed to the forward strand.
-
#start ⇒ String
The start position of the range on the reference, 0-based inclusive.
-
#transcript ⇒ Google::Apis::GenomicsV1::Transcript
A transcript represents the assertion that a particular region of the reference genome may be transcribed as RNA.
-
#type ⇒ String
The data type for this annotation.
-
#variant ⇒ Google::Apis::GenomicsV1::VariantAnnotation
A variant annotation, which describes the effect of a variant on the genome, the coding sequence, and/or higher level consequences at the organism level e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Annotation
constructor
A new instance of Annotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ Annotation
Returns a new instance of Annotation.
2422 2423 2424 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 2422 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_set_id ⇒ String
The annotation set to which this annotation belongs.
Corresponds to the JSON property annotationSetId
2366 2367 2368 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 2366 def annotation_set_id @annotation_set_id end |
#end ⇒ String
The end position of the range on the reference, 0-based exclusive.
Corresponds to the JSON property end
2420 2421 2422 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 2420 def end @end end |
#id ⇒ String
The server-generated annotation ID, unique across all annotations.
Corresponds to the JSON property id
2389 2390 2391 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 2389 def id @id end |
#info ⇒ Hash<String,Array<Object>>
A map of additional read alignment information. This must be of the form
mapinfo
2415 2416 2417 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 2415 def info @info end |
#name ⇒ String
The display name of this annotation.
Corresponds to the JSON property name
2371 2372 2373 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 2371 def name @name end |
#reference_id ⇒ String
The ID of the Google Genomics reference associated with this range.
Corresponds to the JSON property referenceId
2384 2385 2386 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 2384 def reference_id @reference_id end |
#reference_name ⇒ String
The display name corresponding to the reference specified by
referenceId, for example chr1, 1, or chrX.
Corresponds to the JSON property referenceName
2403 2404 2405 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 2403 def reference_name @reference_name end |
#reverse_strand ⇒ Boolean Also known as: reverse_strand?
Whether this range refers to the reverse strand, as opposed to the forward
strand. Note that regardless of this field, the start/end position of the
range always refer to the forward strand.
Corresponds to the JSON property reverseStrand
2396 2397 2398 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 2396 def reverse_strand @reverse_strand end |
#start ⇒ String
The start position of the range on the reference, 0-based inclusive.
Corresponds to the JSON property start
2361 2362 2363 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 2361 def start @start end |
#transcript ⇒ Google::Apis::GenomicsV1::Transcript
A transcript represents the assertion that a particular region of the
reference genome may be transcribed as RNA.
Corresponds to the JSON property transcript
2356 2357 2358 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 2356 def transcript @transcript end |
#type ⇒ String
The data type for this annotation. Must match the containing annotation
set's type.
Corresponds to the JSON property type
2409 2410 2411 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 2409 def type @type end |
#variant ⇒ Google::Apis::GenomicsV1::VariantAnnotation
A variant annotation, which describes the effect of a variant on the
genome, the coding sequence, and/or higher level consequences at the
organism level e.g. pathogenicity. This field is only set for annotations
of type VARIANT.
Corresponds to the JSON property variant
2379 2380 2381 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 2379 def variant @variant end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 2427 def update!(**args) @transcript = args[:transcript] if args.key?(:transcript) @start = args[:start] if args.key?(:start) @annotation_set_id = args[:annotation_set_id] if args.key?(:annotation_set_id) @name = args[:name] if args.key?(:name) @variant = args[:variant] if args.key?(:variant) @reference_id = args[:reference_id] if args.key?(:reference_id) @id = args[:id] if args.key?(:id) @reverse_strand = args[:reverse_strand] if args.key?(:reverse_strand) @reference_name = args[:reference_name] if args.key?(:reference_name) @type = args[:type] if args.key?(:type) @info = args[:info] if args.key?(:info) @end = args[:end] if args.key?(:end) end |