Class: Google::Apis::GenomicsV1::ReadGroupSet
- Inherits:
-
Object
- Object
- Google::Apis::GenomicsV1::ReadGroupSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/genomics_v1/classes.rb,
generated/google/apis/genomics_v1/representations.rb,
generated/google/apis/genomics_v1/representations.rb
Overview
A read group set is a logical collection of read groups, which are collections of reads produced by a sequencer. A read group set typically models reads corresponding to one sample, sequenced one way, and aligned one way.
- A read group set belongs to one dataset.
- A read group belongs to one read group set.
- A read belongs to one read group. For more genomics resource definitions, see Fundamentals of Google Genomics
Instance Attribute Summary collapse
-
#dataset_id ⇒ String
The dataset to which this read group set belongs.
-
#filename ⇒ String
The filename of the original source file for this read group set, if any.
-
#id ⇒ String
The server-generated read group set ID, unique for all read group sets.
-
#info ⇒ Hash<String,Array<Object>>
A map of additional read group set information.
-
#name ⇒ String
The read group set name.
-
#read_groups ⇒ Array<Google::Apis::GenomicsV1::ReadGroup>
The read groups in this set.
-
#reference_set_id ⇒ String
The reference set to which the reads in this read group set are aligned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReadGroupSet
constructor
A new instance of ReadGroupSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ ReadGroupSet
Returns a new instance of ReadGroupSet.
1912 1913 1914 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1912 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataset_id ⇒ String
The dataset to which this read group set belongs.
Corresponds to the JSON property datasetId
1910 1911 1912 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1910 def dataset_id @dataset_id end |
#filename ⇒ String
The filename of the original source file for this read group set, if any.
Corresponds to the JSON property filename
1884 1885 1886 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1884 def filename @filename end |
#id ⇒ String
The server-generated read group set ID, unique for all read group sets.
Corresponds to the JSON property id
1905 1906 1907 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1905 def id @id end |
#info ⇒ Hash<String,Array<Object>>
A map of additional read group set information.
Corresponds to the JSON property info
1900 1901 1902 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1900 def info @info end |
#name ⇒ String
The read group set name. By default this will be initialized to the sample
name of the sequenced data contained in this set.
Corresponds to the JSON property name
1890 1891 1892 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1890 def name @name end |
#read_groups ⇒ Array<Google::Apis::GenomicsV1::ReadGroup>
The read groups in this set. There are typically 1-10 read groups in a read
group set.
Corresponds to the JSON property readGroups
1879 1880 1881 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1879 def read_groups @read_groups end |
#reference_set_id ⇒ String
The reference set to which the reads in this read group set are aligned.
Corresponds to the JSON property referenceSetId
1895 1896 1897 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1895 def reference_set_id @reference_set_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1917 1918 1919 1920 1921 1922 1923 1924 1925 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1917 def update!(**args) @read_groups = args[:read_groups] if args.key?(:read_groups) @filename = args[:filename] if args.key?(:filename) @name = args[:name] if args.key?(:name) @reference_set_id = args[:reference_set_id] if args.key?(:reference_set_id) @info = args[:info] if args.key?(:info) @id = args[:id] if args.key?(:id) @dataset_id = args[:dataset_id] if args.key?(:dataset_id) end |