Class: Google::Apis::GenomicsV1::SearchAnnotationSetsRequest
- Inherits:
-
Object
- Object
- Google::Apis::GenomicsV1::SearchAnnotationSetsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/genomics_v1/classes.rb,
generated/google/apis/genomics_v1/representations.rb,
generated/google/apis/genomics_v1/representations.rb
Instance Attribute Summary collapse
-
#dataset_ids ⇒ Array<String>
Required.
-
#name ⇒ String
Only return annotations sets for which a substring of the name matches this string (case insensitive).
-
#page_size ⇒ Fixnum
The maximum number of results to return in a single page.
-
#page_token ⇒ String
The continuation token, which is used to page through large result sets.
-
#reference_set_id ⇒ String
If specified, only annotation sets associated with the given reference set are returned.
-
#types ⇒ Array<String>
If specified, only annotation sets that have any of these types are returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchAnnotationSetsRequest
constructor
A new instance of SearchAnnotationSetsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ SearchAnnotationSetsRequest
Returns a new instance of SearchAnnotationSetsRequest.
1594 1595 1596 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1594 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataset_ids ⇒ Array<String>
Required. The dataset IDs to search within. Caller must have READ access
to these datasets.
Corresponds to the JSON property datasetIds
1574 1575 1576 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1574 def dataset_ids @dataset_ids end |
#name ⇒ String
Only return annotations sets for which a substring of the name matches this
string (case insensitive).
Corresponds to the JSON property name
1586 1587 1588 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1586 def name @name end |
#page_size ⇒ Fixnum
The maximum number of results to return in a single page. If unspecified,
defaults to 128. The maximum value is 1024.
Corresponds to the JSON property pageSize
1568 1569 1570 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1568 def page_size @page_size end |
#page_token ⇒ String
The continuation token, which is used to page through large result sets.
To get the next page of results, set this parameter to the value of
nextPageToken from the previous response.
Corresponds to the JSON property pageToken
1562 1563 1564 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1562 def page_token @page_token end |
#reference_set_id ⇒ String
If specified, only annotation sets associated with the given reference set
are returned.
Corresponds to the JSON property referenceSetId
1592 1593 1594 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1592 def reference_set_id @reference_set_id end |
#types ⇒ Array<String>
If specified, only annotation sets that have any of these types are
returned.
Corresponds to the JSON property types
1580 1581 1582 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1580 def types @types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1599 1600 1601 1602 1603 1604 1605 1606 |
# File 'generated/google/apis/genomics_v1/classes.rb', line 1599 def update!(**args) @page_token = args[:page_token] if args.key?(:page_token) @page_size = args[:page_size] if args.key?(:page_size) @dataset_ids = args[:dataset_ids] if args.key?(:dataset_ids) @types = args[:types] if args.key?(:types) @name = args[:name] if args.key?(:name) @reference_set_id = args[:reference_set_id] if args.key?(:reference_set_id) end |