Class: Google::Apis::LoggingV2beta1::LoggingService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::LoggingV2beta1::LoggingService
- Defined in:
- generated/google/apis/logging_v2beta1/service.rb
Overview
Stackdriver Logging API
Writes log entries and manages your Stackdriver Logging configuration.
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Attributes inherited from Core::BaseService
#authorization, #base_path, #batch_path, #client, #client_options, #request_options, #root_url, #upload_path
Instance Method Summary collapse
-
#create_project_metric(parent, log_metric_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogMetric
Creates a logs-based metric.
-
#create_project_sink(parent, log_sink_object = nil, unique_writer_identity: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogSink
Creates a sink that exports specified log entries to a destination.
-
#delete_billing_account_log(log_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::Empty
Deletes all the log entries in a log.
-
#delete_log(log_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::Empty
Deletes all the log entries in a log.
-
#delete_organization_log(log_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::Empty
Deletes all the log entries in a log.
-
#delete_project_metric(metric_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::Empty
Deletes a logs-based metric.
-
#delete_project_sink(sink_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::Empty
Deletes a sink.
-
#get_project_metric(metric_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogMetric
Gets a logs-based metric.
-
#get_project_sink(sink_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogSink
Gets a sink.
-
#initialize ⇒ LoggingService
constructor
A new instance of LoggingService.
-
#list_billing_account_logs(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListLogsResponse
Lists the logs in projects or organizations.
-
#list_entry_log_entries(list_log_entries_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListLogEntriesResponse
Lists log entries.
-
#list_logs(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListLogsResponse
Lists the logs in projects or organizations.
-
#list_monitored_resource_descriptors(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListMonitoredResourceDescriptorsResponse
Lists the descriptors for monitored resource types used by Stackdriver Logging.
-
#list_organization_logs(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListLogsResponse
Lists the logs in projects or organizations.
-
#list_project_metrics(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListLogMetricsResponse
Lists logs-based metrics.
-
#list_project_sinks(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListSinksResponse
Lists sinks.
-
#update_project_metric(metric_name, log_metric_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogMetric
Creates or updates a logs-based metric.
-
#update_project_sink(sink_name, log_sink_object = nil, unique_writer_identity: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogSink
Updates a sink.
-
#write_entry_log_entries(write_log_entries_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::WriteLogEntriesResponse
Writes log entries to Stackdriver Logging.
Methods inherited from Core::BaseService
#batch, #batch_upload, #fetch_all, #http
Constructor Details
#initialize ⇒ LoggingService
Returns a new instance of LoggingService.
45 46 47 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 45 def initialize super('https://logging.googleapis.com/', '') end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
38 39 40 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 38 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
43 44 45 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 43 def quota_user @quota_user end |
Instance Method Details
#create_project_metric(parent, log_metric_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogMetric
Creates a logs-based metric.
134 135 136 137 138 139 140 141 142 143 144 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 134 def create_project_metric(parent, log_metric_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta1/{+parent}/metrics', ) command.request_representation = Google::Apis::LoggingV2beta1::LogMetric::Representation command.request_object = log_metric_object command.response_representation = Google::Apis::LoggingV2beta1::LogMetric::Representation command.response_class = Google::Apis::LoggingV2beta1::LogMetric command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_sink(parent, log_sink_object = nil, unique_writer_identity: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogSink
Creates a sink that exports specified log entries to a destination. The export of newly-ingested log entries begins immediately, unless the current time is outside the sink's start and end times or the sink's writer_identity is not permitted to write to the destination. A sink can export log entries only from the resource owning the sink.
568 569 570 571 572 573 574 575 576 577 578 579 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 568 def create_project_sink(parent, log_sink_object = nil, unique_writer_identity: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta1/{+parent}/sinks', ) command.request_representation = Google::Apis::LoggingV2beta1::LogSink::Representation command.request_object = log_sink_object command.response_representation = Google::Apis::LoggingV2beta1::LogSink::Representation command.response_class = Google::Apis::LoggingV2beta1::LogSink command.params['parent'] = parent unless parent.nil? command.query['uniqueWriterIdentity'] = unique_writer_identity unless unique_writer_identity.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_billing_account_log(log_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::Empty
Deletes all the log entries in a log. The log reappears if it receives new entries.
607 608 609 610 611 612 613 614 615 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 607 def delete_billing_account_log(log_name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2beta1/{+logName}', ) command.response_representation = Google::Apis::LoggingV2beta1::Empty::Representation command.response_class = Google::Apis::LoggingV2beta1::Empty command.params['logName'] = log_name unless log_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_log(log_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::Empty
Deletes all the log entries in a log. The log reappears if it receives new entries.
313 314 315 316 317 318 319 320 321 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 313 def delete_log(log_name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2beta1/{+logName}', ) command.response_representation = Google::Apis::LoggingV2beta1::Empty::Representation command.response_class = Google::Apis::LoggingV2beta1::Empty command.params['logName'] = log_name unless log_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_organization_log(log_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::Empty
Deletes all the log entries in a log. The log reappears if it receives new entries.
725 726 727 728 729 730 731 732 733 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 725 def delete_organization_log(log_name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2beta1/{+logName}', ) command.response_representation = Google::Apis::LoggingV2beta1::Empty::Representation command.response_class = Google::Apis::LoggingV2beta1::Empty command.params['logName'] = log_name unless log_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_metric(metric_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::Empty
Deletes a logs-based metric.
167 168 169 170 171 172 173 174 175 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 167 def delete_project_metric(metric_name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2beta1/{+metricName}', ) command.response_representation = Google::Apis::LoggingV2beta1::Empty::Representation command.response_class = Google::Apis::LoggingV2beta1::Empty command.params['metricName'] = metric_name unless metric_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_sink(sink_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::Empty
Deletes a sink. If the sink has a unique writer_identity, then that service account is also deleted.
393 394 395 396 397 398 399 400 401 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 393 def delete_project_sink(sink_name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2beta1/{+sinkName}', ) command.response_representation = Google::Apis::LoggingV2beta1::Empty::Representation command.response_class = Google::Apis::LoggingV2beta1::Empty command.params['sinkName'] = sink_name unless sink_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_metric(metric_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogMetric
Gets a logs-based metric.
240 241 242 243 244 245 246 247 248 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 240 def get_project_metric(metric_name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta1/{+metricName}', ) command.response_representation = Google::Apis::LoggingV2beta1::LogMetric::Representation command.response_class = Google::Apis::LoggingV2beta1::LogMetric command.params['metricName'] = metric_name unless metric_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_sink(sink_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogSink
Gets a sink.
468 469 470 471 472 473 474 475 476 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 468 def get_project_sink(sink_name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta1/{+sinkName}', ) command.response_representation = Google::Apis::LoggingV2beta1::LogSink::Representation command.response_class = Google::Apis::LoggingV2beta1::LogSink command.params['sinkName'] = sink_name unless sink_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_billing_account_logs(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListLogsResponse
Lists the logs in projects or organizations. Only logs that have entries are listed.
649 650 651 652 653 654 655 656 657 658 659 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 649 def list_billing_account_logs(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta1/{+parent}/logs', ) command.response_representation = Google::Apis::LoggingV2beta1::ListLogsResponse::Representation command.response_class = Google::Apis::LoggingV2beta1::ListLogsResponse command.params['parent'] = parent unless parent.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_entry_log_entries(list_log_entries_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListLogEntriesResponse
Lists log entries. Use this method to retrieve log entries from Stackdriver Logging. For ways to export log entries, see Exporting Logs.
69 70 71 72 73 74 75 76 77 78 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 69 def list_entry_log_entries(list_log_entries_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta1/entries:list', ) command.request_representation = Google::Apis::LoggingV2beta1::ListLogEntriesRequest::Representation command.request_object = list_log_entries_request_object command.response_representation = Google::Apis::LoggingV2beta1::ListLogEntriesResponse::Representation command.response_class = Google::Apis::LoggingV2beta1::ListLogEntriesResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_logs(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListLogsResponse
Lists the logs in projects or organizations. Only logs that have entries are listed.
355 356 357 358 359 360 361 362 363 364 365 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 355 def list_logs(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta1/{+parent}/logs', ) command.response_representation = Google::Apis::LoggingV2beta1::ListLogsResponse::Representation command.response_class = Google::Apis::LoggingV2beta1::ListLogsResponse command.params['parent'] = parent unless parent.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_monitored_resource_descriptors(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListMonitoredResourceDescriptorsResponse
Lists the descriptors for monitored resource types used by Stackdriver Logging.
688 689 690 691 692 693 694 695 696 697 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 688 def list_monitored_resource_descriptors(page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta1/monitoredResourceDescriptors', ) command.response_representation = Google::Apis::LoggingV2beta1::ListMonitoredResourceDescriptorsResponse::Representation command.response_class = Google::Apis::LoggingV2beta1::ListMonitoredResourceDescriptorsResponse command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_organization_logs(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListLogsResponse
Lists the logs in projects or organizations. Only logs that have entries are listed.
767 768 769 770 771 772 773 774 775 776 777 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 767 def list_organization_logs(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta1/{+parent}/logs', ) command.response_representation = Google::Apis::LoggingV2beta1::ListLogsResponse::Representation command.response_class = Google::Apis::LoggingV2beta1::ListLogsResponse command.params['parent'] = parent unless parent.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_metrics(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListLogMetricsResponse
Lists logs-based metrics.
207 208 209 210 211 212 213 214 215 216 217 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 207 def list_project_metrics(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta1/{+parent}/metrics', ) command.response_representation = Google::Apis::LoggingV2beta1::ListLogMetricsResponse::Representation command.response_class = Google::Apis::LoggingV2beta1::ListLogMetricsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_sinks(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::ListSinksResponse
Lists sinks.
433 434 435 436 437 438 439 440 441 442 443 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 433 def list_project_sinks(parent, page_token: nil, page_size: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2beta1/{+parent}/sinks', ) command.response_representation = Google::Apis::LoggingV2beta1::ListSinksResponse::Representation command.response_class = Google::Apis::LoggingV2beta1::ListSinksResponse command.params['parent'] = parent unless parent.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_project_metric(metric_name, log_metric_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogMetric
Creates or updates a logs-based metric.
275 276 277 278 279 280 281 282 283 284 285 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 275 def update_project_metric(metric_name, log_metric_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'v2beta1/{+metricName}', ) command.request_representation = Google::Apis::LoggingV2beta1::LogMetric::Representation command.request_object = log_metric_object command.response_representation = Google::Apis::LoggingV2beta1::LogMetric::Representation command.response_class = Google::Apis::LoggingV2beta1::LogMetric command.params['metricName'] = metric_name unless metric_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_project_sink(sink_name, log_sink_object = nil, unique_writer_identity: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::LogSink
Updates a sink. If the named sink doesn't exist, then this method is identical to sinks.create. If the named sink does exist, then this method replaces the following fields in the existing sink with values from the new sink: destination, filter, output_version_format, start_time, and end_time. The updated filter might also have a new writer_identity; see the unique_writer_identity field.
517 518 519 520 521 522 523 524 525 526 527 528 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 517 def update_project_sink(sink_name, log_sink_object = nil, unique_writer_identity: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'v2beta1/{+sinkName}', ) command.request_representation = Google::Apis::LoggingV2beta1::LogSink::Representation command.request_object = log_sink_object command.response_representation = Google::Apis::LoggingV2beta1::LogSink::Representation command.response_class = Google::Apis::LoggingV2beta1::LogSink command.params['sinkName'] = sink_name unless sink_name.nil? command.query['uniqueWriterIdentity'] = unique_writer_identity unless unique_writer_identity.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#write_entry_log_entries(write_log_entries_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::LoggingV2beta1::WriteLogEntriesResponse
Writes log entries to Stackdriver Logging. All log entries are written by this method.
100 101 102 103 104 105 106 107 108 109 |
# File 'generated/google/apis/logging_v2beta1/service.rb', line 100 def write_entry_log_entries(write_log_entries_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2beta1/entries:write', ) command.request_representation = Google::Apis::LoggingV2beta1::WriteLogEntriesRequest::Representation command.request_object = write_log_entries_request_object command.response_representation = Google::Apis::LoggingV2beta1::WriteLogEntriesResponse::Representation command.response_class = Google::Apis::LoggingV2beta1::WriteLogEntriesResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |