Class: Google::Apis::SheetsV4::AutoFillRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::AutoFillRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/sheets_v4/classes.rb,
generated/google/apis/sheets_v4/representations.rb,
generated/google/apis/sheets_v4/representations.rb
Overview
Fills in more data based on existing data.
Instance Attribute Summary collapse
-
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
-
#source_and_destination ⇒ Google::Apis::SheetsV4::SourceAndDestination
A combination of a source range and how to extend that source.
-
#use_alternate_series ⇒ Boolean
(also: #use_alternate_series?)
True if we should generate data with the "alternate" series.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoFillRequest
constructor
A new instance of AutoFillRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ AutoFillRequest
Returns a new instance of AutoFillRequest.
1239 1240 1241 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 1239 def initialize(**args) update!(**args) end |
Instance Attribute Details
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
All indexes are zero-based.
Indexes are half open, e.g the start index is inclusive
and the end index is exclusive -- [start_index, end_index).
Missing indexes indicate the range is unbounded on that side.
For example, if "Sheet1" is sheet ID 0, then:
Sheet1!A1:A1 == sheet_id: 0,
start_row_index: 0, end_row_index: 1,
start_column_index: 0, end_column_index: 1
Sheet1!A3:B4 == sheet_id: 0,
start_row_index: 2, end_row_index: 4,
start_column_index: 0, end_column_index: 2
Sheet1!A:B == sheet_id: 0,
start_column_index: 0, end_column_index: 2
Sheet1!A5:B == sheet_id: 0,
start_row_index: 4,
start_column_index: 0, end_column_index: 2
Sheet1 == sheet_id:0
The start index must always be less than or equal to the end index.
If the start index equals the end index, then the range is empty.
Empty ranges are typically not meaningful and are usually rendered in the
UI as #REF!.
Corresponds to the JSON property range
1230 1231 1232 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 1230 def range @range end |
#source_and_destination ⇒ Google::Apis::SheetsV4::SourceAndDestination
A combination of a source range and how to extend that source.
Corresponds to the JSON property sourceAndDestination
1204 1205 1206 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 1204 def source_and_destination @source_and_destination end |
#use_alternate_series ⇒ Boolean Also known as: use_alternate_series?
True if we should generate data with the "alternate" series.
This differs based on the type and amount of source data.
Corresponds to the JSON property useAlternateSeries
1236 1237 1238 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 1236 def use_alternate_series @use_alternate_series end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1244 1245 1246 1247 1248 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 1244 def update!(**args) @source_and_destination = args[:source_and_destination] if args.key?(:source_and_destination) @range = args[:range] if args.key?(:range) @use_alternate_series = args[:use_alternate_series] if args.key?(:use_alternate_series) end |