Class: Google::Apis::SheetsV4::ConditionalFormatRule
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::ConditionalFormatRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/sheets_v4/classes.rb,
generated/google/apis/sheets_v4/representations.rb,
generated/google/apis/sheets_v4/representations.rb
Overview
A rule describing a conditional format.
Instance Attribute Summary collapse
-
#boolean_rule ⇒ Google::Apis::SheetsV4::BooleanRule
A rule that may or may not match, depending on the condition.
-
#gradient_rule ⇒ Google::Apis::SheetsV4::GradientRule
A rule that applies a gradient color scale format, based on the interpolation points listed.
-
#ranges ⇒ Array<Google::Apis::SheetsV4::GridRange>
The ranges that will be formatted if the condition is true.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConditionalFormatRule
constructor
A new instance of ConditionalFormatRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ ConditionalFormatRule
Returns a new instance of ConditionalFormatRule.
5014 5015 5016 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boolean_rule ⇒ Google::Apis::SheetsV4::BooleanRule
A rule that may or may not match, depending on the condition.
Corresponds to the JSON property booleanRule
5006 5007 5008 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5006 def boolean_rule @boolean_rule end |
#gradient_rule ⇒ Google::Apis::SheetsV4::GradientRule
A rule that applies a gradient color scale format, based on
the interpolation points listed. The format of a cell will vary
based on its contents as compared to the values of the interpolation
points.
Corresponds to the JSON property gradientRule
5001 5002 5003 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5001 def gradient_rule @gradient_rule end |
#ranges ⇒ Array<Google::Apis::SheetsV4::GridRange>
The ranges that will be formatted if the condition is true.
All the ranges must be on the same grid.
Corresponds to the JSON property ranges
5012 5013 5014 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5012 def ranges @ranges end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5019 5020 5021 5022 5023 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 5019 def update!(**args) @gradient_rule = args[:gradient_rule] if args.key?(:gradient_rule) @boolean_rule = args[:boolean_rule] if args.key?(:boolean_rule) @ranges = args[:ranges] if args.key?(:ranges) end |