Class: Google::Apis::SheetsV4::InsertRangeRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::InsertRangeRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/sheets_v4/classes.rb,
generated/google/apis/sheets_v4/representations.rb,
generated/google/apis/sheets_v4/representations.rb
Overview
Inserts cells into a range, shifting the existing cells over or down.
Instance Attribute Summary collapse
-
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
-
#shift_dimension ⇒ String
The dimension which will be shifted when inserting cells.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InsertRangeRequest
constructor
A new instance of InsertRangeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ InsertRangeRequest
3801 3802 3803 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 3801 def initialize(**args) update!(**args) end |
Instance Attribute Details
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
All indexes are zero-based.
Indexes are half open, e.g the start index is inclusive
and the end index is exclusive -- [start_index, end_index).
Missing indexes indicate the range is unbounded on that side.
For example, if "Sheet1" is sheet ID 0, then:
Sheet1!A1:A1 == sheet_id: 0,
start_row_index: 0, end_row_index: 1,
start_column_index: 0, end_column_index: 1
Sheet1!A3:B4 == sheet_id: 0,
start_row_index: 2, end_row_index: 4,
start_column_index: 0, end_column_index: 2
Sheet1!A:B == sheet_id: 0,
start_column_index: 0, end_column_index: 2
Sheet1!A5:B == sheet_id: 0,
start_row_index: 4,
start_column_index: 0, end_column_index: 2
Sheet1 == sheet_id:0
The start index must always be less than or equal to the end index.
If the start index equals the end index, then the range is empty.
Empty ranges are typically not meaningful and are usually rendered in the
UI as #REF!.
Corresponds to the JSON property range
3799 3800 3801 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 3799 def range @range end |
#shift_dimension ⇒ String
The dimension which will be shifted when inserting cells.
If ROWS, existing cells will be shifted down.
If COLUMNS, existing cells will be shifted right.
Corresponds to the JSON property shiftDimension
3773 3774 3775 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 3773 def shift_dimension @shift_dimension end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3806 3807 3808 3809 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 3806 def update!(**args) @shift_dimension = args[:shift_dimension] if args.key?(:shift_dimension) @range = args[:range] if args.key?(:range) end |