Class: Google::Apis::SheetsV4::UpdateBordersRequest
- Inherits:
-
Object
- Object
- Google::Apis::SheetsV4::UpdateBordersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/sheets_v4/classes.rb,
generated/google/apis/sheets_v4/representations.rb,
generated/google/apis/sheets_v4/representations.rb
Overview
Updates the borders of a range. If a field is not set in the request, that means the border remains as-is. For example, with two subsequent UpdateBordersRequest:
- range: A1:A5
top: RED, bottom: WHITE - range: A1:A5
left: BLUEThat would result in A1:A5 having a borders oftop: RED, bottom: WHITE, left: BLUE. If you want to clear a border, explicitly set the style to NONE.
Instance Attribute Summary collapse
-
#bottom ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
-
#inner_horizontal ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
-
#inner_vertical ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
-
#left ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
-
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
-
#right ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
-
#top ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateBordersRequest
constructor
A new instance of UpdateBordersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ UpdateBordersRequest
Returns a new instance of UpdateBordersRequest.
2864 2865 2866 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 2864 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bottom ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
Corresponds to the JSON property bottom
2826 2827 2828 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 2826 def bottom @bottom end |
#inner_horizontal ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
Corresponds to the JSON property innerHorizontal
2811 2812 2813 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 2811 def inner_horizontal @inner_horizontal end |
#inner_vertical ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
Corresponds to the JSON property innerVertical
2831 2832 2833 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 2831 def inner_vertical @inner_vertical end |
#left ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
Corresponds to the JSON property left
2821 2822 2823 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 2821 def left @left end |
#range ⇒ Google::Apis::SheetsV4::GridRange
A range on a sheet.
All indexes are zero-based.
Indexes are half open, e.g the start index is inclusive
and the end index is exclusive -- [start_index, end_index).
Missing indexes indicate the range is unbounded on that side.
For example, if "Sheet1" is sheet ID 0, then:
Sheet1!A1:A1 == sheet_id: 0,
start_row_index: 0, end_row_index: 1,
start_column_index: 0, end_column_index: 1
Sheet1!A3:B4 == sheet_id: 0,
start_row_index: 2, end_row_index: 4,
start_column_index: 0, end_column_index: 2
Sheet1!A:B == sheet_id: 0,
start_column_index: 0, end_column_index: 2
Sheet1!A5:B == sheet_id: 0,
start_row_index: 4,
start_column_index: 0, end_column_index: 2
Sheet1 == sheet_id:0
The start index must always be less than or equal to the end index.
If the start index equals the end index, then the range is empty.
Empty ranges are typically not meaningful and are usually rendered in the
UI as #REF!.
Corresponds to the JSON property range
2862 2863 2864 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 2862 def range @range end |
#right ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
Corresponds to the JSON property right
2836 2837 2838 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 2836 def right @right end |
#top ⇒ Google::Apis::SheetsV4::Border
A border along a cell.
Corresponds to the JSON property top
2816 2817 2818 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 2816 def top @top end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2869 2870 2871 2872 2873 2874 2875 2876 2877 |
# File 'generated/google/apis/sheets_v4/classes.rb', line 2869 def update!(**args) @inner_horizontal = args[:inner_horizontal] if args.key?(:inner_horizontal) @top = args[:top] if args.key?(:top) @left = args[:left] if args.key?(:left) @bottom = args[:bottom] if args.key?(:bottom) @inner_vertical = args[:inner_vertical] if args.key?(:inner_vertical) @right = args[:right] if args.key?(:right) @range = args[:range] if args.key?(:range) end |