Class: Google::Apis::SlidesV1::CreateSlideRequest
- Inherits:
-
Object
- Object
- Google::Apis::SlidesV1::CreateSlideRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/slides_v1/classes.rb,
generated/google/apis/slides_v1/representations.rb,
generated/google/apis/slides_v1/representations.rb
Overview
Creates a new slide.
Instance Attribute Summary collapse
-
#insertion_index ⇒ Fixnum
The optional zero-based index indicating where to insert the slides.
-
#object_id_prop ⇒ String
A user-supplied object ID.
-
#slide_layout_reference ⇒ Google::Apis::SlidesV1::LayoutReference
Slide layout reference.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateSlideRequest
constructor
A new instance of CreateSlideRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ CreateSlideRequest
Returns a new instance of CreateSlideRequest.
3470 3471 3472 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3470 def initialize(**args) update!(**args) end |
Instance Attribute Details
#insertion_index ⇒ Fixnum
The optional zero-based index indicating where to insert the slides.
If you don't specify an index, the new slide is created at the end.
Corresponds to the JSON property insertionIndex
3461 3462 3463 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3461 def insertion_index @insertion_index end |
#object_id_prop ⇒ String
A user-supplied object ID.
If you specify an ID, it must be unique among all pages and page elements
in the presentation. The ID must start with an alphanumeric character or an
underscore (matches regex [a-zA-Z0-9_]); remaining characters
may include those as well as a hyphen or colon (matches regex
[a-zA-Z0-9_-:]).
The length of the ID must not be less than 5 or greater than 50.
If you don't specify an ID, a unique one is generated.
Corresponds to the JSON property objectId
3455 3456 3457 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3455 def object_id_prop @object_id_prop end |
#slide_layout_reference ⇒ Google::Apis::SlidesV1::LayoutReference
Slide layout reference. This may reference either:
- A predefined layout
- One of the layouts in the presentation.
Corresponds to the JSON property
slideLayoutReference
3468 3469 3470 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3468 def @slide_layout_reference end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3475 3476 3477 3478 3479 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3475 def update!(**args) @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop) @insertion_index = args[:insertion_index] if args.key?(:insertion_index) @slide_layout_reference = args[:slide_layout_reference] if args.key?(:slide_layout_reference) end |