Class: Google::Apis::SlidesV1::CreateTableRequest
- Inherits:
-
Object
- Object
- Google::Apis::SlidesV1::CreateTableRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/slides_v1/classes.rb,
generated/google/apis/slides_v1/representations.rb,
generated/google/apis/slides_v1/representations.rb
Overview
Creates a new table.
Instance Attribute Summary collapse
-
#columns ⇒ Fixnum
Number of columns in the table.
-
#element_properties ⇒ Google::Apis::SlidesV1::PageElementProperties
Common properties for a page element.
-
#object_id_prop ⇒ String
A user-supplied object ID.
-
#rows ⇒ Fixnum
Number of rows in the table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateTableRequest
constructor
A new instance of CreateTableRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ CreateTableRequest
Returns a new instance of CreateTableRequest.
3081 3082 3083 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3081 def initialize(**args) update!(**args) end |
Instance Attribute Details
#columns ⇒ Fixnum
Number of columns in the table.
Corresponds to the JSON property columns
3053 3054 3055 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3053 def columns @columns end |
#element_properties ⇒ Google::Apis::SlidesV1::PageElementProperties
Common properties for a page element.
Note: When you initially create a
PageElement, the API may modify
the values of both size and transform, but the
visual size will be unchanged.
Corresponds to the JSON property elementProperties
3079 3080 3081 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3079 def element_properties @element_properties end |
#object_id_prop ⇒ String
A user-supplied object ID.
If you specify an ID, it must be unique among all pages and page elements
in the presentation. The ID must start with an alphanumeric character or an
underscore (matches regex [a-zA-Z0-9_]); remaining characters
may include those as well as a hyphen or colon (matches regex
[a-zA-Z0-9_-:]).
The length of the ID must not be less than 5 or greater than 50.
If you don't specify an ID, a unique one is generated.
Corresponds to the JSON property objectId
3065 3066 3067 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3065 def object_id_prop @object_id_prop end |
#rows ⇒ Fixnum
Number of rows in the table.
Corresponds to the JSON property rows
3070 3071 3072 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3070 def rows @rows end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3086 3087 3088 3089 3090 3091 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3086 def update!(**args) @columns = args[:columns] if args.key?(:columns) @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop) @rows = args[:rows] if args.key?(:rows) @element_properties = args[:element_properties] if args.key?(:element_properties) end |