Class: Google::Apis::SlidesV1::CreateVideoRequest
- Inherits:
-
Object
- Object
- Google::Apis::SlidesV1::CreateVideoRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- generated/google/apis/slides_v1/classes.rb,
generated/google/apis/slides_v1/representations.rb,
generated/google/apis/slides_v1/representations.rb
Overview
Creates a video.
Instance Attribute Summary collapse
-
#element_properties ⇒ Google::Apis::SlidesV1::PageElementProperties
Common properties for a page element.
-
#id ⇒ String
The video source's unique identifier for this video.
-
#object_id_prop ⇒ String
A user-supplied object ID.
-
#source ⇒ String
The video source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateVideoRequest
constructor
A new instance of CreateVideoRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Methods included from Core::JsonObjectSupport
Methods included from Core::Hashable
Constructor Details
#initialize(**args) ⇒ CreateVideoRequest
Returns a new instance of CreateVideoRequest.
3033 3034 3035 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3033 def initialize(**args) update!(**args) end |
Instance Attribute Details
#element_properties ⇒ Google::Apis::SlidesV1::PageElementProperties
Common properties for a page element.
Note: When you initially create a
PageElement, the API may modify
the values of both size and transform, but the
visual size will be unchanged.
Corresponds to the JSON property elementProperties
3024 3025 3026 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3024 def element_properties @element_properties end |
#id ⇒ String
The video source's unique identifier for this video.
e.g. For YouTube video https://www.youtube.com/watch?v=7U3axjORYZ0,
the ID is 7U3axjORYZ0.
Corresponds to the JSON property id
3031 3032 3033 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3031 def id @id end |
#object_id_prop ⇒ String
A user-supplied object ID.
If you specify an ID, it must be unique among all pages and page elements
in the presentation. The ID must start with an alphanumeric character or an
underscore (matches regex [a-zA-Z0-9_]); remaining characters
may include those as well as a hyphen or colon (matches regex
[a-zA-Z0-9_-:]).
The length of the ID must not be less than 5 or greater than 50.
If you don't specify an ID, a unique one is generated.
Corresponds to the JSON property objectId
3010 3011 3012 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3010 def object_id_prop @object_id_prop end |
#source ⇒ String
The video source.
Corresponds to the JSON property source
3015 3016 3017 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3015 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3038 3039 3040 3041 3042 3043 |
# File 'generated/google/apis/slides_v1/classes.rb', line 3038 def update!(**args) @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop) @source = args[:source] if args.key?(:source) @element_properties = args[:element_properties] if args.key?(:element_properties) @id = args[:id] if args.key?(:id) end |